from os import remove as remove_file
from os import environ
from os import rename
import os
from os.path import join as join_path
import sys
import logging
import json

from gzip import GzipFile

from requests import get as get_request
from requests import post as post_request

from metasort.exceptions import AnalysisNotFound
from flask import request
from onecodex.cli import OneCodexArgParser
from onecodex.cli import OneCodexAuth



_ALLOWED_EXTENSIONS = set(["fastq","fq","fa","fasta"])
cred_fp = os.path.expanduser('~/.onecodex')
if os.environ.get("ONE_CODEX_API_KEY") is not None:
    _ONECODEX_APIKEY = os.environ.get("ONE_CODEX_API_KEY")
elif os.path.exists(cred_fp):
    creds = json.load(open(cred_fp, mode='r'))
    _ONECODEX_APIKEY = creds["api_key"]    
else:
    logging.error('Please set your ONE_CODEX_API_KEY. i.e. export ONE_CODEX_API_KEY="123535643"')
    sys.exit()

_BASE_API_URL = "https://beta.onecodex.com/api/v0/"
_UPLOAD_FOLDER = '/tmp'

from cStringIO import StringIO
import sys

class Capturing(list):
    def __enter__(self):
        self._stdout = sys.stdout
        sys.stdout = self._stringio = StringIO()
        return self
    def __exit__(self, *args):
        self.extend(self._stringio.getvalue().splitlines())
        sys.stdout = self._stdout


def change_file_name(filename,sample_id):
    filepath = join_path(_UPLOAD_FOLDER, filename)
    basename = filename.rsplit('.', 1)[0]
    filename = filename.replace(basename,sample_id)
    rename(filepath, join_path(_UPLOAD_FOLDER, filename))


def is_allowed_file(filename):
    is_valid_filename = '.' in filename
    has_valid_extension = filename.rsplit('.', 1)[1] in _ALLOWED_EXTENSIONS
    is_allowed_file = is_valid_filename and has_valid_extension
    return is_allowed_file


def upload_genome_file(filename):
    absolute_filename = join_path(
        _UPLOAD_FOLDER,
        filename
    )
    return upload_genome_file_path(files)
    


def upload_genome_file_path(absolute_filename):
    parser = OneCodexArgParser()
    args = parser.parse_args(['upload',absolute_filename])
    OneCodexAuth(args)
    with Capturing() as output:
        args.run(args)
    sample_id = output[0].split(' ')[-1][:-1]
    return sample_id    


def get_analyses():
    response = _get_request("analyses")
    return response.json()


def get_analysis_table_from_id(analysis_id):
    response = _get_request("analyses/{}/table".format(analysis_id))
    return response.json()

def get_analysis_from_id(analysis_id):
    response = _get_request("analyses/{}".format(analysis_id))
    return response.json()

def format_analyses(analyses):
    formatted_analyses = []
    for analysis in analyses:
        if analysis['analysis_status'] == 'Success':
            css_class = 'success'
        elif analysis['analysis_status'] == 'Pending':
            css_class = 'secondary disabled'
        elif analysis['analysis_status'] == 'Failed':
            css_class = 'alert'
        else:
            css_class = 'disabled'

        formatted_analysis = {
            'id': analysis['id'],
            'css_class': css_class,
            'sample_filename': analysis['sample_filename'],
        }
        formatted_analyses.append(formatted_analysis)
    return formatted_analyses


def get_sample_id_from_analysis_id(analysis_id):
    analyses = get_analyses()
    for analysis in analyses:
        if analysis['id'] == analysis_id:
            return analysis['sample_id']
    raise AnalysisNotFound


def process_analysis(analysis_id,dir = _UPLOAD_FOLDER):
    local_filename = _download_raw_analysis(analysis_id)

    local_unzipped_filename = join_path(
        dir,
        'read_data_{}.tsv'.format(analysis_id),
    )
    _unzip_file(local_filename, local_unzipped_filename)

    remove_file(local_filename)
    return local_unzipped_filename


def _download_raw_analysis(analysis_id):
    local_filename = join_path(
        _UPLOAD_FOLDER,
        'raw_{}.tsv.gz'.format(analysis_id),
    )
    raw_analysis = get_request(
        '{}analyses/{}/raw'.format(_BASE_API_URL, analysis_id),
        auth=(_ONECODEX_APIKEY, ''),
        stream=True,
    )
    with open(local_filename, 'wb') as f:
        for chunk in raw_analysis.iter_content(chunk_size=1024):
            if chunk:
                f.write(chunk)
                f.flush()
    return local_filename


def _unzip_file(gz_file, target_filename):
    unzipped_file = GzipFile(fileobj=open(gz_file, 'rb'))
    with open(target_filename, 'wb') as _file:
        _file.write(unzipped_file.read())


def _get_request(sub_url):
    response = get_request(
        _BASE_API_URL + sub_url,
        auth=(_ONECODEX_APIKEY, ''),
        allow_redirects=True,
    )
    return response

def get_taxon_to_species_dict():
    tax_id_to_species = {}
    data = {"1266925": {"name": "Nitrosospira briensis C-128", "rank": "Strain"}, "370622": {"name": "Aureimonas altamirensis", "rank": "Species"}, "370623": {"name": "Streptomyces phage mu1/6", "rank": "Species"}, "1266923": {"name": "Brachyspira hyodysenteriae ATCC 27164", "rank": "Strain"}, "1035308": {"name": "Dehalobacter sp. FTH1", "rank": "Species"}, "1332069": {"name": "Pantoea sp. AS-PWVM4", "rank": "Species"}, "1410900": {"name": "Staphylococcus aureus F74035", "rank": "Strain"}, "1159905": {"name": "Porcine coronavirus HKU15", "rank": "Species"}, "1410902": {"name": "Staphylococcus aureus H37776", "rank": "Strain"}, "1159907": {"name": "White-eye coronavirus HKU16", "rank": "Species"}, "1159900": {"name": "Salmonella enterica subsp. enterica serovar Typhimurium str. LT2-4_delta.ramA::kan", "rank": "Strain"}, "1159901": {"name": "Deltacoronavirus", "rank": "Genus"}, "1159902": {"name": "Common-moorhen coronavirus HKU21", "rank": "Species"}, "1410907": {"name": "Staphylococcus aureus H48054", "rank": "Strain"}, "1410908": {"name": "Staphylococcus aureus S39407", "rank": "Strain"}, "1410909": {"name": "Staphylococcus aureus H44713", "rank": "Strain"}, "1159908": {"name": "Wigeon coronavirus HKU20", "rank": "Species"}, "868174": {"name": "Escherichia coli DEC8E", "rank": "Strain"}, "1123359": {"name": "Tetragenococcus muriaticus DSM 15685", "rank": "Strain"}, "868176": {"name": "Escherichia coli DEC9B", "rank": "Strain"}, "868177": {"name": "Escherichia coli DEC9C", "rank": "Strain"}, "868170": {"name": "Escherichia coli DEC8A", "rank": "Strain"}, "868171": {"name": "Escherichia coli DEC8B", "rank": "Strain"}, "868172": {"name": "Escherichia coli DEC8C", "rank": "Strain"}, "868173": {"name": "Escherichia coli DEC8D", "rank": "Strain"}, "34476": {"name": "Mitosporic Tremellales", "rank": "No rank"}, "1123354": {"name": "Tepidiphilus margaritifer DSM 15129", "rank": "Strain"}, "1123355": {"name": "Terasakiella pusilla DSM 6293", "rank": "Strain"}, "1123356": {"name": "Terrimonas ferruginea DSM 30193", "rank": "Strain"}, "1175850": {"name": "Gammapapillomavirus 8", "rank": "Species"}, "1175851": {"name": "Gammapapillomavirus 9", "rank": "Species"}, "1175852": {"name": "Gammapapillomavirus 10", "rank": "Species"}, "1175853": {"name": "Deltapapillomavirus 5", "rank": "Species"}, "1175854": {"name": "Lambdapapillomavirus 3", "rank": "Species"}, "1175855": {"name": "Lambdapapillomavirus 4", "rank": "Species"}, "1077972": {"name": "Arthrobacter globiformis NBRC 12137", "rank": "Strain"}, "452758": {"name": "Allamanda leaf curl virus", "rank": "Species"}, "1077976": {"name": "Gordonia polyisoprenivorans NBRC 16320 = JCM 10675", "rank": "Strain"}, "1427342": {"name": "Pseudomonas aeruginosa SCV20265", "rank": "Strain"}, "1077974": {"name": "Gordonia effusa NBRC 100432", "rank": "Strain"}, "1077975": {"name": "Gordonia rubripertincta NBRC 101908", "rank": "Strain"}, "1506184": {"name": "Mesta yellow vein mosaic virus alphasatellite India:Hoshiarpur:Okra:2013", "rank": "Strain"}, "1413459": {"name": "Staphylococcus aureus C1894", "rank": "Strain"}, "1413458": {"name": "Staphylococcus aureus C1891", "rank": "Strain"}, "1413451": {"name": "Staphylococcus aureus VE08/02244ST1", "rank": "Strain"}, "1413450": {"name": "Staphylococcus aureus VE08/02242ST1", "rank": "Strain"}, "1413457": {"name": "Staphylococcus aureus C4668", "rank": "Strain"}, "1413456": {"name": "Staphylococcus aureus C3865", "rank": "Strain"}, "1413455": {"name": "Staphylococcus aureus C5086", "rank": "Strain"}, "1413454": {"name": "Staphylococcus aureus C3489", "rank": "Strain"}, "1409461": {"name": "Staphylococcus aureus AMMC6002", "rank": "Strain"}, "1409460": {"name": "Staphylococcus aureus HOAG6005", "rank": "Strain"}, "1409463": {"name": "Staphylococcus aureus AMMC6007", "rank": "Strain"}, "1409462": {"name": "Staphylococcus aureus AMMC6003", "rank": "Strain"}, "1137258": {"name": "Salinispora arenicola CNX891", "rank": "Strain"}, "1409464": {"name": "Staphylococcus aureus AMMC6011", "rank": "Strain"}, "528360": {"name": "Neisseria gonorrhoeae SK-93-1035", "rank": "Strain"}, "1409466": {"name": "Staphylococcus aureus SJOS6016", "rank": "Strain"}, "1137254": {"name": "Salinispora arenicola CNT857", "rank": "Strain"}, "1409468": {"name": "Staphylococcus aureus SMMC6034", "rank": "Strain"}, "1137256": {"name": "Salinispora arenicola CNT798", "rank": "Strain"}, "1281240": {"name": "Escherichia coli UMEA 3318-1", "rank": "Strain"}, "1281247": {"name": "Escherichia coli UMEA 3355-1", "rank": "Strain"}, "1137251": {"name": "Salinispora arenicola CNH905", "rank": "Strain"}, "1137252": {"name": "Salinispora arenicola CNH941", "rank": "Strain"}, "1137253": {"name": "Salinispora arenicola CNT800", "rank": "Strain"}, "1166018": {"name": "Fibrella aestuarina BUZ 2", "rank": "Strain"}, "1417599": {"name": "Ralstonia phage RSK1", "rank": "Species"}, "1166015": {"name": "Corynebacterium diphtheriae bv. intermedius str. NCTC 5011", "rank": "Strain"}, "1166016": {"name": "Pectobacterium sp. SCC3193", "rank": "Species"}, "1166017": {"name": "Mycobacterium abscessus CF", "rank": "Strain"}, "1158708": {"name": "Staphylococcus aureus M1010", "rank": "Strain"}, "186777": {"name": "Mulikevirus", "rank": "Genus"}, "1510466": {"name": "Candidatus Nitrosopumilus koreensis", "rank": "Species"}, "503388": {"name": "Lactococcus phage asccphi28", "rank": "Species"}, "1305617": {"name": "Porphyromonas crevioricanis JCM 15906", "rank": "Strain"}, "1177766": {"name": "Dyozetapapillomavirus 1", "rank": "Species"}, "1227466": {"name": "Halorubrum coriense DSM 10284", "rank": "Strain"}, "1305618": {"name": "Porphyromonas cansulci JCM 13913", "rank": "Strain"}, "515446": {"name": "Verbena virus Y", "rank": "Species"}, "515444": {"name": "Eupatorium vein clearing virus", "rank": "Species"}, "1100843": {"name": "Acinetobacter baumannii TYTH-3", "rank": "Strain"}, "613202": {"name": "Prochlorococcus sp. W11", "rank": "Species"}, "613203": {"name": "Prochlorococcus sp. W12", "rank": "Species"}, "613200": {"name": "Prochlorococcus sp. W9", "rank": "Species"}, "613201": {"name": "Prochlorococcus sp. W10", "rank": "Species"}, "1041504": {"name": "Candidatus Arthromitus sp. SFB-rat-Yit", "rank": "Species"}, "1159904": {"name": "Night-heron coronavirus HKU19", "rank": "Species"}, "941970": {"name": "Liberibacter phage SC2", "rank": "Species"}, "1410901": {"name": "Staphylococcus aureus F74039", "rank": "Strain"}, "66869": {"name": "Streptomyces atroolivaceus", "rank": "Species"}, "1159906": {"name": "Sparrow coronavirus HKU17", "rank": "Species"}, "1410903": {"name": "Staphylococcus aureus H37781", "rank": "Strain"}, "1087481": {"name": "Paenibacillus peoriae KCTC 3763", "rank": "Strain"}, "1462608": {"name": "Pseudomonas phage KPP25", "rank": "Species"}, "1087482": {"name": "Salmonella phage S16", "rank": "Species"}, "1410904": {"name": "Staphylococcus aureus H41336", "rank": "Strain"}, "1453336": {"name": "Pseudomonas phage SPM-1", "rank": "Species"}, "1410905": {"name": "Staphylococcus aureus F77710", "rank": "Strain"}, "1410906": {"name": "Staphylococcus aureus H48052", "rank": "Strain"}, "1151312": {"name": "Peptoclostridium difficile 842", "rank": "Strain"}, "1159903": {"name": "Magpie-robin coronavirus HKU18", "rank": "Species"}, "1421971": {"name": "Mycobacterium tuberculosis TB_RSA55", "rank": "Strain"}, "1421970": {"name": "Mycobacterium tuberculosis TB_RSA54", "rank": "Strain"}, "1421973": {"name": "Mycobacterium tuberculosis TB_RSA57", "rank": "Strain"}, "1421972": {"name": "Mycobacterium tuberculosis TB_RSA56", "rank": "Strain"}, "1421975": {"name": "Mycobacterium tuberculosis TB_RSA59", "rank": "Strain"}, "1421974": {"name": "Mycobacterium tuberculosis TB_RSA58", "rank": "Strain"}, "1411695": {"name": "Escherichia coli 1240", "rank": "Strain"}, "1411694": {"name": "Escherichia coli 38.52", "rank": "Strain"}, "1421979": {"name": "Mycobacterium tuberculosis TB_RSA63", "rank": "Strain"}, "1421978": {"name": "Mycobacterium tuberculosis TB_RSA62", "rank": "Strain"}, "1411698": {"name": "Escherichia coli 38.16", "rank": "Strain"}, "117198": {"name": "Rhynchosia golden mosaic virus", "rank": "Species"}, "718271": {"name": "Campylobacter jejuni subsp. jejuni S3", "rank": "Strain"}, "718274": {"name": "Salmonella enterica subsp. enterica serovar Typhimurium str. T000240", "rank": "Strain"}, "868175": {"name": "Escherichia coli DEC9A", "rank": "Strain"}, "1354162": {"name": "Mycobacterium africanum MAL010071", "rank": "Strain"}, "1354161": {"name": "Mycobacterium africanum MAL010070", "rank": "Strain"}, "1354160": {"name": "Mycobacterium tuberculosis MAL010130", "rank": "Strain"}, "1354166": {"name": "Mycobacterium africanum MAL010081", "rank": "Strain"}, "1354165": {"name": "Mycobacterium tuberculosis MAL010079", "rank": "Strain"}, "1354164": {"name": "Mycobacterium africanum MAL010074", "rank": "Strain"}, "34479": {"name": "Spizellomycetaceae", "rank": "Family"}, "34478": {"name": "Spizellomycetales", "rank": "Order"}, "1151317": {"name": "Peptoclostridium difficile DA00044", "rank": "Strain"}, "713612": {"name": "Rhodococcus sp. Chr-9", "rank": "Species"}, "1000589": {"name": "Streptococcus dysgalactiae subsp. equisimilis SK1249", "rank": "Strain"}, "1000588": {"name": "Streptococcus mitis bv. 2 str. SK95", "rank": "Strain"}, "868178": {"name": "Escherichia coli DEC9D", "rank": "Strain"}, "868179": {"name": "Escherichia coli DEC9E", "rank": "Strain"}, "496807": {"name": "Eragrostis streak virus", "rank": "Species"}, "1295721": {"name": "Mycobacterium tuberculosis TKK_02_0005", "rank": "Strain"}, "1295720": {"name": "Mycobacterium tuberculosis TKK_02_0004", "rank": "Strain"}, "1295723": {"name": "Mycobacterium tuberculosis TKK_02_0007", "rank": "Strain"}, "1295725": {"name": "Mycobacterium tuberculosis TKK_02_0009", "rank": "Strain"}, "1295724": {"name": "Mycobacterium tuberculosis TKK_02_0008", "rank": "Strain"}, "1295727": {"name": "Mycobacterium tuberculosis TKK_02_0011", "rank": "Strain"}, "1295726": {"name": "Mycobacterium tuberculosis TKK_02_0010", "rank": "Strain"}, "1427327": {"name": "Mycobacterium tuberculosis XTB13-278", "rank": "Strain"}, "717610": {"name": "Vibrio harveyi group", "rank": "Species group"}, "194397": {"name": "Fusarium graminearum dsRNA mycovirus-1", "rank": "Species"}, "1418319": {"name": "Staphylococcus aureus M17033", "rank": "Strain"}, "1418318": {"name": "Staphylococcus aureus M17027", "rank": "Strain"}, "1418315": {"name": "Staphylococcus aureus H88170", "rank": "Strain"}, "1418314": {"name": "Staphylococcus aureus H88163", "rank": "Strain"}, "1418317": {"name": "Staphylococcus aureus M13099", "rank": "Strain"}, "1418316": {"name": "Staphylococcus aureus M13074", "rank": "Strain"}, "1418311": {"name": "Staphylococcus aureus H81898", "rank": "Strain"}, "1418310": {"name": "Staphylococcus aureus H47117", "rank": "Strain"}, "1418313": {"name": "Staphylococcus aureus H88149", "rank": "Strain"}, "1418312": {"name": "Staphylococcus aureus H81901", "rank": "Strain"}, "1454030": {"name": "Dragonfly larvae associated circular virus-9", "rank": "Species"}, "1144271": {"name": "Staphylococcus aureus subsp. aureus 118", "rank": "Strain"}, "1144272": {"name": "Staphylococcus aureus subsp. aureus GR1", "rank": "Strain"}, "1144273": {"name": "Anaerophaga thermohalophila str. Valhall", "rank": "Strain"}, "1388564": {"name": "Staphylococcus aureus M0746", "rank": "Strain"}, "515351": {"name": "Lacticigenium naphtae", "rank": "Species"}, "145391": {"name": "Staphylococcus hominis subsp. hominis", "rank": "Subspecies"}, "984175": {"name": "Cronobacter phage ENT39118", "rank": "Species"}, "1417116": {"name": "Staphylococcus aureus F82573", "rank": "Strain"}, "1165094": {"name": "Richelia intracellularis HH01", "rank": "Strain"}, "1165096": {"name": "Methylotenera sp. 73s", "rank": "Species"}, "1165091": {"name": "Pseudoalteromonas flavipulchra JG1", "rank": "Strain"}, "1165090": {"name": "Imtechella halotolerans", "rank": "Species"}, "1165092": {"name": "Lachnospiraceae bacterium JC7", "rank": "Species"}, "326423": {"name": "Bacillus amyloliquefaciens subsp. plantarum str. FZB42", "rank": "Strain"}, "326425": {"name": "Lactobacillus helveticus CNRZ32", "rank": "Strain"}, "326424": {"name": "Frankia alni ACN14a", "rank": "Strain"}, "326427": {"name": "Chloroflexus aggregans DSM 9485", "rank": "Strain"}, "326426": {"name": "Bifidobacterium breve UCC2003", "rank": "Strain"}, "1234409": {"name": "Catellicoccus marimammalium M35/04/3", "rank": "Strain"}, "373193": {"name": "Xenotropic MuLV-related virus VP62", "rank": "Strain"}, "909928": {"name": "Negativicoccus", "rank": "Genus"}, "1163537": {"name": "Tianjin totivirus", "rank": "Species"}, "1417114": {"name": "Staphylococcus aureus M42518", "rank": "Strain"}, "869309": {"name": "Streptococcus pneumoniae SPNA45", "rank": "Strain"}, "869304": {"name": "Streptococcus pneumoniae SPN034183", "rank": "Strain"}, "869306": {"name": "Streptococcus pneumoniae SPN994038", "rank": "Strain"}, "869307": {"name": "Streptococcus pneumoniae SPN994039", "rank": "Strain"}, "869303": {"name": "Streptococcus pneumoniae SPN034156", "rank": "Strain"}, "145579": {"name": "Bdellovibrio phage phiMH2K", "rank": "Species"}, "114517": {"name": "Aeromonas veronii bv. sobria", "rank": "Strain"}, "756067": {"name": "Microcoleus vaginatus FGP-2", "rank": "Strain"}, "76980": {"name": "Ahrensia kielensis", "rank": "Species"}, "69891": {"name": "Trichophyton soudanense", "rank": "Species"}, "1448710": {"name": "Mycobacterium tuberculosis M1704", "rank": "Strain"}, "1448711": {"name": "Mycobacterium tuberculosis M1726", "rank": "Strain"}, "1448712": {"name": "Mycobacterium tuberculosis M1728", "rank": "Strain"}, "1448713": {"name": "Mycobacterium tuberculosis M1734", "rank": "Strain"}, "1448714": {"name": "Mycobacterium tuberculosis M1759", "rank": "Strain"}, "1448715": {"name": "Mycobacterium tuberculosis M1762", "rank": "Strain"}, "1448716": {"name": "Mycobacterium tuberculosis M1780", "rank": "Strain"}, "1448717": {"name": "Mycobacterium tuberculosis M1787", "rank": "Strain"}, "1448718": {"name": "Mycobacterium tuberculosis M1782", "rank": "Strain"}, "1448719": {"name": "Mycobacterium tuberculosis M1816", "rank": "Strain"}, "1053215": {"name": "Bacillus cereus ISP2954", "rank": "Strain"}, "1053214": {"name": "Bacillus cereus IS845/00", "rank": "Strain"}, "1053217": {"name": "Bacillus cereus K-5975c", "rank": "Strain"}, "1053216": {"name": "Bacillus cereus ISP3191", "rank": "Strain"}, "1053211": {"name": "Bacillus cereus HuB4-4", "rank": "Strain"}, "1053210": {"name": "Bacillus cereus HuB4-10", "rank": "Strain"}, "1053213": {"name": "Bacillus cereus IS195", "rank": "Strain"}, "1053212": {"name": "Bacillus cereus HuB5-5", "rank": "Strain"}, "1415764": {"name": "Streptococcus pneumoniae 27", "rank": "Strain"}, "1053219": {"name": "Bacillus cereus MC67", "rank": "Strain"}, "1053218": {"name": "Bacillus cereus MC118", "rank": "Strain"}, "119164": {"name": "Polerovirus", "rank": "Genus"}, "83816": {"name": "Methanobrevibacter ruminantium", "rank": "Species"}, "1520703": {"name": "'Chrysanthemum coronarium' phytoplasma", "rank": "Species"}, "119163": {"name": "Luteoviridae", "rank": "Family"}, "126333": {"name": "Desulfovibrio desulfuricans subsp. aestuarii", "rank": "Subspecies"}, "362787": {"name": "Candidatus Protochlamydia amoebophila", "rank": "Species"}, "51229": {"name": "Wigglesworthia glossinidia", "rank": "Species"}, "51228": {"name": "Wigglesworthia", "rank": "Genus"}, "1427249": {"name": "Mycobacterium tuberculosis XTB13-167", "rank": "Strain"}, "1427248": {"name": "Mycobacterium tuberculosis XTB13-165", "rank": "Strain"}, "1388379": {"name": "Staphylococcus aureus M0572", "rank": "Strain"}, "1388378": {"name": "Staphylococcus aureus M0569", "rank": "Strain"}, "1427245": {"name": "Mycobacterium tuberculosis XTB13-161", "rank": "Strain"}, "1388376": {"name": "Staphylococcus aureus M0567", "rank": "Strain"}, "1388375": {"name": "Staphylococcus aureus M0566", "rank": "Strain"}, "1427246": {"name": "Mycobacterium tuberculosis XTB13-162", "rank": "Strain"}, "1388373": {"name": "Staphylococcus aureus M0563", "rank": "Strain"}, "1388372": {"name": "Staphylococcus aureus M0560", "rank": "Strain"}, "1388371": {"name": "Staphylococcus aureus M0559", "rank": "Strain"}, "1427242": {"name": "Mycobacterium tuberculosis XTB13-156", "rank": "Strain"}, "649507": {"name": "Cesiribacter andamanensis", "rank": "Species"}, "1190603": {"name": "Enterovibrio norvegicus FF-33", "rank": "Strain"}, "1190605": {"name": "Enterovibrio norvegicus FF-162", "rank": "Strain"}, "1190606": {"name": "Enterovibrio calviensis 1F-211", "rank": "Strain"}, "1190607": {"name": "Enterovibrio calviensis 1F-230", "rank": "Strain"}, "1328032": {"name": "Porcine stool-associated circular virus 3", "rank": "Species"}, "1328030": {"name": "Cellulophaga phage phi13:2", "rank": "Species"}, "1328031": {"name": "Porcine stool-associated circular virus 2", "rank": "Species"}, "1367494": {"name": "Pseudomonas aeruginosa PAO1-VE13", "rank": "Strain"}, "1281248": {"name": "Escherichia coli UMEA 3391-1", "rank": "Strain"}, "684949": {"name": "Deinococcus sp. 2009", "rank": "Species"}, "544404": {"name": "Escherichia coli O157:H7 str. TW14359", "rank": "Strain"}, "544406": {"name": "Helicobacter pylori B128", "rank": "Strain"}, "1206724": {"name": "Nocardia brasiliensis NBRC 14402", "rank": "Strain"}, "1206727": {"name": "Nocardia cerradoensis NBRC 101014", "rank": "Strain"}, "1206726": {"name": "Nocardia carnea NBRC 14403", "rank": "Strain"}, "1206721": {"name": "Nocardia asiatica NBRC 100129", "rank": "Strain"}, "1206720": {"name": "Nocardia aobensis NBRC 100429", "rank": "Strain"}, "1206723": {"name": "Nocardia abscessus NBRC 100374", "rank": "Strain"}, "1206722": {"name": "Nocardia araoensis NBRC 100135", "rank": "Strain"}, "1206729": {"name": "Nocardia exalbida NBRC 100660", "rank": "Strain"}, "1206728": {"name": "Nocardia cyriacigeorgica NBRC 100375", "rank": "Strain"}, "1409469": {"name": "Staphylococcus aureus SMMC6037", "rank": "Strain"}, "1281242": {"name": "Escherichia coli UMEA 3329-1", "rank": "Strain"}, "71186": {"name": "Tomato leaf curl Sinaloa virus", "rank": "Species"}, "1281241": {"name": "Escherichia coli UMEA 3323-1", "rank": "Strain"}, "675820": {"name": "Vibrio mimicus VM223", "rank": "Strain"}, "1173764": {"name": "Listeria phage LP-048", "rank": "Species"}, "1137257": {"name": "Salinispora arenicola CNX508", "rank": "Strain"}, "1137250": {"name": "Salinispora arenicola CNB527", "rank": "Strain"}, "1173766": {"name": "Listeria phage LP-125", "rank": "Species"}, "1281246": {"name": "Escherichia coli UMEA 3342-1", "rank": "Strain"}, "1435369": {"name": "Burkholderia pseudomallei MSHR4003", "rank": "Strain"}, "1435368": {"name": "Burkholderia sp. MSHR4009", "rank": "Species"}, "301297": {"name": "Dehalococcoidia", "rank": "Class"}, "1205": {"name": "Trichodesmium", "rank": "Genus"}, "1435360": {"name": "Staphylococcus aureus CUHK_BJ2002", "rank": "Strain"}, "1435363": {"name": "Burkholderia pseudomallei MSHR4868", "rank": "Strain"}, "1206": {"name": "Trichodesmium erythraeum", "rank": "Species"}, "1435365": {"name": "Burkholderia pseudomallei TSV 48", "rank": "Strain"}, "1435364": {"name": "Burkholderia pseudomallei MSHR4378", "rank": "Strain"}, "1203": {"name": "Scytonema", "rank": "Genus"}, "1435366": {"name": "Burkholderia sp. MSHR4018", "rank": "Species"}, "1173762": {"name": "Salmonella phage FSL SP-076", "rank": "Species"}, "312349": {"name": "Procyon lotor papillomavirus 1", "rank": "Strain"}, "1124958": {"name": "Salmonella enterica subsp. enterica serovar Muenster str. 0315", "rank": "Strain"}, "1124956": {"name": "Salmonella enterica subsp. enterica serovar Minnesota str. ATCC 49284", "rank": "Strain"}, "1124955": {"name": "Salmonella enterica subsp. enterica serovar Miami str. 1923", "rank": "Strain"}, "1402548": {"name": "Pseudomonas aeruginosa BL07", "rank": "Strain"}, "1124953": {"name": "Salmonella enterica subsp. enterica serovar Kentucky str. N312", "rank": "Strain"}, "1124952": {"name": "Salmonella enterica subsp. enterica serovar Kentucky str. 22694", "rank": "Strain"}, "1124951": {"name": "Salmonella enterica subsp. enterica serovar Kentucky str. 29166", "rank": "Strain"}, "1124950": {"name": "Salmonella enterica subsp. enterica serovar Kentucky str. 13562", "rank": "Strain"}, "1402473": {"name": "Mycobacterium tuberculosis SK-E", "rank": "Strain"}, "1402547": {"name": "Pseudomonas aeruginosa BL06", "rank": "Strain"}, "1158509": {"name": "Staphylococcus aureus M0077", "rank": "Strain"}, "1158508": {"name": "Staphylococcus aureus M0055", "rank": "Strain"}, "1158507": {"name": "Staphylococcus aureus M0006", "rank": "Strain"}, "1158506": {"name": "Staphylococcus aureus M1578", "rank": "Strain"}, "1158505": {"name": "Staphylococcus aureus M1565", "rank": "Strain"}, "1402478": {"name": "Mycobacterium tuberculosis SK-B", "rank": "Strain"}, "1158503": {"name": "Staphylococcus aureus M1556", "rank": "Strain"}, "1158502": {"name": "Staphylococcus aureus M1544", "rank": "Strain"}, "1158501": {"name": "Staphylococcus aureus M1533", "rank": "Strain"}, "1158500": {"name": "Staphylococcus aureus M1531", "rank": "Strain"}, "1379725": {"name": "Circoviridae 21 LDMD-2013", "rank": "Species"}, "1379720": {"name": "Circoviridae 16 LDMD-2013", "rank": "Species"}, "1379721": {"name": "Circoviridae 17 LDMD-2013", "rank": "Species"}, "1379723": {"name": "Circoviridae 19 LDMD-2013", "rank": "Species"}, "1095103": {"name": "Pseudomonas syringae pv. actinidiae ICMP 18884", "rank": "Strain"}, "1173769": {"name": "Salmonella phage FSL SP-004", "rank": "Species"}, "218538": {"name": "Dialister invisus", "rank": "Species"}, "932919": {"name": "Listeria monocytogenes SLCC2755", "rank": "Strain"}, "47758": {"name": "Streptomyces sulphureus", "rank": "Species"}, "1167006": {"name": "Desulfocapsa sulfexigens DSM 10523", "rank": "Strain"}, "540988": {"name": "Thermus islandicus", "rank": "Species"}, "1121388": {"name": "Derxia gummosa DSM 723", "rank": "Strain"}, "42252": {"name": "Desulfovibrio termitidis", "rank": "Species"}, "100755": {"name": "Sweet potato leaf curl virus", "rank": "Species"}, "1239962": {"name": "Mariniradius saccharolyticus AK6", "rank": "Strain"}, "1536652": {"name": "Desulfobulbus sp. Tol-SR", "rank": "Species"}, "1536651": {"name": "Desulfosporosinus sp. Tol-M", "rank": "Species"}, "218284": {"name": "Bacillus vietnamensis", "rank": "Species"}, "313439": {"name": "Streptococcus massiliensis", "rank": "Species"}, "137591": {"name": "Weissella cibaria", "rank": "Species"}, "1121382": {"name": "Deinococcus misasensis DSM 22328", "rank": "Strain"}, "1121385": {"name": "Demetria terragena DSM 11295", "rank": "Strain"}, "1298885": {"name": "Thaumarchaeota archaeon SCGC AAA282-K18", "rank": "Species"}, "33910": {"name": "Amycolatopsis mediterranei", "rank": "Species"}, "1310164": {"name": "Corynebacterium crenatum MT", "rank": "Strain"}, "1315148": {"name": "Acinetobacter baumannii TG2013", "rank": "Strain"}, "1315149": {"name": "Acinetobacter baumannii TG2014", "rank": "Strain"}, "1315146": {"name": "Acinetobacter baumannii TG15242", "rank": "Strain"}, "1315147": {"name": "Acinetobacter baumannii TG2012", "rank": "Strain"}, "1315144": {"name": "Acinetobacter baumannii TG15240", "rank": "Strain"}, "1315145": {"name": "Acinetobacter baumannii TG15241", "rank": "Strain"}, "1315142": {"name": "Acinetobacter baumannii TG15238", "rank": "Strain"}, "1315143": {"name": "Acinetobacter baumannii TG15239", "rank": "Strain"}, "1315140": {"name": "Acinetobacter baumannii TG15236", "rank": "Strain"}, "1315141": {"name": "Acinetobacter baumannii TG15237", "rank": "Strain"}, "342230": {"name": "Amycolatopsis taiwanensis", "rank": "Species"}, "1028567": {"name": "Sulfolobus acidocaldarius Ron12/I", "rank": "Strain"}, "1028566": {"name": "Sulfolobus acidocaldarius N8", "rank": "Strain"}, "1329853": {"name": "Enterobacter cloacae UCICRE 5", "rank": "Strain"}, "1329852": {"name": "Enterobacter cloacae UCICRE 3", "rank": "Strain"}, "5059": {"name": "Aspergillus flavus", "rank": "Species"}, "1329855": {"name": "Enterobacter cloacae UCICRE 11", "rank": "Strain"}, "1329854": {"name": "Enterobacter cloacae UCICRE 9", "rank": "Strain"}, "232346": {"name": "Halomonas alkaliantarctica", "rank": "Species"}, "5052": {"name": "Aspergillus", "rank": "Genus"}, "73030": {"name": "Dechloromonas agitata", "rank": "Species"}, "454171": {"name": "Chthonomonas calidirosea", "rank": "Species"}, "404217": {"name": "Yersinia pestis biovar Orientalis str. MG05-1020", "rank": "Strain"}, "404216": {"name": "Yersinia pestis biovar Mediaevalis str. K1973002", "rank": "Strain"}, "404215": {"name": "Yersinia pestis biovar Antiqua str. B42003004", "rank": "Strain"}, "404214": {"name": "Yersinia pestis biovar Orientalis str. F1991016", "rank": "Strain"}, "404218": {"name": "Yersinia pestis biovar Antiqua str. UG05-0454", "rank": "Strain"}, "1117108": {"name": "Paenibacillus alvei TS-15", "rank": "Strain"}, "1117109": {"name": "Paenibacillus alvei A6-6i-x", "rank": "Strain"}, "54315": {"name": "Bovine viral diarrhea virus 2", "rank": "Species"}, "54311": {"name": "Spirulina subsalsa", "rank": "Species"}, "983328": {"name": "Campylobacter fetus subsp. venerealis NCTC 10354", "rank": "Strain"}, "227470": {"name": "Aeromonas phage Aeh1", "rank": "Species"}, "1042399": {"name": "Lactobacillus delbrueckii subsp. bulgaricus CNCM I-1632", "rank": "Strain"}, "1341120": {"name": "Pseudohaliea", "rank": "Genus"}, "747657": {"name": "Brettanomyces bruxellensis CBS 2499", "rank": "Strain"}, "136241": {"name": "Mycoplasma haemocanis", "rank": "Species"}, "186328": {"name": "Entomoplasmatales", "rank": "Order"}, "186329": {"name": "Acholeplasmatales", "rank": "Order"}, "58344": {"name": "Streptomyces celluloflavus", "rank": "Species"}, "58347": {"name": "Kitasatospora azatica", "rank": "Species"}, "286420": {"name": "Hahella ganghwensis", "rank": "Species"}, "58340": {"name": "Streptomyces lavendulae subsp. lavendulae", "rank": "Subspecies"}, "390884": {"name": "Echinicola vietnamensis", "rank": "Species"}, "1338505": {"name": "Mycobacterium tuberculosis OM-V02_005", "rank": "Strain"}, "1231298": {"name": "Cassava mosaic Madagascar alphasatellite", "rank": "Species"}, "1231296": {"name": "Unclassified Begomovirus-associated alphasatellites", "rank": "No rank"}, "573825": {"name": "Leptospira interrogans serovar Lai str. IPAV", "rank": "Strain"}, "645991": {"name": "Syntrophobotulus glycolicus DSM 8271", "rank": "Strain"}, "1224922": {"name": "Staphylococcus aureus M0213", "rank": "Strain"}, "70566": {"name": "Akabane virus", "rank": "Species"}, "512030": {"name": "Acidovorax sp. NO-1", "rank": "Species"}, "759620": {"name": "Weissella ceti", "rank": "Species"}, "45661": {"name": "Banana bract mosaic virus", "rank": "Species"}, "1212584": {"name": "Shigella sonnei 09-4962", "rank": "Strain"}, "371601": {"name": "Bacteroides xylanisolvens", "rank": "Species"}, "1165076": {"name": "Imtechella", "rank": "Genus"}, "887313": {"name": "Campylobacter coli Z156", "rank": "Strain"}, "887312": {"name": "Campylobacter coli H56", "rank": "Strain"}, "887311": {"name": "Campylobacter coli H9", "rank": "Strain"}, "887310": {"name": "Campylobacter coli H8", "rank": "Strain"}, "887317": {"name": "Campylobacter coli 2680", "rank": "Strain"}, "391596": {"name": "Pedobacter sp. BAL39", "rank": "Species"}, "887315": {"name": "Campylobacter coli 2548", "rank": "Strain"}, "887314": {"name": "Campylobacter coli Z163", "rank": "Strain"}, "887319": {"name": "Campylobacter coli 2688", "rank": "Strain"}, "887318": {"name": "Campylobacter coli 2685", "rank": "Strain"}, "1212582": {"name": "Shigella sonnei 09-1032", "rank": "Strain"}, "1212583": {"name": "Shigella sonnei 09-2245", "rank": "Strain"}, "354276": {"name": "Enterobacter cloacae complex", "rank": "Species group"}, "38033": {"name": "Chaetomium globosum", "rank": "Species"}, "406327": {"name": "Methanococcus vannielii SB", "rank": "Strain"}, "687377": {"name": "Torque teno mini virus 9", "rank": "Species"}, "687376": {"name": "Torque teno mini virus 8", "rank": "Species"}, "1151313": {"name": "Peptoclostridium difficile 6041", "rank": "Strain"}, "687374": {"name": "Torque teno mini virus 6", "rank": "Species"}, "687373": {"name": "Torque teno mini virus 5", "rank": "Species"}, "687372": {"name": "Torque teno mini virus 4", "rank": "Species"}, "687371": {"name": "Torque teno mini virus 3", "rank": "Species"}, "687370": {"name": "Torque teno mini virus 2", "rank": "Species"}, "1151319": {"name": "Peptoclostridium difficile DA00065", "rank": "Strain"}, "1151318": {"name": "Peptoclostridium difficile DA00062", "rank": "Strain"}, "43662": {"name": "Pseudoalteromonas piscicida", "rank": "Species"}, "43663": {"name": "Arthrobacter aurescens", "rank": "Species"}, "687379": {"name": "Torque teno midi virus 1", "rank": "Species"}, "43661": {"name": "Shewanella benthica", "rank": "Species"}, "188333": {"name": "Ageratum enation virus", "rank": "Species"}, "1154995": {"name": "Helicobacter phage 1961P", "rank": "Species"}, "260684": {"name": "Kakugo virus", "rank": "Strain"}, "1156844": {"name": "Streptomyces sp. HmicA12", "rank": "Species"}, "1420596": {"name": "Bordetella pertussis CHLA-11", "rank": "Strain"}, "1156841": {"name": "Streptomyces sp. ScaeMP-e10", "rank": "Species"}, "1156843": {"name": "Streptomyces sp. LaPpAH-165", "rank": "Species"}, "1129792": {"name": "Weissella oryzae", "rank": "Species"}, "1129793": {"name": "Glaciecola polaris LMG 21857", "rank": "Strain"}, "1420599": {"name": "Pseudomonas protegens Cab57", "rank": "Strain"}, "1129794": {"name": "Glaciecola psychrophila 170", "rank": "Strain"}, "646529": {"name": "Desulfosporosinus acidiphilus SJ4", "rank": "Strain"}, "1344996": {"name": "Staphylococcus epidermidis MC19", "rank": "Strain"}, "1344995": {"name": "Staphylococcus epidermidis MC28", "rank": "Strain"}, "1344994": {"name": "Staphylococcus epidermidis Scl19", "rank": "Strain"}, "1344993": {"name": "Staphylococcus epidermidis Scl22", "rank": "Strain"}, "1344992": {"name": "Staphylococcus epidermidis Scl25", "rank": "Strain"}, "151157": {"name": "Acetobacter subgen. Acetobacter", "rank": "Subgenus"}, "1344990": {"name": "Staphylococcus epidermidis CIM37", "rank": "Strain"}, "1344999": {"name": "Staphylococcus epidermidis APO35", "rank": "Strain"}, "1344998": {"name": "Staphylococcus epidermidis CIM40", "rank": "Strain"}, "412694": {"name": "Bacillus thuringiensis str. Al Hakam", "rank": "Strain"}, "329858": {"name": "Cohnella thermotolerans", "rank": "Species"}, "329854": {"name": "Bacteroides intestinalis", "rank": "Species"}, "329857": {"name": "Cohnella", "rank": "Genus"}, "1336238": {"name": "Mesoplasma seiffertii ATCC 49495", "rank": "Strain"}, "330084": {"name": "Amycolatopsis jejuensis", "rank": "Species"}, "1336233": {"name": "Shewanella waksmanii ATCC BAA-643", "rank": "Strain"}, "1336232": {"name": "Mesoplasma chauliocola ATCC 49578", "rank": "Strain"}, "1336237": {"name": "Pseudomonas flectens ATCC 12775", "rank": "Strain"}, "1336236": {"name": "Ruminococcus flavefaciens ATCC 19208", "rank": "Strain"}, "1336235": {"name": "Rhizobium selenitireducens ATCC BAA-1503", "rank": "Strain"}, "1336234": {"name": "Atopobacter phocae ATCC BAA-285", "rank": "Strain"}, "706433": {"name": "Solobacterium moorei F0204", "rank": "Strain"}, "706434": {"name": "Megasphaera micronuciformis F0359", "rank": "Strain"}, "706435": {"name": "Capnocytophaga sp. oral taxon 329", "rank": "Species"}, "706436": {"name": "Capnocytophaga sp. oral taxon 329 str. F0087", "rank": "Strain"}, "706437": {"name": "Streptococcus anginosus F0211", "rank": "Strain"}, "706438": {"name": "Actinomyces sp. oral taxon 171", "rank": "Species"}, "706439": {"name": "Actinomyces sp. oral taxon 171 str. F0337", "rank": "Strain"}, "109270": {"name": "Equine foamy virus", "rank": "Species"}, "1417756": {"name": "Feline bocavirus 2", "rank": "Species"}, "1330992": {"name": "Unclassified Salivirus", "rank": "No rank"}, "1121448": {"name": "Desulfovibrio gigas DSM 1382 = ATCC 19364", "rank": "Strain"}, "335103": {"name": "Adult diarrheal rotavirus strain J19", "rank": "Strain"}, "1121440": {"name": "Desulfovibrio aminophilus DSM 12254", "rank": "Strain"}, "1121441": {"name": "Desulfovibrio bastinii DSM 16055", "rank": "Strain"}, "1121447": {"name": "Desulfovibrio frigidus DSM 17176", "rank": "Strain"}, "1121444": {"name": "Desulfovibrio desulfuricans subsp. aestuarii DSM 17919 = ATCC 29578", "rank": "Strain"}, "1121445": {"name": "Desulfovibrio desulfuricans subsp. desulfuricans DSM 642", "rank": "Strain"}, "376469": {"name": "Olivibacter", "rank": "Genus"}, "1239293": {"name": "Deinococcus-Thermus bacterium JGI 0000112-G17", "rank": "Species"}, "1239292": {"name": "Thioalkalivibrio sp. ALgr3", "rank": "Species"}, "1239291": {"name": "Bacteroidetes bacterium JGI 0000112-P09", "rank": "Species"}, "1347087": {"name": "Paucisalibacillus sp. EB02", "rank": "Species"}, "1248903": {"name": "Escherichia coli O145:H28 str. RM12761", "rank": "Strain"}, "1248902": {"name": "Escherichia coli O145:H28 str. RM13514", "rank": "Strain"}, "161528": {"name": "Erythrobacter sp. SD-21", "rank": "Species"}, "937775": {"name": "Methanoplanus limicola DSM 2279", "rank": "Strain"}, "937774": {"name": "Taylorella equigenitalis MCE9", "rank": "Strain"}, "937777": {"name": "Deinococcus peraridilitoris DSM 19664", "rank": "Strain"}, "937773": {"name": "Staphylococcus pseudintermedius HKU10-03", "rank": "Strain"}, "937772": {"name": "Gamma proteobacterium IMCC1989", "rank": "Species"}, "396811": {"name": "Fulvivirga", "rank": "Genus"}, "903934": {"name": "Acinetobacter baumannii OIFC338", "rank": "Strain"}, "903935": {"name": "Acinetobacter baumannii OIFC111", "rank": "Strain"}, "903936": {"name": "Acinetobacter baumannii Naval-78", "rank": "Strain"}, "903937": {"name": "Acinetobacter baumannii AA-014", "rank": "Strain"}, "903930": {"name": "Acinetobacter baumannii OIFC099", "rank": "Strain"}, "903931": {"name": "Acinetobacter baumannii WC-A-92", "rank": "Strain"}, "903932": {"name": "Acinetobacter baumannii OIFC065", "rank": "Strain"}, "903933": {"name": "Acinetobacter baumannii OIFC047", "rank": "Strain"}, "1410847": {"name": "Staphylococcus aureus T84595", "rank": "Strain"}, "1423807": {"name": "Lactobacillus suebicus DSM 5007 = KCTC 3549", "rank": "Strain"}, "1213187": {"name": "Tobacco leaf chlorosis betasatellite", "rank": "Species"}, "512009": {"name": "Unclassified Enterobacteria phage G4 clade", "rank": "No rank"}, "1410840": {"name": "Staphylococcus aureus F80358", "rank": "Strain"}, "1225788": {"name": "Bacillus amyloliquefaciens subsp. plantarum AS43.3", "rank": "Strain"}, "488937": {"name": "Desulfonatronospira", "rank": "Genus"}, "384676": {"name": "Pseudomonas entomophila L48", "rank": "Strain"}, "171280": {"name": "Mycoplasma buteonis", "rank": "Species"}, "1410843": {"name": "Staphylococcus aureus F80354", "rank": "Strain"}, "1225780": {"name": "Dickeya dianthicola IPO 980", "rank": "Strain"}, "1225781": {"name": "Vibrio cholerae VC35", "rank": "Strain"}, "1225782": {"name": "Vibrio cholerae VC4370", "rank": "Strain"}, "1225783": {"name": "Vibrio cholerae VC1761", "rank": "Strain"}, "1225785": {"name": "Dickeya sp. DW 0440", "rank": "Species"}, "1225786": {"name": "Dickeya solani IPO 2222", "rank": "Strain"}, "488939": {"name": "Desulfonatronospira thiodismutans", "rank": "Species"}, "1328371": {"name": "Klebsiella pneumoniae MGH 35", "rank": "Strain"}, "1328370": {"name": "Klebsiella pneumoniae MGH 32", "rank": "Strain"}, "1328373": {"name": "Klebsiella pneumoniae MGH 39", "rank": "Strain"}, "1328372": {"name": "Klebsiella pneumoniae MGH 36", "rank": "Strain"}, "1328375": {"name": "Klebsiella pneumoniae MGH 43", "rank": "Strain"}, "1328374": {"name": "Klebsiella pneumoniae MGH 40", "rank": "Strain"}, "1328377": {"name": "Klebsiella pneumoniae MGH 45", "rank": "Strain"}, "1328376": {"name": "Klebsiella pneumoniae MGH 44", "rank": "Strain"}, "1328379": {"name": "Klebsiella pneumoniae MGH 47", "rank": "Strain"}, "1328378": {"name": "Klebsiella pneumoniae MGH 46", "rank": "Strain"}, "196242": {"name": "Enterobacteria phage BP-4795", "rank": "Species"}, "1411693": {"name": "Escherichia coli 1047", "rank": "Strain"}, "1411692": {"name": "Escherichia coli 897", "rank": "Strain"}, "40": {"name": "Stigmatella", "rank": "Genus"}, "12208": {"name": "Pea seed-borne mosaic virus", "rank": "Species"}, "12209": {"name": "Pepper mottle virus", "rank": "Species"}, "5551": {"name": "Trichophyton rubrum", "rank": "Species"}, "5550": {"name": "Trichophyton", "rank": "Genus"}, "35517": {"name": "Eubacterium brachy", "rank": "Species"}, "5552": {"name": "Trichosporon", "rank": "Genus"}, "12202": {"name": "Lettuce mosaic virus", "rank": "Species"}, "12203": {"name": "Maize dwarf mosaic virus", "rank": "Species"}, "12204": {"name": "Ornithogalum mosaic virus", "rank": "Species"}, "12205": {"name": "Papaya ringspot virus", "rank": "Species"}, "167963": {"name": "Unclassified Chloroflexi", "rank": "No rank"}, "1421977": {"name": "Mycobacterium tuberculosis TB_RSA61", "rank": "Strain"}, "53424": {"name": "Thermodesulfobacterium hveragerdense", "rank": "Species"}, "655809": {"name": "Prevotella sp. oral taxon 472", "rank": "Species"}, "1422039": {"name": "Mycobacterium tuberculosis TB_RSA123", "rank": "Strain"}, "1422038": {"name": "Mycobacterium tuberculosis TB_RSA122", "rank": "Strain"}, "410072": {"name": "Coprococcus comes", "rank": "Species"}, "415001": {"name": "Puniceicoccales", "rank": "Order"}, "415002": {"name": "Puniceicoccaceae", "rank": "Family"}, "1422036": {"name": "Mycobacterium tuberculosis TB_RSA120", "rank": "Strain"}, "1422030": {"name": "Mycobacterium tuberculosis TB_RSA114", "rank": "Strain"}, "1422033": {"name": "Mycobacterium tuberculosis TB_RSA117", "rank": "Strain"}, "1471501": {"name": "Prochlorococcus sp. scB245a_518A17", "rank": "Species"}, "1471500": {"name": "Prochlorococcus sp. scB243_498P3", "rank": "Species"}, "1471503": {"name": "Prochlorococcus sp. scB245a_518D8", "rank": "Species"}, "1471502": {"name": "Prochlorococcus sp. scB245a_518A6", "rank": "Species"}, "1471505": {"name": "Prochlorococcus sp. scB245a_518I6", "rank": "Species"}, "1471504": {"name": "Prochlorococcus sp. scB245a_518E10", "rank": "Species"}, "1471507": {"name": "Prochlorococcus sp. scB245a_518K17", "rank": "Species"}, "1471506": {"name": "Prochlorococcus sp. scB245a_518J7", "rank": "Species"}, "1471509": {"name": "Prochlorococcus sp. scB245a_519A13", "rank": "Species"}, "1471508": {"name": "Prochlorococcus sp. scB245a_518O7", "rank": "Species"}, "1329363": {"name": "Yersinia enterocolitica subsp. palearctica YE-P1", "rank": "Strain"}, "1435988": {"name": "Burkholderia sp. MSHR44", "rank": "Species"}, "1444129": {"name": "Escherichia coli 5-366-08_S3_C1", "rank": "Strain"}, "1444128": {"name": "Escherichia coli 5-172-05_S3_C1", "rank": "Strain"}, "1495041": {"name": "Thermopetrobacter", "rank": "Genus"}, "1444123": {"name": "Escherichia coli 2-222-05_S3_C1", "rank": "Strain"}, "1444122": {"name": "Escherichia coli 2-210-07_S3_C1", "rank": "Strain"}, "1444121": {"name": "Escherichia coli 2-177-06_S3_C1", "rank": "Strain"}, "1444120": {"name": "Escherichia coli 2-156-04_S3_C1", "rank": "Strain"}, "1444127": {"name": "Escherichia coli 2-474-04_S3_C1", "rank": "Strain"}, "1444126": {"name": "Escherichia coli 2-460-02_S3_C1", "rank": "Strain"}, "1444125": {"name": "Escherichia coli 2-427-07_S3_C1", "rank": "Strain"}, "1444124": {"name": "Escherichia coli 2-316-03_S3_C1", "rank": "Strain"}, "380397": {"name": "Streptococcus ictaluri", "rank": "Species"}, "1408224": {"name": "Sinorhizobium americanum CCGM7", "rank": "Strain"}, "1150864": {"name": "Micromonospora lupini str. Lupac 08", "rank": "Strain"}, "380393": {"name": "Lactobacillus namurensis", "rank": "Species"}, "1435984": {"name": "Burkholderia pseudomallei MSHR62", "rank": "Strain"}, "1435987": {"name": "Burkholderia pseudomallei MSHR465J", "rank": "Strain"}, "1435986": {"name": "Burkholderia pseudomallei MSHR449", "rank": "Strain"}, "1126921": {"name": "Escherichia coli C78_09C", "rank": "Strain"}, "913324": {"name": "Gamma proteobacterium SCGC AAA001-B15", "rank": "Species"}, "1302176": {"name": "Teloschistineae", "rank": "Suborder"}, "913326": {"name": "Skermanella stibiiresistens", "rank": "Species"}, "913327": {"name": "Gamma proteobacterium SCGC AAA007-O20", "rank": "Species"}, "913320": {"name": "Candidatus Aerophobus profundus SCGC AAA252-L23", "rank": "Strain"}, "1126922": {"name": "Escherichia coli C79_08", "rank": "Strain"}, "913322": {"name": "Euryarchaeota archaeon SCGC AAA252-I15", "rank": "Species"}, "1435982": {"name": "Burkholderia pseudomallei MSHR303", "rank": "Strain"}, "913328": {"name": "SAR202 cluster bacterium SCGC AAA240-N13", "rank": "Species"}, "913329": {"name": "SAR324 cluster bacterium SCGC AAA001-C10", "rank": "Species"}, "455436": {"name": "Glaciecola sp. HTCC2999", "rank": "Species"}, "762376": {"name": "Achromobacter xylosoxidans A8", "rank": "Strain"}, "37206": {"name": "Helicoverpa armigera stunt virus", "rank": "Species"}, "1147034": {"name": "Staphylococcus aureus PM1", "rank": "Strain"}, "1203611": {"name": "Alistipes onderdonkii WAL 8169 = DSM 19147", "rank": "Strain"}, "64320": {"name": "Zika virus", "rank": "Species"}, "64322": {"name": "Carnimonas", "rank": "Genus"}, "64323": {"name": "Carnimonas nigrificans", "rank": "Species"}, "1453080": {"name": "Faba bean necrotic yellows C1 alphasatellite", "rank": "Species"}, "1453081": {"name": "Faba bean necrotic yellows C11 alphasatellite", "rank": "Species"}, "1453082": {"name": "Faba bean necrotic yellows C7 alphasatellite", "rank": "Species"}, "1203619": {"name": "Corynebacterium sp. KPL1986", "rank": "Species"}, "906668": {"name": "Escherichia phage HK75", "rank": "Species"}, "1388468": {"name": "Staphylococcus aureus M0699", "rank": "Strain"}, "1381111": {"name": "Corynebacterium pseudodiphtheriticum 090104", "rank": "Strain"}, "1381115": {"name": "Staphylococcus aureus subsp. aureus Tager 104", "rank": "Strain"}, "1381116": {"name": "Lactobacillus rhamnosus 2166", "rank": "Strain"}, "1381117": {"name": "Campylobacter jejuni X", "rank": "Strain"}, "1381118": {"name": "Lactobacillus crispatus 2029", "rank": "Strain"}, "1381119": {"name": "Lactobacillus jensenii MD IIE-70(2)", "rank": "Strain"}, "1398953": {"name": "Acinetobacter baumannii UH12408", "rank": "Strain"}, "1297569": {"name": "Mesorhizobium metallidurans STM 2683", "rank": "Strain"}, "562981": {"name": "Gemella haemolysans M341", "rank": "Strain"}, "562982": {"name": "Gemella morbillorum M424", "rank": "Strain"}, "562983": {"name": "Gemella sanguinis M325", "rank": "Strain"}, "336828": {"name": "Rhodonellum psychrophilum", "rank": "Species"}, "1256195": {"name": "Lactobacillus paracasei subsp. paracasei CNCM I-2877", "rank": "Strain"}, "336827": {"name": "Rhodonellum", "rank": "Genus"}, "555217": {"name": "Zymomonas mobilis subsp. mobilis ATCC 10988", "rank": "Strain"}, "1513212": {"name": "Lepidopteran iteradensovirus 3", "rank": "Species"}, "1513213": {"name": "Lepidopteran iteradensovirus 4", "rank": "Species"}, "1513210": {"name": "Lepidopteran iteradensovirus 1", "rank": "Species"}, "1513211": {"name": "Lepidopteran iteradensovirus 2", "rank": "Species"}, "1513214": {"name": "Lepidopteran iteradensovirus 5", "rank": "Species"}, "913970": {"name": "Microviridae phi-CA82", "rank": "Species"}, "1292019": {"name": "Bacillus sp. 278922_107", "rank": "Species"}, "186103": {"name": "Streptococcus pyogenes MGAS8232", "rank": "Strain"}, "83341": {"name": "Gordonia rhizosphera", "rank": "Species"}, "1380391": {"name": "Dongia sp. URHE0060", "rank": "Species"}, "1380390": {"name": "Solirubrobacterales bacterium URHD0059", "rank": "Species"}, "1380393": {"name": "Geodermatophilaceae bacterium URHA0031", "rank": "Species"}, "1380392": {"name": "Nocardioides sp. URHA0020", "rank": "Species"}, "1380394": {"name": "Rhodospirillales bacterium URHD0088", "rank": "Species"}, "1505605": {"name": "Hymenobacter sp. IS2118", "rank": "Species"}, "910048": {"name": "Latescibacteria bacterium SCGC AAA252-B13", "rank": "Species"}, "991991": {"name": "Vibrio cholerae CP1035(8)", "rank": "Strain"}, "991990": {"name": "Vibrio cholerae CP1030(3)", "rank": "Strain"}, "991993": {"name": "Vibrio cholerae CP1040(13)", "rank": "Strain"}, "1463857": {"name": "Streptomyces sp. NRRL F-5126", "rank": "Species"}, "991995": {"name": "Vibrio cholerae CP1047(20)", "rank": "Strain"}, "1463851": {"name": "Streptomyces sp. NRRL F-4474", "rank": "Species"}, "1463852": {"name": "Streptomyces sp. NRRL F-4835", "rank": "Species"}, "991996": {"name": "Vibrio cholerae CP1050(23)", "rank": "Strain"}, "991999": {"name": "Vibrio cholerae HE-16", "rank": "Strain"}, "991998": {"name": "Vibrio cholerae HE-09", "rank": "Strain"}, "910049": {"name": "Latescibacteria bacterium SCGC AAA252-D10", "rank": "Species"}, "1463858": {"name": "Streptomyces sp. NRRL F-5135", "rank": "Species"}, "1141526": {"name": "Pseudomonas phage vB_Pae-Kakheti25", "rank": "Species"}, "1141525": {"name": "Pseudomonas phage vB_Pae-TbilisiM32", "rank": "Species"}, "1037911": {"name": "Pseudomonas fluorescens A506", "rank": "Strain"}, "1223572": {"name": "Dickeya dadantii NCPPB 898", "rank": "Strain"}, "997337": {"name": "Salmonella enterica subsp. enterica serovar Newport str. VA_R100512572", "rank": "Strain"}, "997336": {"name": "Salmonella enterica subsp. enterica serovar Newport str. VA_R100512570", "rank": "Strain"}, "997335": {"name": "Salmonella enterica subsp. enterica serovar Newport str. VA_R100506907", "rank": "Strain"}, "997334": {"name": "Salmonella enterica subsp. enterica serovar Oranienburg str. 701", "rank": "Strain"}, "997333": {"name": "Salmonella enterica subsp. enterica serovar Oranienburg str. 0250", "rank": "Strain"}, "997332": {"name": "Salmonella enterica subsp. enterica serovar Meleagridis str. 0047", "rank": "Strain"}, "997330": {"name": "Salmonella enterica subsp. enterica serovar Choleraesuis str. 0006", "rank": "Strain"}, "997339": {"name": "Salmonella enterica subsp. enterica serovar Newport str. WA_14882", "rank": "Strain"}, "997338": {"name": "Salmonella enterica subsp. enterica serovar Newport str. WA_14881", "rank": "Strain"}, "1453501": {"name": "Microbulbifer sp. HZ11", "rank": "Species"}, "1453500": {"name": "Schleiferia thermophila str. Yellowstone", "rank": "Strain"}, "1453503": {"name": "Pseudomonas pseudoalcaligenes AD6", "rank": "Strain"}, "1453502": {"name": "Aeromonas hydrophila AD9", "rank": "Strain"}, "1453505": {"name": "Flavobacterium chungangense LMG 26729", "rank": "Strain"}, "675512": {"name": "Mycobacterium tuberculosis SUMu001", "rank": "Strain"}, "675513": {"name": "Mycobacterium tuberculosis SUMu002", "rank": "Strain"}, "675511": {"name": "Methylomicrobium buryatense 5G", "rank": "Strain"}, "675516": {"name": "Mycobacterium tuberculosis SUMu005", "rank": "Strain"}, "675517": {"name": "Mycobacterium tuberculosis SUMu006", "rank": "Strain"}, "675514": {"name": "Mycobacterium tuberculosis SUMu003", "rank": "Strain"}, "675515": {"name": "Mycobacterium tuberculosis SUMu004", "rank": "Strain"}, "675518": {"name": "Mycobacterium tuberculosis SUMu007", "rank": "Strain"}, "675519": {"name": "Mycobacterium tuberculosis SUMu008", "rank": "Strain"}, "875170": {"name": "Celeribacter", "rank": "Genus"}, "875171": {"name": "Celeribacter baekdonensis", "rank": "Species"}, "1300150": {"name": "Enterococcus mundtii QU 25", "rank": "Strain"}, "1134475": {"name": "Pseudomonas fragi A22", "rank": "Strain"}, "1134474": {"name": "Cellvibrio sp. BR", "rank": "Species"}, "1187956": {"name": "Streptococcus thermophilus MN-ZLW-002", "rank": "Strain"}, "88646": {"name": "Teloschistaceae", "rank": "Family"}, "1303769": {"name": "Enterococcus faecium E155", "rank": "Strain"}, "33001": {"name": "Desulfurella", "rank": "Genus"}, "33002": {"name": "Desulfurella acetivorans", "rank": "Species"}, "33007": {"name": "Actinomyces neuii", "rank": "Species"}, "285810": {"name": "Pyrenochaeta", "rank": "Genus"}, "1074190": {"name": "Streptococcus mutans TCI-30", "rank": "Strain"}, "1236000": {"name": "Klebsiella phage JD001", "rank": "Species"}, "38304": {"name": "Corynebacterium tuberculostearicum", "rank": "Species"}, "1428456": {"name": "Kolente virus", "rank": "Species"}, "1455626": {"name": "Human cyclovirus", "rank": "Species"}, "1428452": {"name": "Morganella morganii F675", "rank": "Strain"}, "1173064": {"name": "Anaplasma phagocytophilum str. JM", "rank": "Strain"}, "1312929": {"name": "Cherry rusty mottle associated virus", "rank": "Species"}, "1312920": {"name": "Lactobacillus casei LcA", "rank": "Strain"}, "1356861": {"name": "Francisella noatunensis subsp. orientalis LADL--07-285A", "rank": "Strain"}, "510684": {"name": "Sneathiellales", "rank": "Order"}, "367850": {"name": "Sida mosaic Sinaloa virus", "rank": "Species"}, "934799": {"name": "Taupapillomavirus", "rank": "Genus"}, "1422553": {"name": "Staphylococcus aureus VET0286R", "rank": "Strain"}, "397275": {"name": "Andreprevotia", "rank": "Genus"}, "1500294": {"name": "Chryseobacterium sp. YR485", "rank": "Species"}, "397278": {"name": "Marmoricola aequoreus", "rank": "Species"}, "1529058": {"name": "Vibrio phage ICP2_2013_A_Haiti", "rank": "Species"}, "869806": {"name": "Marivirga", "rank": "Genus"}, "84205": {"name": "Chlorobium ferrooxidans", "rank": "Species"}, "869801": {"name": "Streptococcus pneumoniae SPN061370", "rank": "Strain"}, "435590": {"name": "Bacteroides vulgatus ATCC 8482", "rank": "Strain"}, "712156": {"name": "Atopobium sp. oral taxon 199", "rank": "Species"}, "1382700": {"name": "Escherichia coli PMV-1", "rank": "Strain"}, "712158": {"name": "Atopobium sp. oral taxon 810", "rank": "Species"}, "1265656": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 57.A.08", "rank": "Strain"}, "1265657": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 04.O.05", "rank": "Strain"}, "1265654": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 47.E.09", "rank": "Strain"}, "1265655": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 52.F.08", "rank": "Strain"}, "1265652": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 41.E.09", "rank": "Strain"}, "1265653": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 45.E.09", "rank": "Strain"}, "1265650": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 21.H.10", "rank": "Strain"}, "1265651": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 37.F.02", "rank": "Strain"}, "1265658": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 09.F.08", "rank": "Strain"}, "1265659": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 14.E.05", "rank": "Strain"}, "435591": {"name": "Parabacteroides distasonis ATCC 8503", "rank": "Strain"}, "747491": {"name": "Borrelia burgdorferi CA8", "rank": "Strain"}, "1485951": {"name": "Desulfurobacteriales", "rank": "Order"}, "1455597": {"name": "Escherichia coli 4552-1", "rank": "Strain"}, "1455598": {"name": "Escherichia coli 7996-1", "rank": "Strain"}, "1455599": {"name": "Escherichia coli 11117", "rank": "Strain"}, "121791": {"name": "Nipah virus", "rank": "Species"}, "478812": {"name": "Tomato leaf curl New Delhi betasatellite", "rank": "Species"}, "1398086": {"name": "Bacillus coagulans P38", "rank": "Strain"}, "1398080": {"name": "Staphylococcus aureus M1473", "rank": "Strain"}, "1398081": {"name": "Staphylococcus aureus M1474", "rank": "Strain"}, "910046": {"name": "Unclassified Latescibacteria", "rank": "No rank"}, "2239": {"name": "Halobacterium", "rank": "Genus"}, "985077": {"name": "Burkholderia cenocepacia BC7", "rank": "Strain"}, "985076": {"name": "Burkholderia cenocepacia K56-2Valvano", "rank": "Strain"}, "751944": {"name": "Halobacterium sp. DL1", "rank": "Species"}, "751945": {"name": "Thermus oshimai JL-2", "rank": "Strain"}, "985078": {"name": "Burkholderia multivorans CF2", "rank": "Strain"}, "1448929": {"name": "Candidatus Fervidibacter sacchari", "rank": "Species"}, "1448928": {"name": "Candidatus Fervidibacter", "rank": "Genus"}, "105972": {"name": "Methylosarcina fibrata", "rank": "Species"}, "1458253": {"name": "Streptococcus dentisani", "rank": "Species"}, "265291": {"name": "Comamonas badia", "rank": "Species"}, "265294": {"name": "Ambystoma tigrinum virus", "rank": "Species"}, "1324608": {"name": "Yersinia pseudotuberculosis B-7194", "rank": "Strain"}, "1414747": {"name": "Mycobacterium phage Validus", "rank": "Species"}, "1450746": {"name": "Pithovirus sibericum", "rank": "Species"}, "118139": {"name": "Teschovirus", "rank": "Genus"}, "1458258": {"name": "Bordetella bronchiseptica B18-5 (C3)", "rank": "Strain"}, "41527": {"name": "Salmonella bongori serovar 48:z41:--", "rank": "Strain"}, "1109438": {"name": "Candidatus Arthromitus sp. SFB-mouse-SU", "rank": "Species"}, "395922": {"name": "Coraliomargarita akajimensis", "rank": "Species"}, "395923": {"name": "Bartonella rochalimae", "rank": "Species"}, "1352227": {"name": "Ralstonia phage RSS30", "rank": "Species"}, "1136161": {"name": "Vibrio cyclitrophicus 1F273", "rank": "Strain"}, "1136160": {"name": "Vibrio cyclitrophicus 1F175", "rank": "Strain"}, "1136163": {"name": "Vibrio cyclitrophicus FF75", "rank": "Strain"}, "249523": {"name": "Aestuariibacter", "rank": "Genus"}, "1136165": {"name": "Vibrio cyclitrophicus FF274", "rank": "Strain"}, "1136164": {"name": "Vibrio cyclitrophicus FF160", "rank": "Strain"}, "1136167": {"name": "Vibrio cyclitrophicus ZF28", "rank": "Strain"}, "1136166": {"name": "Vibrio cyclitrophicus ZF14", "rank": "Strain"}, "1157951": {"name": "Providencia stuartii MRSN 2154", "rank": "Strain"}, "1136168": {"name": "Vibrio cyclitrophicus ZF30", "rank": "Strain"}, "1448699": {"name": "Mycobacterium tuberculosis M1488", "rank": "Strain"}, "1448698": {"name": "Mycobacterium tuberculosis M1481", "rank": "Strain"}, "1448695": {"name": "Mycobacterium tuberculosis M1459", "rank": "Strain"}, "1448694": {"name": "Mycobacterium tuberculosis M1458", "rank": "Strain"}, "1448697": {"name": "Mycobacterium tuberculosis M1475", "rank": "Strain"}, "1448696": {"name": "Mycobacterium tuberculosis M1461", "rank": "Strain"}, "1448691": {"name": "Mycobacterium tuberculosis M1700", "rank": "Strain"}, "1448690": {"name": "Mycobacterium tuberculosis M1449", "rank": "Strain"}, "1448693": {"name": "Mycobacterium tuberculosis M1456", "rank": "Strain"}, "1448692": {"name": "Mycobacterium tuberculosis M1452", "rank": "Strain"}, "1449340": {"name": "Carnobacterium jeotgali MS3", "rank": "Strain"}, "1449341": {"name": "Carnobacterium maltaromaticum DSM 20342", "rank": "Strain"}, "1449342": {"name": "Carnobacterium mobile DSM 4848", "rank": "Strain"}, "1449343": {"name": "Carnobacterium pleistocenium FTR1", "rank": "Strain"}, "1449345": {"name": "Helicobacter rodentium ATCC 700285", "rank": "Strain"}, "1449346": {"name": "Kitasatospora azatica KCTC 9699", "rank": "Strain"}, "1449347": {"name": "Kitasatospora mediocidica KCTC 9733", "rank": "Strain"}, "1449349": {"name": "Pseudomonas syringae DSM 10604", "rank": "Strain"}, "1131629": {"name": "Streptococcus pneumoniae GA62681", "rank": "Strain"}, "1131628": {"name": "Streptococcus pneumoniae GA58981", "rank": "Strain"}, "1131622": {"name": "Porcine bocavirus 5/JS677", "rank": "Strain"}, "1131627": {"name": "Streptococcus pneumoniae GA60132", "rank": "Strain"}, "374106": {"name": "Campylobacter cuniculorum", "rank": "Species"}, "1515": {"name": "Ruminiclostridium thermocellum", "rank": "Species"}, "1303256": {"name": "Sphingobium sp. DC-2", "rank": "Species"}, "1281076": {"name": "Escherichia coli HVH 143 (4-5674999)", "rank": "Strain"}, "5206": {"name": "Filobasidiella", "rank": "Genus"}, "102793": {"name": "H5N1 subtype", "rank": "Strain"}, "1406225": {"name": "Cystobacter violaceus Cb vi76", "rank": "Strain"}, "102796": {"name": "H9N2 subtype", "rank": "Strain"}, "1358438": {"name": "Lutibaculum", "rank": "Genus"}, "883109": {"name": "Eubacterium infirmum F0142", "rank": "Strain"}, "883103": {"name": "Dolosigranulum pigrum ATCC 51524", "rank": "Strain"}, "883100": {"name": "Delftia acidovorans CCUG 15835", "rank": "Strain"}, "883101": {"name": "Delftia acidovorans CCUG 274B", "rank": "Strain"}, "264124": {"name": "Botryobasidium botryosum", "rank": "Species"}, "1212545": {"name": "Staphylococcus arlettae CVD059", "rank": "Strain"}, "1212546": {"name": "Anoxybacillus kamchatkensis G10", "rank": "Strain"}, "1212547": {"name": "Clostridium tyrobutyricum UC7086", "rank": "Strain"}, "341945": {"name": "Unclassified Orthohepadnavirus", "rank": "No rank"}, "1212549": {"name": "Pseudomonas stutzeri B1SMN1", "rank": "Strain"}, "341941": {"name": "Gammalipothrixvirus", "rank": "Genus"}, "341940": {"name": "Betalipothrixvirus", "rank": "Genus"}, "1478": {"name": "Bacillus simplex", "rank": "Species"}, "1479": {"name": "Bacillus smithii", "rank": "Species"}, "1474": {"name": "Sporosarcina pasteurii", "rank": "Species"}, "1471": {"name": "Bacillus methanolicus", "rank": "Species"}, "1144275": {"name": "Corallococcus coralloides DSM 2259", "rank": "Strain"}, "868864": {"name": "Desulfurobacterium thermolithotrophum DSM 11699", "rank": "Strain"}, "1409658": {"name": "Staphylococcus aureus COAS6087", "rank": "Strain"}, "1028307": {"name": "Enterobacter aerogenes KCTC 2190", "rank": "Strain"}, "1409659": {"name": "Staphylococcus aureus SCLE6035", "rank": "Strain"}, "1409656": {"name": "Staphylococcus aureus OCMM6095", "rank": "Strain"}, "457388": {"name": "Parabacteroides sp. 2_1_7", "rank": "Species"}, "1409657": {"name": "Staphylococcus aureus GGMC6018", "rank": "Strain"}, "457387": {"name": "Bacteroides sp. 1_1_30", "rank": "Species"}, "1409654": {"name": "Staphylococcus aureus FVRH6074", "rank": "Strain"}, "457382": {"name": "Phaius virus X", "rank": "Species"}, "1391912": {"name": "Acinetobacter oleivorans CIP 110421", "rank": "Strain"}, "1391915": {"name": "Sporothrix schenckii ATCC 58251", "rank": "Strain"}, "1218579": {"name": "Leptospira interrogans str. 2003000735", "rank": "Strain"}, "1218578": {"name": "Leptospira interrogans str. 2002000632", "rank": "Strain"}, "1218577": {"name": "Leptospira interrogans str. 2002000631", "rank": "Strain"}, "1409652": {"name": "Staphylococcus aureus UCIM6101", "rank": "Strain"}, "1218574": {"name": "Leptospira interrogans serovar Pomona str. Fox 32256", "rank": "Strain"}, "1409653": {"name": "Staphylococcus aureus FVRH6067", "rank": "Strain"}, "1323529": {"name": "Dill cryptic virus 2", "rank": "Species"}, "1409650": {"name": "Staphylococcus aureus LAMC6094", "rank": "Strain"}, "72556": {"name": "Achromobacter piechaudii", "rank": "Species"}, "72558": {"name": "Sporisorium reilianum", "rank": "Species"}, "1323524": {"name": "Red clover cryptic virus 2", "rank": "Species"}, "1548750": {"name": "Anoxybacillus sp. BCO1", "rank": "Species"}, "1323523": {"name": "Hop trefoil cryptic virus 2", "rank": "Species"}, "1392244": {"name": "Pseudozyma brasiliensis", "rank": "Species"}, "90240": {"name": "Moraxella caprae", "rank": "Species"}, "332160": {"name": "Solibacterales", "rank": "Order"}, "519049": {"name": "Borrelia garinii Far04", "rank": "Strain"}, "552063": {"name": "Salinarimonas rosea", "rank": "Species"}, "90243": {"name": "Oligella", "rank": "Genus"}, "1150674": {"name": "Desulfurococcus amylolyticus Z-533", "rank": "Strain"}, "1150676": {"name": "Rhodococcus sp. 29MFTsu3.1", "rank": "Species"}, "983952": {"name": "Methyloversatilis universalis Fam500", "rank": "Strain"}, "1214915": {"name": "Mycobacterium smegmatis MKD8", "rank": "Strain"}, "1214914": {"name": "Sulfobacillus thermosulfidooxidans str. Cutipay", "rank": "Strain"}, "983954": {"name": "Methyloversatilis sp. RZ18-153", "rank": "Strain"}, "1214916": {"name": "Pseudomonas aeruginosa PABL056", "rank": "Strain"}, "1064592": {"name": "Naumovozyma castellii CBS 4309", "rank": "Strain"}, "1281019": {"name": "Escherichia coli HVH 82 (4-2209276)", "rank": "Strain"}, "1430896": {"name": "Haemophilus parahaemolyticus G321", "rank": "Strain"}, "1430897": {"name": "Chlamydia pneumoniae B21", "rank": "Strain"}, "1430898": {"name": "Mycoplasma pirum MPI25960", "rank": "Strain"}, "180874": {"name": "Bacillus thuringiensis serovar pondicheriensis", "rank": "Strain"}, "180877": {"name": "Bacillus thuringiensis serovar pulsiensis", "rank": "Strain"}, "445692": {"name": "Cyanophage NATL2A-133", "rank": "Species"}, "445693": {"name": "Cyanophage NATL1A-7", "rank": "Species"}, "263476": {"name": "Viridibacillus arenosi", "rank": "Species"}, "445696": {"name": "Prochlorococcus phage P-HM2", "rank": "Species"}, "1444208": {"name": "Escherichia coli 2-427-07_S4_C1", "rank": "Strain"}, "1444209": {"name": "Escherichia coli 2-460-02_S4_C1", "rank": "Strain"}, "1281038": {"name": "Escherichia coli HVH 102 (4-6906788)", "rank": "Strain"}, "1281039": {"name": "Escherichia coli HVH 103 (4-5904188)", "rank": "Strain"}, "1444202": {"name": "Escherichia coli 2-052-05_S4_C1", "rank": "Strain"}, "1444203": {"name": "Escherichia coli 2-156-04_S4_C1", "rank": "Strain"}, "1444200": {"name": "Escherichia coli 2-005-03_S4_C1", "rank": "Strain"}, "1444201": {"name": "Escherichia coli 2-011-08_S4_C1", "rank": "Strain"}, "1444206": {"name": "Escherichia coli 2-222-05_S4_C1", "rank": "Strain"}, "1444207": {"name": "Escherichia coli 2-316-03_S4_C1", "rank": "Strain"}, "1444204": {"name": "Escherichia coli 2-177-06_S4_C1", "rank": "Strain"}, "1444205": {"name": "Escherichia coli 2-210-07_S4_C1", "rank": "Strain"}, "1422545": {"name": "Staphylococcus aureus VET0271R", "rank": "Strain"}, "1422544": {"name": "Staphylococcus aureus VET0270R", "rank": "Strain"}, "1422547": {"name": "Staphylococcus aureus VET0278R", "rank": "Strain"}, "1422546": {"name": "Staphylococcus aureus VET0275R", "rank": "Strain"}, "1422541": {"name": "Staphylococcus aureus VET0267R", "rank": "Strain"}, "1422540": {"name": "Staphylococcus aureus VET0263R", "rank": "Strain"}, "1422543": {"name": "Staphylococcus aureus VET0269R", "rank": "Strain"}, "1422542": {"name": "Staphylococcus aureus VET0268R", "rank": "Strain"}, "1422549": {"name": "Staphylococcus aureus VET0280R", "rank": "Strain"}, "1422548": {"name": "Staphylococcus aureus VET0279R", "rank": "Strain"}, "186821": {"name": "Sporolactobacillaceae", "rank": "Family"}, "186820": {"name": "Listeriaceae", "rank": "Family"}, "186823": {"name": "Alicyclobacillaceae", "rank": "Family"}, "186822": {"name": "Paenibacillaceae", "rank": "Family"}, "186825": {"name": "Unclassified Bacillales", "rank": "No rank"}, "186824": {"name": "Thermoactinomycetaceae", "rank": "Family"}, "186827": {"name": "Aerococcaceae", "rank": "Family"}, "186826": {"name": "Lactobacillales", "rank": "Order"}, "186828": {"name": "Carnobacteriaceae", "rank": "Family"}, "545275": {"name": "Thioalkalivibrio sp. ALE20", "rank": "Species"}, "545276": {"name": "Thioalkalivibrio sp. ALJ24", "rank": "Species"}, "12049": {"name": "Soybean dwarf virus", "rank": "Species"}, "12045": {"name": "Potato leafroll virus", "rank": "Species"}, "12040": {"name": "Barley yellow dwarf virus-PAV", "rank": "Species"}, "12041": {"name": "Bean leafroll virus", "rank": "Species"}, "12042": {"name": "Beet western yellows virus", "rank": "Species"}, "1158318": {"name": "Desulfurobacterium sp. TC5-1", "rank": "Species"}, "1236944": {"name": "Lactococcus lactis subsp. lactis JCM 5805 = NBRC 100933", "rank": "Strain"}, "45658": {"name": "Vibrio scophthalmi", "rank": "Species"}, "147498": {"name": "Pleosporales incertae sedis", "rank": "No rank"}, "1202768": {"name": "Halopiger salifodinae", "rank": "Species"}, "1291006": {"name": "Clavibacter cf. michiganensis LMG 26808", "rank": "Strain"}, "1281012": {"name": "Escherichia coli HVH 73 (4-2393174)", "rank": "Strain"}, "281472": {"name": "Jiangella", "rank": "Genus"}, "281473": {"name": "Jiangella gansuensis", "rank": "Species"}, "433660": {"name": "Nocardioides halotolerans", "rank": "Species"}, "1240771": {"name": "Escherichia coli O104:H4 str. 11-02093", "rank": "Strain"}, "1501230": {"name": "Paenibacillus sp. MSt1", "rank": "Species"}, "1281013": {"name": "Escherichia coli HVH 74 (4-1034782)", "rank": "Strain"}, "1278308": {"name": "Zimmermannella faecalis ATCC 13722", "rank": "Strain"}, "1344414": {"name": "Trichoderma reesei RUT C-30", "rank": "Strain"}, "1278309": {"name": "Amphritea japonica ATCC BAA-1530", "rank": "Strain"}, "300175": {"name": "Mopeia virus AN20410", "rank": "Strain"}, "1397867": {"name": "Mycobacterium tuberculosis TKK_02_0022", "rank": "Strain"}, "180856": {"name": "Bacillus thuringiensis serovar konkukian", "rank": "Strain"}, "52604": {"name": "Pleurocapsales", "rank": "Order"}, "52605": {"name": "Myxosarcina", "rank": "Genus"}, "1278304": {"name": "Acholeplasma granularum ATCC 19168", "rank": "Strain"}, "939": {"name": "Hydrogenobacter", "rank": "Genus"}, "462590": {"name": "Pseudomonas phage YuA", "rank": "Species"}, "931": {"name": "Thiobacillus thioparus", "rank": "Species"}, "930": {"name": "Acidithiobacillus thiooxidans", "rank": "Species"}, "933": {"name": "Thiomicrospira", "rank": "Genus"}, "934": {"name": "Thiomicrospira pelophila", "rank": "Species"}, "936": {"name": "Thiovulum", "rank": "Genus"}, "353209": {"name": "Reticuloendotheliosis virus group", "rank": "No rank"}, "259354": {"name": "Desulfatibacillum alkenivorans", "rank": "Species"}, "1421858": {"name": "Staphylococcus aureus H68996", "rank": "Strain"}, "44011": {"name": "Ferrimonas", "rank": "Genus"}, "44012": {"name": "Ferrimonas balearica", "rank": "Species"}, "1397860": {"name": "Mycobacterium tuberculosis TKK_02_0015", "rank": "Strain"}, "44014": {"name": "Polynucleobacter necessarius subsp. necessarius", "rank": "Subspecies"}, "455632": {"name": "Streptomyces griseus subsp. griseus NBRC 13350", "rank": "Strain"}, "455631": {"name": "Peptoclostridium difficile QCD-66c26", "rank": "Strain"}, "1247113": {"name": "Astrovirus VA4", "rank": "Species"}, "1247115": {"name": "Diuris virus A", "rank": "Species"}, "1247114": {"name": "Astrovirus MLB3", "rank": "Species"}, "1247116": {"name": "Diuris virus B", "rank": "Species"}, "1038844": {"name": "Escherichia coli O104:H4 str. TY-2482", "rank": "Strain"}, "1310568": {"name": "Acinetobacter baumannii 916567", "rank": "Strain"}, "52226": {"name": "Mitsuokella multacida", "rank": "Species"}, "979894": {"name": "Spathaspora arborariae", "rank": "Species"}, "886872": {"name": "Leuconostoc argentinum KCTC 3773", "rank": "Strain"}, "1005485": {"name": "Escherichia coli NE1487", "rank": "Strain"}, "406556": {"name": "Streptococcus pneumoniae SP3-BS71", "rank": "Strain"}, "406557": {"name": "Streptococcus pneumoniae SP6-BS73", "rank": "Strain"}, "926027": {"name": "Escherichia coli O157:H- str. 493-89", "rank": "Strain"}, "926026": {"name": "Escherichia coli O157:H7 str. G5101", "rank": "Strain"}, "1310567": {"name": "Acinetobacter baumannii 1046674", "rank": "Strain"}, "59736": {"name": "Leifsonia xyli subsp. xyli", "rank": "Subspecies"}, "68337": {"name": "Deferribacteres", "rank": "Class"}, "926029": {"name": "Escherichia coli O55:H7 str. 3256-97", "rank": "Strain"}, "341685": {"name": "Tomato yellow leaf curl Mali virus-associated DNA beta", "rank": "Species"}, "406558": {"name": "Streptococcus pneumoniae SP9-BS68", "rank": "Strain"}, "406559": {"name": "Streptococcus pneumoniae SP11-BS70", "rank": "Strain"}, "135621": {"name": "Pseudomonadaceae", "rank": "Family"}, "135620": {"name": "Oceanospirillaceae", "rank": "Family"}, "135623": {"name": "Vibrionales", "rank": "Order"}, "135622": {"name": "Alteromonadales", "rank": "Order"}, "135625": {"name": "Pasteurellales", "rank": "Order"}, "168470": {"name": "Laribacter", "rank": "Genus"}, "168471": {"name": "Laribacter hongkongensis", "rank": "Species"}, "1009708": {"name": "Alpha proteobacterium SCGC AAA536-G10", "rank": "Species"}, "340486": {"name": "Candidatus Prevotella conceptionensis", "rank": "Species"}, "1463828": {"name": "Streptomyces sp. NRRL B-1322", "rank": "Species"}, "1412685": {"name": "Staphylococcus aureus T16669", "rank": "Strain"}, "1412684": {"name": "Staphylococcus aureus T16664", "rank": "Strain"}, "1412687": {"name": "Staphylococcus aureus T17131", "rank": "Strain"}, "1448520": {"name": "Mycobacterium tuberculosis TKK_05MA_0056", "rank": "Strain"}, "1412681": {"name": "Staphylococcus aureus M73703", "rank": "Strain"}, "1412680": {"name": "Staphylococcus aureus M73702", "rank": "Strain"}, "1412683": {"name": "Staphylococcus aureus S56450", "rank": "Strain"}, "34029": {"name": "Leptothrix cholodnii", "rank": "Species"}, "1333542": {"name": "Pseudomonas aeruginosa str. C 1426", "rank": "Strain"}, "1412689": {"name": "Staphylococcus aureus T20118", "rank": "Strain"}, "1412688": {"name": "Staphylococcus aureus T17141", "rank": "Strain"}, "34021": {"name": "Candidatus Liberibacter asiaticus", "rank": "Species"}, "502177": {"name": "Unclassified Sobemovirus", "rank": "No rank"}, "1005488": {"name": "Escherichia coli PA3", "rank": "Strain"}, "376852": {"name": "Goatpox virus Pellor", "rank": "Strain"}, "1178526": {"name": "Streptococcus agalactiae GB00112", "rank": "Strain"}, "176106": {"name": "Sulfolobus islandicus filamentous virus", "rank": "Species"}, "735504": {"name": "Unclassified Gammapapillomavirus", "rank": "No rank"}, "176102": {"name": "Pseudoalteromonas agarivorans", "rank": "Species"}, "1005941": {"name": "Planococcus halocryophilus Or1", "rank": "Strain"}, "203267": {"name": "Tropheryma whipplei str. Twist", "rank": "Strain"}, "62322": {"name": "Shewanella baltica", "rank": "Species"}, "1310563": {"name": "Acinetobacter baumannii 972082", "rank": "Strain"}, "59732": {"name": "Chryseobacterium", "rank": "Genus"}, "1173434": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN000205", "rank": "Strain"}, "1173435": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN000207", "rank": "Strain"}, "1173436": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN000209", "rank": "Strain"}, "1173437": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN000210", "rank": "Strain"}, "1173430": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN000196", "rank": "Strain"}, "763034": {"name": "Bacteroides fluxus YIT 12057", "rank": "Strain"}, "1173432": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN000201", "rank": "Strain"}, "1173433": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN000204", "rank": "Strain"}, "559737": {"name": "Xanthomonas campestris pv. musacearum NCPPB 4381", "rank": "Strain"}, "559736": {"name": "Xanthomonas vasicola pv. vasculorum NCPPB 702", "rank": "Strain"}, "1173438": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN000213", "rank": "Strain"}, "1173439": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN000214", "rank": "Strain"}, "243243": {"name": "Mycobacterium avium 104", "rank": "Strain"}, "1310562": {"name": "Acinetobacter baumannii 472237-1196", "rank": "Strain"}, "1348657": {"name": "Thauera terpenica 58Eu", "rank": "Strain"}, "1298880": {"name": "Streptomyces sp. TAA486", "rank": "Species"}, "206160": {"name": "Sandfly fever Naples virus", "rank": "Species"}, "1141722": {"name": "Tomato leaf curl Togo virus", "rank": "Species"}, "688540": {"name": "Sweet potato golden vein associated virus", "rank": "Species"}, "600809": {"name": "Blattabacterium sp. (Periplaneta americana) str. BPLAN", "rank": "Strain"}, "582419": {"name": "Thermococcus sp. ES1", "rank": "Species"}, "439235": {"name": "Desulfatibacillum alkenivorans AK-01", "rank": "Strain"}, "12814": {"name": "Respiratory syncytial virus", "rank": "Species"}, "1265494": {"name": "Thioalkalivibrio sp. ALE11", "rank": "Species"}, "1265495": {"name": "Thioalkalivibrio sp. ALE23", "rank": "Species"}, "1265497": {"name": "Thioalkalivibrio sp. ALMg2", "rank": "Species"}, "1265490": {"name": "Pseudomonas sp. URMO17WK12:I8", "rank": "Species"}, "913090": {"name": "Escherichia coli TW10722", "rank": "Strain"}, "913091": {"name": "Escherichia coli TW10598", "rank": "Strain"}, "29419": {"name": "Helicobacter canis", "rank": "Species"}, "386487": {"name": "Candidatus Ruthia magnifica", "rank": "Species"}, "11070": {"name": "Dengue virus 4", "rank": "Strain"}, "11071": {"name": "Japanese encephalitis virus group", "rank": "Subgenus"}, "11072": {"name": "Japanese encephalitis virus", "rank": "Species"}, "554155": {"name": "Arthroderma otae CBS 113480", "rank": "Strain"}, "11079": {"name": "Murray Valley encephalitis virus", "rank": "Species"}, "375432": {"name": "Haemophilus influenzae R3021", "rank": "Strain"}, "246144": {"name": "Enterococcus italicus", "rank": "Species"}, "1177153": {"name": "Klebsiella pneumoniae subsp. pneumoniae LZ", "rank": "Strain"}, "413684": {"name": "Unclassified Simian adenoviruses", "rank": "No rank"}, "1177154": {"name": "Alcanivorax sp. 19-m-6", "rank": "Species"}, "1234776": {"name": "Trichoderma longibrachiatum SMF2", "rank": "Strain"}, "1031709": {"name": "Propionibacterium acnes 6609", "rank": "Strain"}, "1298609": {"name": "Psychrobacter sp. JCM 18901", "rank": "Species"}, "1298608": {"name": "Psychrobacter sp. JCM 18900", "rank": "Species"}, "1298607": {"name": "Psychrobacter sp. JCM 18902", "rank": "Species"}, "120577": {"name": "Brucella ceti", "rank": "Species"}, "1298600": {"name": "Vibrio sp. JCM 18905", "rank": "Species"}, "120574": {"name": "Streptococcus phage MM1", "rank": "Species"}, "1447441": {"name": "Mycobacterium tuberculosis MD19693", "rank": "Strain"}, "1447440": {"name": "Mycobacterium tuberculosis MD19964", "rank": "Strain"}, "1447443": {"name": "Mycobacterium tuberculosis MD17614", "rank": "Strain"}, "1447442": {"name": "Mycobacterium tuberculosis MD19042", "rank": "Strain"}, "1447445": {"name": "Mycobacterium tuberculosis MD18115", "rank": "Strain"}, "1447444": {"name": "Mycobacterium tuberculosis MD17615", "rank": "Strain"}, "1447447": {"name": "Mycobacterium tuberculosis MD19043", "rank": "Strain"}, "1447446": {"name": "Mycobacterium tuberculosis MD17748", "rank": "Strain"}, "1447449": {"name": "Mycobacterium tuberculosis MD20845", "rank": "Strain"}, "1447448": {"name": "Mycobacterium tuberculosis MD20344", "rank": "Strain"}, "1348384": {"name": "Rotavirus H", "rank": "Species"}, "134287": {"name": "Secondary endosymbiont of Heteropsylla cubana", "rank": "Species"}, "1388728": {"name": "Staphylococcus aureus M0968", "rank": "Strain"}, "1388729": {"name": "Staphylococcus aureus M0969", "rank": "Strain"}, "1438799": {"name": "Klebsiella pneumoniae MGH 76", "rank": "Strain"}, "1438798": {"name": "Klebsiella pneumoniae MGH 75", "rank": "Strain"}, "1438797": {"name": "Klebsiella pneumoniae MGH 74", "rank": "Strain"}, "1388725": {"name": "Staphylococcus aureus M0965", "rank": "Strain"}, "1381097": {"name": "Gluconobacter thailandicus NBRC 3257", "rank": "Strain"}, "1388727": {"name": "Staphylococcus aureus M0967", "rank": "Strain"}, "620833": {"name": "Fusobacterium periodonticum D10", "rank": "Strain"}, "1438792": {"name": "Klebsiella pneumoniae MGH 69", "rank": "Strain"}, "1438791": {"name": "Klebsiella pneumoniae MGH 68", "rank": "Strain"}, "1388723": {"name": "Staphylococcus aureus M0962", "rank": "Strain"}, "1405120": {"name": "Cronobacter helveticus 513", "rank": "Strain"}, "996651": {"name": "Camelus dromedarius papillomavirus type 2", "rank": "Species"}, "204470": {"name": "Alicyclobacillus pomorum", "rank": "Species"}, "658599": {"name": "Chlamydia trachomatis L2tet1", "rank": "Strain"}, "280354": {"name": "Bacillus anthracis str. CNEVA-9066", "rank": "Strain"}, "280355": {"name": "Bacillus anthracis str. A1055", "rank": "Strain"}, "1299270": {"name": "Wallemia ichthyophaga EXF-994", "rank": "Strain"}, "457421": {"name": "Clostridiales bacterium 1_7_47FAA", "rank": "Species"}, "765840": {"name": "Moraxella macacae", "rank": "Species"}, "457422": {"name": "Erysipelotrichaceae bacterium 2_2_44A", "rank": "Species"}, "1006583": {"name": "Aguacate virus", "rank": "Species"}, "1006581": {"name": "Mycoplasma gallisepticum S6", "rank": "Strain"}, "457428": {"name": "Streptomyces lividans TK24", "rank": "Strain"}, "457429": {"name": "Streptomyces pristinaespiralis ATCC 25486", "rank": "Strain"}, "1110703": {"name": "Unclassified Nudiviridae", "rank": "No rank"}, "1413599": {"name": "Staphylococcus aureus 08142-8", "rank": "Strain"}, "1250520": {"name": "Klebsiella pneumoniae RYC492", "rank": "Strain"}, "861109": {"name": "Sphingobium indicum B90A", "rank": "Strain"}, "1220574": {"name": "Gordonia amicalis NBRC 100051 = JCM 11271", "rank": "Strain"}, "229278": {"name": "Murine pneumotropic virus", "rank": "Species"}, "558314": {"name": "Desulfurobacteriaceae", "rank": "Family"}, "1413596": {"name": "Staphylococcus aureus 47P9", "rank": "Strain"}, "1413597": {"name": "Staphylococcus aureus 08134-6", "rank": "Strain"}, "928729": {"name": "Saccharomonospora halophila 8", "rank": "Strain"}, "2138": {"name": "Spiroplasma poulsonii", "rank": "Species"}, "928722": {"name": "Sinorhizobium meliloti AK58", "rank": "Strain"}, "2137": {"name": "Spiroplasma apis", "rank": "Species"}, "2134": {"name": "Spiroplasma melliferum", "rank": "Species"}, "2132": {"name": "Spiroplasma", "rank": "Genus"}, "2130": {"name": "Ureaplasma urealyticum", "rank": "Species"}, "2131": {"name": "Spiroplasmataceae", "rank": "Family"}, "1085029": {"name": "Halophilic archaeon J07HB67", "rank": "Species"}, "35701": {"name": "Heliobacterium modesticaldum", "rank": "Species"}, "35703": {"name": "Citrobacter amalonaticus", "rank": "Species"}, "323261": {"name": "Nitrosococcus oceani ATCC 19707", "rank": "Strain"}, "1085027": {"name": "Burkholderia pseudomallei 1026a", "rank": "Strain"}, "563194": {"name": "Pediococcus acidilactici 7_4", "rank": "Strain"}, "426371": {"name": "Algoriphagus vanfongensis", "rank": "Species"}, "1032362": {"name": "Clostridium phage phiCD38-2", "rank": "Species"}, "910039": {"name": "Aminicenantes bacterium SCGC AAA252-K06", "rank": "Species"}, "910038": {"name": "Unclassified Aminicenantes", "rank": "No rank"}, "1133319": {"name": "Bacteroides reticulotermitis", "rank": "Species"}, "665944": {"name": "Klebsiella sp. 4_1_44FAA", "rank": "Species"}, "665945": {"name": "Lactobacillus sp. 7_1_47FAA", "rank": "Species"}, "665946": {"name": "Neisseria sp. GT4A_CT1", "rank": "Species"}, "665940": {"name": "Clostridium sp. 7_3_54FAA", "rank": "Species"}, "665941": {"name": "Coprobacillus sp. 3_3_56FAA", "rank": "Species"}, "665942": {"name": "Desulfovibrio sp. 6_1_46AFAA", "rank": "Species"}, "665943": {"name": "Eggerthella sp. 1_3_56FAA", "rank": "Species"}, "31713": {"name": "Lettuce infectious yellows virus", "rank": "Species"}, "31711": {"name": "Cardamine chlorotic fleck virus", "rank": "Species"}, "665948": {"name": "Pseudomonas sp. 2_1_26", "rank": "Species"}, "665949": {"name": "Tannerella sp. 6_1_58FAA_CT1", "rank": "Species"}, "1134840": {"name": "Enterococcus faecium S447", "rank": "Strain"}, "1134841": {"name": "Enterococcus faecium V689", "rank": "Strain"}, "1134842": {"name": "Staphylococcus aureus subsp. aureus CM05", "rank": "Strain"}, "265": {"name": "Paracoccus", "rank": "Genus"}, "264": {"name": "Francisella tularensis subsp. novicida", "rank": "Subspecies"}, "266": {"name": "Paracoccus denitrificans", "rank": "Species"}, "263": {"name": "Francisella tularensis", "rank": "Species"}, "262": {"name": "Francisella", "rank": "Genus"}, "1988": {"name": "Actinomadura", "rank": "Genus"}, "189769": {"name": "Chrysiogenales", "rank": "Order"}, "1439144": {"name": "Streptococcus pyogenes ABC020046470", "rank": "Strain"}, "1439147": {"name": "Streptococcus pyogenes ABC020046559", "rank": "Strain"}, "1439146": {"name": "Streptococcus pyogenes ABC020046534", "rank": "Strain"}, "586133": {"name": "Nematocida parisii", "rank": "Species"}, "586132": {"name": "Nematocida", "rank": "Genus"}, "585203": {"name": "Streptococcus mitis SK564", "rank": "Strain"}, "1439149": {"name": "Streptococcus pyogenes ABC020046589", "rank": "Strain"}, "1073999": {"name": "Cronobacter condimenti 1330", "rank": "Strain"}, "300231": {"name": "Glaciecola nitratireducens", "rank": "Species"}, "32257": {"name": "Kingella", "rank": "Genus"}, "1678": {"name": "Bifidobacterium", "rank": "Genus"}, "1679": {"name": "Bifidobacterium longum subsp. longum", "rank": "Subspecies"}, "5341": {"name": "Agaricus bisporus", "rank": "Species"}, "515575": {"name": "Algerian watermelon mosaic virus", "rank": "Species"}, "626887": {"name": "Marinobacter nanhaiticus D15-8W", "rank": "Strain"}, "407976": {"name": "Shewanella baltica OS223", "rank": "Strain"}, "407975": {"name": "Prevotella pleuritidis", "rank": "Species"}, "1037890": {"name": "Klebsiella pneumoniae JH1", "rank": "Strain"}, "1508454": {"name": "Haloferax sp. ATB1", "rank": "Species"}, "82689": {"name": "Salmonella enterica subsp. enterica serovar Muenster", "rank": "Strain"}, "1409539": {"name": "Staphylococcus aureus SJUD6041", "rank": "Strain"}, "754262": {"name": "Actinobacillus pleuropneumoniae serovar 13 str. N273", "rank": "Strain"}, "1079922": {"name": "Commensalibacter", "rank": "Genus"}, "754260": {"name": "Actinobacillus pleuropneumoniae serovar 11 str. 56153", "rank": "Strain"}, "754261": {"name": "Actinobacillus pleuropneumoniae serovar 12 str. 1096", "rank": "Strain"}, "908009": {"name": "Bhendi yellow vein India betasatellite", "rank": "Species"}, "187410": {"name": "Yersinia pestis KIM10+", "rank": "Strain"}, "160386": {"name": "Corynebacterium casei", "rank": "Species"}, "67351": {"name": "Streptomyces puniceus", "rank": "Species"}, "67352": {"name": "Streptomyces purpeofuscus", "rank": "Species"}, "67356": {"name": "Streptomyces resistomycificus", "rank": "Species"}, "1427244": {"name": "Mycobacterium tuberculosis XTB13-159", "rank": "Strain"}, "1094944": {"name": "Sphingomonas sp. JGI 0001003-D23", "rank": "Species"}, "1392008": {"name": "Staphylococcus aureus M0979", "rank": "Strain"}, "1392009": {"name": "Staphylococcus aureus M0980", "rank": "Strain"}, "1094945": {"name": "Sphingomonas sp. JGI 0001003-H15", "rank": "Species"}, "1392002": {"name": "Mycobacterium avium 05-4293", "rank": "Strain"}, "46677": {"name": "Pseudomonas agarici", "rank": "Species"}, "1392000": {"name": "Mycobacterium avium 10-5581", "rank": "Strain"}, "1392007": {"name": "Lactobacillus equi DPC 6820", "rank": "Strain"}, "1392005": {"name": "Comamonas testosteroni TK102", "rank": "Strain"}, "129875": {"name": "Human mastadenovirus A", "rank": "Species"}, "1094947": {"name": "Rhizobium sp. JGI 0001002-C21", "rank": "Species"}, "1427243": {"name": "Mycobacterium tuberculosis XTB13-158", "rank": "Strain"}, "1388370": {"name": "Staphylococcus aureus M0558", "rank": "Strain"}, "1120956": {"name": "Afifella pfennigii DSM 17143", "rank": "Strain"}, "486408": {"name": "Lactobacillus rhamnosus HN001", "rank": "Strain"}, "486409": {"name": "Bifidobacterium animalis subsp. lactis HN019", "rank": "Strain"}, "1418409": {"name": "Staphylococcus aureus M66407", "rank": "Strain"}, "1418408": {"name": "Staphylococcus aureus M64056", "rank": "Strain"}, "1418405": {"name": "Staphylococcus aureus M17301", "rank": "Strain"}, "1418404": {"name": "Staphylococcus aureus M17299", "rank": "Strain"}, "1418407": {"name": "Staphylococcus aureus M25139", "rank": "Strain"}, "1418406": {"name": "Staphylococcus aureus M21126", "rank": "Strain"}, "1418401": {"name": "Staphylococcus aureus H89939", "rank": "Strain"}, "1418400": {"name": "Staphylococcus aureus H83025", "rank": "Strain"}, "1418403": {"name": "Staphylococcus aureus M13559", "rank": "Strain"}, "1418402": {"name": "Staphylococcus aureus H89941", "rank": "Strain"}, "1051613": {"name": "Verticillium alfalfae", "rank": "Species"}, "876270": {"name": "Methyloferula stellata", "rank": "Species"}, "85454": {"name": "Alternanthera mosaic virus", "rank": "Species"}, "69525": {"name": "Natrinema pellirubrum", "rank": "Species"}, "69527": {"name": "Natrinema pallidum", "rank": "Species"}, "1198989": {"name": "PhiCD119likevirus", "rank": "Genus"}, "190062": {"name": "Fowl aviadenovirus B", "rank": "Species"}, "190063": {"name": "Fowl aviadenovirus C", "rank": "Species"}, "190061": {"name": "Fowl aviadenovirus A", "rank": "Species"}, "190064": {"name": "Fowl aviadenovirus D", "rank": "Species"}, "190065": {"name": "Fowl aviadenovirus E", "rank": "Species"}, "12199": {"name": "Cowpea aphid-borne mosaic virus", "rank": "Species"}, "784613": {"name": "Lactobacillus delbrueckii subsp. bulgaricus PB2003/044-T3-4", "rank": "Strain"}, "101851": {"name": "Glarea", "rank": "Genus"}, "101850": {"name": "Thysanoplusia orichalcea nucleopolyhedrovirus", "rank": "Species"}, "101852": {"name": "Glarea lozoyensis", "rank": "Species"}, "291183": {"name": "Lacinutrix", "rank": "Genus"}, "113370": {"name": "Spodoptera frugiperda ascovirus 1a", "rank": "Species"}, "1427455": {"name": "Kluyveromyces dobzhanskii CBS 2104", "rank": "Subspecies"}, "78527": {"name": "Rhizobium undicola", "rank": "Species"}, "1397278": {"name": "Leucobacter sp. PH1c", "rank": "Species"}, "1397276": {"name": "Bacillus sp. H1a", "rank": "Species"}, "1397277": {"name": "Bacillus sp. H1m", "rank": "Species"}, "1397275": {"name": "Achromobacter sp. DH1f", "rank": "Species"}, "1129369": {"name": "Mycoplasma hyorhinis GDL-1", "rank": "Strain"}, "1129368": {"name": "Spiroplasma melliferum IPMB4A", "rank": "Strain"}, "145262": {"name": "Methanothermobacter thermautotrophicus", "rank": "Species"}, "145263": {"name": "Methanothermobacter marburgensis", "rank": "Species"}, "145260": {"name": "Methanothermobacter", "rank": "Genus"}, "1028805": {"name": "Haemophilus haemolyticus M21621", "rank": "Strain"}, "1028802": {"name": "Haemophilus haemolyticus M19107", "rank": "Strain"}, "1028803": {"name": "Haemophilus haemolyticus M19501", "rank": "Strain"}, "1028800": {"name": "Neorhizobium galegae bv. orientalis str. HAMBI 540", "rank": "Strain"}, "1028801": {"name": "Neorhizobium galegae bv. officinalis bv. officinalis str. HAMBI 1141", "rank": "Strain"}, "1547437": {"name": "Hoeflea sp. BAL378", "rank": "Species"}, "1151226": {"name": "Escherichia coli B26-2", "rank": "Strain"}, "984262": {"name": "Saprospira grandis str. Lewin", "rank": "Strain"}, "480808": {"name": "Mycobacterium phage Giles", "rank": "Species"}, "1151222": {"name": "Escherichia coli B36-2", "rank": "Strain"}, "1215079": {"name": "Peptoclostridium difficile T3", "rank": "Strain"}, "1215078": {"name": "Peptoclostridium difficile E7", "rank": "Strain"}, "633415": {"name": "Aeromonas sanarellii", "rank": "Species"}, "633417": {"name": "Aeromonas taiwanensis", "rank": "Species"}, "1215071": {"name": "Peptoclostridium difficile E19", "rank": "Strain"}, "1215070": {"name": "Peptoclostridium difficile T23", "rank": "Strain"}, "1215073": {"name": "Peptoclostridium difficile T42", "rank": "Strain"}, "1215072": {"name": "Peptoclostridium difficile E24", "rank": "Strain"}, "1215075": {"name": "Peptoclostridium difficile E14", "rank": "Strain"}, "1215074": {"name": "Peptoclostridium difficile T6", "rank": "Strain"}, "1215077": {"name": "Peptoclostridium difficile E9", "rank": "Strain"}, "1215076": {"name": "Peptoclostridium difficile T17", "rank": "Strain"}, "939126": {"name": "Verrucomicrobia bacterium SCGC AAA027-I19", "rank": "Species"}, "626369": {"name": "Granulicatella elegans ATCC 700633", "rank": "Strain"}, "1151228": {"name": "Escherichia coli B40-2", "rank": "Strain"}, "1047034": {"name": "Aminicenantes bacterium SCGC AAA252-O11", "rank": "Species"}, "73561": {"name": "Citrus psorosis virus", "rank": "Species"}, "1354507": {"name": "Mycobacterium phage Adawi", "rank": "Species"}, "537937": {"name": "Bifidobacterium longum subsp. infantis CCUG 52486", "rank": "Strain"}, "1354508": {"name": "Mycobacterium phage Bane1", "rank": "Species"}, "1047036": {"name": "Aminicenantes bacterium SCGC AAA252-P13", "rank": "Species"}, "1310637": {"name": "Acinetobacter baumannii 809848", "rank": "Strain"}, "1397897": {"name": "Mycobacterium tuberculosis TKK_03_0031", "rank": "Strain"}, "1397894": {"name": "Mycobacterium tuberculosis TKK_03_0027", "rank": "Strain"}, "1397895": {"name": "Mycobacterium tuberculosis TKK_03_0029", "rank": "Strain"}, "1397892": {"name": "Mycobacterium tuberculosis TKK_03_0025", "rank": "Strain"}, "1397893": {"name": "Mycobacterium tuberculosis TKK_03_0026", "rank": "Strain"}, "1397890": {"name": "Mycobacterium tuberculosis TKK_03_0020", "rank": "Strain"}, "1397891": {"name": "Mycobacterium tuberculosis TKK_03_0022", "rank": "Strain"}, "1169204": {"name": "Brucella abortus 355/78", "rank": "Strain"}, "1169205": {"name": "Brucella abortus 544", "rank": "Strain"}, "1169206": {"name": "Brucella abortus 600/64", "rank": "Strain"}, "1169207": {"name": "Brucella abortus 63/130", "rank": "Strain"}, "1310639": {"name": "Acinetobacter baumannii 272263", "rank": "Strain"}, "1397899": {"name": "Mycobacterium tuberculosis TKK_03_0033", "rank": "Strain"}, "375177": {"name": "Haemophilus influenzae 3655", "rank": "Strain"}, "1367491": {"name": "Campylobacter coli 76339", "rank": "Strain"}, "1047032": {"name": "Aminicenantes bacterium SCGC AAA252-O09", "rank": "Species"}, "1408859": {"name": "Borrelia burgdorferi IPT2", "rank": "Strain"}, "1408858": {"name": "Borrelia burgdorferi IPT19", "rank": "Strain"}, "1408857": {"name": "Borrelia garinii IPT140", "rank": "Strain"}, "1408856": {"name": "Borrelia garinii IPT139", "rank": "Strain"}, "1110509": {"name": "Methanosaeta harundinacea 6Ac", "rank": "Strain"}, "1408854": {"name": "Borrelia garinii IPT134", "rank": "Strain"}, "1408853": {"name": "Borrelia garinii IPT133", "rank": "Strain"}, "1408852": {"name": "Borrelia garinii IPT131", "rank": "Strain"}, "1408851": {"name": "Borrelia garinii IPT130", "rank": "Strain"}, "1285": {"name": "Staphylococcus intermedius", "rank": "Species"}, "1284": {"name": "Staphylococcus hyicus", "rank": "Species"}, "475794": {"name": "Haliea", "rank": "Genus"}, "1402683": {"name": "Staphylococcus aureus M1174", "rank": "Strain"}, "1281": {"name": "Staphylococcus carnosus", "rank": "Species"}, "1402685": {"name": "Staphylococcus aureus M1176", "rank": "Strain"}, "1402686": {"name": "Staphylococcus aureus M1177", "rank": "Strain"}, "1282": {"name": "Staphylococcus epidermidis", "rank": "Species"}, "1402688": {"name": "Staphylococcus aureus M1179", "rank": "Strain"}, "1402689": {"name": "Staphylococcus aureus M1180", "rank": "Strain"}, "1288": {"name": "Staphylococcus xylosus", "rank": "Species"}, "323655": {"name": "Neorhizobium galegae bv. orientalis", "rank": "Strain"}, "323656": {"name": "Neorhizobium galegae bv. officinalis", "rank": "Strain"}, "1401639": {"name": "Acinetobacter baumannii NCGM 237", "rank": "Strain"}, "1214102": {"name": "Mycobacterium fortuitum subsp. fortuitum DSM 46621", "rank": "Strain"}, "1214101": {"name": "Streptomyces davawensis JCM 4913", "rank": "Strain"}, "1388489": {"name": "Staphylococcus aureus M0727", "rank": "Strain"}, "1388488": {"name": "Staphylococcus aureus M0725", "rank": "Strain"}, "196403": {"name": "Baboon endogenous virus", "rank": "Species"}, "211866": {"name": "Tobacco leaf curl Yunnan virus", "rank": "Species"}, "1388481": {"name": "Staphylococcus aureus M0716", "rank": "Strain"}, "1388480": {"name": "Staphylococcus aureus M0715", "rank": "Strain"}, "1388483": {"name": "Staphylococcus aureus M0720", "rank": "Strain"}, "1388482": {"name": "Staphylococcus aureus M0718", "rank": "Strain"}, "1388485": {"name": "Staphylococcus aureus M0722", "rank": "Strain"}, "1388484": {"name": "Staphylococcus aureus M0721", "rank": "Strain"}, "1388487": {"name": "Staphylococcus aureus M0724", "rank": "Strain"}, "1388486": {"name": "Staphylococcus aureus M0723", "rank": "Strain"}, "1448798": {"name": "Mycobacterium tuberculosis M2360", "rank": "Strain"}, "1448799": {"name": "Mycobacterium tuberculosis M2145", "rank": "Strain"}, "437163": {"name": "Halomicrobium katesii", "rank": "Species"}, "1448790": {"name": "Mycobacterium tuberculosis M2442", "rank": "Strain"}, "1448791": {"name": "Mycobacterium tuberculosis M2440", "rank": "Strain"}, "1448792": {"name": "Mycobacterium tuberculosis M2435", "rank": "Strain"}, "1448794": {"name": "Mycobacterium tuberculosis M2416", "rank": "Strain"}, "1448795": {"name": "Mycobacterium tuberculosis M2402", "rank": "Strain"}, "1448796": {"name": "Mycobacterium tuberculosis M2376", "rank": "Strain"}, "1448797": {"name": "Mycobacterium tuberculosis M2361", "rank": "Strain"}, "873448": {"name": "Streptococcus porcinus str. Jelinkova 176", "rank": "Strain"}, "873449": {"name": "Streptococcus criceti HS-6", "rank": "Strain"}, "255727": {"name": "Coriobacterineae", "rank": "Suborder"}, "255726": {"name": "Acidimicrobineae", "rank": "Suborder"}, "255725": {"name": "Rubrobacterineae", "rank": "Suborder"}, "592029": {"name": "Nonlabens dokdonensis DSW-6", "rank": "Strain"}, "255728": {"name": "Sphaerobacterineae", "rank": "Suborder"}, "1472425": {"name": "Prunus virus T", "rank": "Species"}, "1472424": {"name": "Unclassified Tepovirus", "rank": "No rank"}, "12194": {"name": "Lily virus X", "rank": "Species"}, "40520": {"name": "Ruminococcus obeum", "rank": "Species"}, "40521": {"name": "Listeria phage A118", "rank": "Species"}, "1422396": {"name": "Staphylococcus aureus VET0057R", "rank": "Strain"}, "40523": {"name": "Listeria phage A511", "rank": "Species"}, "472759": {"name": "Nitrosococcus halophilus Nc 4", "rank": "Strain"}, "1302647": {"name": "Enterococcus faecium LCT-EF297", "rank": "Strain"}, "261827": {"name": "Algibacter", "rank": "Genus"}, "1457392": {"name": "Pseudomonas aeruginosa PA96", "rank": "Strain"}, "1457393": {"name": "Acetobacter aceti 1023", "rank": "Strain"}, "1457394": {"name": "Staphylococcus aureus MM66", "rank": "Strain"}, "1457395": {"name": "Lactobacillus rhamnosus PEL5", "rank": "Strain"}, "1457396": {"name": "Lactobacillus rhamnosus PEL6", "rank": "Strain"}, "1163302": {"name": "Streptococcus anginosus T5", "rank": "Strain"}, "1163301": {"name": "Streptococcus anginosus 1505", "rank": "Strain"}, "1538": {"name": "Clostridium ljungdahlii", "rank": "Species"}, "70856": {"name": "Aeromonas popoffii", "rank": "Species"}, "1531": {"name": "Clostridium clostridioforme", "rank": "Species"}, "1195068": {"name": "Staphylococcus phage StauST398-1", "rank": "Species"}, "1535": {"name": "Clostridium leptum", "rank": "Species"}, "1534": {"name": "Clostridium kluyveri", "rank": "Species"}, "1483572": {"name": "Thermofilum carboxyditrophus", "rank": "Species"}, "1029990": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 0322", "rank": "Strain"}, "1029997": {"name": "Salmonella enterica subsp. enterica serovar Heidelberg str. SARA35", "rank": "Strain"}, "1029996": {"name": "Salmonella enterica subsp. enterica serovar Heidelberg str. SARA37", "rank": "Strain"}, "278069": {"name": "Tomato leaf curl China betasatellite", "rank": "Species"}, "1029999": {"name": "Salmonella enterica subsp. enterica serovar Heidelberg str. SARA31", "rank": "Strain"}, "1029998": {"name": "Salmonella enterica subsp. enterica serovar Heidelberg str. SARA32", "rank": "Strain"}, "1248399": {"name": "Campylobacter jejuni subsp. jejuni BIGS0004", "rank": "Strain"}, "59735": {"name": "Bergeyella", "rank": "Genus"}, "1243663": {"name": "Paenibacillus sp. G4", "rank": "Species"}, "1243662": {"name": "Paenibacillus sp. G1", "rank": "Species"}, "418127": {"name": "Staphylococcus aureus subsp. aureus Mu3", "rank": "Strain"}, "41514": {"name": "Salmonella enterica subsp. arizonae serovar 62:z4,z23:-", "rank": "Strain"}, "545422": {"name": "Francisella tularensis subsp. novicida FTE", "rank": "Strain"}, "458234": {"name": "Francisella tularensis subsp. holarctica FTNF002-00", "rank": "Strain"}, "642478": {"name": "Lettuce chlorosis virus", "rank": "Species"}, "458233": {"name": "Macrococcus caseolyticus JCSC5402", "rank": "Strain"}, "147206": {"name": "Collinsella stercoris", "rank": "Species"}, "147207": {"name": "Collinsella intestinalis", "rank": "Species"}, "1267001": {"name": "Mycoplasma synoviae ATCC 25204", "rank": "Strain"}, "1267000": {"name": "Mycoplasma hominis ATCC 27545", "rank": "Strain"}, "1267003": {"name": "Lactobacillus parabrevis ATCC 53295", "rank": "Strain"}, "1267002": {"name": "Mycoplasma gallisepticum ATCC 19610", "rank": "Strain"}, "1267005": {"name": "Hyphomicrobium zavarzinii ATCC 27496", "rank": "Strain"}, "1267004": {"name": "Brachyspira innocens ATCC 29796", "rank": "Strain"}, "1267006": {"name": "Xylella fastidiosa subsp. multiplex ATCC 35871", "rank": "Strain"}, "1192592": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. 2010K-0284", "rank": "Strain"}, "1192593": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. 2010K-0286", "rank": "Strain"}, "1192590": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. 2010K-0267", "rank": "Strain"}, "1192591": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. 2010K-0271", "rank": "Strain"}, "46225": {"name": "Moraxella", "rank": "Subgenus"}, "46226": {"name": "Branhamella", "rank": "Subgenus"}, "457402": {"name": "Eubacterium sp. 3_1_31", "rank": "Species"}, "457403": {"name": "Fusobacterium nucleatum subsp. animalis 11_3_2", "rank": "Strain"}, "457400": {"name": "Escherichia sp. 1_1_43", "rank": "Species"}, "457401": {"name": "Escherichia sp. 4_1_40B", "rank": "Species"}, "457406": {"name": "Micromonospora sp. M42", "rank": "Species"}, "239759": {"name": "Alistipes", "rank": "Genus"}, "457404": {"name": "Fusobacterium ulcerans 12-1B", "rank": "Strain"}, "457405": {"name": "Fusobacterium nucleatum subsp. animalis 7_1", "rank": "Strain"}, "1190572": {"name": "Neisseria meningitidis NM3139", "rank": "Strain"}, "1190573": {"name": "Neisseria meningitidis NM045", "rank": "Strain"}, "1190570": {"name": "Neisseria meningitidis 2002030", "rank": "Strain"}, "1190571": {"name": "Neisseria meningitidis NM3141", "rank": "Strain"}, "1190576": {"name": "Neisseria meningitidis NM1476", "rank": "Strain"}, "1190577": {"name": "Neisseria meningitidis NM0552", "rank": "Strain"}, "307444": {"name": "Erinnyis ello granulovirus", "rank": "Species"}, "1190575": {"name": "Neisseria meningitidis NM003", "rank": "Strain"}, "1190578": {"name": "Neisseria meningitidis NM518", "rank": "Strain"}, "1190579": {"name": "Neisseria meningitidis NM3173", "rank": "Strain"}, "192848": {"name": "Bear Canyon virus", "rank": "Species"}, "263531": {"name": "Possum enterovirus W1", "rank": "Strain"}, "1409555": {"name": "Staphylococcus aureus UCIM6056", "rank": "Strain"}, "1409554": {"name": "Staphylococcus aureus MISS6125", "rank": "Strain"}, "1409557": {"name": "Staphylococcus aureus KINW6016", "rank": "Strain"}, "1409556": {"name": "Staphylococcus aureus UCIM6057", "rank": "Strain"}, "1409551": {"name": "Staphylococcus aureus HOAG6047", "rank": "Strain"}, "1409550": {"name": "Staphylococcus aureus HOAG6043", "rank": "Strain"}, "1409553": {"name": "Staphylococcus aureus PLAC6024", "rank": "Strain"}, "1409552": {"name": "Staphylococcus aureus OCMM6057", "rank": "Strain"}, "1409559": {"name": "Staphylococcus aureus HOAG6092", "rank": "Strain"}, "1409558": {"name": "Staphylococcus aureus FVRH6011", "rank": "Strain"}, "1161424": {"name": "Fusobacterium necrophorum subsp. funduliforme Fnf 1007", "rank": "Strain"}, "78448": {"name": "Bifidobacterium pullorum", "rank": "Species"}, "1117633": {"name": "Tailam virus", "rank": "Species"}, "758832": {"name": "Escherichia coli ECC-Z", "rank": "Strain"}, "1438773": {"name": "Klebsiella pneumoniae CHS 67", "rank": "Strain"}, "1041159": {"name": "Ensifer sp. WSM1721", "rank": "Species"}, "596": {"name": "Salmonella enterica subsp. enterica serovar Muenchen", "rank": "Strain"}, "595": {"name": "Salmonella enterica subsp. enterica serovar Infantis", "rank": "Strain"}, "594": {"name": "Salmonella enterica subsp. enterica serovar Gallinarum", "rank": "Strain"}, "1480694": {"name": "Spirochaeta sp. JC230", "rank": "Species"}, "590": {"name": "Salmonella", "rank": "Genus"}, "1041151": {"name": "Sinorhizobium meliloti 4H41", "rank": "Strain"}, "1041150": {"name": "Sinorhizobium medicae WSM244", "rank": "Strain"}, "41459": {"name": "Sweet potato mild mottle virus", "rank": "Species"}, "1041152": {"name": "Sinorhizobium meliloti CIAM1775", "rank": "Strain"}, "1041155": {"name": "Sinorhizobium meliloti MVII-I", "rank": "Strain"}, "1041154": {"name": "Sinorhizobium meliloti Mlalz-1", "rank": "Strain"}, "1041157": {"name": "Sinorhizobium meliloti WSM1022", "rank": "Strain"}, "598": {"name": "Salmonella enterica subsp. enterica serovar Rubislaw", "rank": "Strain"}, "59512": {"name": "Planktothrix rubescens", "rank": "Species"}, "59511": {"name": "Pseudomonas syringae pv. maculicola", "rank": "Strain"}, "1435362": {"name": "Burkholderia pseudomallei MSHR5492", "rank": "Strain"}, "1438776": {"name": "Klebsiella pneumoniae CHS 72", "rank": "Strain"}, "54396": {"name": "Endosymbiont of Riftia pachyptila", "rank": "Species"}, "436911": {"name": "Steller sea lion vesivirus", "rank": "Species"}, "90010": {"name": "Unclassified Enterovirus", "rank": "No rank"}, "53991": {"name": "Tomato leaf curl Java betasatellite", "rank": "Species"}, "1422379": {"name": "Staphylococcus aureus DAR5794", "rank": "Strain"}, "1422376": {"name": "Staphylococcus aureus DAR5797", "rank": "Strain"}, "1422377": {"name": "Staphylococcus aureus DAR5796", "rank": "Strain"}, "1422374": {"name": "Staphylococcus aureus DAR5799", "rank": "Strain"}, "1422375": {"name": "Staphylococcus aureus DAR5798", "rank": "Strain"}, "1422372": {"name": "Staphylococcus aureus DAR5801", "rank": "Strain"}, "1422373": {"name": "Staphylococcus aureus DAR5800", "rank": "Strain"}, "701091": {"name": "Bipolaris maydis C5", "rank": "Strain"}, "1422371": {"name": "Staphylococcus aureus DAR5802", "rank": "Strain"}, "520489": {"name": "Brucella suis bv. 5 str. 513", "rank": "Strain"}, "520488": {"name": "Brucella suis bv. 4 str. 40", "rank": "Strain"}, "520487": {"name": "Brucella suis bv. 3 str. 686", "rank": "Strain"}, "1042316": {"name": "Unclassified Armatimonadetes", "rank": "No rank"}, "1412838": {"name": "Escherichia coli FCH1", "rank": "Strain"}, "1412839": {"name": "Escherichia coli FCP1", "rank": "Strain"}, "1412836": {"name": "Escherichia coli FBH1", "rank": "Strain"}, "1412837": {"name": "Escherichia coli FBP1", "rank": "Strain"}, "1412834": {"name": "Escherichia coli FAP1", "rank": "Strain"}, "1412835": {"name": "Escherichia coli FAP2", "rank": "Strain"}, "1412832": {"name": "Escherichia coli FAH2", "rank": "Strain"}, "1412833": {"name": "Escherichia coli FAH1", "rank": "Strain"}, "1412830": {"name": "Escherichia coli 53C", "rank": "Strain"}, "1089132": {"name": "Mycobacterium phage SG4", "rank": "Species"}, "1089130": {"name": "Mycobacterium phage Nova", "rank": "Species"}, "1089137": {"name": "Mycobacterium phage Stinger", "rank": "Species"}, "1089136": {"name": "Mycobacterium phage JacAttac", "rank": "Species"}, "1089135": {"name": "Mycobacterium phage Firecracker", "rank": "Species"}, "562747": {"name": "Ludwigia leaf distortion betasatellite", "rank": "Species"}, "1089138": {"name": "Quail picornavirus QPV1/HUN/2010", "rank": "Species"}, "1423537": {"name": "Mycobacterium tuberculosis BTB11-133", "rank": "Strain"}, "1423536": {"name": "Mycobacterium tuberculosis BTB11-112", "rank": "Strain"}, "1423535": {"name": "Mycobacterium tuberculosis BTB11-047", "rank": "Strain"}, "1423534": {"name": "Mycobacterium tuberculosis BTB11-027", "rank": "Strain"}, "158879": {"name": "Staphylococcus aureus subsp. aureus N315", "rank": "Strain"}, "158878": {"name": "Staphylococcus aureus subsp. aureus Mu50", "rank": "Strain"}, "1423531": {"name": "Mycobacterium tuberculosis BTB10-472", "rank": "Strain"}, "1423530": {"name": "Mycobacterium tuberculosis BTB10-426", "rank": "Strain"}, "158877": {"name": "Yokenella regensburgei", "rank": "Species"}, "158876": {"name": "Yokenella", "rank": "Genus"}, "1347392": {"name": "Anaerosalibacter sp. ND1", "rank": "Species"}, "1347393": {"name": "Bacteroidaceae bacterium MS4", "rank": "Species"}, "1124954": {"name": "Salmonella enterica subsp. enterica serovar Kentucky str. 20793", "rank": "Strain"}, "55518": {"name": "Magnetospirillum gryphiswaldense", "rank": "Species"}, "55511": {"name": "Staphylococcus phage 187", "rank": "Species"}, "639021": {"name": "Magnaporthales", "rank": "Order"}, "979214": {"name": "Staphylococcus epidermidis NIHLM031", "rank": "Strain"}, "1123268": {"name": "Sphingomonas jaspsi DSM 18422", "rank": "Strain"}, "1123269": {"name": "Sphingomonas sanxanigenens DSM 19645 = NX02", "rank": "Strain"}, "1089110": {"name": "Mycobacterium phage Akoma", "rank": "Species"}, "1123265": {"name": "Sphingobacterium thalpophilum DSM 11723", "rank": "Strain"}, "1123267": {"name": "Sphingomonas astaxanthinifaciens DSM 22298", "rank": "Strain"}, "1123261": {"name": "Solimonas soli DSM 21787", "rank": "Strain"}, "1123262": {"name": "Solirubrobacter soli DSM 22325", "rank": "Strain"}, "1123263": {"name": "Solobacterium moorei DSM 22971", "rank": "Strain"}, "74349": {"name": "Sulfitobacter guttiformis", "rank": "Species"}, "979217": {"name": "Staphylococcus epidermidis NIHLM008", "rank": "Strain"}, "1411587": {"name": "Staphylococcus aureus W21932", "rank": "Strain"}, "979211": {"name": "Staphylococcus epidermidis NIHLM023", "rank": "Strain"}, "979212": {"name": "Staphylococcus epidermidis NIHLM021", "rank": "Strain"}, "1331660": {"name": "Acinetobacter haemolyticus MTCC 9819", "rank": "Strain"}, "979213": {"name": "Staphylococcus epidermidis NIHLM020", "rank": "Strain"}, "1105381": {"name": "Posavirus 2", "rank": "Species"}, "452662": {"name": "Sphingobium japonicum UT26S", "rank": "Strain"}, "663321": {"name": "Candidatus Regiella insecticola LSR1", "rank": "Strain"}, "171552": {"name": "Prevotellaceae", "rank": "Family"}, "171551": {"name": "Porphyromonadaceae", "rank": "Family"}, "171550": {"name": "Rikenellaceae", "rank": "Family"}, "330779": {"name": "Sulfolobus acidocaldarius DSM 639", "rank": "Strain"}, "300852": {"name": "Thermus thermophilus HB8", "rank": "Strain"}, "1230338": {"name": "Moraxella macacae 0408225", "rank": "Strain"}, "1158504": {"name": "Staphylococcus aureus M1563", "rank": "Strain"}, "380676": {"name": "Enterobacteria phage JS", "rank": "Species"}, "339268": {"name": "Mycobacterium colombiense", "rank": "Species"}, "301105": {"name": "Enterobacter hormaechei subsp. hormaechei", "rank": "Subspecies"}, "301102": {"name": "Enterobacter hormaechei subsp. oharae", "rank": "Subspecies"}, "1291338": {"name": "Leptospira interrogans serovar Copenhageni str. Fiocruz LV3076", "rank": "Strain"}, "870187": {"name": "Thiothrix nivea DSM 5205", "rank": "Strain"}, "1122132": {"name": "Kaistia granuli DSM 23481", "rank": "Strain"}, "1122131": {"name": "Kaistia adipata DSM 17808", "rank": "Strain"}, "1122130": {"name": "Jonesia quinghaiensis DSM 15701", "rank": "Strain"}, "1122137": {"name": "Kordiimonas gwangyangensis DSM 19435", "rank": "Strain"}, "1122135": {"name": "Kiloniella laminariae DSM 19542", "rank": "Strain"}, "1122134": {"name": "Kangiella aquimarina DSM 16071", "rank": "Strain"}, "701769": {"name": "PG1-like phages", "rank": "No rank"}, "1122139": {"name": "Kushneria aurantia DSM 21353", "rank": "Strain"}, "1122138": {"name": "Kribbella catacumbae DSM 19601", "rank": "Strain"}, "244589": {"name": "Sulfolobus spindle-shaped virus 1", "rank": "Species"}, "1248436": {"name": "Bacillus anthracis str. 3166", "rank": "Strain"}, "1248431": {"name": "Bacillus anthracis str. 3154", "rank": "Strain"}, "244581": {"name": "Candidatus Caedibacter acanthamoebae", "rank": "Species"}, "244582": {"name": "Candidatus Paracaedibacter symbiosus", "rank": "Species"}, "1248438": {"name": "Pseudomonas alcaliphila 34", "rank": "Strain"}, "223262": {"name": "East African cassava mosaic Cameroon virus", "rank": "Species"}, "392409": {"name": "Sphingomonas jaspsi", "rank": "Species"}, "286130": {"name": "Sulfuricurvum", "rank": "Genus"}, "223264": {"name": "East African cassava mosaic Malawi virus", "rank": "Species"}, "10464": {"name": "Agrotis segetum granulovirus", "rank": "Species"}, "1415758": {"name": "Streptococcus pseudopneumoniae G42", "rank": "Strain"}, "1415759": {"name": "Streptococcus pseudopneumoniae 22725", "rank": "Strain"}, "10468": {"name": "Helicoverpa zea single nucleopolyhedrovirus", "rank": "Species"}, "1415754": {"name": "Marinobacter sp. MCTG268", "rank": "Species"}, "1415755": {"name": "Halomonas sp. TG39a", "rank": "Species"}, "1123242": {"name": "Schlesneria paludicola DSM 18645", "rank": "Strain"}, "454286": {"name": "Coccidioides immitis RMSCC 3703", "rank": "Strain"}, "1182553": {"name": "Cladophialophora psammophila", "rank": "Species"}, "1173779": {"name": "Salmonella enterica subsp. diarizonae serovar 60:r:e,n,x,z15", "rank": "Strain"}, "1121374": {"name": "Dasania marina DSM 21967", "rank": "Strain"}, "1121375": {"name": "Deefgea rivuli DSM 18356", "rank": "Strain"}, "1121377": {"name": "Deinococcus apachensis DSM 19763", "rank": "Strain"}, "1121370": {"name": "Corynebacterium ulceribovis DSM 45146", "rank": "Strain"}, "1121372": {"name": "Gryllotalpicola ginsengisoli DSM 22003", "rank": "Strain"}, "1121373": {"name": "Cytophaga aurantiaca DSM 3654", "rank": "Strain"}, "57609": {"name": "Unclassified Xanthomonadaceae (miscellaneous)", "rank": "No rank"}, "1121378": {"name": "Deinococcus aquatilis DSM 23025", "rank": "Strain"}, "1121379": {"name": "Deinococcus ficus DSM 19119", "rank": "Strain"}, "1510155": {"name": "Falconid herpesvirus 1", "rank": "Species"}, "515178": {"name": "Sapovirus GIII", "rank": "Strain"}, "696855": {"name": "Nebovirus", "rank": "Genus"}, "696856": {"name": "Newbury-1 virus", "rank": "Species"}, "1348114": {"name": "Pseudoalteromonas sp. OCN003", "rank": "Species"}, "412614": {"name": "Vibrio cholerae 2740-80", "rank": "Strain"}, "696859": {"name": "Murine mastadenovirus C", "rank": "Species"}, "515177": {"name": "Sapovirus GII", "rank": "Strain"}, "1345532": {"name": "Helicobacter pylori SA252C", "rank": "Strain"}, "1345533": {"name": "Helicobacter pylori SA45A", "rank": "Strain"}, "1345530": {"name": "Helicobacter pylori SA251C", "rank": "Strain"}, "1345531": {"name": "Helicobacter pylori SA252A", "rank": "Strain"}, "1345536": {"name": "Helicobacter pylori SA46C", "rank": "Strain"}, "1345537": {"name": "Helicobacter pylori SA47A", "rank": "Strain"}, "1345534": {"name": "Helicobacter pylori SA45C", "rank": "Strain"}, "1345535": {"name": "Helicobacter pylori SA46A", "rank": "Strain"}, "376170": {"name": "Haloplanus", "rank": "Genus"}, "376171": {"name": "Haloplanus natans", "rank": "Species"}, "568703": {"name": "Lactobacillus rhamnosus GG", "rank": "Strain"}, "1287264": {"name": "Mesorhizobium sp. LNJC380A00", "rank": "Species"}, "274584": {"name": "Thielaviopsis basicola mitovirus", "rank": "Species"}, "508770": {"name": "Sciscionella marina", "rank": "Species"}, "1287268": {"name": "Mesorhizobium sp. LNJC384A00", "rank": "Species"}, "266854": {"name": "Granulicoccus phenolivorans", "rank": "Species"}, "12916": {"name": "Acidovorax", "rank": "Genus"}, "12914": {"name": "Acidianus", "rank": "Genus"}, "1073570": {"name": "Streptococcus thermophilus MTCC 5461", "rank": "Strain"}, "1073574": {"name": "Gordonia araii NBRC 100433", "rank": "Strain"}, "29510": {"name": "Turneriella parva", "rank": "Species"}, "29511": {"name": "Leptospira wolbachii", "rank": "Species"}, "1181738": {"name": "Escherichia coli KTE192", "rank": "Strain"}, "1181739": {"name": "Escherichia coli KTE193", "rank": "Strain"}, "1181736": {"name": "Escherichia coli KTE190", "rank": "Strain"}, "1181737": {"name": "Escherichia coli KTE191", "rank": "Strain"}, "1181734": {"name": "Escherichia coli KTE188", "rank": "Strain"}, "1181735": {"name": "Escherichia coli KTE189", "rank": "Strain"}, "1181732": {"name": "Escherichia coli KTE186", "rank": "Strain"}, "1181733": {"name": "Escherichia coli KTE187", "rank": "Strain"}, "1181730": {"name": "Escherichia coli KTE184", "rank": "Strain"}, "1181731": {"name": "Escherichia coli KTE185", "rank": "Strain"}, "207830": {"name": "Mamestra configurata nucleopolyhedrovirus A", "rank": "Species"}, "1281031": {"name": "Escherichia coli HVH 95 (4-6074464)", "rank": "Strain"}, "1354676": {"name": "Coxiella burnetii Cb185", "rank": "Strain"}, "1167009": {"name": "Aggregatibacter actinomycetemcomitans serotype b str. SCC4092", "rank": "Strain"}, "745017": {"name": "Salmonella enterica subsp. enterica serovar Montevideo str. 495297-1", "rank": "Strain"}, "745016": {"name": "Salmonella enterica subsp. enterica serovar Montevideo str. 316111868", "rank": "Strain"}, "745015": {"name": "Salmonella enterica subsp. enterica serovar Montevideo str. 315996572", "rank": "Strain"}, "745014": {"name": "Gamma proteobacterium HIMB55", "rank": "Species"}, "1310743": {"name": "Acinetobacter baumannii 1264936", "rank": "Strain"}, "745019": {"name": "Salmonella enterica subsp. enterica serovar Montevideo str. 495297-4", "rank": "Strain"}, "745018": {"name": "Salmonella enterica subsp. enterica serovar Montevideo str. 495297-3", "rank": "Strain"}, "175304": {"name": "Lentibacillus", "rank": "Genus"}, "1438698": {"name": "Klebsiella pneumoniae BIDMC 55", "rank": "Strain"}, "1438699": {"name": "Klebsiella pneumoniae BIDMC 60", "rank": "Strain"}, "1388649": {"name": "Staphylococcus aureus M0873", "rank": "Strain"}, "1388648": {"name": "Staphylococcus aureus M0872", "rank": "Strain"}, "1388647": {"name": "Staphylococcus aureus M0870", "rank": "Strain"}, "1388646": {"name": "Staphylococcus aureus M0869", "rank": "Strain"}, "1388645": {"name": "Staphylococcus aureus M0868", "rank": "Strain"}, "1388644": {"name": "Staphylococcus aureus M0867", "rank": "Strain"}, "1388643": {"name": "Staphylococcus aureus M0866", "rank": "Strain"}, "1388642": {"name": "Staphylococcus aureus M0865", "rank": "Strain"}, "1388641": {"name": "Staphylococcus aureus M0864", "rank": "Strain"}, "1388640": {"name": "Staphylococcus aureus M0863", "rank": "Strain"}, "1169332": {"name": "Escherichia coli KTE12", "rank": "Strain"}, "1169333": {"name": "Escherichia coli KTE14", "rank": "Strain"}, "162027": {"name": "Haliangium", "rank": "Genus"}, "323097": {"name": "Nitrobacter hamburgensis X14", "rank": "Strain"}, "658655": {"name": "Lachnospiraceae bacterium 1_4_56FAA", "rank": "Species"}, "658656": {"name": "Lachnospiraceae bacterium 6_1_37FAA", "rank": "Species"}, "658657": {"name": "Erysipelotrichaceae bacterium 21_3", "rank": "Species"}, "658659": {"name": "Erysipelotrichaceae bacterium 3_1_53", "rank": "Species"}, "323098": {"name": "Nitrobacter winogradskyi Nb-255", "rank": "Strain"}, "1299334": {"name": "Mycobacterium xenopi 4042", "rank": "Strain"}, "1299332": {"name": "Mycobacterium ulcerans str. Harvey", "rank": "Strain"}, "1299333": {"name": "Mycobacterium xenopi 3993", "rank": "Strain"}, "1299330": {"name": "Mycobacterium avium subsp. avium 2285 (R)", "rank": "Strain"}, "1299331": {"name": "Mycobacterium intracellulare 1956", "rank": "Strain"}, "91625": {"name": "Umbelopsis isabellina", "rank": "Species"}, "35593": {"name": "Peanut chlorotic streak virus", "rank": "Species"}, "1227360": {"name": "Viridibacillus arenosi FSL R5-213", "rank": "Strain"}, "1227363": {"name": "Lactobacillus saerimneri 30a", "rank": "Strain"}, "1422272": {"name": "Staphylococcus aureus DAR2026", "rank": "Strain"}, "1484693": {"name": "Rhodoferax saidenbachensis", "rank": "Species"}, "65058": {"name": "Corynebacterium ulcerans", "rank": "Species"}, "265976": {"name": "Serinicoccus", "rank": "Genus"}, "714961": {"name": "Lysinibacillus fusiformis ZC1", "rank": "Strain"}, "178901": {"name": "Acetobacter malorum", "rank": "Species"}, "714962": {"name": "Escherichia coli IHE3034", "rank": "Strain"}, "116085": {"name": "Coprococcus catus", "rank": "Species"}, "116089": {"name": "Lactobacillus psittaci", "rank": "Species"}, "1172567": {"name": "Streptomyces globisporus C-1027", "rank": "Strain"}, "1172566": {"name": "Natrinema sp. J7-1", "rank": "Species"}, "1172562": {"name": "Helicobacter cinaedi PAGU611", "rank": "Strain"}, "115991": {"name": "Enterobacteria phage RB43", "rank": "Species"}, "115992": {"name": "Vibrio phage nt-1", "rank": "Species"}, "1735": {"name": "Holdemanella biformis", "rank": "Species"}, "1736": {"name": "Eubacterium limosum", "rank": "Species"}, "1731": {"name": "Eubacterium acidaminophilum", "rank": "Species"}, "1730": {"name": "Eubacterium", "rank": "Genus"}, "991919": {"name": "Escherichia coli O145:NM", "rank": "Strain"}, "1434930": {"name": "Burkholderia pseudomallei MSHR7334", "rank": "Strain"}, "991910": {"name": "Escherichia coli O111:H8", "rank": "Strain"}, "991913": {"name": "Escherichia coli O103:H25", "rank": "Strain"}, "991915": {"name": "Escherichia coli O121:H19", "rank": "Strain"}, "572478": {"name": "Vulcanisaeta distributa DSM 14429", "rank": "Strain"}, "1409645": {"name": "Staphylococcus aureus SMMC6121", "rank": "Strain"}, "1116027": {"name": "Escherichia coli 2866350", "rank": "Strain"}, "1138884": {"name": "Enterococcus faecium EnGen0013", "rank": "Strain"}, "1138885": {"name": "Enterococcus faecium EnGen0014", "rank": "Strain"}, "1138886": {"name": "Enterococcus faecium EnGen0019", "rank": "Strain"}, "1138887": {"name": "Enterococcus faecium EnGen0008", "rank": "Strain"}, "1138880": {"name": "Enterococcus faecium EnGen0005", "rank": "Strain"}, "1138881": {"name": "Enterococcus faecium EnGen0012", "rank": "Strain"}, "1138882": {"name": "Enterococcus faecium EnGen0010", "rank": "Strain"}, "1138883": {"name": "Enterococcus faecium EnGen0022", "rank": "Strain"}, "189831": {"name": "Unclassified Adenoviridae", "rank": "No rank"}, "189830": {"name": "Snake adenovirus 1", "rank": "Strain"}, "1138888": {"name": "Enterococcus faecium EnGen0015", "rank": "Strain"}, "1138889": {"name": "Enterococcus faecium EnGen0017", "rank": "Strain"}, "1157348": {"name": "Enterococcus faecalis EnGen0110", "rank": "Strain"}, "1157349": {"name": "Enterococcus faecalis EnGen0091", "rank": "Strain"}, "1157344": {"name": "Enterococcus faecalis EnGen0120", "rank": "Strain"}, "1157345": {"name": "Enterococcus faecalis EnGen0089", "rank": "Strain"}, "1157346": {"name": "Enterococcus faecalis EnGen0090", "rank": "Strain"}, "1157347": {"name": "Enterococcus faecalis EnGen0109", "rank": "Strain"}, "1157342": {"name": "Enterococcus faecalis EnGen0106", "rank": "Strain"}, "1157343": {"name": "Enterococcus faecalis EnGen0088", "rank": "Strain"}, "2071": {"name": "Saccharothrix", "rank": "Genus"}, "2070": {"name": "Pseudonocardiaceae", "rank": "Family"}, "2077": {"name": "Sporolactobacillus", "rank": "Genus"}, "2074": {"name": "Pseudonocardia autotrophica", "rank": "Species"}, "1115807": {"name": "Enterococcus faecalis E12", "rank": "Strain"}, "1548151": {"name": "Helicobacter sp. MIT 11-5569", "rank": "Species"}, "1548153": {"name": "Campylobacter sp. MIT 97-5078", "rank": "Species"}, "1548152": {"name": "Helicobacter sp. MIT 09-6949", "rank": "Species"}, "1221274": {"name": "Acinetobacter baumannii AB_TG2018", "rank": "Strain"}, "1221275": {"name": "Acinetobacter baumannii AB_TG2022", "rank": "Strain"}, "1221276": {"name": "Acinetobacter baumannii AB_TG2023", "rank": "Strain"}, "1221270": {"name": "Acinetobacter baumannii AB_909-02-7", "rank": "Strain"}, "1221271": {"name": "Acinetobacter baumannii AB_909-05", "rank": "Strain"}, "1221273": {"name": "Acinetobacter baumannii AB_TG19617", "rank": "Strain"}, "1221278": {"name": "Acinetobacter baumannii AB_TG2028", "rank": "Strain"}, "1221279": {"name": "Acinetobacter baumannii AB_TG2030", "rank": "Strain"}, "83618": {"name": "Pseudoxanthomonas", "rank": "Genus"}, "83615": {"name": "Luteimonas mephitis", "rank": "Species"}, "83614": {"name": "Luteimonas", "rank": "Genus"}, "1353276": {"name": "Olleya marilimosa CAM030", "rank": "Strain"}, "83612": {"name": "Psychroflexus", "rank": "Genus"}, "1353275": {"name": "Mycobacterium abscessus V06705", "rank": "Strain"}, "46021": {"name": "Paramecium bursaria Chlorella virus NY2A", "rank": "Species"}, "755272": {"name": "Micromonas pusilla virus 12T", "rank": "Species"}, "888824": {"name": "Streptococcus sanguinis SK1087", "rank": "Strain"}, "888825": {"name": "Streptococcus sanguinis VMC66", "rank": "Strain"}, "888826": {"name": "Campylobacter upsaliensis JV21", "rank": "Strain"}, "888827": {"name": "Arcobacter butzleri JV22", "rank": "Strain"}, "888820": {"name": "Streptococcus sanguinis SK1056", "rank": "Strain"}, "888821": {"name": "Streptococcus sanguinis SK1057", "rank": "Strain"}, "888822": {"name": "Streptococcus sanguinis SK1058", "rank": "Strain"}, "888823": {"name": "Streptococcus sanguinis SK1059", "rank": "Strain"}, "888828": {"name": "Haemophilus parainfluenzae ATCC 33392", "rank": "Strain"}, "1307761": {"name": "Salinispira pacifica", "rank": "Species"}, "425279": {"name": "Rehmannia mosaic virus", "rank": "Species"}, "1324404": {"name": "Leptospira broomii serovar Hurstbridge", "rank": "Strain"}, "1520332": {"name": "Blueberry mosaic associated virus", "rank": "Species"}, "992003": {"name": "Vibrio cholerae HC-47A1", "rank": "Strain"}, "1032869": {"name": "Pasteurella multocida subsp. multocida str. Anand1_goat", "rank": "Strain"}, "256618": {"name": "Parvibaculum lavamentivorans", "rank": "Species"}, "256616": {"name": "Parvibaculum", "rank": "Genus"}, "551788": {"name": "Caldicoprobacter oshimai", "rank": "Species"}, "269277": {"name": "Squash leaf curl Philippines virus", "rank": "Species"}, "1476390": {"name": "Pseudomonas phage vB_PaeS_SCH_Ab26", "rank": "Species"}, "353212": {"name": "Mammalian gammaretrovirus group", "rank": "No rank"}, "353210": {"name": "Replication competent viruses", "rank": "No rank"}, "1071969": {"name": "Yersinia enterocolitica subsp. palearctica PhRBD_Ye1", "rank": "Strain"}, "1498500": {"name": "Halorubrum sp. BV1", "rank": "Species"}, "1165933": {"name": "Rhodosporidium toruloides MTCC 457", "rank": "Strain"}, "1049782": {"name": "Leptospira borgpetersenii str. UI 09149", "rank": "Strain"}, "1300225": {"name": "Agrobacterium tumefaciens WRT31", "rank": "Strain"}, "1300224": {"name": "Agrobacterium tumefaciens P4", "rank": "Strain"}, "908124": {"name": "Okra leaf curl India virus India:Sonipat EL14A:2006", "rank": "Strain"}, "908125": {"name": "Okra enation leaf curl virus", "rank": "Species"}, "908123": {"name": "Okra leaf curl India virus", "rank": "Species"}, "1300223": {"name": "Lactobacillus rhamnosus K32", "rank": "Strain"}, "1300222": {"name": "Brevibacillus borstelensis AK1", "rank": "Strain"}, "1291329": {"name": "Leptospira interrogans serovar Copenhageni str. 200701182", "rank": "Strain"}, "1291328": {"name": "Leptospira interrogans serovar Copenhageni str. Fiocruz LV4152", "rank": "Strain"}, "1400891": {"name": "Mycobacterium tuberculosis KT-0035", "rank": "Strain"}, "1400897": {"name": "Mycobacterium tuberculosis KT-0045", "rank": "Strain"}, "285679": {"name": "Micromonospora lupini", "rank": "Species"}, "1400895": {"name": "Mycobacterium tuberculosis KT-0043", "rank": "Strain"}, "1400894": {"name": "Mycobacterium tuberculosis KT-0041", "rank": "Strain"}, "1291321": {"name": "Leptospira interrogans serovar Copenhageni str. Fiocruz LV256", "rank": "Strain"}, "1291320": {"name": "Leptospira interrogans serovar Copenhageni str. P2431", "rank": "Strain"}, "1400899": {"name": "Mycobacterium tuberculosis KT-0048", "rank": "Strain"}, "1400898": {"name": "Mycobacterium tuberculosis KT-0047", "rank": "Strain"}, "1291325": {"name": "Leptospira interrogans serovar Copenhageni str. Fiocruz LV4108", "rank": "Strain"}, "1291324": {"name": "Leptospira interrogans serovar Copenhageni str. Fiocruz LV237", "rank": "Strain"}, "1291327": {"name": "Leptospira interrogans serovar Copenhageni str. Fiocruz LV4118", "rank": "Strain"}, "1291326": {"name": "Leptospira interrogans serovar Copenhageni str. Fiocruz LV4113", "rank": "Strain"}, "996640": {"name": "Paenibacillus sp. ICGEB2008", "rank": "Species"}, "398720": {"name": "Leeuwenhoekiella blandensis MED217", "rank": "Strain"}, "1104641": {"name": "Marinimicrobia bacterium JGI 0000077-B04", "rank": "Species"}, "224308": {"name": "Bacillus subtilis subsp. subtilis str. 168", "rank": "Strain"}, "290336": {"name": "Klebsiella oxytoca M5al", "rank": "Strain"}, "741277": {"name": "Fischerella sp. JSC-11", "rank": "Species"}, "42680": {"name": "Spinach latent virus", "rank": "Species"}, "741275": {"name": "Punctularia strigosozonata HHB-11173 SS5", "rank": "Strain"}, "290338": {"name": "Citrobacter koseri ATCC BAA-895", "rank": "Strain"}, "375477": {"name": "Exiguobacterium sp. NG55", "rank": "Species"}, "76123": {"name": "Prevotella enoeca", "rank": "Species"}, "76122": {"name": "Alloprevotella tannerae", "rank": "Species"}, "943908": {"name": "Human polyomavirus 9", "rank": "Species"}, "666475": {"name": "Pseudomonas syringae pv. aesculi str. 2250", "rank": "Strain"}, "1398004": {"name": "Staphylococcus aureus M1379", "rank": "Strain"}, "1398005": {"name": "Staphylococcus aureus M1380", "rank": "Strain"}, "1398006": {"name": "Staphylococcus aureus M1382", "rank": "Strain"}, "1398007": {"name": "Staphylococcus aureus M1383", "rank": "Strain"}, "1398000": {"name": "Staphylococcus aureus M1371", "rank": "Strain"}, "1398001": {"name": "Staphylococcus aureus M1372", "rank": "Strain"}, "1398002": {"name": "Staphylococcus aureus M1377", "rank": "Strain"}, "1398003": {"name": "Staphylococcus aureus M1378", "rank": "Strain"}, "1398008": {"name": "Staphylococcus aureus M1384", "rank": "Strain"}, "1398009": {"name": "Staphylococcus aureus M1385", "rank": "Strain"}, "91613": {"name": "Colombian datura virus", "rank": "Species"}, "1406816": {"name": "Zucchini tigre mosaic virus", "rank": "Species"}, "992033": {"name": "Helicobacter pylori Hp A-5", "rank": "Strain"}, "992032": {"name": "Helicobacter pylori Hp A-4", "rank": "Strain"}, "992031": {"name": "Helicobacter pylori NQ4110", "rank": "Strain"}, "992030": {"name": "Helicobacter pylori NQ4161", "rank": "Strain"}, "992037": {"name": "Helicobacter pylori Hp A-20", "rank": "Strain"}, "992036": {"name": "Helicobacter pylori Hp A-17", "rank": "Strain"}, "992035": {"name": "Helicobacter pylori Hp A-11", "rank": "Strain"}, "992034": {"name": "Helicobacter pylori Hp A-9", "rank": "Strain"}, "1552123": {"name": "Listeriaceae bacterium FSL A5-0281", "rank": "Species"}, "1049795": {"name": "Leptospira interrogans serovar Autumnalis str. LP101", "rank": "Strain"}, "992038": {"name": "Helicobacter pylori Hp H-16", "rank": "Strain"}, "1049790": {"name": "Leptospira inadai serovar Lyme str. 10", "rank": "Strain"}, "190304": {"name": "Fusobacterium nucleatum subsp. nucleatum ATCC 25586", "rank": "Strain"}, "1159029": {"name": "Helicobacter pylori GAM120Ai", "rank": "Strain"}, "999410": {"name": "Clostridium clostridioforme CM201", "rank": "Strain"}, "999411": {"name": "Clostridium colicanis 209318", "rank": "Strain"}, "999412": {"name": "Clostridium hathewayi 12489931", "rank": "Strain"}, "999413": {"name": "Clostridium innocuum 2959", "rank": "Strain"}, "999414": {"name": "Fusobacterium nucleatum subsp. animalis F0419", "rank": "Strain"}, "999415": {"name": "Eggerthia catenaformis OT 569 = DSM 20559", "rank": "Strain"}, "999416": {"name": "Parabacteroides distasonis CL03T12C09", "rank": "Strain"}, "72759": {"name": "Staphylococcus aureus subsp. anaerobius", "rank": "Subspecies"}, "999418": {"name": "Parabacteroides goldsteinii CL02T12C30", "rank": "Strain"}, "999419": {"name": "Parabacteroides johnsonii CL02T12C29", "rank": "Strain"}, "72750": {"name": "Beet pseudoyellows virus", "rank": "Species"}, "47863": {"name": "Micromonospora globosa", "rank": "Species"}, "1149862": {"name": "Pelosinus fermentans B4", "rank": "Strain"}, "1149860": {"name": "Pelosinus fermentans A11", "rank": "Strain"}, "1149866": {"name": "New World begomovirus associated satellite DNA", "rank": "Species"}, "981329": {"name": "Acinetobacter baumannii W7282", "rank": "Strain"}, "1338031": {"name": "Vibrio parahaemolyticus O1:K33", "rank": "Strain"}, "117541": {"name": "Salmonella enterica subsp. enterica serovar Ohio", "rank": "Strain"}, "487899": {"name": "Xanthomonas campestris pv. viticola", "rank": "Strain"}, "40070": {"name": "Unclassified Chordopoxvirinae", "rank": "No rank"}, "197162": {"name": "Deferribacter desulfuricans", "rank": "Species"}, "981323": {"name": "Gordonia phage GTE2", "rank": "Species"}, "984307": {"name": "Burkholderia kururiensis", "rank": "Species"}, "1329856": {"name": "Enterobacter cloacae UCICRE 12", "rank": "Strain"}, "547558": {"name": "Methanohalophilus mahii DSM 5219", "rank": "Strain"}, "547559": {"name": "Natrialba magadii ATCC 43099", "rank": "Strain"}, "232348": {"name": "Synechococcus sp. CB0101", "rank": "Species"}, "981327": {"name": "Acinetobacter lwoffii NCTC 5866 = CIP 64.10", "rank": "Strain"}, "1068980": {"name": "Amycolatopsis nigrescens CSC17Ta-90", "rank": "Strain"}, "981326": {"name": "Acinetobacter pittii DSM 21653", "rank": "Strain"}, "1260358": {"name": "Enterococcus faecalis 06-MB-DW-09", "rank": "Strain"}, "1260359": {"name": "Enterococcus faecalis 06-MB-S-04", "rank": "Strain"}, "1570301": {"name": "Aureobasidiaceae", "rank": "Family"}, "1429904": {"name": "Mycobacterium phage HanShotFirst", "rank": "Species"}, "1429905": {"name": "Mycobacterium phage JAMaL", "rank": "Species"}, "981324": {"name": "Acinetobacter bereziniae LMG 1003", "rank": "Strain"}, "1260355": {"name": "Enterococcus faecalis 20-SD-BW-08", "rank": "Strain"}, "1260356": {"name": "Enterococcus faecalis 13-SD-W-01", "rank": "Strain"}, "1260357": {"name": "Enterococcus faecalis F01966", "rank": "Strain"}, "1410774": {"name": "Staphylococcus aureus T47181", "rank": "Strain"}, "582899": {"name": "Hyphomicrobium denitrificans ATCC 51888", "rank": "Strain"}, "215689": {"name": "Erwinia sp. Ejp617", "rank": "Species"}, "1161132": {"name": "Rabbit astrovirus TN/2208/2010", "rank": "Species"}, "1310772": {"name": "Acinetobacter baumannii 1130196", "rank": "Strain"}, "1310773": {"name": "Acinetobacter baumannii 883425", "rank": "Strain"}, "1310770": {"name": "Acinetobacter baumannii 1295549", "rank": "Strain"}, "1310771": {"name": "Acinetobacter baumannii 1058283", "rank": "Strain"}, "1310776": {"name": "Acinetobacter baumannii 1413735", "rank": "Strain"}, "1310777": {"name": "Acinetobacter baumannii 1262761-97", "rank": "Strain"}, "1310774": {"name": "Acinetobacter baumannii 1232509", "rank": "Strain"}, "1310775": {"name": "Acinetobacter baumannii 1392509", "rank": "Strain"}, "1169327": {"name": "Escherichia coli KTE6", "rank": "Strain"}, "1169326": {"name": "Escherichia coli KTE5", "rank": "Strain"}, "1310778": {"name": "Acinetobacter baumannii 426863", "rank": "Strain"}, "1310779": {"name": "Acinetobacter baumannii 1424608", "rank": "Strain"}, "1169323": {"name": "Escherichia coli KTE231", "rank": "Strain"}, "1169322": {"name": "Citrobacter sp. KTE151", "rank": "Species"}, "1169321": {"name": "Escherichia sp. KTE114", "rank": "Species"}, "1169320": {"name": "Escherichia coli KTE35", "rank": "Strain"}, "1408958": {"name": "Mycobacterium tuberculosis UT0094", "rank": "Strain"}, "1408959": {"name": "Mycobacterium tuberculosis UT0096", "rank": "Strain"}, "1235689": {"name": "Pseudomonas phage AF", "rank": "Species"}, "1408952": {"name": "Mycobacterium tuberculosis UT0088", "rank": "Strain"}, "1408953": {"name": "Mycobacterium tuberculosis UT0089", "rank": "Strain"}, "1408950": {"name": "Mycobacterium tuberculosis UT0085", "rank": "Strain"}, "1408951": {"name": "Mycobacterium tuberculosis UT0087", "rank": "Strain"}, "1408956": {"name": "Mycobacterium tuberculosis UT0092", "rank": "Strain"}, "1408957": {"name": "Mycobacterium tuberculosis UT0093", "rank": "Strain"}, "1408954": {"name": "Mycobacterium tuberculosis UT0090", "rank": "Strain"}, "1408955": {"name": "Mycobacterium tuberculosis UT0091", "rank": "Strain"}, "1518149": {"name": "Thalassotalea", "rank": "Genus"}, "474186": {"name": "Enterococcus faecalis OG1RF", "rank": "Strain"}, "1427749": {"name": "Amycolatopsis sp. MJM2582", "rank": "Species"}, "186739": {"name": "Bartonella washoensis", "rank": "Species"}, "879567": {"name": "Desulfovibrio piezophilus", "rank": "Species"}, "1287065": {"name": "Helicobacter pylori UM045", "rank": "Strain"}, "1446612": {"name": "Escherichia coli O157:H7 str. 07-3391", "rank": "Strain"}, "1446611": {"name": "Escherichia coli O157:H7 str. 07-3091", "rank": "Strain"}, "1446610": {"name": "Escherichia coli O157:H7 str. 06-4039", "rank": "Strain"}, "1446617": {"name": "Escherichia coli O157:H7 str. 2009C-4258", "rank": "Strain"}, "1446616": {"name": "Escherichia coli O157:H7 str. 08-4529", "rank": "Strain"}, "1446615": {"name": "Escherichia coli O157:H7 str. 08-4169", "rank": "Strain"}, "1446614": {"name": "Escherichia coli O157:H7 str. 08-3527", "rank": "Strain"}, "115780": {"name": "Desulfotignum", "rank": "Genus"}, "115781": {"name": "Desulfotignum balticum", "rank": "Species"}, "1446619": {"name": "Escherichia coli O157:H7 str. 2009EL1705", "rank": "Strain"}, "1446618": {"name": "Escherichia coli O157:H7 str. 2009EL1449", "rank": "Strain"}, "115784": {"name": "Phaffomycetaceae", "rank": "Family"}, "491205": {"name": "Chryseobacterium hispalense DSM 25574", "rank": "Strain"}, "1175631": {"name": "Pectobacterium wasabiae CFBP 3304", "rank": "Strain"}, "1175632": {"name": "Mycobacterium abscessus M139", "rank": "Strain"}, "1175633": {"name": "Mycobacterium abscessus M148", "rank": "Strain"}, "103603": {"name": "Snakehead virus", "rank": "Species"}, "1388526": {"name": "Staphylococcus aureus M0418", "rank": "Strain"}, "1388527": {"name": "Staphylococcus aureus M0432", "rank": "Strain"}, "1388524": {"name": "Staphylococcus aureus M0395", "rank": "Strain"}, "1388525": {"name": "Staphylococcus aureus M0407", "rank": "Strain"}, "1388522": {"name": "Staphylococcus aureus M0371", "rank": "Strain"}, "1388523": {"name": "Staphylococcus aureus M0379", "rank": "Strain"}, "1388520": {"name": "Staphylococcus aureus M0608", "rank": "Strain"}, "1388521": {"name": "Staphylococcus aureus M0620", "rank": "Strain"}, "1388528": {"name": "Staphylococcus aureus M0443", "rank": "Strain"}, "1388529": {"name": "Staphylococcus aureus M0456", "rank": "Strain"}, "687860": {"name": "Salmonella enterica subsp. enterica serovar Dublin str. HWS51", "rank": "Strain"}, "76947": {"name": "Sphingobium herbicidovorans", "rank": "Species"}, "43357": {"name": "Kutzneria albida", "rank": "Species"}, "43354": {"name": "Prauserella rugosa", "rank": "Species"}, "43353": {"name": "Xanthomonas axonopodis pv. manihotis", "rank": "Strain"}, "1163408": {"name": "Rhodanobacter fulvus Jip2", "rank": "Strain"}, "1163409": {"name": "Rhodanobacter thiooxydans LCS2", "rank": "Strain"}, "1163407": {"name": "Rhodanobacter spathiphylli B39", "rank": "Strain"}, "1219626": {"name": "Peptostreptococcus sp. MV1", "rank": "Species"}, "10990": {"name": "Rice black streaked dwarf virus", "rank": "Species"}, "10991": {"name": "Rice dwarf virus", "rank": "Species"}, "10992": {"name": "Oryzavirus", "rank": "Genus"}, "10993": {"name": "Birnaviridae", "rank": "Family"}, "10995": {"name": "Infectious bursal disease virus", "rank": "Species"}, "183916": {"name": "Actinomyces vaccimaxillae", "rank": "Species"}, "1195236": {"name": "Clostridium termitidis CT1112", "rank": "Strain"}, "1195237": {"name": "Mycobacterium bovis BCG str. Frappier", "rank": "Strain"}, "49012": {"name": "Sporisorium scitamineum", "rank": "Species"}, "646010": {"name": "Suakwa aphid-borne yellows virus", "rank": "Species"}, "1191522": {"name": "Vibrio harveyi ZJ0603", "rank": "Strain"}, "1191523": {"name": "Melioribacter roseus P3M-2", "rank": "Strain"}, "311231": {"name": "Burkholderia ginsengisoli", "rank": "Species"}, "1434159": {"name": "Shigella flexneri 2001042", "rank": "Strain"}, "1434158": {"name": "Shigella flexneri 2001004", "rank": "Strain"}, "1434155": {"name": "Shigella flexneri 1997005", "rank": "Strain"}, "1434154": {"name": "Shigella flexneri 51581", "rank": "Strain"}, "1434157": {"name": "Shigella flexneri 2001020", "rank": "Strain"}, "1434156": {"name": "Shigella flexneri 2000019", "rank": "Strain"}, "1434151": {"name": "Shigella flexneri 51575", "rank": "Strain"}, "1434150": {"name": "Shigella flexneri 2002007", "rank": "Strain"}, "1434153": {"name": "Shigella flexneri 51577", "rank": "Strain"}, "1434152": {"name": "Shigella flexneri 51576", "rank": "Strain"}, "10662": {"name": "Myoviridae", "rank": "Family"}, "10663": {"name": "T4likevirus", "rank": "Genus"}, "10660": {"name": "Corticovirus", "rank": "Genus"}, "10661": {"name": "Pseudoalteromonas phage PM2", "rank": "Species"}, "10665": {"name": "Enterobacteria phage T4", "rank": "Strain"}, "563045": {"name": "Comamonas testosteroni S44", "rank": "Strain"}, "563040": {"name": "Sulfurimonas autotrophica DSM 16294", "rank": "Strain"}, "563041": {"name": "Helicobacter pylori G27", "rank": "Strain"}, "1413357": {"name": "Staphylococcus aureus 10S00488", "rank": "Strain"}, "1413350": {"name": "Staphylococcus aureus 07-03450", "rank": "Strain"}, "1398154": {"name": "Sporothrix brasiliensis 5110", "rank": "Strain"}, "39960": {"name": "Erythrobacter litoralis", "rank": "Species"}, "39962": {"name": "Legionella moravica", "rank": "Species"}, "42005": {"name": "Porcine hemagglutinating encephalomyelitis virus", "rank": "Strain"}, "1413352": {"name": "Staphylococcus aureus 08-01084", "rank": "Strain"}, "1413353": {"name": "Staphylococcus aureus 08-01085", "rank": "Strain"}, "252583": {"name": "Vibrio ezurae", "rank": "Species"}, "1173757": {"name": "Salmonella phage FSL SP-088", "rank": "Species"}, "429009": {"name": "Ammonifex degensii KC4", "rank": "Strain"}, "1155718": {"name": "Streptomyces sp. MspMP-M5", "rank": "Species"}, "442346": {"name": "Francisella tularensis subsp. novicida GA99-3548", "rank": "Strain"}, "1413358": {"name": "Staphylococcus aureus 10S01493", "rank": "Strain"}, "1155715": {"name": "Streptomyces sp. CcalMP-8W", "rank": "Species"}, "1155714": {"name": "Streptomyces sp. LaPpAH-108", "rank": "Species"}, "1155717": {"name": "Streptomyces sp. DvalAA-83", "rank": "Species"}, "1095641": {"name": "Vibrio cholerae O1 str. EDC-022", "rank": "Strain"}, "1090319": {"name": "Sphingomonas phyllosphaerae FA2", "rank": "Strain"}, "1090318": {"name": "Sphingomonas phyllosphaerae 5.2", "rank": "Strain"}, "252584": {"name": "Pieris rapae granulovirus", "rank": "Species"}, "463392": {"name": "Black raspberry virus F", "rank": "Species"}, "1090317": {"name": "Sphingomonas melonis FR1", "rank": "Strain"}, "1090316": {"name": "Sphingomonas melonis C3", "rank": "Strain"}, "1426844": {"name": "Helicobacter pylori NY40", "rank": "Strain"}, "933388": {"name": "Penicillium oxalicum 114-2", "rank": "Strain"}, "1161915": {"name": "Ureaplasma urealyticum 2608", "rank": "Strain"}, "1161916": {"name": "Ureaplasma urealyticum 4155", "rank": "Strain"}, "1161917": {"name": "Ureaplasma urealyticum 4318", "rank": "Strain"}, "1161911": {"name": "Corynebacterium pseudotuberculosis Cp162", "rank": "Strain"}, "1161912": {"name": "Thermosipho africanus H17ap60334", "rank": "Strain"}, "1161918": {"name": "Brachyspira pilosicoli WesB", "rank": "Strain"}, "1505648": {"name": "Geobacillus thermoleovorans group", "rank": "Species group"}, "904313": {"name": "Staphylococcus aureus subsp. aureus VCU006", "rank": "Strain"}, "904315": {"name": "Staphylococcus epidermidis VCU013", "rank": "Strain"}, "904314": {"name": "Staphylococcus pettenkoferi VCU012", "rank": "Strain"}, "904317": {"name": "Staphylococcus epidermidis VCU028", "rank": "Strain"}, "760794": {"name": "Streptococcus pneumoniae GA18068", "rank": "Strain"}, "904319": {"name": "Staphylococcus epidermidis VCU037", "rank": "Strain"}, "904318": {"name": "Staphylococcus epidermidis VCU036", "rank": "Strain"}, "1154825": {"name": "Streptococcus agalactiae BSU450", "rank": "Strain"}, "604332": {"name": "Meiothermus rufus", "rank": "Species"}, "222557": {"name": "Macrobrachium rosenbergii nodavirus", "rank": "Species"}, "604331": {"name": "Meiothermus rufus DSM 22234", "rank": "Strain"}, "28229": {"name": "Colwellia psychrerythraea", "rank": "Species"}, "28228": {"name": "Colwellia", "rank": "Genus"}, "28224": {"name": "Mesoplasma seiffertii", "rank": "Species"}, "28227": {"name": "Mycoplasma penetrans", "rank": "Species"}, "28221": {"name": "Deltaproteobacteria", "rank": "Class"}, "28223": {"name": "Desulfobacula toluolica", "rank": "Species"}, "12627": {"name": "Cowpea mottle virus", "rank": "Species"}, "521095": {"name": "Atopobium parvulum DSM 20469", "rank": "Strain"}, "166974": {"name": "Lechevalieria", "rank": "Genus"}, "2279": {"name": "Staphylothermus", "rank": "Genus"}, "2275": {"name": "Desulfurococcus mucosus", "rank": "Species"}, "2277": {"name": "Pyrobaculum islandicum", "rank": "Species"}, "2276": {"name": "Pyrobaculum", "rank": "Genus"}, "2271": {"name": "Thermoproteus tenax", "rank": "Species"}, "2270": {"name": "Thermoproteus", "rank": "Genus"}, "2273": {"name": "Desulfurococcus", "rank": "Genus"}, "2272": {"name": "Desulfurococcaceae", "rank": "Family"}, "1444282": {"name": "Escherichia coli 6-319-05_S4_C3", "rank": "Strain"}, "1409693": {"name": "Staphylococcus aureus WAMC6108", "rank": "Strain"}, "1444280": {"name": "Escherichia coli 4-203-08_S4_C3", "rank": "Strain"}, "1444281": {"name": "Escherichia coli 6-175-07_S4_C3", "rank": "Strain"}, "1409696": {"name": "Staphylococcus aureus MISS6080", "rank": "Strain"}, "1409697": {"name": "Staphylococcus aureus WMCA6091", "rank": "Strain"}, "1409694": {"name": "Staphylococcus aureus OCMM6123", "rank": "Strain"}, "1409695": {"name": "Staphylococcus aureus UCIM6134", "rank": "Strain"}, "1444288": {"name": "Enterobacter sp. 5-4", "rank": "Species"}, "1409699": {"name": "Staphylococcus aureus WMCA6092", "rank": "Strain"}, "488537": {"name": "Clostridium perfringens D str. JGS1721", "rank": "Strain"}, "343516": {"name": "Escherichia phage phiV10", "rank": "Species"}, "343517": {"name": "Paenibacillus barengoltzii", "rank": "Species"}, "1330700": {"name": "Thermus caliditerrae", "rank": "Species"}, "488538": {"name": "Candidatus Puniceispirillum marinum IMCC1322", "rank": "Strain"}, "1229751": {"name": "Lactococcus phage BM13", "rank": "Species"}, "632292": {"name": "Caldicellulosiruptor hydrothermalis 108", "rank": "Strain"}, "1443889": {"name": "Rhodococcus fascians 02-816c", "rank": "Strain"}, "1443888": {"name": "Rhodococcus fascians 02-815", "rank": "Strain"}, "58343": {"name": "Streptomyces canus", "rank": "Species"}, "1270196": {"name": "Pedobacter sp. R20-19", "rank": "Species"}, "1270193": {"name": "Flavobacterium sp. KJJ", "rank": "Species"}, "133448": {"name": "Citrobacter youngae", "rank": "Species"}, "121871": {"name": "Haloterrigena", "rank": "Genus"}, "121872": {"name": "Haloterrigena thermotolerans", "rank": "Species"}, "10617": {"name": "Human papillomavirus type 4", "rank": "Strain"}, "119210": {"name": "H3N2 subtype", "rank": "Strain"}, "1462419": {"name": "Candidatus Iainarchaeum andersonii", "rank": "Species"}, "1462418": {"name": "Candidatus Iainarchaeum", "rank": "Genus"}, "1543381": {"name": "Xanthomonadaceae bacterium 3.5X", "rank": "Species"}, "1462416": {"name": "Candidatus Hydrogenedens terephthalicus", "rank": "Species"}, "1462415": {"name": "Candidatus Hydrogenedens", "rank": "Genus"}, "1123493": {"name": "Vibrio litoralis DSM 17657", "rank": "Strain"}, "553601": {"name": "Staphylococcus aureus A10102", "rank": "Strain"}, "1123490": {"name": "Veillonella montpellierensis DSM 17217", "rank": "Strain"}, "1123497": {"name": "Vibrio rhizosphaerae DSM 18581", "rank": "Strain"}, "1123494": {"name": "Vibrio pacinii DSM 19139", "rank": "Strain"}, "1226334": {"name": "Lactobacillus helveticus CIRM-BIA 951", "rank": "Strain"}, "1123499": {"name": "Vitreoscilla stercoraria DSM 513", "rank": "Strain"}, "192073": {"name": "Shewanella denitrificans", "rank": "Species"}, "1226115": {"name": "Klebsiella pneumoniae subsp. pneumoniae KpQ3", "rank": "Strain"}, "74152": {"name": "Elusimicrobia", "rank": "Phylum"}, "565052": {"name": "Tobacco yellow crinkle virus", "rank": "Species"}, "565050": {"name": "Caulobacter crescentus NA1000", "rank": "Strain"}, "579137": {"name": "Methanocaldococcus vulcanius M7", "rank": "Strain"}, "382245": {"name": "Aeromonas salmonicida subsp. salmonicida A449", "rank": "Strain"}, "1177191": {"name": "Grapevine geminivirus", "rank": "Species"}, "579138": {"name": "Zymomonas mobilis subsp. pomaceae ATCC 29192", "rank": "Strain"}, "936381": {"name": "Selenomonas sp. CM52", "rank": "Species"}, "208964": {"name": "Pseudomonas aeruginosa PAO1", "rank": "Strain"}, "208963": {"name": "Pseudomonas aeruginosa UCBPP-PA14", "rank": "Strain"}, "208962": {"name": "Escherichia albertii", "rank": "Species"}, "1205683": {"name": "Yersinia massiliensis CCUG 53443", "rank": "Strain"}, "1205681": {"name": "Bartonella rattaustraliani AUST/NH4", "rank": "Strain"}, "1205680": {"name": "Reyranella massiliensis 521", "rank": "Strain"}, "447106": {"name": "Leptospira licerasiae", "rank": "Species"}, "447107": {"name": "Leptospira licerasiae serovar Varillal", "rank": "Strain"}, "1341683": {"name": "Acinetobacter brisouii CIP 110357", "rank": "Strain"}, "1341684": {"name": "Brucella canis 04-2330-1", "rank": "Strain"}, "1341685": {"name": "Brucella canis 96-7258", "rank": "Strain"}, "1341686": {"name": "Brucella melitensis 02-5863-1", "rank": "Strain"}, "1341688": {"name": "Brucella sp. 04-5288", "rank": "Species"}, "89623": {"name": "Snow goose hepatitis B virus", "rank": "Strain"}, "220932": {"name": "Tomato leaf curl Karnataka virus", "rank": "Species"}, "393117": {"name": "Listeria monocytogenes FSL J1-194", "rank": "Strain"}, "1414720": {"name": "Clostridium sp. JCC", "rank": "Species"}, "1414721": {"name": "Clostridium sp. JCD", "rank": "Species"}, "663282": {"name": "Drosophila melanogaster totivirus SW-2009a", "rank": "Species"}, "1335626": {"name": "Middle East respiratory syndrome coronavirus", "rank": "Species"}, "453363": {"name": "Streptococcus pneumoniae SP195", "rank": "Strain"}, "453362": {"name": "Streptococcus pneumoniae CDC1873-00", "rank": "Strain"}, "453361": {"name": "Streptococcus pneumoniae CDC1087-00", "rank": "Strain"}, "453366": {"name": "Streptococcus pneumoniae MLV-016", "rank": "Strain"}, "453365": {"name": "Streptococcus pneumoniae CDC3059-06", "rank": "Strain"}, "453364": {"name": "Streptococcus pneumoniae CDC0288-04", "rank": "Strain"}, "417127": {"name": "Zunongwangia", "rank": "Genus"}, "1412609": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20120734", "rank": "Strain"}, "1412608": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20120687", "rank": "Strain"}, "1412605": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20120590", "rank": "Strain"}, "1412604": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20120581", "rank": "Strain"}, "283735": {"name": "Leeuwenhoekiella", "rank": "Genus"}, "283734": {"name": "Staphylococcus pseudintermedius", "rank": "Species"}, "1412601": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20120051", "rank": "Strain"}, "1412600": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20100325", "rank": "Strain"}, "1412603": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20120580", "rank": "Strain"}, "1412602": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20120356", "rank": "Strain"}, "1461694": {"name": "Oceanicola sp. 22II-S11g", "rank": "Species"}, "1417034": {"name": "Staphylococcus aureus F60357", "rank": "Strain"}, "1417037": {"name": "Staphylococcus aureus W53395", "rank": "Strain"}, "109993": {"name": "Porcine cytomegalovirus", "rank": "Species"}, "1417031": {"name": "Mycobacterium tuberculosis KT-0087", "rank": "Strain"}, "1417030": {"name": "Mycobacterium tuberculosis KT-0086", "rank": "Strain"}, "1417033": {"name": "Staphylococcus aureus W46839", "rank": "Strain"}, "1461693": {"name": "Actibacterium atlanticum", "rank": "Species"}, "1417039": {"name": "Staphylococcus aureus F63750", "rank": "Strain"}, "1417038": {"name": "Staphylococcus aureus W18442", "rank": "Strain"}, "152053": {"name": "Starkeya", "rank": "Genus"}, "539738": {"name": "Bacillales Family XI. Incertae Sedis", "rank": "No rank"}, "1000952": {"name": "Vibrio cholerae HC-17A2", "rank": "Strain"}, "1000953": {"name": "Vibrio cholerae HC-72A2", "rank": "Strain"}, "1000951": {"name": "Vibrio cholerae HC-81A2", "rank": "Strain"}, "555603": {"name": "Mycobacterium phage Solon", "rank": "Species"}, "591001": {"name": "Acidaminococcus fermentans DSM 20731", "rank": "Strain"}, "363464": {"name": "Gracilibacteria", "rank": "Phylum"}, "191032": {"name": "Cereal yellow dwarf virus-RPV satellite RNA", "rank": "Species"}, "1351702": {"name": "Sulfolobus monocaudavirus SMV1", "rank": "Species"}, "1387312": {"name": "Methylophilus sp. OH31", "rank": "Species"}, "374847": {"name": "Candidatus Korarchaeum cryptofilum OPF8", "rank": "Strain"}, "1340485": {"name": "Streptococcus mitis 18/56", "rank": "Strain"}, "1340484": {"name": "Streptococcus mitis 17/34", "rank": "Strain"}, "1340486": {"name": "Streptococcus mitis 29/42", "rank": "Strain"}, "62928": {"name": "Azoarcus sp. BH72", "rank": "Species"}, "414528": {"name": "Chilli ringspot virus", "rank": "Species"}, "441": {"name": "Gluconobacter", "rank": "Genus"}, "442": {"name": "Gluconobacter oxydans", "rank": "Species"}, "445": {"name": "Legionella", "rank": "Genus"}, "444": {"name": "Legionellaceae", "rank": "Family"}, "446": {"name": "Legionella pneumophila", "rank": "Species"}, "1410733": {"name": "Staphylococcus aureus W85047", "rank": "Strain"}, "1410732": {"name": "Staphylococcus aureus M52055", "rank": "Strain"}, "1410731": {"name": "Staphylococcus aureus H12818", "rank": "Strain"}, "1410730": {"name": "Staphylococcus aureus M16486", "rank": "Strain"}, "1410737": {"name": "Staphylococcus aureus T62328", "rank": "Strain"}, "1410736": {"name": "Staphylococcus aureus F25913", "rank": "Strain"}, "1410735": {"name": "Staphylococcus aureus F16077", "rank": "Strain"}, "1410734": {"name": "Staphylococcus aureus H60145", "rank": "Strain"}, "1410739": {"name": "Staphylococcus aureus T66243", "rank": "Strain"}, "1401691": {"name": "Brucella abortus 82", "rank": "Strain"}, "159252": {"name": "Planaria asexual strain-specific virus-like element type 1", "rank": "Species"}, "160846": {"name": "Natrialba taiwanensis", "rank": "Species"}, "160845": {"name": "Clostridium stercorarium subsp. stercorarium", "rank": "Subspecies"}, "160844": {"name": "Narcissus common latent virus", "rank": "Species"}, "160843": {"name": "Narcissus yellow stripe virus", "rank": "Species"}, "160842": {"name": "Narcissus late season yellows virus", "rank": "Species"}, "159254": {"name": "Parachlamydia acanthamoebae str. Hall's coccus", "rank": "Strain"}, "876138": {"name": "Streptococcus agalactiae FSL S3-026", "rank": "Strain"}, "1157679": {"name": "Oxalobacteraceae bacterium JGI 0001004-K23", "rank": "Species"}, "1050716": {"name": "Candidate division YNPFFA", "rank": "No rank"}, "1421834": {"name": "Staphylococcus aureus F27252", "rank": "Strain"}, "1421835": {"name": "Staphylococcus aureus F36090", "rank": "Strain"}, "1421836": {"name": "Staphylococcus aureus F36091", "rank": "Strain"}, "1421837": {"name": "Staphylococcus aureus F36097", "rank": "Strain"}, "1421830": {"name": "Staphylococcus aureus F23610", "rank": "Strain"}, "1421831": {"name": "Staphylococcus aureus F23613", "rank": "Strain"}, "1421832": {"name": "Staphylococcus aureus F26032", "rank": "Strain"}, "1421833": {"name": "Staphylococcus aureus F26051", "rank": "Strain"}, "1421838": {"name": "Staphylococcus aureus F36099", "rank": "Strain"}, "1421839": {"name": "Staphylococcus aureus F45779", "rank": "Strain"}, "431958": {"name": "Wallemiales", "rank": "Order"}, "431959": {"name": "Wallemiales incertae sedis", "rank": "No rank"}, "234267": {"name": "Candidatus Solibacter usitatus Ellin6076", "rank": "Strain"}, "1131935": {"name": "Paenibacillus dendritiformis C454", "rank": "Strain"}, "1438717": {"name": "Klebsiella pneumoniae CHS 11", "rank": "Strain"}, "1438715": {"name": "Klebsiella pneumoniae CHS 09", "rank": "Strain"}, "1438714": {"name": "Klebsiella pneumoniae CHS 08", "rank": "Strain"}, "1438713": {"name": "Klebsiella pneumoniae CHS 07", "rank": "Strain"}, "1438712": {"name": "Klebsiella pneumoniae CHS 06", "rank": "Strain"}, "1438711": {"name": "Klebsiella pneumoniae CHS 05", "rank": "Strain"}, "1266977": {"name": "Sida yellow net virus", "rank": "Species"}, "1438719": {"name": "Klebsiella pneumoniae CHS 13", "rank": "Strain"}, "1438718": {"name": "Klebsiella pneumoniae CHS 12", "rank": "Strain"}, "1411529": {"name": "Staphylococcus aureus H34245", "rank": "Strain"}, "1411528": {"name": "Staphylococcus aureus H31290", "rank": "Strain"}, "1018": {"name": "Capnocytophaga ochracea", "rank": "Species"}, "1019": {"name": "Capnocytophaga sputigena", "rank": "Species"}, "1014": {"name": "Weeksella virosa", "rank": "Species"}, "1015": {"name": "Bergeyella zoohelcum", "rank": "Species"}, "1016": {"name": "Capnocytophaga", "rank": "Genus"}, "1017": {"name": "Capnocytophaga gingivalis", "rank": "Species"}, "1411525": {"name": "Staphylococcus aureus H27862", "rank": "Strain"}, "1011": {"name": "Sporocytophaga", "rank": "Genus"}, "1411527": {"name": "Staphylococcus aureus H31276", "rank": "Strain"}, "1013": {"name": "Weeksella", "rank": "Genus"}, "427315": {"name": "Tomato yellow dwarf disease associated satellite DNA beta-Kochi", "rank": "Species"}, "427317": {"name": "Sulfolobus islandicus M.14.25", "rank": "Strain"}, "432025": {"name": "Mixiomycetes", "rank": "Class"}, "427318": {"name": "Sulfolobus islandicus M.16.27", "rank": "Strain"}, "1007109": {"name": "Alpha proteobacterium SCGC AAA076-C03", "rank": "Species"}, "1007103": {"name": "Paenibacillus elgii B69", "rank": "Strain"}, "1007104": {"name": "Sphingomonas sp. S17", "rank": "Species"}, "1007105": {"name": "Pusillimonas sp. T7-7", "rank": "Species"}, "1302858": {"name": "Borrelia miyamotoi LB-2001", "rank": "Strain"}, "431957": {"name": "Wallemiomycetes", "rank": "Class"}, "391593": {"name": "Roseobacter sp. CCS2", "rank": "Species"}, "391592": {"name": "Caminibacter mediatlanticus TB-2", "rank": "Strain"}, "391591": {"name": "Vibrio shilonii AK1", "rank": "Strain"}, "1400770": {"name": "Cladonia metacorallifera KoLRI002260", "rank": "Strain"}, "1418290": {"name": "Staphylococcus aureus F48959", "rank": "Strain"}, "1418291": {"name": "Staphylococcus aureus F52326", "rank": "Strain"}, "1418292": {"name": "Staphylococcus aureus F59332", "rank": "Strain"}, "1418293": {"name": "Staphylococcus aureus F59335", "rank": "Strain"}, "1418294": {"name": "Staphylococcus aureus F71576", "rank": "Strain"}, "1418295": {"name": "Staphylococcus aureus F74820", "rank": "Strain"}, "1418296": {"name": "Staphylococcus aureus F80972", "rank": "Strain"}, "1513187": {"name": "Hemipteran ambidensovirus 1", "rank": "Species"}, "1418298": {"name": "Staphylococcus aureus H15899", "rank": "Strain"}, "1418299": {"name": "Staphylococcus aureus H15911", "rank": "Strain"}, "887316": {"name": "Campylobacter coli 2553", "rank": "Strain"}, "1432324": {"name": "Candidatus Aminicenans", "rank": "Genus"}, "391595": {"name": "Roseobacter litoralis Och 149", "rank": "Strain"}, "1432326": {"name": "Candidatus Microgenomatus", "rank": "Genus"}, "1304866": {"name": "Clostridium sp. ASBs410", "rank": "Species"}, "1304865": {"name": "Cellulomonas sp. KRMCY2", "rank": "Species"}, "547145": {"name": "Hydrogenobaculum sp. SHO", "rank": "Species"}, "547144": {"name": "Hydrogenobaculum sp. HO", "rank": "Species"}, "547146": {"name": "Hydrogenobaculum sp. SN", "rank": "Species"}, "547143": {"name": "Hydrogenobaculum sp. 3684", "rank": "Species"}, "391598": {"name": "Flavobacteria bacterium BAL38", "rank": "Species"}, "1267547": {"name": "Bacillus subtilis MB73/2", "rank": "Strain"}, "437663": {"name": "Brucella sp. UK1/97", "rank": "Species"}, "1281258": {"name": "Escherichia coli UMEA 3656-1", "rank": "Strain"}, "421010": {"name": "Hippeastrum mosaic virus", "rank": "Species"}, "421012": {"name": "Freesia mosaic virus", "rank": "Species"}, "1123366": {"name": "Thalassospira xiamenensis M-5 = DSM 17429", "rank": "Strain"}, "1157469": {"name": "Enterococcus faecium EnGen0174", "rank": "Strain"}, "1157468": {"name": "Enterococcus faecium EnGen0173", "rank": "Strain"}, "1262449": {"name": "Clostridium pasteurianum DSM 525 = ATCC 6013", "rank": "Strain"}, "86": {"name": "Hyphomonas jannaschiana", "rank": "Species"}, "1281259": {"name": "Escherichia coli UMEA 3662-1", "rank": "Strain"}, "85": {"name": "Hyphomonas", "rank": "Genus"}, "146292": {"name": "Verrucariaceae", "rank": "Family"}, "1157460": {"name": "Enterococcus faecium EnGen0165", "rank": "Strain"}, "88": {"name": "Leptothrix", "rank": "Genus"}, "146291": {"name": "Verrucariales", "rank": "Order"}, "1157465": {"name": "Enterococcus faecium EnGen0170", "rank": "Strain"}, "1157464": {"name": "Enterococcus faecium EnGen0169", "rank": "Strain"}, "1157467": {"name": "Enterococcus faecium EnGen0172", "rank": "Strain"}, "1157466": {"name": "Enterococcus faecium EnGen0171", "rank": "Strain"}, "1410932": {"name": "Salmonella enterica subsp. enterica serovar Give var. 15 str. CFSAN004343", "rank": "Strain"}, "1435446": {"name": "Sclerotinia sclerotiorum mitovirus 6", "rank": "Species"}, "115542": {"name": "Lactobacillus coryniformis subsp. torquens", "rank": "Subspecies"}, "115541": {"name": "Lactobacillus coryniformis subsp. coryniformis", "rank": "Subspecies"}, "1310808": {"name": "Acinetobacter baumannii 470922", "rank": "Strain"}, "1310809": {"name": "Acinetobacter baumannii 1539026", "rank": "Strain"}, "1310805": {"name": "Acinetobacter baumannii 1426993", "rank": "Strain"}, "1310806": {"name": "Acinetobacter baumannii 1505311", "rank": "Strain"}, "1310807": {"name": "Acinetobacter baumannii 1488685", "rank": "Strain"}, "1310800": {"name": "Acinetobacter baumannii 1000160", "rank": "Strain"}, "1310801": {"name": "Acinetobacter baumannii 339786", "rank": "Strain"}, "1310802": {"name": "Acinetobacter baumannii 11126", "rank": "Strain"}, "1310803": {"name": "Acinetobacter baumannii 730795", "rank": "Strain"}, "1158154": {"name": "Thioalkalivibrio sp. AKL6", "rank": "Species"}, "409438": {"name": "Escherichia coli SE11", "rank": "Strain"}, "1117319": {"name": "Pseudoalteromonas spongiae UST010723-006", "rank": "Strain"}, "1117318": {"name": "Pseudoalteromonas rubra ATCC 29570", "rank": "Strain"}, "1117317": {"name": "Pseudoalteromonas piscicida JCM 20779", "rank": "Strain"}, "1117316": {"name": "Pseudoalteromonas marina mano4", "rank": "Strain"}, "1117315": {"name": "Pseudoalteromonas haloplanktis ATCC 14393", "rank": "Strain"}, "1117314": {"name": "Pseudoalteromonas citrea NCIMB 1889", "rank": "Strain"}, "1117313": {"name": "Pseudoalteromonas arctica A 37-1-2", "rank": "Strain"}, "1324218": {"name": "Mycobacterium tuberculosis TKK-01-0001", "rank": "Strain"}, "163654": {"name": "Okra leaf curl virus", "rank": "Species"}, "195054": {"name": "Human parechovirus", "rank": "Species"}, "195056": {"name": "Rice yellow mottle virus satellite", "rank": "Species"}, "1010795": {"name": "Escherichia coli O5", "rank": "Strain"}, "1908": {"name": "Streptomyces globisporus", "rank": "Species"}, "1909": {"name": "Streptomyces griseolus", "rank": "Species"}, "1906": {"name": "Streptomyces fradiae", "rank": "Species"}, "1907": {"name": "Streptomyces glaucescens", "rank": "Species"}, "1905": {"name": "Streptomyces exfoliatus", "rank": "Species"}, "1902": {"name": "Streptomyces coelicolor", "rank": "Species"}, "1901": {"name": "Streptomyces clavuligerus", "rank": "Species"}, "39498": {"name": "Eubacterium yurii", "rank": "Species"}, "904748": {"name": "Staphylococcus aureus subsp. aureus 21267", "rank": "Strain"}, "1216932": {"name": "Clostridium sp. M2/40", "rank": "Species"}, "39490": {"name": "Eubacterium ramulus", "rank": "Species"}, "1460244": {"name": "Streptomyces sp. PCS3-D2", "rank": "Species"}, "39492": {"name": "Eubacterium siraeum", "rank": "Species"}, "39496": {"name": "Eubacterium ventriosum", "rank": "Species"}, "39497": {"name": "Eubacterium xylanophilum", "rank": "Species"}, "81406": {"name": "Desulfovibrio alcoholivorans", "rank": "Species"}, "81408": {"name": "Geobacillus caldoxylosilyticus", "rank": "Species"}, "40136": {"name": "Oligotropha", "rank": "Genus"}, "398511": {"name": "Bacillus pseudofirmus OF4", "rank": "Strain"}, "398512": {"name": "Pseudobacteroides cellulosolvens ATCC 35603 = DSM 2933", "rank": "Strain"}, "398513": {"name": "Bifidobacterium bifidum NCIMB 41171", "rank": "Strain"}, "70796": {"name": "Avian encephalomyelitis virus", "rank": "Species"}, "70799": {"name": "Nodularia spumigena", "rank": "Species"}, "213185": {"name": "Methanotorris formicicus", "rank": "Species"}, "510831": {"name": "Francisella tularensis subsp. tularensis NE061598", "rank": "Strain"}, "215920": {"name": "Sadwavirus", "rank": "Genus"}, "1483681": {"name": "Tortoise rafivirus A", "rank": "Species"}, "1151310": {"name": "Peptoclostridium difficile 840", "rank": "Strain"}, "1078034": {"name": "Escherichia coli O145:H28", "rank": "Strain"}, "1078035": {"name": "Escherichia coli O145:H28 str. 4865/96", "rank": "Strain"}, "1078032": {"name": "Escherichia coli O45:H2", "rank": "Strain"}, "1078033": {"name": "Escherichia coli O45:H2 str. 03-EN-705", "rank": "Strain"}, "1078030": {"name": "Escherichia coli O91:H21 str. B2F1", "rank": "Strain"}, "1078031": {"name": "Escherichia coli O121:H19 str. MT#2", "rank": "Strain"}, "1392082": {"name": "Staphylococcus aureus M1087", "rank": "Strain"}, "1392083": {"name": "Staphylococcus aureus M1088", "rank": "Strain"}, "1392080": {"name": "Staphylococcus aureus M1084", "rank": "Strain"}, "1392081": {"name": "Staphylococcus aureus M1085", "rank": "Strain"}, "1392086": {"name": "Staphylococcus aureus M1091", "rank": "Strain"}, "1392087": {"name": "Staphylococcus aureus M1094", "rank": "Strain"}, "1392084": {"name": "Staphylococcus aureus M1089", "rank": "Strain"}, "1392085": {"name": "Staphylococcus aureus M1090", "rank": "Strain"}, "1432658": {"name": "Enterococcus phage IME-EF4", "rank": "Species"}, "1392088": {"name": "Staphylococcus aureus M1096", "rank": "Strain"}, "1392089": {"name": "Staphylococcus aureus M1097", "rank": "Strain"}, "1151314": {"name": "Peptoclostridium difficile 6042", "rank": "Strain"}, "1151122": {"name": "Microbacterium sp. 292MF", "rank": "Species"}, "1403880": {"name": "Staphylococcus aureus M1497", "rank": "Strain"}, "1403883": {"name": "Staphylococcus aureus M1500", "rank": "Strain"}, "1403882": {"name": "Staphylococcus aureus M1499", "rank": "Strain"}, "1403885": {"name": "Staphylococcus aureus M1502", "rank": "Strain"}, "1403884": {"name": "Staphylococcus aureus M1501", "rank": "Strain"}, "1403887": {"name": "Staphylococcus aureus M1504", "rank": "Strain"}, "1403886": {"name": "Staphylococcus aureus M1503", "rank": "Strain"}, "1403889": {"name": "Staphylococcus aureus M1506", "rank": "Strain"}, "1403888": {"name": "Staphylococcus aureus M1505", "rank": "Strain"}, "1151128": {"name": "Pseudomonas umsongensis 20MFCvi1.1", "rank": "Strain"}, "1151316": {"name": "Peptoclostridium difficile 6057", "rank": "Strain"}, "405782": {"name": "Streptacidiphilus anmyonensis", "rank": "Species"}, "405783": {"name": "Streptacidiphilus rugosus", "rank": "Species"}, "685948": {"name": "Fervidicoccales", "rank": "Order"}, "685949": {"name": "Fervidicoccaceae", "rank": "Family"}, "40281": {"name": "Cryphonectria hypovirus 1", "rank": "Species"}, "40282": {"name": "Cryphonectria hypovirus 2", "rank": "Species"}, "43660": {"name": "Pseudoalteromonas undina", "rank": "Species"}, "1111454": {"name": "Megasphaera sp. BV3C16-1", "rank": "Species"}, "77022": {"name": "Cylindrospermopsis raciborskii", "rank": "Species"}, "77021": {"name": "Cylindrospermopsis", "rank": "Genus"}, "748811": {"name": "Sulfuritalea hydrogenivorans", "rank": "Species"}, "1438688": {"name": "Escherichia coli MGH 58", "rank": "Strain"}, "1448522": {"name": "Mycobacterium tuberculosis TKK_05MA_2005", "rank": "Strain"}, "12615": {"name": "Cherry leaf roll virus", "rank": "Species"}, "904740": {"name": "Staphylococcus aureus subsp. aureus 21239", "rank": "Strain"}, "58134": {"name": "Desulfotomaculum guttoideum", "rank": "Species"}, "58135": {"name": "Desulfotomaculum kuznetsovii", "rank": "Species"}, "58138": {"name": "Desulfotomaculum acetoxidans", "rank": "Species"}, "1165702": {"name": "Staphylococcus phage phi7401PVL", "rank": "Species"}, "1158158": {"name": "Thioalkalivibrio sp. AKL10", "rank": "Species"}, "1281257": {"name": "Escherichia coli UMEA 3652-1", "rank": "Strain"}, "699218": {"name": "Megasphaera genomosp. type_1 str. 28L", "rank": "Strain"}, "1005479": {"name": "Escherichia coli FRIK2001", "rank": "Strain"}, "1326980": {"name": "Sulfolobales archaeon AZ1", "rank": "Species"}, "1005477": {"name": "Escherichia coli FRIK1999", "rank": "Strain"}, "1005474": {"name": "Escherichia coli FDA506", "rank": "Strain"}, "508525": {"name": "Leptospira interrogans serovar Medanensis", "rank": "Strain"}, "1005472": {"name": "Escherichia coli FDA507", "rank": "Strain"}, "1005473": {"name": "Escherichia coli FDA517", "rank": "Strain"}, "1005470": {"name": "Escherichia coli FDA504", "rank": "Strain"}, "1005471": {"name": "Escherichia coli FDA505", "rank": "Strain"}, "1235983": {"name": "Propionibacterium sp. JGI 0001002-M06", "rank": "Species"}, "1235982": {"name": "Burkholderiales bacterium JGI 0001003-J08", "rank": "Species"}, "885867": {"name": "Prochlorococcus phage P-SSP10", "rank": "Species"}, "681288": {"name": "Staphylococcus aureus subsp. aureus ED98", "rank": "Strain"}, "1193028": {"name": "Leptospira interrogans serovar Lora str. TE 1992", "rank": "Strain"}, "743273": {"name": "Bordetella pertussis B0558", "rank": "Strain"}, "1235980": {"name": "Flavobacterium sp. JGI 0001001-D01", "rank": "Species"}, "743274": {"name": "Bordetella pertussis B1193", "rank": "Strain"}, "743276": {"name": "Bordetella pertussis B1834", "rank": "Strain"}, "1286279": {"name": "Serratia sp. C-1", "rank": "Species"}, "1193027": {"name": "Leptospira interrogans serovar Lora", "rank": "Strain"}, "1235985": {"name": "Chitinophaga sp. JGI 0001002-D04", "rank": "Species"}, "351073": {"name": "Mammalian orthoreovirus", "rank": "Species"}, "91464": {"name": "Synechococcus sp. PCC 7335", "rank": "Species"}, "634441": {"name": "Tomato leaf curl Sulawesi virus", "rank": "Species"}, "1169284": {"name": "Enterococcus faecalis EnGen0345", "rank": "Strain"}, "1169285": {"name": "Enterococcus faecalis EnGen0346", "rank": "Strain"}, "1169286": {"name": "Enterococcus faecalis ATCC 19433", "rank": "Strain"}, "1169287": {"name": "Enterococcus faecalis EnGen0362", "rank": "Strain"}, "1169280": {"name": "Enterococcus faecalis EnGen0341", "rank": "Strain"}, "1169281": {"name": "Enterococcus faecalis EnGen0366", "rank": "Strain"}, "1169282": {"name": "Enterococcus faecalis EnGen0344", "rank": "Strain"}, "1169283": {"name": "Enterococcus faecalis EnGen0361", "rank": "Strain"}, "234831": {"name": "Pseudoalteromonas sp. SM9913", "rank": "Species"}, "1169288": {"name": "Enterococcus faecalis EnGen0348", "rank": "Strain"}, "475861": {"name": "Nupapillomavirus", "rank": "Genus"}, "1094993": {"name": "Candida albicans P37039", "rank": "Strain"}, "1344997": {"name": "Staphylococcus epidermidis MC16", "rank": "Strain"}, "1094991": {"name": "Candida albicans P34048", "rank": "Strain"}, "1094990": {"name": "Candida albicans P57072", "rank": "Strain"}, "1094997": {"name": "Candida albicans P75063", "rank": "Strain"}, "1094996": {"name": "Candida albicans P57055", "rank": "Strain"}, "1094995": {"name": "Candida albicans P75016", "rank": "Strain"}, "1094994": {"name": "Candida albicans P75010", "rank": "Strain"}, "1094999": {"name": "Candida albicans P76067", "rank": "Strain"}, "1094998": {"name": "Candida albicans P76055", "rank": "Strain"}, "1120928": {"name": "Acinetobacter tjernbergiae DSM 14971 = CIP 107465", "rank": "Strain"}, "1120929": {"name": "Acinetobacter towneri DSM 14962 = CIP 107472", "rank": "Strain"}, "1120921": {"name": "Acidaminococcus intestini DSM 21505", "rank": "Strain"}, "1120926": {"name": "Acinetobacter gerneri DSM 14967 = CIP 107464", "rank": "Strain"}, "1120927": {"name": "Acinetobacter tandoii DSM 14970 = CIP 107469", "rank": "Strain"}, "1120924": {"name": "Acinetobacter baylyi DSM 14961 = CIP 107474", "rank": "Strain"}, "1120925": {"name": "Acinetobacter bouvetii DSM 14964 = CIP 107468", "rank": "Strain"}, "1344991": {"name": "Staphylococcus epidermidis Scl31", "rank": "Strain"}, "1163065": {"name": "Pseudomonas sp. CBZ-4", "rank": "Species"}, "1287182": {"name": "Mesorhizobium sp. L48C026A00", "rank": "Species"}, "1228012": {"name": "Spodoptera exigua iflavirus 2", "rank": "Species"}, "1227349": {"name": "Paenibacillus sp. FSL H7-689", "rank": "Species"}, "907240": {"name": "Helicobacter pylori Gambia94/24", "rank": "Strain"}, "932662": {"name": "Mud crab dicistrovirus", "rank": "Species"}, "1281122": {"name": "Escherichia coli HVH 195 (3-7155360)", "rank": "Strain"}, "243159": {"name": "Acidithiobacillus ferrooxidans ATCC 23270", "rank": "Strain"}, "143921": {"name": "Epinephelus tauvina nervous necrosis virus", "rank": "Species"}, "143920": {"name": "Alphanodavirus", "rank": "Genus"}, "1342301": {"name": "Sulfitobacter sp. NB-77", "rank": "Species"}, "1342302": {"name": "Sulfitobacter sp. NB-68", "rank": "Species"}, "889487": {"name": "Streptomyces sp. S4", "rank": "Species"}, "1121902": {"name": "Flexibacter elegans DSM 3317", "rank": "Strain"}, "535744": {"name": "Cronobacter universalis", "rank": "Species"}, "1184396": {"name": "Mesotoga", "rank": "Genus"}, "1448552": {"name": "Mycobacterium tuberculosis TKK_05SA_0052", "rank": "Strain"}, "1448550": {"name": "Mycobacterium tuberculosis TKK_05SA_0048", "rank": "Strain"}, "1276246": {"name": "Spiroplasma culicicola AES-1", "rank": "Strain"}, "1448556": {"name": "Mycobacterium tuberculosis TKK_05SA_0058", "rank": "Strain"}, "1448554": {"name": "Mycobacterium tuberculosis TKK_05SA_0054", "rank": "Strain"}, "1448555": {"name": "Mycobacterium tuberculosis TKK_05SA_0055", "rank": "Strain"}, "1448559": {"name": "Mycobacterium tuberculosis TKK_04_0074", "rank": "Strain"}, "388467": {"name": "Planktothrix agardhii NIVA-CYA 126/8", "rank": "Strain"}, "127511": {"name": "Vibrio phage Vf12", "rank": "Species"}, "10815": {"name": "Abutilon mosaic virus", "rank": "Species"}, "10814": {"name": "Begomovirus", "rank": "Genus"}, "10817": {"name": "African cassava mosaic virus", "rank": "Species"}, "1208600": {"name": "Bacillus sp. FJAT-14578", "rank": "Species"}, "1444711": {"name": "Chlamydia sp. 'Diamant'", "rank": "Species"}, "1444712": {"name": "Chlamydia sp. 'Rubis'", "rank": "Species"}, "10812": {"name": "Mastrevirus", "rank": "Genus"}, "93683": {"name": "Roseivivax halodurans", "rank": "Species"}, "93682": {"name": "Roseivivax", "rank": "Genus"}, "1238193": {"name": "Vibrio parahaemolyticus VP2007-095", "rank": "Strain"}, "1238192": {"name": "Vibrio parahaemolyticus VP2007-007", "rank": "Strain"}, "1238190": {"name": "Halomonas jeotgali Hwa", "rank": "Strain"}, "1238197": {"name": "Vibrio parahaemolyticus 3256", "rank": "Strain"}, "1238196": {"name": "Vibrio parahaemolyticus 12310", "rank": "Strain"}, "1238195": {"name": "Vibrio parahaemolyticus 10296", "rank": "Strain"}, "1238194": {"name": "Vibrio parahaemolyticus SBR10290", "rank": "Strain"}, "1219585": {"name": "Arcanobacterium sp. S3PF19", "rank": "Species"}, "1238199": {"name": "Vibrio parahaemolyticus 949", "rank": "Strain"}, "1238198": {"name": "Vibrio parahaemolyticus 3259", "rank": "Strain"}, "1219581": {"name": "Actinomyces sp. S4-C9", "rank": "Species"}, "29388": {"name": "Staphylococcus capitis", "rank": "Species"}, "29385": {"name": "Staphylococcus saprophyticus", "rank": "Species"}, "345073": {"name": "Vibrio cholerae O395", "rank": "Strain"}, "345072": {"name": "Vibrio cholerae MO10", "rank": "Strain"}, "345075": {"name": "Vibrio cholerae V51", "rank": "Strain"}, "29380": {"name": "Staphylococcus caprae", "rank": "Species"}, "29383": {"name": "Staphylococcus equorum subsp. equorum", "rank": "Subspecies"}, "345076": {"name": "Vibrio cholerae V52", "rank": "Strain"}, "499556": {"name": "Chapare virus", "rank": "Species"}, "186540": {"name": "Sudan ebolavirus", "rank": "Species"}, "186541": {"name": "Tai Forest ebolavirus", "rank": "Species"}, "1238449": {"name": "Vibrio nigripulchritudo SO65", "rank": "Strain"}, "367336": {"name": "Rhodobacterales bacterium HTCC2255", "rank": "Species"}, "272831": {"name": "Neisseria meningitidis FAM18", "rank": "Strain"}, "755178": {"name": "Cyanobacterium aponinum PCC 10605", "rank": "Strain"}, "1238444": {"name": "Vibrio nigripulchritudo MADA3029", "rank": "Strain"}, "221287": {"name": "Mastigocladopsis repens", "rank": "Species"}, "221282": {"name": "Mastigocladopsis", "rank": "Genus"}, "221288": {"name": "Mastigocladopsis repens PCC 10914", "rank": "Strain"}, "185300": {"name": "Paludibacter propionicigenes", "rank": "Species"}, "136992": {"name": "Methylosarcina lacus", "rank": "Species"}, "136993": {"name": "Methylosinus sp. LW4", "rank": "Species"}, "136996": {"name": "Rhizobium lupini", "rank": "Species"}, "177758": {"name": "Thermotoga lettingae", "rank": "Species"}, "272164": {"name": "Olleya marilimosa", "rank": "Species"}, "1234378": {"name": "Lawsonia intracellularis N343", "rank": "Strain"}, "12417": {"name": "Lactobacillus phage phiadh", "rank": "Species"}, "325775": {"name": "Coxiella endosymbiont of Amblyomma americanum", "rank": "Species"}, "1219050": {"name": "Sphingomonas paucimobilis NBRC 13935", "rank": "Strain"}, "1161899": {"name": "Unclassified Clostridiales Family XI. Incertae Sedis", "rank": "No rank"}, "303300": {"name": "Taro vein chlorosis virus", "rank": "Species"}, "1576597": {"name": "Circoviridae LDMD-2013a", "rank": "Species"}, "403957": {"name": "Virgibacillus sp. SK37", "rank": "Species"}, "308906": {"name": "Megalocytivirus", "rank": "Genus"}, "904294": {"name": "Streptococcus sp. oral taxon 056 str. F0418", "rank": "Strain"}, "904296": {"name": "Oribacterium sp. oral taxon 108 str. F0425", "rank": "Strain"}, "690086": {"name": "Salinarimonas", "rank": "Genus"}, "1035188": {"name": "Haemophilus pittmaniae HK 85", "rank": "Strain"}, "702985": {"name": "Salmonella enterica subsp. enterica serovar Paratyphi B str. SARA62", "rank": "Strain"}, "760801": {"name": "Streptococcus pneumoniae GA19923", "rank": "Strain"}, "760800": {"name": "Streptococcus pneumoniae GA19690", "rank": "Strain"}, "760803": {"name": "Streptococcus pneumoniae GA40028", "rank": "Strain"}, "760802": {"name": "Streptococcus pneumoniae GA19998", "rank": "Strain"}, "760805": {"name": "Streptococcus pneumoniae GA40410", "rank": "Strain"}, "760804": {"name": "Streptococcus pneumoniae GA40183", "rank": "Strain"}, "760806": {"name": "Streptococcus pneumoniae GA40563", "rank": "Strain"}, "760809": {"name": "Streptococcus pneumoniae GA41301", "rank": "Strain"}, "760808": {"name": "Streptococcus pneumoniae GA41277", "rank": "Strain"}, "51967": {"name": "Korarchaeota", "rank": "Phylum"}, "1538552": {"name": "Clostridium sp. NCR", "rank": "Species"}, "1538553": {"name": "Methylomonas denitrificans", "rank": "Species"}, "1538550": {"name": "Ethiopian tobacco bushy top virus satellite RNA", "rank": "Species"}, "1443897": {"name": "Rhodococcus fascians A76", "rank": "Strain"}, "1003110": {"name": "Verrucosispora maris", "rank": "Species"}, "55207": {"name": "Pectobacterium betavasculorum", "rank": "Species"}, "55206": {"name": "Spirochaeta smaragdinae", "rank": "Species"}, "55205": {"name": "Caldicellulosiruptor owensensis", "rank": "Species"}, "1231903": {"name": "Eilat virus", "rank": "Species"}, "1035185": {"name": "Streptococcus parasanguinis SK236", "rank": "Strain"}, "174951": {"name": "Ramlibacter", "rank": "Genus"}, "318424": {"name": "Mycobacterium rufum", "rank": "Species"}, "318425": {"name": "Mycobacterium aromaticivorans", "rank": "Species"}, "1464778": {"name": "Cassava Ivorian bacilliform virus", "rank": "Species"}, "1132026": {"name": "Burkholderia phage KL1", "rank": "Species"}, "1094478": {"name": "Acinetobacter baumannii ABNIH14", "rank": "Strain"}, "1094479": {"name": "Acinetobacter baumannii ABNIH15", "rank": "Strain"}, "263004": {"name": "Sweet potato chlorotic fleck virus", "rank": "Species"}, "263001": {"name": "Tomato leaf curl Java virus", "rank": "Species"}, "1542665": {"name": "Mesta yellow vein mosaic virus alphasatellite", "rank": "Species"}, "492736": {"name": "Dyadobacter alkalitolerans", "rank": "Species"}, "1094475": {"name": "Acinetobacter baumannii ABNIH11", "rank": "Strain"}, "1094477": {"name": "Acinetobacter baumannii ABNIH13", "rank": "Strain"}, "420324": {"name": "Microvirga lupini", "rank": "Species"}, "1121443": {"name": "Desulfovibrio cuneatus DSM 11391", "rank": "Strain"}, "551895": {"name": "Iodobacteriophage phiPLPE", "rank": "Species"}, "335100": {"name": "Rotavirus D", "rank": "Species"}, "176652": {"name": "Invertebrate iridescent virus 6", "rank": "Species"}, "200666": {"name": "Sphingobacteriales", "rank": "Order"}, "1331282": {"name": "Bordetella pertussis CHLA-15", "rank": "Strain"}, "268407": {"name": "Paenibacillus wynnii", "rank": "Species"}, "491952": {"name": "Marinomonas posidonica IVIA-Po-181", "rank": "Strain"}, "1159613": {"name": "Cronobacter muytjensii ATCC 51329", "rank": "Strain"}, "1159614": {"name": "Cronobacter sakazakii ES35", "rank": "Strain"}, "1159617": {"name": "Yersinia pestis INS", "rank": "Strain"}, "196094": {"name": "Turnip crinkle virus satellite RNA", "rank": "Species"}, "471717": {"name": "Melon aphid-borne yellows virus", "rank": "Species"}, "1397910": {"name": "Mycobacterium tuberculosis TKK_04_0006", "rank": "Strain"}, "1397917": {"name": "Mycobacterium tuberculosis TKK_04_0022", "rank": "Strain"}, "43": {"name": "Cystobacter fuscus", "rank": "Species"}, "191289": {"name": "Sclerophthora macrospora virus A", "rank": "Species"}, "1414644": {"name": "Tall oatgrass mosaic virus", "rank": "Species"}, "341167": {"name": "East Asian Passiflora virus", "rank": "Species"}, "294747": {"name": "Candida tropicalis MYA-3404", "rank": "Strain"}, "294748": {"name": "Candida albicans WO-1", "rank": "Strain"}, "1397914": {"name": "Mycobacterium tuberculosis TKK_04_0018", "rank": "Strain"}, "1005539": {"name": "Escherichia coli EC1737", "rank": "Strain"}, "1005538": {"name": "Escherichia coli EC1736", "rank": "Strain"}, "1005533": {"name": "Escherichia coli EC4437", "rank": "Strain"}, "1005532": {"name": "Escherichia coli EC4436", "rank": "Strain"}, "1005531": {"name": "Escherichia coli EC4439", "rank": "Strain"}, "1005537": {"name": "Escherichia coli EC1735", "rank": "Strain"}, "1513460": {"name": "Unassigned Marseilleviridae", "rank": "No rank"}, "1005535": {"name": "Escherichia coli EC1738", "rank": "Strain"}, "1341019": {"name": "Parvovirus NIH-CQV", "rank": "Species"}, "57029": {"name": "Psychroflexus torquis", "rank": "Species"}, "854826": {"name": "Kluyveromyces aestuarii ATCC 18862", "rank": "Strain"}, "1412528": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20120213", "rank": "Strain"}, "1412529": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20120200", "rank": "Strain"}, "1411645": {"name": "Escherichia coli IS9", "rank": "Strain"}, "1412520": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. SA20093543", "rank": "Strain"}, "1412521": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. SA20090877", "rank": "Strain"}, "1412522": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. SA20093538", "rank": "Strain"}, "1412523": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. SA20091739", "rank": "Strain"}, "1412524": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. SA20094079", "rank": "Strain"}, "89374": {"name": "Saprospiraceae", "rank": "Family"}, "1412526": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20121825", "rank": "Strain"}, "1412527": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20121826", "rank": "Strain"}, "35818": {"name": "Helicobacter pullorum", "rank": "Species"}, "1417171": {"name": "Staphylococcus aureus H65830", "rank": "Strain"}, "1417172": {"name": "Staphylococcus aureus H72115", "rank": "Strain"}, "1417173": {"name": "Staphylococcus aureus H72119", "rank": "Strain"}, "1417174": {"name": "Staphylococcus aureus H72129_090612", "rank": "Strain"}, "1417175": {"name": "Staphylococcus aureus H75423", "rank": "Strain"}, "1417176": {"name": "Staphylococcus aureus H75425", "rank": "Strain"}, "1417177": {"name": "Staphylococcus aureus M49501", "rank": "Strain"}, "1417178": {"name": "Staphylococcus aureus M52622", "rank": "Strain"}, "1417179": {"name": "Staphylococcus aureus M55878", "rank": "Strain"}, "35814": {"name": "Bordetella holmesii", "rank": "Species"}, "35817": {"name": "Helicobacter heilmannii", "rank": "Species"}, "84107": {"name": "Coriobacteriaceae", "rank": "Family"}, "1355368": {"name": "Arcobacter sp. AF1028", "rank": "Species"}, "84108": {"name": "Slackia", "rank": "Genus"}, "84109": {"name": "Slackia exigua", "rank": "Species"}, "527002": {"name": "Yersinia aldovae ATCC 35236", "rank": "Strain"}, "527000": {"name": "Bacillus pseudomycoides DSM 12442", "rank": "Strain"}, "527001": {"name": "Salmonella enterica subsp. enterica serovar Typhi str. Ty21a", "rank": "Strain"}, "527004": {"name": "Yersinia rohdei ATCC 43380", "rank": "Strain"}, "525898": {"name": "Sulfurospirillum deleyianum DSM 6946", "rank": "Strain"}, "525897": {"name": "Desulfomicrobium baculatum DSM 4028", "rank": "Strain"}, "991925": {"name": "Vibrio cholerae CP1038(11)", "rank": "Strain"}, "666635": {"name": "Vernonia yellow vein betasatellite", "rank": "Species"}, "1001744": {"name": "Streptococcus pneumoniae PT8114", "rank": "Strain"}, "1001745": {"name": "Streptococcus pneumoniae 07AR0125", "rank": "Strain"}, "1074122": {"name": "Streptococcus mutans TCI-143", "rank": "Strain"}, "1074123": {"name": "Streptococcus mutans TCI-145", "rank": "Strain"}, "1074124": {"name": "Streptococcus mutans TCI-146", "rank": "Strain"}, "1001741": {"name": "Mycobacterium abscessus 6G-0125-S", "rank": "Strain"}, "1074126": {"name": "Streptococcus mutans TCI-149", "rank": "Strain"}, "1074127": {"name": "Streptococcus mutans TCI-151", "rank": "Strain"}, "1074128": {"name": "Streptococcus mutans TCI-152", "rank": "Strain"}, "1074129": {"name": "Streptococcus mutans TCI-153", "rank": "Strain"}, "1500258": {"name": "Rhizobium sp. YR528", "rank": "Species"}, "1500259": {"name": "Rhizobium sp. YR519", "rank": "Species"}, "35325": {"name": "DsRNA viruses", "rank": "No rank"}, "1413336": {"name": "Staphylococcus aureus 22835", "rank": "Strain"}, "1413337": {"name": "Staphylococcus aureus 22837", "rank": "Strain"}, "1413334": {"name": "Staphylococcus aureus 22825", "rank": "Strain"}, "1413332": {"name": "Staphylococcus aureus UB 08-172", "rank": "Strain"}, "1413333": {"name": "Staphylococcus aureus 19571", "rank": "Strain"}, "1413330": {"name": "Staphylococcus aureus 2011-60-2256-5", "rank": "Strain"}, "1413331": {"name": "Staphylococcus aureus UB 08-116", "rank": "Strain"}, "1310573": {"name": "Acinetobacter baumannii 18689", "rank": "Strain"}, "1413338": {"name": "Staphylococcus aureus 22838", "rank": "Strain"}, "1413339": {"name": "Staphylococcus aureus 22841", "rank": "Strain"}, "292635": {"name": "Laceyella", "rank": "Genus"}, "324770": {"name": "Cryptococcus dejecticola", "rank": "Species"}, "292632": {"name": "Subdoligranulum", "rank": "Genus"}, "292638": {"name": "Globuloviridae", "rank": "Family"}, "398199": {"name": "Proteiniclasticum ruminis", "rank": "Species"}, "246787": {"name": "Bacteroides cellulosilyticus", "rank": "Species"}, "1465765": {"name": "Oceanobacillus massiliensis", "rank": "Species"}, "1465766": {"name": "Paenibacillus senegalensis", "rank": "Species"}, "1357294": {"name": "Staphylococcus equorum UMC-CNS-924", "rank": "Strain"}, "1357295": {"name": "Klebsiella pneumoniae EGD-HP19-C", "rank": "Strain"}, "363253": {"name": "Lawsonia intracellularis PHE/MN1-00", "rank": "Strain"}, "1357297": {"name": "Serratia marcescens EGD-HP20", "rank": "Strain"}, "1357290": {"name": "Pseudomonas viridiflava CC1582", "rank": "Strain"}, "1357291": {"name": "Pseudomonas viridiflava TA043", "rank": "Strain"}, "328670": {"name": "Banana streak GF virus", "rank": "Species"}, "699166": {"name": "Citrivirus", "rank": "Genus"}, "363259": {"name": "Kaistia granuli", "rank": "Species"}, "247080": {"name": "Ralstonia phage p12J", "rank": "Species"}, "1301280": {"name": "Invertebrate iridovirus 25", "rank": "Species"}, "285535": {"name": "Streptomyces fulvoviolaceus", "rank": "Species"}, "1301283": {"name": "Oscillatoriophycideae", "rank": "Subclass"}, "285530": {"name": "Streptomyces sviceus", "rank": "Species"}, "182270": {"name": "Aurantimonas coralicida", "rank": "Species"}, "108": {"name": "Spirosoma linguale", "rank": "Species"}, "411467": {"name": "Pseudoflavonifractor capillosus ATCC 29799", "rank": "Strain"}, "411464": {"name": "Desulfovibrio piger ATCC 29098", "rank": "Strain"}, "411465": {"name": "Parvimonas micra ATCC 33270", "rank": "Strain"}, "411462": {"name": "Dorea longicatena DSM 13814", "rank": "Strain"}, "411463": {"name": "Eubacterium ventriosum ATCC 27560", "rank": "Strain"}, "411460": {"name": "Ruminococcus torques ATCC 27756", "rank": "Strain"}, "411461": {"name": "Dorea formicigenerans ATCC 27755", "rank": "Strain"}, "101": {"name": "Flectobacillus", "rank": "Genus"}, "103": {"name": "Flectobacillus major", "rank": "Species"}, "104": {"name": "Cyclobacterium marinum", "rank": "Species"}, "105": {"name": "Runella", "rank": "Genus"}, "106": {"name": "Runella slithyformis", "rank": "Species"}, "107": {"name": "Spirosoma", "rank": "Genus"}, "51354": {"name": "Maize chlorotic dwarf virus", "rank": "Species"}, "638": {"name": "Arsenophonus nasoniae", "rank": "Species"}, "1043493": {"name": "Lysinimicrobium mangrovi", "rank": "Species"}, "632": {"name": "Yersinia pestis", "rank": "Species"}, "633": {"name": "Yersinia pseudotuberculosis", "rank": "Species"}, "630": {"name": "Yersinia enterocolitica", "rank": "Species"}, "631": {"name": "Yersinia intermedia", "rank": "Species"}, "636": {"name": "Edwardsiella tarda", "rank": "Species"}, "637": {"name": "Arsenophonus", "rank": "Genus"}, "634": {"name": "Yersinia bercovieri", "rank": "Species"}, "635": {"name": "Edwardsiella", "rank": "Genus"}, "1422813": {"name": "Staphylococcus aureus VET1959S", "rank": "Strain"}, "1130832": {"name": "Rhodosporidium toruloides NP11", "rank": "Strain"}, "423605": {"name": "Elusimicrobium minutum", "rank": "Species"}, "423604": {"name": "Elusimicrobium", "rank": "Genus"}, "1211117": {"name": "Bacillus anthracis str. UR-1", "rank": "Strain"}, "1211114": {"name": "Pseudoxanthomonas sp. GW2", "rank": "Species"}, "1211115": {"name": "Chelatococcus sp. GW1", "rank": "Species"}, "1211112": {"name": "Pseudomonas psychrophila HA-4", "rank": "Strain"}, "1211113": {"name": "Pseudomonas aeruginosa DQ8", "rank": "Strain"}, "1265684": {"name": "Streptococcus agalactiae SS1219", "rank": "Strain"}, "1144308": {"name": "Brevibacillus sp. BC25", "rank": "Species"}, "1144309": {"name": "Burkholderia sp. BT03", "rank": "Species"}, "1265682": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 31.H.09", "rank": "Strain"}, "1144304": {"name": "Caulobacter sp. AP07", "rank": "Species"}, "1144305": {"name": "Novosphingobium sp. AP12", "rank": "Species"}, "1144306": {"name": "Rhizobium sp. AP16", "rank": "Species"}, "1144307": {"name": "Sphingobium sp. AP49", "rank": "Species"}, "1144300": {"name": "Lactobacillus gastricus PS3", "rank": "Strain"}, "1144302": {"name": "Escherichia coli SCI-07", "rank": "Strain"}, "1144303": {"name": "Escherichia coli J53", "rank": "Strain"}, "1249621": {"name": "Cupriavidus sp. HMR-1", "rank": "Species"}, "51680": {"name": "Ribgrass mosaic virus", "rank": "Species"}, "1227498": {"name": "Natronococcus jeotgali DSM 18795", "rank": "Strain"}, "1227499": {"name": "Natronolimnobius innermongolicus JCM 12255", "rank": "Strain"}, "1227496": {"name": "Natrinema versiforme JCM 10478", "rank": "Strain"}, "1227497": {"name": "Natronococcus amylolyticus DSM 10524", "rank": "Strain"}, "1227494": {"name": "Natrinema altunense JCM 12890", "rank": "Strain"}, "1227495": {"name": "Natrinema pallidum DSM 3751", "rank": "Strain"}, "1227492": {"name": "Natrialba chahannaoensis JCM 10990", "rank": "Strain"}, "1227493": {"name": "Natrialba hulunbeirensis JCM 10989", "rank": "Strain"}, "1227490": {"name": "Halovivax asiaticus JCM 14624", "rank": "Strain"}, "1227491": {"name": "Natrialba aegyptia DSM 13077", "rank": "Strain"}, "1262652": {"name": "Salmonella enterica subsp. enterica serovar Agona str. SH08SF124", "rank": "Strain"}, "1262650": {"name": "Staphylococcus xylosus NJ", "rank": "Strain"}, "1262654": {"name": "Salmonella enterica subsp. enterica serovar Agona str. SH10GFN094", "rank": "Strain"}, "36403": {"name": "Potato virus T", "rank": "Species"}, "1119": {"name": "Aphanocapsa", "rank": "Genus"}, "1118": {"name": "Chroococcales", "rank": "Order"}, "521393": {"name": "Actinomyces timonensis DSM 23838", "rank": "Strain"}, "1111": {"name": "Porphyrobacter", "rank": "Genus"}, "1117": {"name": "Cyanobacteria", "rank": "Phylum"}, "1047037": {"name": "Aminicenantes bacterium SCGC AAA252-P19", "rank": "Species"}, "1448721": {"name": "Mycobacterium tuberculosis M1848", "rank": "Strain"}, "80635": {"name": "Coniophora", "rank": "Genus"}, "61435": {"name": "Dehalococcoides mccartyi", "rank": "Species"}, "61434": {"name": "Dehalococcoides", "rank": "Genus"}, "61432": {"name": "Unclassified Flavobacteriaceae", "rank": "No rank"}, "80637": {"name": "Coniophora puteana", "rank": "Species"}, "1439077": {"name": "Streptococcus pyogenes ABC020033233", "rank": "Strain"}, "1382932": {"name": "Bacillus phage Troll", "rank": "Species"}, "11757": {"name": "Mouse mammary tumor virus", "rank": "Species"}, "1297617": {"name": "Intestinimonas butyriciproducens", "rank": "Species"}, "1448628": {"name": "Mycobacterium tuberculosis M1025", "rank": "Strain"}, "1448629": {"name": "Mycobacterium tuberculosis M1026", "rank": "Strain"}, "1038067": {"name": "XMRV-related viruses", "rank": "Strain"}, "1448624": {"name": "Mycobacterium tuberculosis M1021", "rank": "Strain"}, "1448625": {"name": "Mycobacterium tuberculosis M1023", "rank": "Strain"}, "1448626": {"name": "Mycobacterium tuberculosis M1022", "rank": "Strain"}, "1448627": {"name": "Mycobacterium tuberculosis M1024", "rank": "Strain"}, "1448620": {"name": "Mycobacterium tuberculosis M1010", "rank": "Strain"}, "1448621": {"name": "Mycobacterium tuberculosis M1012", "rank": "Strain"}, "1448622": {"name": "Mycobacterium tuberculosis M1011", "rank": "Strain"}, "1448623": {"name": "Mycobacterium tuberculosis M1017", "rank": "Strain"}, "517418": {"name": "Chloroherpeton thalassium ATCC 35110", "rank": "Strain"}, "72275": {"name": "Alteromonadaceae", "rank": "Family"}, "72274": {"name": "Pseudomonadales", "rank": "Order"}, "72276": {"name": "Ectothiorhodospiraceae", "rank": "Family"}, "1259844": {"name": "Pseudomonas sp. FGI182", "rank": "Species"}, "517417": {"name": "Chlorobaculum parvum NCIB 8327", "rank": "Strain"}, "72273": {"name": "Thiotrichales", "rank": "Order"}, "431891": {"name": "Burkholderia phage phi644-2", "rank": "Species"}, "431893": {"name": "Burkholderia phage phiE202", "rank": "Species"}, "431892": {"name": "Burkholderia phage phiE12-2", "rank": "Species"}, "431894": {"name": "Burkholderia phage phiE255", "rank": "Species"}, "1401072": {"name": "Prevotella bivia DNF00650", "rank": "Strain"}, "1310971": {"name": "Acinetobacter baumannii 25750_7", "rank": "Strain"}, "1401070": {"name": "Peptoniphilus lacrimalis DNF00528", "rank": "Strain"}, "1401071": {"name": "Staphylococcus haemolyticus DNF00585", "rank": "Strain"}, "1401077": {"name": "Prevotella denticola DNF00960", "rank": "Strain"}, "1401074": {"name": "Prevotella buccalis DNF00853", "rank": "Strain"}, "1401075": {"name": "Prevotella disiens DNF00882", "rank": "Strain"}, "1401078": {"name": "Prevotella buccalis DNF00985", "rank": "Strain"}, "1401079": {"name": "Mogibacterium timidum ATCC 33093", "rank": "Strain"}, "1053243": {"name": "Bacillus cereus VD196", "rank": "Strain"}, "320599": {"name": "Solirubrobacteraceae", "rank": "Family"}, "990068": {"name": "Lebetimonas sp. JH292", "rank": "Species"}, "990069": {"name": "Lebetimonas sp. JH369", "rank": "Species"}, "309390": {"name": "Tomato leaf curl Joydebpur virus", "rank": "Species"}, "1439072": {"name": "Streptococcus pyogenes ABC020032186", "rank": "Strain"}, "1405498": {"name": "Staphylococcus simulans UMC-CNS-990", "rank": "Strain"}, "1405499": {"name": "Cronobacter helveticus 1159", "rank": "Strain"}, "1197728": {"name": "Candidatus Prevotella conceptionensis 9403948", "rank": "Strain"}, "1423806": {"name": "Lactobacillus sucicola DSM 21376 = JCM 15457", "rank": "Strain"}, "1282358": {"name": "Shigella flexneri Shi06HN006", "rank": "Strain"}, "1197727": {"name": "Pseudomonas sp. Ag1", "rank": "Species"}, "1197721": {"name": "Pseudomonas mendocina DLHK", "rank": "Strain"}, "1310929": {"name": "Acinetobacter baumannii 25691_5", "rank": "Strain"}, "87265": {"name": "Umbilicariaceae", "rank": "Family"}, "1310926": {"name": "Acinetobacter baumannii 25691_2", "rank": "Strain"}, "1310925": {"name": "Acinetobacter baumannii 25691_1", "rank": "Strain"}, "1310924": {"name": "Acinetobacter baumannii 25766_10", "rank": "Strain"}, "1310923": {"name": "Acinetobacter baumannii 25766_9", "rank": "Strain"}, "1310921": {"name": "Acinetobacter baumannii 25766_7", "rank": "Strain"}, "1310920": {"name": "Acinetobacter baumannii 25766_6", "rank": "Strain"}, "321318": {"name": "Dietzia cinnamea", "rank": "Species"}, "321314": {"name": "Salmonella enterica subsp. enterica serovar Choleraesuis str. SC-B67", "rank": "Strain"}, "321315": {"name": "Sphaerisporangium", "rank": "Genus"}, "63363": {"name": "Aquifex aeolicus", "rank": "Species"}, "313985": {"name": "Geobacter lovleyi", "rank": "Species"}, "279280": {"name": "Burkholderia phage BcepC6B", "rank": "Species"}, "279281": {"name": "Lactobacillus phage phiAT3", "rank": "Strain"}, "101534": {"name": "Candidatus Blochmannia pennsylvanicus", "rank": "Species"}, "1427216": {"name": "Mycobacterium tuberculosis XTB13-125", "rank": "Strain"}, "1427217": {"name": "Mycobacterium tuberculosis XTB13-126", "rank": "Strain"}, "1427214": {"name": "Mycobacterium tuberculosis XTB13-123", "rank": "Strain"}, "1194149": {"name": "Salmonella enterica subsp. enterica serovar Hartford str. CFSAN001075", "rank": "Strain"}, "1268992": {"name": "Escherichia coli 908521", "rank": "Strain"}, "1268993": {"name": "Escherichia coli 908522", "rank": "Strain"}, "1268990": {"name": "Escherichia coli 907892", "rank": "Strain"}, "1268991": {"name": "Escherichia coli 908519", "rank": "Strain"}, "1268996": {"name": "Escherichia coli 908541", "rank": "Strain"}, "1268997": {"name": "Escherichia coli 908555", "rank": "Strain"}, "1268994": {"name": "Escherichia coli 908524", "rank": "Strain"}, "1268995": {"name": "Escherichia coli 908525", "rank": "Strain"}, "1427212": {"name": "Mycobacterium tuberculosis XTB13-121", "rank": "Strain"}, "1268998": {"name": "Escherichia coli 908573", "rank": "Strain"}, "1268999": {"name": "Escherichia coli 908585", "rank": "Strain"}, "698757": {"name": "Pyrobaculum oguniense TE7", "rank": "Strain"}, "1427213": {"name": "Mycobacterium tuberculosis XTB13-122", "rank": "Strain"}, "152217": {"name": "Gremmeniella abietina RNA virus L1", "rank": "Species"}, "484896": {"name": "Pseudomonas phage LUZ19", "rank": "Species"}, "1427210": {"name": "Mycobacterium tuberculosis XTB13-119", "rank": "Strain"}, "1266844": {"name": "Acetobacter pasteurianus 386B", "rank": "Strain"}, "1266845": {"name": "Carnobacterium sp. WN1359", "rank": "Species"}, "1427211": {"name": "Mycobacterium tuberculosis XTB13-120", "rank": "Strain"}, "82347": {"name": "Facklamia languida", "rank": "Species"}, "152219": {"name": "Menangle virus", "rank": "Species"}, "45406": {"name": "Enterobacteria phage RB32", "rank": "Species"}, "384677": {"name": "Ornithinimicrobium pekingense", "rank": "Species"}, "1280688": {"name": "Pseudobutyrivibrio ruminis CF1b", "rank": "Strain"}, "1280689": {"name": "Clostridium paraputrificum AGR2156", "rank": "Strain"}, "1280684": {"name": "Butyrivibrio sp. FCS006", "rank": "Species"}, "1280685": {"name": "Butyrivibrio sp. NC3005", "rank": "Species"}, "1280686": {"name": "Butyrivibrio sp. MC2013", "rank": "Species"}, "1280687": {"name": "Butyrivibrio fibrisolvens YRB2005", "rank": "Strain"}, "1280680": {"name": "Butyrivibrio sp. LC3010", "rank": "Species"}, "1280681": {"name": "Butyrivibrio sp. WCD2001", "rank": "Species"}, "1280682": {"name": "Butyrivibrio sp. XBB1001", "rank": "Species"}, "420645": {"name": "Lactobacillus equicursoris", "rank": "Species"}, "85991": {"name": "Chlamydia pecorum", "rank": "Species"}, "1439268": {"name": "Streptococcus pyogenes ABC020056765", "rank": "Strain"}, "671213": {"name": "Leptotrichia sp. oral taxon 225", "rank": "Species"}, "671216": {"name": "Peptoniphilus sp. oral taxon 836", "rank": "Species"}, "1439260": {"name": "Streptococcus pyogenes ABC020056060", "rank": "Strain"}, "671218": {"name": "Alloprevotella rava", "rank": "Species"}, "1439262": {"name": "Streptococcus pyogenes ABC020056068", "rank": "Strain"}, "1427219": {"name": "Mycobacterium tuberculosis XTB13-128", "rank": "Strain"}, "1391432": {"name": "Mycobacterium phage Graduation", "rank": "Species"}, "1391433": {"name": "Mycobacterium phage Zaka", "rank": "Species"}, "1391430": {"name": "Mycobacterium phage CloudWang3", "rank": "Species"}, "1391431": {"name": "Mycobacterium phage Conspiracy", "rank": "Species"}, "1151422": {"name": "Peptoclostridium difficile P46", "rank": "Strain"}, "1338436": {"name": "Sinomonas sp. MUSC 117", "rank": "Species"}, "106962": {"name": "Cryphonectria hypovirus 3", "rank": "Species"}, "106966": {"name": "Enterovirus G", "rank": "Species"}, "1151420": {"name": "Peptoclostridium difficile P42", "rank": "Strain"}, "1151424": {"name": "Peptoclostridium difficile P49", "rank": "Strain"}, "1151429": {"name": "Peptoclostridium difficile P61", "rank": "Strain"}, "1158756": {"name": "Thioalkalivibrio sp. ALJ7", "rank": "Species"}, "1511873": {"name": "Ungulate bocaparvovirus 1", "rank": "Species"}, "1158757": {"name": "Thioalkalivibrio sp. ALJ8", "rank": "Species"}, "697282": {"name": "Methylobacter tundripaludum SV96", "rank": "Strain"}, "697283": {"name": "Streptococcus pneumoniae gamPNI0373", "rank": "Strain"}, "1541822": {"name": "Pseudophaeobacter", "rank": "Genus"}, "224380": {"name": "Desulfonatronumaceae", "rank": "Family"}, "697281": {"name": "Mahella australiensis 50-1 BON", "rank": "Strain"}, "768706": {"name": "Desulfosporosinus orientis DSM 765", "rank": "Strain"}, "768704": {"name": "Desulfosporosinus meridiei DSM 13257", "rank": "Strain"}, "65786": {"name": "Hydrogenophaga intermedia", "rank": "Species"}, "768700": {"name": "Mycoplasma suis str. Illinois", "rank": "Strain"}, "1418441": {"name": "Staphylococcus aureus W80042", "rank": "Strain"}, "1328329": {"name": "Salmonella enterica subsp. enterica serovar Hartford str. 2012K-0272", "rank": "Strain"}, "1418440": {"name": "Staphylococcus aureus W80041", "rank": "Strain"}, "662477": {"name": "Haloarcula vallismortis ATCC 29715", "rank": "Strain"}, "1315967": {"name": "Anoxybacillus flavithermus NBRC 109594", "rank": "Strain"}, "1418442": {"name": "Staphylococcus aureus W82228", "rank": "Strain"}, "1339348": {"name": "Bacteroides uniformis str. 3978 T3 i", "rank": "Strain"}, "1339349": {"name": "Bacteroides uniformis str. 3978 T3 ii", "rank": "Strain"}, "1339346": {"name": "Bacteroides ovatus str. 3725 D1 iv", "rank": "Strain"}, "1339344": {"name": "Parabacteroides distasonis str. 3999B T(B) 4", "rank": "Strain"}, "1339345": {"name": "Parabacteroides distasonis str. 3999B T(B) 6", "rank": "Strain"}, "1339342": {"name": "Parabacteroides distasonis str. 3776 D15 i", "rank": "Strain"}, "1339343": {"name": "Parabacteroides distasonis str. 3776 D15 iv", "rank": "Strain"}, "1339340": {"name": "Bacteroides fragilis str. 1007-1-F #6", "rank": "Strain"}, "1339341": {"name": "Parabacteroides distasonis str. 3776 Po2 i", "rank": "Strain"}, "873127": {"name": "Enterococcus faecium E4453", "rank": "Strain"}, "1450519": {"name": "Dermabacter hominis 1368", "rank": "Strain"}, "1450518": {"name": "Sphingobium lucknowense F2", "rank": "Strain"}, "1450513": {"name": "Haemophilus parasuis HPS9", "rank": "Strain"}, "1450511": {"name": "Enterococcus mundtii CRL35", "rank": "Strain"}, "1450517": {"name": "Escherichia coli MS499", "rank": "Strain"}, "1450515": {"name": "Haemophilus parasuis HPS11", "rank": "Strain"}, "1450514": {"name": "Haemophilus parasuis HPS10", "rank": "Strain"}, "1051792": {"name": "Grapevine Pinot gris virus", "rank": "Species"}, "1111710": {"name": "Spodoptera exigua iflavirus 1", "rank": "Species"}, "1281049": {"name": "Escherichia coli HVH 113 (4-7535473)", "rank": "Strain"}, "766502": {"name": "Millerozyma", "rank": "Genus"}, "374838": {"name": "Reinekea blandensis", "rank": "Species"}, "504481": {"name": "Sediminibacterium", "rank": "Genus"}, "989": {"name": "Marinilabilia salmonicolor", "rank": "Species"}, "504483": {"name": "Spirochaeta cellobiosiphila", "rank": "Species"}, "1160213": {"name": "Brucella melitensis UK23/06", "rank": "Strain"}, "504487": {"name": "Jejuia pallidilutea", "rank": "Species"}, "392021": {"name": "Rickettsia rickettsii str. 'Sheila Smith'", "rank": "Strain"}, "982": {"name": "Cytophaga fermentans", "rank": "Species"}, "984": {"name": "Pedobacter heparinus", "rank": "Species"}, "985": {"name": "Cytophaga hutchinsonii", "rank": "Species"}, "986": {"name": "Flavobacterium johnsoniae", "rank": "Species"}, "987": {"name": "Aquimarina latercula", "rank": "Species"}, "1127123": {"name": "Escherichia coli C161_11", "rank": "Strain"}, "1127122": {"name": "Helicobacter pylori XZ274", "rank": "Strain"}, "444860": {"name": "Synechococcus phage S-SM2", "rank": "Species"}, "1127126": {"name": "Escherichia coli C213_10", "rank": "Strain"}, "1127125": {"name": "Escherichia coli 8624", "rank": "Strain"}, "1127124": {"name": "Escherichia coli C170_11", "rank": "Strain"}, "1127129": {"name": "Leuconostoc citreum LBAE E16", "rank": "Strain"}, "1127128": {"name": "Leuconostoc citreum LBAE C11", "rank": "Strain"}, "401562": {"name": "Aureimonas ureilytica", "rank": "Species"}, "68228": {"name": "Streptomyces lilacinus", "rank": "Species"}, "1163482": {"name": "Salmonella phage vB_SenS-Ent1", "rank": "Species"}, "1267358": {"name": "Mycobacterium tuberculosis TKK-01-0021", "rank": "Strain"}, "931210": {"name": "Human papillomavirus type 129", "rank": "Species"}, "735331": {"name": "Leptothrix ochracea", "rank": "Species"}, "68223": {"name": "Streptomyces katrae", "rank": "Species"}, "1159496": {"name": "Cronobacter dublinensis subsp. lactaridi LMG 23825", "rank": "Strain"}, "35518": {"name": "Eubacterium nodatum", "rank": "Species"}, "1281046": {"name": "Escherichia coli HVH 110 (4-6978754)", "rank": "Strain"}, "742845": {"name": "Malasseziaceae", "rank": "Family"}, "889218": {"name": "Campylobacter jejuni subsp. jejuni 55037", "rank": "Strain"}, "889219": {"name": "Campylobacter jejuni subsp. jejuni 86605", "rank": "Strain"}, "575195": {"name": "Haloarcula salaria", "rank": "Species"}, "1161427": {"name": "Streptococcus agalactiae BV3L5", "rank": "Strain"}, "1161421": {"name": "Streptococcus oralis SK304", "rank": "Strain"}, "1161422": {"name": "Streptococcus anginosus SK1138", "rank": "Strain"}, "889213": {"name": "Campylobacter jejuni subsp. jejuni 129-258", "rank": "Strain"}, "889214": {"name": "Campylobacter jejuni subsp. jejuni 110-21", "rank": "Strain"}, "889215": {"name": "Campylobacter jejuni subsp. jejuni 140-16", "rank": "Strain"}, "889216": {"name": "Campylobacter jejuni subsp. jejuni 51494", "rank": "Strain"}, "889217": {"name": "Campylobacter jejuni subsp. jejuni 60004", "rank": "Strain"}, "1159490": {"name": "Cronobacter sakazakii E764", "rank": "Strain"}, "1286338": {"name": "Escherichia coli TOP498", "rank": "Strain"}, "1286339": {"name": "Escherichia coli TOP550-1", "rank": "Strain"}, "1286336": {"name": "Escherichia coli TOP293-3", "rank": "Strain"}, "1127673": {"name": "Aliiglaciecola lipolytica E3", "rank": "Strain"}, "1286334": {"name": "Escherichia coli TOP293-1", "rank": "Strain"}, "1286335": {"name": "Escherichia coli TOP293-2", "rank": "Strain"}, "1286332": {"name": "Escherichia coli TOP382-3", "rank": "Strain"}, "1286333": {"name": "Escherichia coli TOP291", "rank": "Strain"}, "1286330": {"name": "Escherichia coli TOP382-1", "rank": "Strain"}, "1286331": {"name": "Escherichia coli TOP382-2", "rank": "Strain"}, "1240482": {"name": "Orbales", "rank": "Order"}, "1240483": {"name": "Orbaceae", "rank": "Family"}, "1046724": {"name": "Marinobacter lipolyticus BF04_CF-4", "rank": "Strain"}, "1422020": {"name": "Mycobacterium tuberculosis TB_RSA104", "rank": "Strain"}, "1154859": {"name": "Streptococcus agalactiae LMG 14609", "rank": "Strain"}, "331627": {"name": "Xanthomonas phage OP2", "rank": "Species"}, "644801": {"name": "Pseudomonas stutzeri RCH2", "rank": "Strain"}, "331625": {"name": "Unclassified Endornavirus", "rank": "No rank"}, "1174504": {"name": "Bacillus psychrosaccharolyticus ATCC 23296", "rank": "Strain"}, "167964": {"name": "Anaerolinea thermophila", "rank": "Species"}, "1236550": {"name": "Kocuria palustris PEL", "rank": "Strain"}, "1422021": {"name": "Mycobacterium tuberculosis TB_RSA105", "rank": "Strain"}, "1123754": {"name": "Rattail cactus necrosis-associated virus", "rank": "Species"}, "1154858": {"name": "Streptococcus agalactiae LMG 14608", "rank": "Strain"}, "1454007": {"name": "Pedobacter borealis DSM 19626", "rank": "Strain"}, "1391493": {"name": "Enterococcus faecalis EnGen0423", "rank": "Strain"}, "630403": {"name": "Tomitella biformata", "rank": "Species"}, "1446569": {"name": "Escherichia coli O121:H19 str. 2011C-3072", "rank": "Strain"}, "1446568": {"name": "Escherichia coli O121:H19 str. 2010EL1058", "rank": "Strain"}, "1446565": {"name": "Escherichia coli O121:H19 str. 2010C-4824", "rank": "Strain"}, "1446564": {"name": "Escherichia coli O121:H19 str. 2010C-4732", "rank": "Strain"}, "1446567": {"name": "Escherichia coli O121:H19 str. 2010C-4989", "rank": "Strain"}, "1446566": {"name": "Escherichia coli O121:H19 str. 2010C-4966", "rank": "Strain"}, "1446561": {"name": "Escherichia coli O121:H19 str. 2010C-3794", "rank": "Strain"}, "938797": {"name": "Beta proteobacterium SCGC AAA028-K02", "rank": "Species"}, "1446563": {"name": "Escherichia coli O121:H19 str. 2010C-4254", "rank": "Strain"}, "1446562": {"name": "Escherichia coli O121:H19 str. 2010C-3840", "rank": "Strain"}, "1157948": {"name": "Thermotoga sp. 2812B", "rank": "Species"}, "209274": {"name": "Entomoplasma lucivorax", "rank": "Species"}, "1094892": {"name": "Megavirus chiliensis", "rank": "Species"}, "1158671": {"name": "Enterococcus faecalis EnGen0284", "rank": "Strain"}, "1158670": {"name": "Enterococcus faecalis EnGen0283", "rank": "Strain"}, "1158673": {"name": "Enterococcus faecalis EnGen0293", "rank": "Strain"}, "1158672": {"name": "Enterococcus faecalis EnGen0286", "rank": "Strain"}, "1158675": {"name": "Enterococcus faecalis ATCC 27275", "rank": "Strain"}, "1158674": {"name": "Enterococcus faecalis EnGen0290", "rank": "Strain"}, "1158677": {"name": "Enterococcus faecalis EnGen0289", "rank": "Strain"}, "1158676": {"name": "Enterococcus faecalis ATCC 27959", "rank": "Strain"}, "1158678": {"name": "Enterococcus faecalis EnGen0285", "rank": "Strain"}, "207721": {"name": "Xanthomonas axonopodis pv. allii", "rank": "Strain"}, "1157949": {"name": "Thermotoga sp. EMP", "rank": "Species"}, "1446699": {"name": "Escherichia coli O165:H25", "rank": "Strain"}, "1446698": {"name": "Escherichia coli O157:NM str. 08-4540", "rank": "Strain"}, "447467": {"name": "Simiduia", "rank": "Genus"}, "1446693": {"name": "Escherichia coli O157:H7 str. K5852", "rank": "Strain"}, "1446692": {"name": "Escherichia coli O157:H7 str. K5806", "rank": "Strain"}, "1446691": {"name": "Escherichia coli O157:H7 str. K5609", "rank": "Strain"}, "1446690": {"name": "Escherichia coli O157:H7 str. K5607", "rank": "Strain"}, "1446697": {"name": "Escherichia coli O157:H7 str. K7140", "rank": "Strain"}, "1446696": {"name": "Escherichia coli O157:H7 str. K6687", "rank": "Strain"}, "1446695": {"name": "Escherichia coli O157:H7 str. K6676", "rank": "Strain"}, "1446694": {"name": "Escherichia coli O157:H7 str. K6590", "rank": "Strain"}, "415000": {"name": "Opitutales", "rank": "Order"}, "1422034": {"name": "Mycobacterium tuberculosis TB_RSA118", "rank": "Strain"}, "1433986": {"name": "Actibacterium", "rank": "Genus"}, "1422037": {"name": "Mycobacterium tuberculosis TB_RSA121", "rank": "Strain"}, "1154854": {"name": "Streptococcus agalactiae STIR-CD-26", "rank": "Strain"}, "314291": {"name": "Vibrio splendidus 12B01", "rank": "Strain"}, "314290": {"name": "Vibrio sp. MED222", "rank": "Species"}, "342948": {"name": "Thermococcus onnurineus", "rank": "Species"}, "342949": {"name": "Pyrococcus sp. NA2", "rank": "Species"}, "13264": {"name": "Brachyspira innocens", "rank": "Species"}, "34058": {"name": "Methylobacter marinus", "rank": "Species"}, "1159070": {"name": "Helicobacter pylori HP250ASii", "rank": "Strain"}, "1159071": {"name": "Helicobacter pylori HP250BFi", "rank": "Strain"}, "1159072": {"name": "Helicobacter pylori HP250BFii", "rank": "Strain"}, "1159073": {"name": "Helicobacter pylori HP250BFiii", "rank": "Strain"}, "1159074": {"name": "Helicobacter pylori HP250BFiV", "rank": "Strain"}, "33967": {"name": "Leuconostoc mesenteroides subsp. mesenteroides", "rank": "Subspecies"}, "33964": {"name": "Leuconostoc citreum", "rank": "Species"}, "33965": {"name": "Leuconostoc mesenteroides subsp. cremoris", "rank": "Subspecies"}, "1159078": {"name": "Helicobacter pylori HP260ASii", "rank": "Strain"}, "1159079": {"name": "Helicobacter pylori HP260BFii", "rank": "Strain"}, "33968": {"name": "Leuconostoc pseudomesenteroides", "rank": "Species"}, "33969": {"name": "Melissococcus", "rank": "Genus"}, "1444057": {"name": "Escherichia coli 3-267-03_S1_C1", "rank": "Strain"}, "1444056": {"name": "Escherichia coli 3-105-05_S1_C1", "rank": "Strain"}, "1444055": {"name": "Escherichia coli 3-073-06_S1_C1", "rank": "Strain"}, "1444054": {"name": "Escherichia coli 3-020-07_S1_C1", "rank": "Strain"}, "1444053": {"name": "Escherichia coli 1-392-07_S1_C1", "rank": "Strain"}, "1444052": {"name": "Escherichia coli 1-250-04_S1_C1", "rank": "Strain"}, "1444051": {"name": "Escherichia coli 1-182-04_S1_C1", "rank": "Strain"}, "1444050": {"name": "Escherichia coli 1-176-05_S1_C1", "rank": "Strain"}, "1471475": {"name": "Prochlorococcus sp. scB243_495N3", "rank": "Species"}, "174142": {"name": "Botrytis virus X", "rank": "Species"}, "1471477": {"name": "Prochlorococcus sp. scB243_495P20", "rank": "Species"}, "1471471": {"name": "Prochlorococcus sp. scB243_495I8", "rank": "Species"}, "1471470": {"name": "Prochlorococcus sp. scB243_495G23", "rank": "Species"}, "1444059": {"name": "Escherichia coli 3-475-03_S1_C1", "rank": "Strain"}, "1444058": {"name": "Escherichia coli 3-373-03_S1_C1", "rank": "Strain"}, "1412619": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20120969", "rank": "Strain"}, "1081894": {"name": "Escherichia coli 09BKT024447", "rank": "Strain"}, "1081895": {"name": "Escherichia coli 08BKT77219", "rank": "Strain"}, "1081896": {"name": "Escherichia coli T1840_97", "rank": "Strain"}, "1202142": {"name": "Citrus chlorotic dwarf associated virus", "rank": "Species"}, "1081890": {"name": "Escherichia coli Bd5610_99", "rank": "Strain"}, "1081891": {"name": "Escherichia coli T1282_01", "rank": "Strain"}, "1081892": {"name": "Escherichia coli T234_00", "rank": "Strain"}, "1081893": {"name": "Escherichia coli T924_01", "rank": "Strain"}, "649462": {"name": "Gracilimonas", "rank": "Genus"}, "238674": {"name": "Chrysanthemum yellows phytoplasma", "rank": "Species"}, "938467": {"name": "Actinobacterium SCGC AAA028-N15", "rank": "Species"}, "744872": {"name": "Treponema caldaria DSM 7334", "rank": "Strain"}, "1154850": {"name": "Streptococcus agalactiae STIR-CD-22", "rank": "Strain"}, "1242967": {"name": "Campylobacter concisus UNSW1", "rank": "Strain"}, "1242966": {"name": "Campylobacter concisus UNSW3", "rank": "Strain"}, "1242965": {"name": "Campylobacter concisus UNSW2", "rank": "Strain"}, "879299": {"name": "Lactobacillus iners LactinV 09V1-c", "rank": "Strain"}, "879298": {"name": "Lactobacillus iners LactinV 03V1-b", "rank": "Strain"}, "879297": {"name": "Lactobacillus iners LactinV 01V1-a", "rank": "Strain"}, "879296": {"name": "Lactobacillus iners SPIN 2503V10-D", "rank": "Strain"}, "879295": {"name": "Lactobacillus iners SPIN 1401G", "rank": "Strain"}, "1545443": {"name": "Belnapia sp. F-4-1", "rank": "Species"}, "1242969": {"name": "Campylobacter concisus ATCC 51562", "rank": "Strain"}, "1242968": {"name": "Campylobacter concisus UNSWCS", "rank": "Strain"}, "1154853": {"name": "Streptococcus agalactiae STIR-CD-25", "rank": "Strain"}, "1033802": {"name": "Salinisphaera shabanensis E1L3A", "rank": "Strain"}, "1033806": {"name": "Halorhabdus tiamatea SARL4B", "rank": "Strain"}, "221360": {"name": "Synechococcus sp. RS9917", "rank": "Species"}, "861208": {"name": "Agrobacterium sp. H13-3", "rank": "Species"}, "280498": {"name": "Leptospira interrogans serovar Grippotyphosa", "rank": "Strain"}, "1154852": {"name": "Streptococcus agalactiae STIR-CD-24", "rank": "Strain"}, "524023": {"name": "Imperata yellow mottle virus", "rank": "Species"}, "54299": {"name": "Chroococcidiopsis thermalis", "rank": "Species"}, "54298": {"name": "Chroococcidiopsis", "rank": "Genus"}, "54291": {"name": "Raoultella ornithinolytica", "rank": "Species"}, "54290": {"name": "GB virus C", "rank": "Species"}, "177416": {"name": "Francisella tularensis subsp. tularensis SCHU S4", "rank": "Strain"}, "561996": {"name": "Mycobacterium phage Brujita", "rank": "Species"}, "561997": {"name": "Mycobacterium phage Butterscotch", "rank": "Species"}, "1232394": {"name": "Francisella tularensis subsp. holarctica F92", "rank": "Strain"}, "561998": {"name": "Mycobacterium phage Gumball", "rank": "Species"}, "1077144": {"name": "Dietzia alimentaria 72", "rank": "Strain"}, "1077143": {"name": "Pasteurella multocida subsp. multocida str. P52VAC", "rank": "Strain"}, "1542498": {"name": "Lelliottia phage phD2B", "rank": "Species"}, "1154774": {"name": "Streptococcus agalactiae FSL S3-062", "rank": "Strain"}, "1154776": {"name": "Streptococcus agalactiae FSL S3-586", "rank": "Strain"}, "1154771": {"name": "Streptococcus agalactiae FSL C1-487", "rank": "Strain"}, "1154772": {"name": "Streptococcus agalactiae FSL S3-077", "rank": "Strain"}, "1154773": {"name": "Streptococcus agalactiae FSL S3-654", "rank": "Strain"}, "1541211": {"name": "Cripavirus NB-1/2011/HUN", "rank": "Species"}, "1154778": {"name": "Streptococcus agalactiae FSL S3-608", "rank": "Strain"}, "1154779": {"name": "Streptococcus agalactiae FSL S3-034", "rank": "Strain"}, "936156": {"name": "Bacillus subtilis BSn5", "rank": "Strain"}, "936157": {"name": "Salmonella enterica subsp. enterica serovar Weltevreden str. 2007-60-3289-1", "rank": "Strain"}, "936154": {"name": "Streptococcus parauberis KCTC 11537", "rank": "Strain"}, "1495045": {"name": "Thermopetrobacter sp. TC1", "rank": "Species"}, "936152": {"name": "Riemerella phage RAP44", "rank": "Species"}, "936153": {"name": "Enterococcus faecalis 62", "rank": "Strain"}, "169963": {"name": "Listeria monocytogenes EGD-e", "rank": "Strain"}, "570924": {"name": "Thermus sp. NMX2.A1", "rank": "Species"}, "333293": {"name": "Ageratum leaf curl virus", "rank": "Species"}, "1294032": {"name": "Tropheryma whipplei str. Sali28", "rank": "Strain"}, "175814": {"name": "Cestrum yellow leaf curling virus", "rank": "Species"}, "1006579": {"name": "Corynebacterium ulcerans FRC11", "rank": "Strain"}, "1294033": {"name": "Tropheryma whipplei str. Art29", "rank": "Strain"}, "388384": {"name": "Pseudoalteromonas sp. BSi20652", "rank": "Species"}, "1294030": {"name": "Tropheryma whipplei str. Neuro14", "rank": "Strain"}, "990268": {"name": "Vibrio maritimus", "rank": "Species"}, "1294031": {"name": "Tropheryma whipplei str. Endo27", "rank": "Strain"}, "1294036": {"name": "Tropheryma whipplei str. Neuro20", "rank": "Strain"}, "1294037": {"name": "Tropheryma whipplei str. Dig9", "rank": "Strain"}, "884215": {"name": "Candidatus Zinderia insecticola", "rank": "Species"}, "884214": {"name": "Candidatus Zinderia", "rank": "Genus"}, "1294034": {"name": "Tropheryma whipplei str. Pneumo30", "rank": "Strain"}, "1294035": {"name": "Tropheryma whipplei str. DigADP25", "rank": "Strain"}, "488241": {"name": "Influenza A virus (A/Korea/426/1968(H2N2))", "rank": "Strain"}, "1423140": {"name": "Gordonia alkanivorans CGMCC 6845", "rank": "Strain"}, "1423141": {"name": "Pseudomonas aeruginosa VRFPA06", "rank": "Strain"}, "1423144": {"name": "Phaeobacter gallaeciensis DSM 26640", "rank": "Strain"}, "1423145": {"name": "Streptococcus thermophilus TH1436", "rank": "Strain"}, "380394": {"name": "Acidithiobacillus ferrooxidans ATCC 53993", "rank": "Strain"}, "863368": {"name": "Lactobacillus reuteri lpuph", "rank": "Strain"}, "863369": {"name": "Lactobacillus reuteri mlc3", "rank": "Strain"}, "866787": {"name": "Alvernaviridae", "rank": "Family"}, "866789": {"name": "Escherichia coli DSM 30083 = JCM 1649 = ATCC 11775", "rank": "Strain"}, "863365": {"name": "Xanthomonas hortorum pv. carotae str. M081", "rank": "Strain"}, "374930": {"name": "Haemophilus influenzae PittEE", "rank": "Strain"}, "374931": {"name": "Haemophilus influenzae PittGG", "rank": "Strain"}, "374932": {"name": "Haemophilus influenzae PittHH", "rank": "Strain"}, "374933": {"name": "Haemophilus influenzae PittII", "rank": "Strain"}, "1502724": {"name": "Devosia sp. LC5", "rank": "Species"}, "1502725": {"name": "Effusibacillus", "rank": "Genus"}, "696369": {"name": "Desulfotomaculum nigrificans DSM 574", "rank": "Strain"}, "762209": {"name": "Bifidobacterium callitrichos", "rank": "Species"}, "1227261": {"name": "Actinobaculum sp. oral taxon 183 str. F0552", "rank": "Strain"}, "648794": {"name": "Aeromonas rivuli", "rank": "Species"}, "1499503": {"name": "Prochlorococcus sp. MIT 0702", "rank": "Species"}, "1499502": {"name": "Prochlorococcus sp. MIT 0701", "rank": "Species"}, "1499501": {"name": "Prochlorococcus sp. SS52", "rank": "Species"}, "1499500": {"name": "Prochlorococcus sp. MIT 0603", "rank": "Species"}, "2189": {"name": "Methanotorris igneus", "rank": "Species"}, "2188": {"name": "Methanococcus voltae", "rank": "Species"}, "2187": {"name": "Methanococcus vannielii", "rank": "Species"}, "2186": {"name": "Methanothermococcus thermolithotrophicus", "rank": "Species"}, "2184": {"name": "Methanococcus", "rank": "Genus"}, "2183": {"name": "Methanococcaceae", "rank": "Family"}, "2182": {"name": "Methanococcales", "rank": "Order"}, "2180": {"name": "Methanothermus fervidus", "rank": "Species"}, "201096": {"name": "Alicycliphilus", "rank": "Genus"}, "1304877": {"name": "Bradyrhizobium japonicum 22", "rank": "Strain"}, "1509403": {"name": "Acinetobacter sp. HR7", "rank": "Species"}, "1071679": {"name": "Burkholderia grimmiae", "rank": "Species"}, "35278": {"name": "SsRNA positive-strand viruses, no DNA stage", "rank": "No rank"}, "925776": {"name": "Xanthomonas perforans 91-118", "rank": "Strain"}, "285217": {"name": "Aspergillus terreus ATCC 20542", "rank": "Strain"}, "1410823": {"name": "Staphylococcus aureus F70893", "rank": "Strain"}, "1410822": {"name": "Staphylococcus aureus H33594", "rank": "Strain"}, "1410821": {"name": "Staphylococcus aureus H33636", "rank": "Strain"}, "1410820": {"name": "Staphylococcus aureus H33602", "rank": "Strain"}, "1410827": {"name": "Staphylococcus aureus H30732", "rank": "Strain"}, "1410826": {"name": "Staphylococcus aureus W60784", "rank": "Strain"}, "1410825": {"name": "Staphylococcus aureus W60774", "rank": "Strain"}, "1410824": {"name": "Staphylococcus aureus T74602", "rank": "Strain"}, "1410829": {"name": "Staphylococcus aureus F74139", "rank": "Strain"}, "1410828": {"name": "Staphylococcus aureus W60801", "rank": "Strain"}, "1460437": {"name": "Helicobacter pylori wls-5-6", "rank": "Strain"}, "1460436": {"name": "Helicobacter pylori wls-5-4", "rank": "Strain"}, "1460435": {"name": "Helicobacter pylori wls-5-18", "rank": "Strain"}, "1460434": {"name": "Helicobacter pylori wls-5-17", "rank": "Strain"}, "1460433": {"name": "Helicobacter pylori wls-5-16", "rank": "Strain"}, "1460432": {"name": "Helicobacter pylori wls-5-15", "rank": "Strain"}, "1460431": {"name": "Helicobacter pylori wls-5-14", "rank": "Strain"}, "1460430": {"name": "Helicobacter pylori wls-5-13", "rank": "Strain"}, "1460439": {"name": "Helicobacter pylori wls-5-8", "rank": "Strain"}, "1460438": {"name": "Helicobacter pylori wls-5-7", "rank": "Strain"}, "864569": {"name": "Streptococcus equinus ATCC 700338", "rank": "Strain"}, "1165867": {"name": "Rhodococcus imtechensis RKJ300 = JCM 13270", "rank": "Strain"}, "188787": {"name": "Deinococci", "rank": "Class"}, "200783": {"name": "Aquificae", "rank": "Phylum"}, "652616": {"name": "Mycobacterium tuberculosis str. Erdman = ATCC 35801", "rank": "Strain"}, "64091": {"name": "Halobacterium sp. NRC-1", "rank": "Strain"}, "652611": {"name": "Pseudomonas aeruginosa PA14", "rank": "Strain"}, "525282": {"name": "Finegoldia magna ATCC 53516", "rank": "Strain"}, "525283": {"name": "Fusobacterium nucleatum subsp. nucleatum ATCC 23726", "rank": "Strain"}, "1303385": {"name": "Tomato leaf curl Liwa virus", "rank": "Species"}, "525281": {"name": "Escherichia coli 83972", "rank": "Strain"}, "1413552": {"name": "Staphylococcus aureus Tur-22", "rank": "Strain"}, "1413553": {"name": "Staphylococcus aureus Tur-4", "rank": "Strain"}, "525284": {"name": "Gardnerella vaginalis ATCC 14019", "rank": "Strain"}, "1413551": {"name": "Staphylococcus aureus Tur-20", "rank": "Strain"}, "763552": {"name": "Mus musculus papillomavirus type 1", "rank": "Strain"}, "1317107": {"name": "Allamanda leaf mottle distortion virus", "rank": "Species"}, "1413558": {"name": "Staphylococcus aureus 16(11S1S4-09)", "rank": "Strain"}, "1413559": {"name": "Staphylococcus aureus 37(18S2S5-05)", "rank": "Strain"}, "141864": {"name": "Tobacco necrosis satellite virus-like", "rank": "No rank"}, "563835": {"name": "Chitinophagaceae", "rank": "Family"}, "712383": {"name": "Microbacterium sp. oral taxon 186", "rank": "Species"}, "305700": {"name": "Thauera sp. 27", "rank": "Species"}, "141860": {"name": "Grapevine fanleaf virus satellite RNA", "rank": "Species"}, "1288079": {"name": "Streptomyces sp. CNT318", "rank": "Species"}, "1383052": {"name": "Hemidesmus yellow mosaic virus", "rank": "Species"}, "1383057": {"name": "Mycobacterium phage Goku", "rank": "Species"}, "1383056": {"name": "Mycobacterium phage Papyrus", "rank": "Species"}, "1383055": {"name": "Mycobacterium phage Phelemich", "rank": "Species"}, "1383054": {"name": "Mycobacterium phage Wheeler", "rank": "Species"}, "1383059": {"name": "Mycobacterium phage Adzzy", "rank": "Species"}, "1214170": {"name": "Streptococcus suis 88-5299A", "rank": "Strain"}, "1156431": {"name": "Streptococcus sp. I-G2", "rank": "Species"}, "588932": {"name": "Brevundimonas naejangsanensis", "rank": "Species"}, "288022": {"name": "Kordiimonas gwangyangensis", "rank": "Species"}, "455434": {"name": "Treponema pallidum subsp. pallidum SS14", "rank": "Strain"}, "379731": {"name": "Pseudomonas stutzeri A1501", "rank": "Strain"}, "1305716": {"name": "Avian paramyxovirus 12", "rank": "Species"}, "1305710": {"name": "Mycobacterium phage vB_MapS_FF47", "rank": "Species"}, "1088890": {"name": "Halastavi arva RNA virus", "rank": "Species"}, "156208": {"name": "Macluravirus", "rank": "Genus"}, "164450": {"name": "Vulcanisaeta", "rank": "Genus"}, "164451": {"name": "Vulcanisaeta distributa", "rank": "Species"}, "156207": {"name": "Tritimovirus", "rank": "Genus"}, "1453472": {"name": "Escherichia coli E1140", "rank": "Strain"}, "281309": {"name": "Bacillus thuringiensis serovar konkukian str. 97-27", "rank": "Strain"}, "1407017": {"name": "Clostridium botulinum B str. Osaka05", "rank": "Strain"}, "288681": {"name": "Bacillus cereus E33L", "rank": "Strain"}, "760142": {"name": "Hippea maritima DSM 10411", "rank": "Strain"}, "408139": {"name": "Leptospira kmetyi", "rank": "Species"}, "119979": {"name": "Thermithiobacillus", "rank": "Genus"}, "525919": {"name": "Anaerococcus prevotii DSM 20548", "rank": "Strain"}, "256818": {"name": "Gulosibacter", "rank": "Genus"}, "1222033": {"name": "Acinetobacter baumannii AB405E4", "rank": "Strain"}, "1222032": {"name": "Acinetobacter baumannii AB4A3", "rank": "Strain"}, "1222031": {"name": "Acinetobacter baumannii AB1H8", "rank": "Strain"}, "119977": {"name": "Acidithiobacillus", "rank": "Genus"}, "525917": {"name": "Thiothrix lacustris", "rank": "Species"}, "1222034": {"name": "Mannheimia haemolytica USDA-ARS-USMARC-184", "rank": "Strain"}, "1001064": {"name": "Rhodotorula glutinis ATCC 204091", "rank": "Strain"}, "945225": {"name": "Spinach curly top Arizona virus", "rank": "Species"}, "754436": {"name": "Photobacterium aphoticum", "rank": "Species"}, "205920": {"name": "Ehrlichia chaffeensis str. Arkansas", "rank": "Strain"}, "205921": {"name": "Streptococcus agalactiae A909", "rank": "Strain"}, "205922": {"name": "Pseudomonas fluorescens Pf0-1", "rank": "Strain"}, "1456752": {"name": "Kama virus", "rank": "Species"}, "119394": {"name": "Thermotoga thermarum", "rank": "Species"}, "1453989": {"name": "Campylobacter lari RM16701", "rank": "Strain"}, "1453988": {"name": "Campylobacter lari RM16712", "rank": "Strain"}, "323449": {"name": "Pontibacter", "rank": "Genus"}, "1453987": {"name": "Chlamydia muridarum str. Nigg 2", "rank": "Strain"}, "1453986": {"name": "Staphylococcus aureus subsp. aureus AMRF2", "rank": "Strain"}, "880073": {"name": "Caldithrix abyssi DSM 13497", "rank": "Strain"}, "880072": {"name": "Desulfobacca acetoxidans DSM 11109", "rank": "Strain"}, "880071": {"name": "Flexibacter litoralis DSM 6794", "rank": "Strain"}, "880070": {"name": "Cyclobacterium marinum DSM 745", "rank": "Strain"}, "1131757": {"name": "Pseudomonas aeruginosa MPAO1/P1", "rank": "Strain"}, "1221253": {"name": "Acinetobacter baumannii AB_2007-16-25-01-7", "rank": "Strain"}, "1394551": {"name": "Vibrio parahaemolyticus S001", "rank": "Strain"}, "11270": {"name": "Rhabdoviridae", "rank": "Family"}, "1131758": {"name": "Pseudomonas aeruginosa MPAO1/P2", "rank": "Strain"}, "1388140": {"name": "Staphylococcus aureus M0211", "rank": "Strain"}, "1388141": {"name": "Staphylococcus aureus M0214", "rank": "Strain"}, "1388142": {"name": "Staphylococcus aureus M0215", "rank": "Strain"}, "1388143": {"name": "Staphylococcus aureus M0218", "rank": "Strain"}, "1388144": {"name": "Staphylococcus aureus M0219", "rank": "Strain"}, "1388145": {"name": "Staphylococcus aureus M0220", "rank": "Strain"}, "1388146": {"name": "Staphylococcus aureus M0224", "rank": "Strain"}, "1388147": {"name": "Staphylococcus aureus M0225", "rank": "Strain"}, "1388148": {"name": "Staphylococcus aureus M0226", "rank": "Strain"}, "1388149": {"name": "Staphylococcus aureus M0227", "rank": "Strain"}, "159122": {"name": "Simian immunodeficiency virus SIV-mnd 2", "rank": "Strain"}, "1151243": {"name": "Escherichia coli B104", "rank": "Strain"}, "1151242": {"name": "Escherichia coli B86", "rank": "Strain"}, "1151241": {"name": "Escherichia coli B85", "rank": "Strain"}, "1151240": {"name": "Escherichia coli B84", "rank": "Strain"}, "1151247": {"name": "Escherichia coli B105", "rank": "Strain"}, "1151246": {"name": "Escherichia coli B49-2", "rank": "Strain"}, "864564": {"name": "Parascardovia denticolens DSM 10105 = JCM 12538", "rank": "Strain"}, "1526743": {"name": "Pantoea sp. NGS-ED-1003", "rank": "Species"}, "557599": {"name": "Mycobacterium kansasii ATCC 12478", "rank": "Strain"}, "557598": {"name": "Laribacter hongkongensis HLHK9", "rank": "Strain"}, "1311043": {"name": "Acinetobacter baumannii 44362_9", "rank": "Strain"}, "1311042": {"name": "Acinetobacter baumannii 44362_8", "rank": "Strain"}, "1311041": {"name": "Acinetobacter baumannii 44362_7", "rank": "Strain"}, "1311040": {"name": "Acinetobacter baumannii 44362_6", "rank": "Strain"}, "1311047": {"name": "Acinetobacter baumannii 25878_3", "rank": "Strain"}, "1311046": {"name": "Acinetobacter baumannii 25878_2", "rank": "Strain"}, "1311045": {"name": "Acinetobacter baumannii 25878_1", "rank": "Strain"}, "1311044": {"name": "Acinetobacter baumannii 44362_10", "rank": "Strain"}, "1453083": {"name": "Faba bean necrotic yellows C9 alphasatellite", "rank": "Species"}, "1131289": {"name": "Zeta proteobacterium SCGC AB-604-B04", "rank": "Species"}, "1131288": {"name": "Zeta proteobacterium SCGC AB-602-E04", "rank": "Species"}, "436066": {"name": "Phlox virus S", "rank": "Species"}, "1131285": {"name": "Zeta proteobacterium SCGC AB-137-I08", "rank": "Species"}, "1131284": {"name": "Zeta proteobacterium SCGC AB-137-C09", "rank": "Species"}, "1131287": {"name": "Zeta proteobacterium SCGC AB-602-C20", "rank": "Species"}, "1131286": {"name": "Zeta proteobacterium SCGC AB-137-J06", "rank": "Species"}, "1131280": {"name": "Unclassified Zetaproteobacteria", "rank": "No rank"}, "1131283": {"name": "Zeta proteobacterium SCGC AB-133-C04", "rank": "Species"}, "1131282": {"name": "Zeta proteobacterium SCGC AB-133-G06", "rank": "Species"}, "1310884": {"name": "Acinetobacter baumannii 25253_10", "rank": "Strain"}, "1310885": {"name": "Acinetobacter baumannii 44895_1", "rank": "Strain"}, "1310886": {"name": "Acinetobacter baumannii 44895_2", "rank": "Strain"}, "1310887": {"name": "Acinetobacter baumannii 44895_3", "rank": "Strain"}, "1310880": {"name": "Acinetobacter baumannii 25253_6", "rank": "Strain"}, "1310881": {"name": "Acinetobacter baumannii 25253_7", "rank": "Strain"}, "1310882": {"name": "Acinetobacter baumannii 25253_8", "rank": "Strain"}, "1310888": {"name": "Acinetobacter baumannii 44895_4", "rank": "Strain"}, "1310889": {"name": "Acinetobacter baumannii 44895_5", "rank": "Strain"}, "114416": {"name": "Lactococcus phage ul36", "rank": "Species"}, "1310711": {"name": "Acinetobacter baumannii 723929", "rank": "Strain"}, "1411582": {"name": "Staphylococcus aureus T86055", "rank": "Strain"}, "291967": {"name": "Acaricomes", "rank": "Genus"}, "712938": {"name": "Lactobacillus fermentum CECT 5716", "rank": "Strain"}, "712934": {"name": "Chloroflexi bacterium oral taxon 439", "rank": "Species"}, "796352": {"name": "Panax virus Y", "rank": "Species"}, "291968": {"name": "Acaricomes phytoseiuli", "rank": "Species"}, "1094": {"name": "Chlorobium phaeovibrioides", "rank": "Species"}, "1096": {"name": "Chlorobium phaeobacteroides", "rank": "Species"}, "1097": {"name": "Chlorobaculum tepidum", "rank": "Species"}, "1090": {"name": "Chlorobi", "rank": "Phylum"}, "1091": {"name": "Chlorobium", "rank": "Genus"}, "1092": {"name": "Chlorobium limicola", "rank": "Species"}, "1099": {"name": "Pelodictyon", "rank": "Genus"}, "351627": {"name": "Caldicellulosiruptor saccharolyticus DSM 8903", "rank": "Strain"}, "1114942": {"name": "Pig stool associated circular ssDNA virus GER2011", "rank": "Strain"}, "1365660": {"name": "Campylobacter jejuni Cj3", "rank": "Strain"}, "1365661": {"name": "Campylobacter jejuni K1", "rank": "Strain"}, "1365662": {"name": "Campylobacter jejuni K5", "rank": "Strain"}, "1287336": {"name": "Mesorhizobium sp. LSJC280B00", "rank": "Species"}, "1428435": {"name": "Oenococcus oeni S11", "rank": "Strain"}, "1169242": {"name": "Brucella suis F8/06-1", "rank": "Strain"}, "1261131": {"name": "Candidatus Liberibacter americanus str. Sao Paulo", "rank": "Strain"}, "1261130": {"name": "Wohlfahrtiimonas chitiniclastica SH04", "rank": "Strain"}, "1408846": {"name": "Borrelia garinii IPT120", "rank": "Strain"}, "1169246": {"name": "Enterococcus faecalis EnGen0327", "rank": "Strain"}, "1169249": {"name": "Enterococcus faecalis EnGen0326", "rank": "Strain"}, "1481186": {"name": "Acinetobacter phage vB_AbaM_Acibel004", "rank": "Species"}, "1418419": {"name": "Staphylococcus aureus T22073", "rank": "Strain"}, "1354513": {"name": "Mycobacterium phage SargentShorty9", "rank": "Species"}, "1116040": {"name": "Escherichia coli P0299438.5", "rank": "Strain"}, "1116041": {"name": "Escherichia coli P0299438.6", "rank": "Strain"}, "1116042": {"name": "Escherichia coli P0299438.7", "rank": "Strain"}, "1321814": {"name": "Eubacterium brachy ATCC 33089", "rank": "Strain"}, "1116044": {"name": "Escherichia coli P0299438.9", "rank": "Strain"}, "1116045": {"name": "Escherichia coli P0299438.10", "rank": "Strain"}, "1116046": {"name": "Escherichia coli P0299438.11", "rank": "Strain"}, "1116047": {"name": "Escherichia coli P0299917.1", "rank": "Strain"}, "1116048": {"name": "Escherichia coli P0299917.2", "rank": "Strain"}, "1116049": {"name": "Escherichia coli P0299917.3", "rank": "Strain"}, "1151193": {"name": "Enterococcus faecalis EnGen0076", "rank": "Strain"}, "1321819": {"name": "Bacteroides pyogenes F0041", "rank": "Strain"}, "1321818": {"name": "Actinomyces johnsonii F0542", "rank": "Strain"}, "1068590": {"name": "Candidatus Rickettsia asemboensis", "rank": "Species"}, "1160202": {"name": "Brucella abortus F5/04-7", "rank": "Strain"}, "252305": {"name": "Oceanicola batsensis HTCC2597", "rank": "Strain"}, "252306": {"name": "Robiginitalea", "rank": "Genus"}, "252307": {"name": "Robiginitalea biformata", "rank": "Species"}, "252301": {"name": "Oceanicola", "rank": "Genus"}, "252302": {"name": "Oceanicola granulosus", "rank": "Species"}, "139276": {"name": "Dacryopinax", "rank": "Genus"}, "139270": {"name": "Newcastle disease virus B1", "rank": "Strain"}, "1115632": {"name": "Arthrobacter sp. 31Y", "rank": "Species"}, "1486403": {"name": "Mycobacterium phage Manad", "rank": "Species"}, "1124471": {"name": "Vibrio cholerae O1 str. 2009V-1131", "rank": "Strain"}, "358709": {"name": "Escherichia coli 101-1", "rank": "Strain"}, "358708": {"name": "Shigella dysenteriae 1012", "rank": "Strain"}, "1297562": {"name": "Phaseolibacter", "rank": "Genus"}, "162291": {"name": "Planomicrobium", "rank": "Genus"}, "1217668": {"name": "Acinetobacter lwoffii NIPH 478", "rank": "Strain"}, "1217669": {"name": "Acinetobacter lwoffii NIPH 715", "rank": "Strain"}, "1217666": {"name": "Acinetobacter junii CIP 107470", "rank": "Strain"}, "1217667": {"name": "Acinetobacter lwoffii CIP 70.31", "rank": "Strain"}, "1217664": {"name": "Acinetobacter junii CIP 64.5", "rank": "Strain"}, "1217665": {"name": "Acinetobacter junii NIPH 182", "rank": "Strain"}, "1217662": {"name": "Acinetobacter johnsonii ANC 3681", "rank": "Strain"}, "1217663": {"name": "Acinetobacter johnsonii CIP 64.6", "rank": "Strain"}, "1217660": {"name": "Acinetobacter indicus ANC 4215", "rank": "Strain"}, "683846": {"name": "Fervidicoccus fontis", "rank": "Species"}, "1160207": {"name": "Brucella abortus F6/05-3", "rank": "Strain"}, "319236": {"name": "Nonlabens sediminis", "rank": "Species"}, "1308540": {"name": "Escherichia coli HM26", "rank": "Strain"}, "1308541": {"name": "Xanthomonas citri subsp. citri A306", "rank": "Strain"}, "637887": {"name": "Ruminiclostridium thermocellum DSM 1313", "rank": "Strain"}, "457416": {"name": "Veillonella sp. 3_1_44", "rank": "Species"}, "1095668": {"name": "Neisseria meningitidis 2001212", "rank": "Strain"}, "1095669": {"name": "Neisseria meningitidis 2007056", "rank": "Strain"}, "265606": {"name": "Rhodopirellula baltica", "rank": "Species"}, "1402538": {"name": "Pseudomonas aeruginosa BWHPSA046", "rank": "Strain"}, "1402539": {"name": "Pseudomonas aeruginosa BWHPSA047", "rank": "Strain"}, "1402536": {"name": "Pseudomonas aeruginosa BWHPSA044", "rank": "Strain"}, "1402537": {"name": "Pseudomonas aeruginosa BWHPSA045", "rank": "Strain"}, "1402534": {"name": "Pseudomonas aeruginosa BWHPSA042", "rank": "Strain"}, "1402535": {"name": "Pseudomonas aeruginosa BWHPSA043", "rank": "Strain"}, "1402532": {"name": "Pseudomonas aeruginosa BWHPSA040", "rank": "Strain"}, "1402533": {"name": "Pseudomonas aeruginosa BWHPSA041", "rank": "Strain"}, "1402530": {"name": "Pseudomonas aeruginosa BWHPSA038", "rank": "Strain"}, "1095665": {"name": "Neisseria meningitidis 63006", "rank": "Strain"}, "1324296": {"name": "Mycobacterium tuberculosis TKK-01-0089", "rank": "Strain"}, "1324297": {"name": "Mycobacterium tuberculosis TKK-01-0090", "rank": "Strain"}, "1324294": {"name": "Mycobacterium tuberculosis TKK-01-0087", "rank": "Strain"}, "1324295": {"name": "Mycobacterium tuberculosis TKK-01-0088", "rank": "Strain"}, "1324292": {"name": "Mycobacterium tuberculosis TKK-01-0085", "rank": "Strain"}, "1324293": {"name": "Mycobacterium tuberculosis TKK-01-0086", "rank": "Strain"}, "1324290": {"name": "Mycobacterium tuberculosis TKK-01-0083", "rank": "Strain"}, "1324291": {"name": "Mycobacterium tuberculosis TKK-01-0084", "rank": "Strain"}, "1283295": {"name": "Delta proteobacterium JGI 0000059-K16", "rank": "Species"}, "1187851": {"name": "Rhodovulum sp. PH10", "rank": "Species"}, "1324298": {"name": "Mycobacterium tuberculosis TKK-01-0091", "rank": "Strain"}, "1324299": {"name": "Mycobacterium tuberculosis TKK-01-0092", "rank": "Strain"}, "1160205": {"name": "Brucella abortus 64/122", "rank": "Strain"}, "1418414": {"name": "Staphylococcus aureus M72095_021113", "rank": "Strain"}, "1151198": {"name": "Enterococcus faecalis EnGen0078", "rank": "Strain"}, "545650": {"name": "Sporothrix brasiliensis", "rank": "Species"}, "1151197": {"name": "Enterococcus faecalis EnGen0073", "rank": "Strain"}, "1418418": {"name": "Staphylococcus aureus T15928", "rank": "Strain"}, "1406863": {"name": "Staphylococcus aureus subsp. aureus Z172", "rank": "Strain"}, "877445": {"name": "Lachnobacterium bovis NK4B19", "rank": "Strain"}, "1406864": {"name": "Mesoplasma florum W37", "rank": "Strain"}, "1151192": {"name": "Enterococcus faecalis EnGen0059", "rank": "Strain"}, "1151191": {"name": "Enterococcus faecalis EnGen0063", "rank": "Strain"}, "1151190": {"name": "Enterococcus faecalis EnGen0066", "rank": "Strain"}, "1281160": {"name": "Escherichia coli KOEGE 43 (105a)", "rank": "Strain"}, "1124477": {"name": "Vibrio cholerae O1 str. 3582-05", "rank": "Strain"}, "765095": {"name": "Propionibacterium acnes HL046PA2", "rank": "Strain"}, "765094": {"name": "Propionibacterium acnes HL046PA1", "rank": "Strain"}, "765097": {"name": "Propionibacterium acnes HL005PA2", "rank": "Strain"}, "765096": {"name": "Propionibacterium acnes HL005PA1", "rank": "Strain"}, "765091": {"name": "Propionibacterium acnes HL059PA1", "rank": "Strain"}, "765090": {"name": "Propionibacterium acnes HL025PA2", "rank": "Strain"}, "765093": {"name": "Propionibacterium acnes HL086PA1", "rank": "Strain"}, "765092": {"name": "Propionibacterium acnes HL059PA2", "rank": "Strain"}, "1193292": {"name": "Klebsiella pneumoniae subsp. pneumoniae 1084", "rank": "Strain"}, "765098": {"name": "Propionibacterium acnes HL005PA3", "rank": "Strain"}, "1408273": {"name": "Pseudomonas aeruginosa LESB65", "rank": "Strain"}, "1408272": {"name": "Pseudomonas aeruginosa LES431", "rank": "Strain"}, "1408271": {"name": "Pseudomonas aeruginosa LES400", "rank": "Strain"}, "1408277": {"name": "Pseudomonas aeruginosa LESlike7", "rank": "Strain"}, "1408276": {"name": "Pseudomonas aeruginosa LESlike5", "rank": "Strain"}, "1408275": {"name": "Pseudomonas aeruginosa LESlike4", "rank": "Strain"}, "1408274": {"name": "Pseudomonas aeruginosa LESlike1", "rank": "Strain"}, "459424": {"name": "Mycobacterium liflandii 128FXT", "rank": "Strain"}, "1124478": {"name": "Vibrio cholerae O1 str. C6706", "rank": "Strain"}, "1203560": {"name": "Corynebacterium sp. KPL1821", "rank": "Species"}, "1455270": {"name": "Mycobacterium tuberculosis NRITLD51", "rank": "Strain"}, "1455273": {"name": "Mycobacterium tuberculosis NRITLD54", "rank": "Strain"}, "1203563": {"name": "Corynebacterium sp. KPL1856", "rank": "Species"}, "1203564": {"name": "Corynebacterium sp. KPL1857", "rank": "Species"}, "1455274": {"name": "Mycobacterium tuberculosis NRITLD55", "rank": "Strain"}, "1203566": {"name": "Corynebacterium sp. KPL1859", "rank": "Species"}, "1203567": {"name": "Corynebacterium sp. KPL1860", "rank": "Species"}, "1455279": {"name": "Mycobacterium tuberculosis NRITLD60", "rank": "Strain"}, "1455278": {"name": "Mycobacterium tuberculosis NRITLD59", "rank": "Strain"}, "5159": {"name": "Ophiostoma", "rank": "Genus"}, "1398989": {"name": "Acinetobacter baumannii UH9007", "rank": "Strain"}, "1398988": {"name": "Acinetobacter baumannii UH8907", "rank": "Strain"}, "1398985": {"name": "Acinetobacter baumannii UH8407", "rank": "Strain"}, "1398984": {"name": "Acinetobacter baumannii UH8107", "rank": "Strain"}, "1398987": {"name": "Acinetobacter baumannii UH8807", "rank": "Strain"}, "1398986": {"name": "Acinetobacter baumannii UH8707", "rank": "Strain"}, "1398981": {"name": "Acinetobacter baumannii UH7707", "rank": "Strain"}, "1398980": {"name": "Acinetobacter baumannii UH7607", "rank": "Strain"}, "1398983": {"name": "Acinetobacter baumannii UH7907", "rank": "Strain"}, "1398982": {"name": "Acinetobacter baumannii UH7807", "rank": "Strain"}, "169438": {"name": "Saccharospirillum impatiens", "rank": "Species"}, "1396859": {"name": "Marinobacter sp. C1S70", "rank": "Species"}, "1396858": {"name": "Marinobacter sp. ES-1", "rank": "Species"}, "1470589": {"name": "Pseudomonas sp. RIT288", "rank": "Species"}, "169435": {"name": "Anaerotruncus colihominis", "rank": "Species"}, "904801": {"name": "Staphylococcus aureus subsp. aureus CO-86", "rank": "Strain"}, "904800": {"name": "Staphylococcus aureus subsp. aureus CO-85", "rank": "Strain"}, "904803": {"name": "Staphylococcus aureus subsp. aureus CO-99", "rank": "Strain"}, "904802": {"name": "Staphylococcus aureus subsp. aureus CO-98", "rank": "Strain"}, "73778": {"name": "Methylocaldum", "rank": "Genus"}, "45497": {"name": "Clostridium ultunense", "rank": "Species"}, "77608": {"name": "Pseudoalteromonas distincta", "rank": "Species"}, "1028799": {"name": "Staphylococcus aureus subsp. aureus VC40", "rank": "Strain"}, "1004787": {"name": "Alteromonas macleodii str. 'Balearic Sea AD45'", "rank": "Strain"}, "1004786": {"name": "Alteromonas macleodii AltDE1", "rank": "Strain"}, "1004785": {"name": "Alteromonas macleodii str. 'Black Sea 11'", "rank": "Strain"}, "885273": {"name": "Campylobacter jejuni subsp. jejuni P110B", "rank": "Strain"}, "1111106": {"name": "Ancylobacter sp. FA202", "rank": "Species"}, "1004788": {"name": "Alteromonas macleodii str. 'English Channel 673'", "rank": "Strain"}, "748727": {"name": "Clostridium ljungdahlii DSM 13528", "rank": "Strain"}, "5007": {"name": "Brettanomyces bruxellensis", "rank": "Species"}, "1502290": {"name": "Marine Group I thaumarchaeote SCGC AAA799-D07", "rank": "Species"}, "1502291": {"name": "Marine Group I thaumarchaeote SCGC AAA799-D11", "rank": "Species"}, "1502292": {"name": "Marine Group I thaumarchaeote SCGC AAA799-E16", "rank": "Species"}, "1502293": {"name": "Marine Group I thaumarchaeote SCGC AAA799-N04", "rank": "Species"}, "1502294": {"name": "Marine Group I thaumarchaeote SCGC AAA799-O18", "rank": "Species"}, "1502295": {"name": "Marine Group I thaumarchaeote SCGC AAA799-P11", "rank": "Species"}, "5009": {"name": "Taphrinaceae", "rank": "Family"}, "5008": {"name": "Taphrinales", "rank": "Order"}, "1231392": {"name": "Oceaniovalibus guishaninsula JLT2003", "rank": "Strain"}, "1231390": {"name": "Pseudomonas fluorescens BS2", "rank": "Strain"}, "1231391": {"name": "Pusillimonas noertemannii BS8", "rank": "Strain"}, "90736": {"name": "Moritella marina", "rank": "Species"}, "255527": {"name": "Saccharospirillaceae", "rank": "Family"}, "255526": {"name": "Halothiobacillaceae", "rank": "Family"}, "1126681": {"name": "Bacillus cereus F", "rank": "Strain"}, "1089300": {"name": "Streptococcus pneumoniae R6M2-PG", "rank": "Strain"}, "1052832": {"name": "Aigarchaeota archaeon SCGC AAA471-J07", "rank": "Species"}, "1052833": {"name": "Aigarchaeota archaeon SCGC AAA471-J08", "rank": "Species"}, "1052830": {"name": "Aigarchaeota archaeon SCGC AAA471-G05", "rank": "Species"}, "1052831": {"name": "Aigarchaeota archaeon SCGC AAA471-I13", "rank": "Species"}, "1052838": {"name": "Aigarchaeota archaeon JGI 0000001-A7", "rank": "Species"}, "1052839": {"name": "Aigarchaeota archaeon JGI 0000001-B8", "rank": "Species"}, "257281": {"name": "Nocardia concava", "rank": "Species"}, "371720": {"name": "Streptomyces monomycini", "rank": "Species"}, "489830": {"name": "Helicoverpa armigera granulovirus", "rank": "Species"}, "886980": {"name": "Skua siadenovirus A", "rank": "Species"}, "53399": {"name": "Hyphomicrobium denitrificans", "rank": "Species"}, "1169176": {"name": "Salinispora arenicola CNH877", "rank": "Strain"}, "1169177": {"name": "Salinispora arenicola CNY260", "rank": "Strain"}, "1169174": {"name": "Salinispora arenicola CNP105", "rank": "Strain"}, "1169175": {"name": "Salinispora arenicola CNH962", "rank": "Strain"}, "1169172": {"name": "Salinispora arenicola CNT799", "rank": "Strain"}, "1169173": {"name": "Salinispora arenicola CNY280", "rank": "Strain"}, "1071073": {"name": "Bacillus sp. NSP22.2", "rank": "Species"}, "1071072": {"name": "Bacillus sp. NSP2.1", "rank": "Species"}, "1071079": {"name": "Bacillus sp. SB47", "rank": "Species"}, "1071078": {"name": "Bacillus sp. NSP9.1", "rank": "Species"}, "1169178": {"name": "Salinispora arenicola CNS051", "rank": "Strain"}, "1169179": {"name": "Salinispora arenicola CNY231", "rank": "Strain"}, "1235430": {"name": "Equus ferus caballus papillomavirus type 7", "rank": "Species"}, "28896": {"name": "Thermoanaerobacterium saccharolyticum", "rank": "Species"}, "1316040": {"name": "Human papillomavirus 132-like viruses", "rank": "Species"}, "28895": {"name": "Thermoanaerobacterium", "rank": "Genus"}, "28892": {"name": "Methanofollis liminatans DSM 4140", "rank": "Strain"}, "28890": {"name": "Euryarchaeota", "rank": "Phylum"}, "189780": {"name": "Unclassified Thermotogales (miscellaneous)", "rank": "No rank"}, "138954": {"name": "Parechovirus", "rank": "Genus"}, "138950": {"name": "Enterovirus C", "rank": "Species"}, "138951": {"name": "Enterovirus D", "rank": "Species"}, "575917": {"name": "Tomato leaf curl Patna virus", "rank": "Species"}, "1422302": {"name": "Staphylococcus aureus DAR5886", "rank": "Strain"}, "338473": {"name": "Actinomyces phage Av-1", "rank": "Species"}, "338478": {"name": "Macaque simian foamy virus", "rank": "Species"}, "1422300": {"name": "Staphylococcus aureus DAR5888", "rank": "Strain"}, "1279019": {"name": "Thioalkalivibrio thiocyanoxidans ARh2", "rank": "Strain"}, "1279018": {"name": "Stenotrophomonas maltophilia ATCC 19867", "rank": "Strain"}, "1279015": {"name": "Oceanimonas smirnovii ATCC BAA-899", "rank": "Strain"}, "1279017": {"name": "Microbulbifer variabilis ATCC 700307", "rank": "Strain"}, "1279016": {"name": "Pseudoalteromonas piscicida ATCC 15057", "rank": "Strain"}, "1279011": {"name": "Mycobacterium tuberculosis PR05", "rank": "Strain"}, "1279010": {"name": "Proteus mirabilis PR03", "rank": "Strain"}, "1279012": {"name": "Streptococcus agalactiae PR06", "rank": "Strain"}, "1047063": {"name": "WS1 bacterium JGI 0000059-K21", "rank": "Species"}, "1047062": {"name": "Unclassified candidate division WS1", "rank": "No rank"}, "1047061": {"name": "Marinimicrobia bacterium JGI 0000059-L03", "rank": "Species"}, "1047060": {"name": "Marinimicrobia bacterium JGI 0000059-E23", "rank": "Species"}, "1447539": {"name": "Pseudomonas aeruginosa BWH031", "rank": "Strain"}, "1447538": {"name": "Pseudomonas aeruginosa BWH030", "rank": "Strain"}, "10239": {"name": "Viruses", "rank": "Superkingdom"}, "1447534": {"name": "Pseudomonas aeruginosa 3579", "rank": "Strain"}, "1447537": {"name": "Pseudomonas aeruginosa BWH029", "rank": "Strain"}, "1447536": {"name": "Pseudomonas aeruginosa 3581", "rank": "Strain"}, "1447531": {"name": "Pseudomonas aeruginosa 3576", "rank": "Strain"}, "1447530": {"name": "Pseudomonas aeruginosa 3575", "rank": "Strain"}, "1447533": {"name": "Pseudomonas aeruginosa 3578", "rank": "Strain"}, "1447532": {"name": "Pseudomonas aeruginosa 3577", "rank": "Strain"}, "1519999": {"name": "Staphylococcus phage phiBU01", "rank": "Species"}, "4815": {"name": "Spizellomyces", "rank": "Genus"}, "689781": {"name": "Oribacterium sp. NK2B42", "rank": "Species"}, "391165": {"name": "Granulibacter bethesdensis CGDNIH1", "rank": "Strain"}, "1273749": {"name": "Halovirus HGTV-1", "rank": "Species"}, "1273748": {"name": "Halovirus HCTV-5", "rank": "Species"}, "1273747": {"name": "Halovirus HCTV-2", "rank": "Species"}, "1273746": {"name": "Halovirus HCTV-1", "rank": "Species"}, "412422": {"name": "Francisella tularensis subsp. holarctica 257", "rank": "Strain"}, "1273741": {"name": "Bacillus phage Eoghan", "rank": "Species"}, "412420": {"name": "Yersinia pestis CA88-4125", "rank": "Strain"}, "1234142": {"name": "Listeria monocytogenes N53-1", "rank": "Strain"}, "242861": {"name": "Burkholderia phage BcepNazgul", "rank": "Species"}, "1234146": {"name": "Bacillus sp. WBUNB001", "rank": "Species"}, "171693": {"name": "Oceanobacillus picturae", "rank": "Species"}, "171695": {"name": "Thermodesulfatator indicus", "rank": "Species"}, "379535": {"name": "Scytonema hofmanni UTEX B 1581", "rank": "Species"}, "11676": {"name": "Human immunodeficiency virus 1", "rank": "Species"}, "94008": {"name": "Thermicanus", "rank": "Genus"}, "94009": {"name": "Thermicanus aegyptius", "rank": "Species"}, "11673": {"name": "Feline immunodeficiency virus", "rank": "Species"}, "1229512": {"name": "Blattabacterium sp. (Panesthia angustipennis spadica) str. BPAA", "rank": "Strain"}, "1522432": {"name": "Pseudoduganella", "rank": "Genus"}, "1080067": {"name": "Citrobacter sp. S-77", "rank": "Species"}, "520458": {"name": "Brucella ceti M490/95/1", "rank": "Strain"}, "520459": {"name": "Brucella ceti M644/93/1", "rank": "Strain"}, "68347": {"name": "Wiseana iridescent virus", "rank": "Strain"}, "520454": {"name": "Brucella abortus bv. 6 str. 870", "rank": "Strain"}, "520455": {"name": "Brucella abortus bv. 9 str. C68", "rank": "Strain"}, "520456": {"name": "Brucella neotomae 5K33", "rank": "Strain"}, "520457": {"name": "Brucella ceti B1/94", "rank": "Strain"}, "520450": {"name": "Brucella abortus bv. 2 str. 86/8/59", "rank": "Strain"}, "520451": {"name": "Brucella abortus bv. 3 str. Tulya", "rank": "Strain"}, "520452": {"name": "Brucella abortus bv. 4 str. 292", "rank": "Strain"}, "520453": {"name": "Brucella abortus bv. 5 str. B3196", "rank": "Strain"}, "991992": {"name": "Vibrio cholerae CP1037(10)", "rank": "Strain"}, "1230342": {"name": "Clostridium tetanomorphum DSM 665", "rank": "Strain"}, "1432848": {"name": "Oenococcus phage phiS13", "rank": "Species"}, "1230340": {"name": "Listeria monocytogenes serotype 4b str. LL195", "rank": "Strain"}, "1230341": {"name": "Salimicrobium sp. MJ3", "rank": "Species"}, "1432847": {"name": "Oenococcus phage phiS11", "rank": "Species"}, "1388257": {"name": "Staphylococcus aureus M0386", "rank": "Strain"}, "991994": {"name": "Vibrio cholerae CP1044(17)", "rank": "Strain"}, "713089": {"name": "Croton yellow vein mosaic alphasatellite", "rank": "Species"}, "29306": {"name": "Streptomyces griseoluteus", "rank": "Species"}, "991997": {"name": "Vibrio cholerae BJG-01", "rank": "Strain"}, "29303": {"name": "Streptomyces cattleya", "rank": "Species"}, "322159": {"name": "Streptococcus thermophilus LMD-9", "rank": "Strain"}, "1463853": {"name": "Streptomyces sp. NRRL F-5008", "rank": "Species"}, "1005432": {"name": "Escherichia coli 99.0839", "rank": "Strain"}, "649742": {"name": "Actinomyces odontolyticus F0309", "rank": "Strain"}, "649743": {"name": "Actinomyces sp. oral taxon 848 str. F0332", "rank": "Strain"}, "649746": {"name": "Anaerobaculum hydrogeniformans", "rank": "Species"}, "649747": {"name": "Aneurinibacillus aneurinilyticus ATCC 12856", "rank": "Strain"}, "1005430": {"name": "Escherichia coli 99.0816", "rank": "Strain"}, "1448595": {"name": "Mycobacterium tuberculosis TKK_04_0137", "rank": "Strain"}, "1005436": {"name": "Escherichia coli 99.1805", "rank": "Strain"}, "1168547": {"name": "Acartia tonsa copepod circovirus", "rank": "Species"}, "1158552": {"name": "Enterococcus faecalis EnGen0234", "rank": "Strain"}, "1448593": {"name": "Mycobacterium tuberculosis TKK_04_0134", "rank": "Strain"}, "1005434": {"name": "Escherichia coli 99.0814", "rank": "Strain"}, "879310": {"name": "Selenomonas sp. oral taxon 137 str. F0430", "rank": "Strain"}, "1005435": {"name": "Escherichia coli 99.1762", "rank": "Strain"}, "1087981": {"name": "Saccharomyces cerevisiae YJSH1", "rank": "Strain"}, "1037915": {"name": "Pseudomonas chlororaphis O6", "rank": "Strain"}, "246969": {"name": "Thermococcus sp. AM4", "rank": "Species"}, "12329": {"name": "Tenuivirus", "rank": "Genus"}, "12321": {"name": "Alfalfa mosaic virus", "rank": "Species"}, "12320": {"name": "Alfamovirus", "rank": "Genus"}, "12327": {"name": "Barley stripe mosaic virus", "rank": "Species"}, "12326": {"name": "Hordeivirus", "rank": "Genus"}, "1177931": {"name": "Thiovulum sp. ES", "rank": "Species"}, "1422178": {"name": "Staphylococcus aureus DAR3847", "rank": "Strain"}, "1422179": {"name": "Staphylococcus aureus DAR3859", "rank": "Strain"}, "645134": {"name": "Spizellomyces punctatus DAOM BR117", "rank": "Strain"}, "620903": {"name": "Negativicoccus succinicivorans", "rank": "Species"}, "1422171": {"name": "Staphylococcus aureus DAR3794", "rank": "Strain"}, "1422172": {"name": "Staphylococcus aureus DAR3796", "rank": "Strain"}, "1422173": {"name": "Staphylococcus aureus DAR3799", "rank": "Strain"}, "1422174": {"name": "Staphylococcus aureus DAR3840", "rank": "Strain"}, "1422175": {"name": "Staphylococcus aureus DAR3842", "rank": "Strain"}, "1422176": {"name": "Staphylococcus aureus DAR3844", "rank": "Strain"}, "1422177": {"name": "Staphylococcus aureus DAR3845", "rank": "Strain"}, "600669": {"name": "Nakaseomyces/Candida clade", "rank": "No rank"}, "1232458": {"name": "Clostridiales bacterium VE202-29", "rank": "Species"}, "1232459": {"name": "Oscillospiraceae bacterium VE202-24", "rank": "Species"}, "204507": {"name": "Neodiprion abietis NPV", "rank": "Species"}, "1159204": {"name": "Mycoplasma gallisepticum NC08_2008.031-4-3P", "rank": "Strain"}, "1159203": {"name": "Mycoplasma gallisepticum CA06_2006.052-5-2P", "rank": "Strain"}, "1159202": {"name": "Mycoplasma gallisepticum NC06_2006.080-5-2P", "rank": "Strain"}, "28072": {"name": "Nostoc sp. PCC 7524", "rank": "Species"}, "28073": {"name": "Lyngbya", "rank": "Genus"}, "1232450": {"name": "Clostridium sp. VE202-10", "rank": "Species"}, "1232451": {"name": "Clostridium hathewayi VE202-11", "rank": "Strain"}, "1232452": {"name": "Clostridiales bacterium VE202-14", "rank": "Species"}, "1232453": {"name": "Clostridiales bacterium VE202-21", "rank": "Species"}, "1232454": {"name": "Clostridiales bacterium VE202-26", "rank": "Species"}, "1159209": {"name": "Streptococcus pneumoniae SPAR27", "rank": "Strain"}, "1159208": {"name": "Streptococcus mitis SPAR10", "rank": "Strain"}, "1285598": {"name": "Rosellinia necatrix megabirnavirus 1", "rank": "Species"}, "59893": {"name": "Paenibacillus peoriae", "rank": "Species"}, "1182263": {"name": "Rickettsia sp. MEAM1 (Bemisia tabaci)", "rank": "Strain"}, "525369": {"name": "Proteus mirabilis ATCC 29906", "rank": "Strain"}, "525368": {"name": "Mycobacterium parascrofulaceum ATCC BAA-614", "rank": "Strain"}, "525361": {"name": "Lactobacillus rhamnosus LMS2-1", "rank": "Strain"}, "525362": {"name": "Lactobacillus ruminis ATCC 25644", "rank": "Strain"}, "525365": {"name": "Lactobacillus ultunensis DSM 16047", "rank": "Strain"}, "525367": {"name": "Listeria grayi DSM 20601", "rank": "Strain"}, "198618": {"name": "Pseudomonas umsongensis", "rank": "Species"}, "1230383": {"name": "Malassezia sympodialis ATCC 42132", "rank": "Strain"}, "198610": {"name": "Unclassified Satellite Nucleic Acids", "rank": "No rank"}, "198612": {"name": "Groundnut bud necrosis virus", "rank": "Species"}, "862945": {"name": "Avian paramyxovirus penguin/Falkland Islands/324/2007", "rank": "Species"}, "936564": {"name": "Klebsiella sp. AS10", "rank": "Species"}, "1138929": {"name": "Enterococcus faecium EnGen0048", "rank": "Strain"}, "862943": {"name": "Spissistilus festinus virus 1", "rank": "Species"}, "1138925": {"name": "Enterococcus faecium EnGen0052", "rank": "Strain"}, "1138924": {"name": "Enterococcus faecium EnGen0056", "rank": "Strain"}, "1138923": {"name": "Enterococcus faecium EnGen0041", "rank": "Strain"}, "1138922": {"name": "Enterococcus faecium EnGen0030", "rank": "Strain"}, "1138921": {"name": "Enterococcus faecium EnGen0038", "rank": "Strain"}, "1138920": {"name": "Enterococcus faecium EnGen0034", "rank": "Strain"}, "760888": {"name": "Streptococcus pneumoniae Netherlands15B-37", "rank": "Strain"}, "1402641": {"name": "Staphylococcus aureus M1127", "rank": "Strain"}, "1105330": {"name": "Escherichia coli TW07509", "rank": "Strain"}, "37124": {"name": "Chikungunya virus", "rank": "Species"}, "760881": {"name": "Streptococcus pneumoniae EU-NP05", "rank": "Strain"}, "760880": {"name": "Streptococcus pneumoniae EU-NP04", "rank": "Strain"}, "760883": {"name": "Streptococcus pneumoniae NP141", "rank": "Strain"}, "760882": {"name": "Streptococcus pneumoniae NP112", "rank": "Strain"}, "760885": {"name": "Streptococcus pneumoniae NP170", "rank": "Strain"}, "760884": {"name": "Streptococcus pneumoniae NP070", "rank": "Strain"}, "760887": {"name": "Streptococcus pneumoniae NorthCarolina6A-23", "rank": "Strain"}, "760886": {"name": "Streptococcus pneumoniae NP127", "rank": "Strain"}, "52258": {"name": "Streptomyces flavovirens", "rank": "Species"}, "1038921": {"name": "Pseudomonas chlororaphis subsp. aureofaciens 30-84", "rank": "Strain"}, "1038922": {"name": "Pseudomonas fluorescens Q2-87", "rank": "Strain"}, "1038923": {"name": "Pseudomonas fluorescens Q8r1-96", "rank": "Strain"}, "1038924": {"name": "Pseudomonas fluorescens SS101", "rank": "Strain"}, "1038927": {"name": "Escherichia coli O104:H4", "rank": "Strain"}, "1295803": {"name": "Mycobacterium tuberculosis OFXR-11", "rank": "Strain"}, "1121880": {"name": "Ferrimonas senticii DSM 18821", "rank": "Strain"}, "526476": {"name": "Tomato leaf curl Palampur virus", "rank": "Species"}, "1444306": {"name": "Sporolactobacillus terrae DSM 11697", "rank": "Strain"}, "146507": {"name": "Aphid secondary symbionts", "rank": "No rank"}, "1357825": {"name": "Enterobacteria phage fiAA91-ss", "rank": "Species"}, "309120": {"name": "Dialister micraerophilus", "rank": "Species"}, "146500": {"name": "Watermelon mosaic virus", "rank": "Species"}, "236750": {"name": "Bacillus phage Bam35c", "rank": "Strain"}, "34383": {"name": "Mitosporic Onygenales", "rank": "No rank"}, "34387": {"name": "Trichophyton tonsurans", "rank": "Species"}, "114922": {"name": "Carrot thin leaf virus", "rank": "Species"}, "114921": {"name": "Beet mosaic virus", "rank": "Species"}, "34384": {"name": "Arthrodermataceae", "rank": "Family"}, "555313": {"name": "Phocaeicola abscessus", "rank": "Species"}, "46913": {"name": "Devosia", "rank": "Genus"}, "555311": {"name": "Sulfolobus solfataricus 98/2", "rank": "Strain"}, "1182167": {"name": "Salmonella enterica subsp. enterica serovar Heidelberg str. CFSAN00325", "rank": "Strain"}, "1182164": {"name": "Salmonella enterica subsp. enterica serovar Heidelberg str. CFSAN00322", "rank": "Strain"}, "1258564": {"name": "Vibrio cholerae P-18785", "rank": "Strain"}, "1258567": {"name": "Escherichia coli LCT-EC52", "rank": "Strain"}, "1461792": {"name": "Malvastrum leaf curl Guangdong betasatellite", "rank": "Species"}, "1182168": {"name": "Salmonella enterica subsp. enterica serovar Heidelberg str. CFSAN00326", "rank": "Strain"}, "39650": {"name": "Cellvibrio mixtus", "rank": "Species"}, "204086": {"name": "Staphylococcus phage 44AHJD", "rank": "Species"}, "69395": {"name": "Caulobacter henricii", "rank": "Species"}, "1305838": {"name": "Streptomyces sp. KhCrAH-40", "rank": "Species"}, "1226323": {"name": "Oscillibacter sp. KLE 1745", "rank": "Species"}, "1435056": {"name": "Trueperella pyogenes TP8", "rank": "Strain"}, "1468169": {"name": "Mycobacterium phage Lamina13", "rank": "Species"}, "152480": {"name": "Burkholderia ambifaria", "rank": "Species"}, "425400": {"name": "Helicobacter sp. MIT 01-6451", "rank": "Species"}, "999627": {"name": "Sedimentitalea nanhaiensis", "rank": "Species"}, "999629": {"name": "Helicobacter pylori B45", "rank": "Strain"}, "999628": {"name": "Methyloversatilis universalis EHg5", "rank": "Strain"}, "1217821": {"name": "Sibine fusca densovirus", "rank": "Strain"}, "1444308": {"name": "Geobacillus thermocatenulatus GS-1", "rank": "Strain"}, "518643": {"name": "Bifidobacterium mongoliense", "rank": "Species"}, "161890": {"name": "Corynebacterium mastitidis", "rank": "Species"}, "161896": {"name": "Corynebacterium camporealensis", "rank": "Species"}, "45254": {"name": "Dysgonomonas capnocytophagoides", "rank": "Species"}, "1189620": {"name": "Flavobacterium sp. ACAM 123", "rank": "Species"}, "45253": {"name": "Unclassified Bacteroidaceae", "rank": "No rank"}, "714943": {"name": "Mucilaginibacter paludis DSM 18603", "rank": "Strain"}, "1550401": {"name": "Marine actinobacterium MedAcidi-G2B", "rank": "Species"}, "1104568": {"name": "Synergistetes bacterium JGI 0000079-D21", "rank": "Species"}, "1104565": {"name": "Poribacteria bacterium WGA-4CII", "rank": "Species"}, "1104566": {"name": "Poribacteria bacterium WGA-3G", "rank": "Species"}, "700939": {"name": "Enterobacteria phage vB_EcoM-VR7", "rank": "Species"}, "587753": {"name": "Pseudomonas chlororaphis", "rank": "Species"}, "721133": {"name": "Nitratireductor indicus", "rank": "Species"}, "478009": {"name": "Halobacterium salinarum R1", "rank": "Strain"}, "478008": {"name": "Escherichia coli O157:H7 str. EC869", "rank": "Strain"}, "478005": {"name": "Escherichia coli O157:H7 str. EC4486", "rank": "Strain"}, "478004": {"name": "Escherichia coli O157:H7 str. EC4401", "rank": "Strain"}, "478007": {"name": "Escherichia coli O157:H7 str. EC508", "rank": "Strain"}, "478006": {"name": "Escherichia coli O157:H7 str. EC4501", "rank": "Strain"}, "1462685": {"name": "Bush viper reovirus", "rank": "Species"}, "285006": {"name": "Saccharomyces cerevisiae RM11-1a", "rank": "Strain"}, "368624": {"name": "Halorubrum lipolyticum", "rank": "Species"}, "368623": {"name": "Halorubrum aidingense", "rank": "Species"}, "1298909": {"name": "Oxalobacteraceae bacterium JGI 0001012-C15", "rank": "Species"}, "1236767": {"name": "Canine papillomavirus 14", "rank": "Species"}, "197461": {"name": "Nesiotobacter exalbescens", "rank": "Species"}, "404011": {"name": "Shewanella piezotolerans", "rank": "Species"}, "431241": {"name": "Trichoderma reesei QM6a", "rank": "Strain"}, "55097": {"name": "Mobala virus", "rank": "Species"}, "1145149": {"name": "Neisseria meningitidis NM36", "rank": "Strain"}, "1145148": {"name": "Neisseria meningitidis NM35", "rank": "Strain"}, "1130329": {"name": "Calescamantes bacterium JGI 0000106-G12", "rank": "Species"}, "1029825": {"name": "Brucella melitensis NI", "rank": "Strain"}, "1145141": {"name": "Neisseria meningitidis 2002007", "rank": "Strain"}, "1145140": {"name": "Neisseria meningitidis 2000063", "rank": "Strain"}, "1130327": {"name": "Thermotogae bacterium JGI 0000106-O11", "rank": "Species"}, "1130326": {"name": "Unclassified Thermotogae", "rank": "No rank"}, "1145145": {"name": "Neisseria meningitidis NM133", "rank": "Strain"}, "1145144": {"name": "Neisseria meningitidis NM607", "rank": "Strain"}, "1145147": {"name": "Neisseria meningitidis NM32", "rank": "Strain"}, "1145146": {"name": "Neisseria meningitidis NM23", "rank": "Strain"}, "325111": {"name": "Ludwigia yellow vein virus", "rank": "Species"}, "325113": {"name": "Ludwigia yellow vein virus-associated DNA beta", "rank": "Species"}, "180526": {"name": "Tobacco curly shoot virus", "rank": "Species"}, "267375": {"name": "Pseudoalteromonas marina", "rank": "Species"}, "267377": {"name": "Methanococcus maripaludis S2", "rank": "Strain"}, "234665": {"name": "Unclassified Gemmatimonadetes", "rank": "No rank"}, "911119": {"name": "Methanobrevibacter smithii TS146B", "rank": "Strain"}, "911118": {"name": "Methanobrevibacter smithii TS146A", "rank": "Strain"}, "911113": {"name": "Bryobacter", "rank": "Genus"}, "1037411": {"name": "Lactobacillus johnsonii pf01", "rank": "Strain"}, "362948": {"name": "Lactobacillus salivarius UCC118", "rank": "Strain"}, "911116": {"name": "Methanobrevibacter smithii TS145A", "rank": "Strain"}, "1476857": {"name": "Bacillus sp. B-jedd", "rank": "Species"}, "557760": {"name": "Rhodobacter sphaeroides KD131", "rank": "Strain"}, "1436302": {"name": "Edwardsiella tarda ET081126R", "rank": "Strain"}, "911244": {"name": "Pseudomonas sp. CFT9", "rank": "Species"}, "1402783": {"name": "Staphylococcus aureus M1298", "rank": "Strain"}, "1192868": {"name": "Pseudaminobacter salicylatoxidans KCT001", "rank": "Strain"}, "190809": {"name": "Arabis mosaic virus large satellite RNA", "rank": "Species"}, "1192866": {"name": "Leptospira borgpetersenii serovar Pomona str. 200901868", "rank": "Strain"}, "1192864": {"name": "Leptospira borgpetersenii serovar Mini str. 200901116", "rank": "Strain"}, "1192865": {"name": "Leptospira borgpetersenii serovar Pomona", "rank": "Strain"}, "1407497": {"name": "Staphylococcus aureus S0924", "rank": "Strain"}, "1407493": {"name": "Shigella phage SfIV", "rank": "Species"}, "665099": {"name": "Bacillus oceanisediminis", "rank": "Species"}, "1407498": {"name": "Staphylococcus aureus S1475", "rank": "Strain"}, "1265510": {"name": "Candidatus Ancillula trichonymphae ImTpAt1", "rank": "Strain"}, "568813": {"name": "Streptococcus suis SC84", "rank": "Strain"}, "910996": {"name": "Hafnia alvei ATCC 13337", "rank": "Strain"}, "928724": {"name": "Saccharomonospora glauca K62", "rank": "Strain"}, "991791": {"name": "Clostridium acetobutylicum DSM 1731", "rank": "Strain"}, "944969": {"name": "Cynomolgus macaque cytomegalovirus strain Ottawa", "rank": "Strain"}, "1448139": {"name": "Aeromonas hydrophila YL17", "rank": "Strain"}, "140892": {"name": "Rickettsia conorii subsp. caspia A-167", "rank": "Strain"}, "1448135": {"name": "Mycoplasma leonicaptivi ATCC 49890", "rank": "Strain"}, "1448136": {"name": "Roseomonas mucosa ATCC BAA-692", "rank": "Strain"}, "1565129": {"name": "Shewanella sp. ECSMB14101", "rank": "Species"}, "1448132": {"name": "Mycoplasma molare ATCC 27746", "rank": "Strain"}, "1436301": {"name": "Edwardsiella tarda ET070829", "rank": "Strain"}, "116532": {"name": "Unclassified Nocardioidaceae", "rank": "No rank"}, "391624": {"name": "Oceanibulbus indolifex HEL-45", "rank": "Strain"}, "85643": {"name": "Thauera sp. MZ1T", "rank": "Species"}, "467174": {"name": "Rickettsia hoogstraalii", "rank": "Species"}, "1168221": {"name": "Coniosporium apollinis CBS 100218", "rank": "Strain"}, "1190": {"name": "Fischerella", "rank": "Genus"}, "1288969": {"name": "Staphylococcus aureus subsp. aureus S0462", "rank": "Strain"}, "1288968": {"name": "Staphylococcus aureus subsp. aureus S0460", "rank": "Strain"}, "1288967": {"name": "Staphylococcus aureus subsp. aureus S2398", "rank": "Strain"}, "1288966": {"name": "Staphylococcus aureus subsp. aureus S2397", "rank": "Strain"}, "1288963": {"name": "Cyclobacteriaceae bacterium AK24", "rank": "Species"}, "351746": {"name": "Pseudomonas putida F1", "rank": "Strain"}, "249151": {"name": "Neodiprion lecontei nucleopolyhedrovirus", "rank": "Species"}, "351745": {"name": "Shewanella sp. W3-18-1", "rank": "Species"}, "1156919": {"name": "Achromobacter piechaudii HLE", "rank": "Strain"}, "1214218": {"name": "Streptococcus suis YS74", "rank": "Strain"}, "1214219": {"name": "Streptococcus suis YS77", "rank": "Strain"}, "1561022": {"name": "Streptomyces sp. CCM_MD2014", "rank": "Species"}, "1561023": {"name": "Curtobacterium sp. MR_MD2014", "rank": "Species"}, "1214212": {"name": "Streptococcus suis YS6", "rank": "Strain"}, "1214213": {"name": "Streptococcus suis YS64", "rank": "Strain"}, "1214210": {"name": "Streptococcus suis YS57", "rank": "Strain"}, "1214211": {"name": "Streptococcus suis YS59", "rank": "Strain"}, "1214216": {"name": "Streptococcus suis YS7", "rank": "Strain"}, "1214217": {"name": "Streptococcus suis YS72", "rank": "Strain"}, "1214214": {"name": "Streptococcus suis YS66", "rank": "Strain"}, "1214215": {"name": "Streptococcus suis YS67", "rank": "Strain"}, "1121924": {"name": "Glaciibacter superstes DSM 21135", "rank": "Strain"}, "471876": {"name": "Streptococcus pyogenes NZ131", "rank": "Strain"}, "471875": {"name": "Ruminococcus lactaris ATCC 29176", "rank": "Strain"}, "471874": {"name": "Providencia stuartii ATCC 25827", "rank": "Strain"}, "471872": {"name": "Streptococcus infantarius subsp. infantarius ATCC BAA-102", "rank": "Strain"}, "471871": {"name": "Clostridium sporogenes ATCC 15579", "rank": "Strain"}, "471870": {"name": "Bacteroides intestinalis DSM 17393", "rank": "Strain"}, "39756": {"name": "Unclassified Totiviridae", "rank": "No rank"}, "39755": {"name": "Leishmaniavirus", "rank": "Genus"}, "1113537": {"name": "Chlamydia/Chlamydophila group", "rank": "No rank"}, "649349": {"name": "Leadbetterella byssophila DSM 17132", "rank": "Strain"}, "39751": {"name": "Avibirnavirus", "rank": "Genus"}, "356797": {"name": "Meganema", "rank": "Genus"}, "1116163": {"name": "Escherichia coli P0304777.1", "rank": "Strain"}, "1116162": {"name": "Escherichia coli P0302308.14", "rank": "Strain"}, "1116161": {"name": "Escherichia coli P0302308.13", "rank": "Strain"}, "1116160": {"name": "Escherichia coli P0302308.12", "rank": "Strain"}, "1116166": {"name": "Escherichia coli P0304777.4", "rank": "Strain"}, "1116165": {"name": "Escherichia coli P0304777.3", "rank": "Strain"}, "1116164": {"name": "Escherichia coli P0304777.2", "rank": "Strain"}, "1116169": {"name": "Escherichia coli P0304777.8", "rank": "Strain"}, "983920": {"name": "Novosphingobium nitrogenifigens DSM 19370", "rank": "Strain"}, "1157036": {"name": "Staphylococcus aureus B53639", "rank": "Strain"}, "1157037": {"name": "Staphylococcus aureus B40723", "rank": "Strain"}, "1157034": {"name": "Staphylococcus aureus M0489", "rank": "Strain"}, "1157035": {"name": "Staphylococcus aureus M0494", "rank": "Strain"}, "1157032": {"name": "Staphylococcus aureus M0468", "rank": "Strain"}, "1157033": {"name": "Staphylococcus aureus M0478", "rank": "Strain"}, "1157030": {"name": "Staphylococcus aureus M0450", "rank": "Strain"}, "1157031": {"name": "Staphylococcus aureus M0467", "rank": "Strain"}, "1157038": {"name": "Staphylococcus aureus B40950", "rank": "Strain"}, "1157039": {"name": "Staphylococcus aureus B147830", "rank": "Strain"}, "1198693": {"name": "Brucella abortus CNGB 1432", "rank": "Strain"}, "1198692": {"name": "Brucella abortus CNGB 1011", "rank": "Strain"}, "1198691": {"name": "Brucella abortus CNGB 966", "rank": "Strain"}, "1198690": {"name": "Brucella abortus CNGB 759", "rank": "Strain"}, "1198697": {"name": "Brucella abortus 88/217", "rank": "Strain"}, "1198696": {"name": "Brucella canis UK10/02", "rank": "Strain"}, "1198695": {"name": "Brucella suis 94/11", "rank": "Strain"}, "1198694": {"name": "Brucella suis F4/06-146", "rank": "Strain"}, "1352583": {"name": "Mycobacterium tuberculosis PanR0702", "rank": "Strain"}, "1352582": {"name": "Mycobacterium tuberculosis PanR0611", "rank": "Strain"}, "1198699": {"name": "Brucella canis F7/05A", "rank": "Strain"}, "1198698": {"name": "Brucella abortus 78/32", "rank": "Strain"}, "1352587": {"name": "Mycobacterium tuberculosis PanR0801", "rank": "Strain"}, "1352586": {"name": "Mycobacterium tuberculosis PanR0708", "rank": "Strain"}, "544645": {"name": "Butyricimonas virosa", "rank": "Species"}, "544644": {"name": "Butyricimonas synergistica", "rank": "Species"}, "1179155": {"name": "Candidatus Photodesmus blepharus", "rank": "Species"}, "454165": {"name": "Salmonella enterica subsp. enterica serovar Schwarzengrund str. SL480", "rank": "Strain"}, "1056807": {"name": "Morococcus cerebrosus", "rank": "Species"}, "1445": {"name": "Bacillus alcalophilus", "rank": "Species"}, "1262529": {"name": "Mycobacterium tuberculosis PanR1005", "rank": "Strain"}, "75914": {"name": "Sclerophthora macrospora virus B", "rank": "Species"}, "1262525": {"name": "Mycobacterium tuberculosis PanR0201", "rank": "Strain"}, "1262527": {"name": "Halovirus HSTV-2", "rank": "Species"}, "1262526": {"name": "Mycobacterium tuberculosis PanR0802", "rank": "Strain"}, "1262521": {"name": "Leuconostoc phage phiLNTR3", "rank": "Species"}, "1262520": {"name": "Leuconostoc phage phiLN6B", "rank": "Species"}, "1262523": {"name": "Leuconostoc phage phiLNTR2", "rank": "Species"}, "1262522": {"name": "Leuconostoc phage P793", "rank": "Species"}, "232270": {"name": "Effusibacillus pohliae", "rank": "Species"}, "1343497": {"name": "Enterococcus faecalis AZ19", "rank": "Strain"}, "1343494": {"name": "Stenotrophomonas phage phiSMA7", "rank": "Species"}, "1343493": {"name": "Grapevine satellite virus", "rank": "Species"}, "1158345": {"name": "Persephonella sp. KM09-Lau-8", "rank": "Species"}, "1094480": {"name": "Acinetobacter baumannii ABNIH16", "rank": "Strain"}, "1418385": {"name": "Staphylococcus aureus F48611", "rank": "Strain"}, "1095745": {"name": "Haemophilus parainfluenzae HK262", "rank": "Strain"}, "1095744": {"name": "Haemophilus parahaemolyticus HK385", "rank": "Strain"}, "1095747": {"name": "Fusobacterium necrophorum subsp. funduliforme ATCC 51357", "rank": "Strain"}, "1095746": {"name": "Haemophilus parainfluenzae HK2019", "rank": "Strain"}, "1095741": {"name": "Streptococcus oralis SK610", "rank": "Strain"}, "1095740": {"name": "Streptococcus oralis SK100", "rank": "Strain"}, "1095743": {"name": "Haemophilus paraphrohaemolyticus HK411", "rank": "Strain"}, "1095742": {"name": "Haemophilus haemolyticus HK386", "rank": "Strain"}, "1095749": {"name": "Pasteurella bettyae CCUG 2042", "rank": "Strain"}, "1041607": {"name": "Wickerhamomyces ciferrii", "rank": "Species"}, "59600": {"name": "Cellulophaga algicola", "rank": "Species"}, "1487582": {"name": "Peptococcaceae bacterium SCADC1_2_3", "rank": "Species"}, "1482564": {"name": "Streptomyces atroolivaceus subgroup", "rank": "No rank"}, "1482561": {"name": "Streptomyces anulatus subgroup", "rank": "No rank"}, "1191313": {"name": "Vibrio splendidus 1S-124", "rank": "Strain"}, "1191312": {"name": "Vibrio splendidus 0407ZC148", "rank": "Strain"}, "717960": {"name": "Faecalitalea cylindroides T2-87", "rank": "Strain"}, "717961": {"name": "Eubacterium siraeum V10Sc8a", "rank": "Strain"}, "717962": {"name": "Coprococcus catus GD/7", "rank": "Strain"}, "717963": {"name": "Methylacidiphilales", "rank": "Order"}, "717964": {"name": "Methylacidiphilaceae", "rank": "Family"}, "1010614": {"name": "Staphylococcus phage S24-1", "rank": "Species"}, "1010616": {"name": "Tomato blistering mosaic virus", "rank": "Species"}, "267407": {"name": "European mountain ash ringspot-associated virus", "rank": "Species"}, "267409": {"name": "Listeria monocytogenes serotype 1/2a str. F6854", "rank": "Strain"}, "267408": {"name": "Arsenicicoccus", "rank": "Genus"}, "576948": {"name": "Rabbit calicivirus Australia 1 MIC-07", "rank": "Species"}, "1001886": {"name": "Vibrio sp. C7", "rank": "Species"}, "1007870": {"name": "Chlamydia trachomatis RC-L2/55", "rank": "Strain"}, "1007871": {"name": "Chlamydia trachomatis RC-J/971", "rank": "Strain"}, "1385855": {"name": "Lactobacillus plantarum 2165", "rank": "Strain"}, "233181": {"name": "Kinetoplastibacterium blastocrithidii", "rank": "Species"}, "1219359": {"name": "Erwinia amylovora NBRC 12687", "rank": "Strain"}, "56957": {"name": "Thermus oshimai", "rank": "Species"}, "233189": {"name": "Anaerolinea", "rank": "Genus"}, "196023": {"name": "Aeromonas hydrophila subsp. hydrophila", "rank": "Subspecies"}, "1487921": {"name": "Clostridium sp. HMP27", "rank": "Species"}, "310749": {"name": "Vicia faba endornavirus", "rank": "Species"}, "48664": {"name": "Xanthomonas fragariae", "rank": "Species"}, "1157472": {"name": "Enterococcus faecium EnGen0177", "rank": "Strain"}, "1123284": {"name": "Sporolactobacillus vineae DSM 21990 = SL153", "rank": "Strain"}, "1091046": {"name": "Mycobacterium abscessus subsp. bolletii BD", "rank": "Strain"}, "1091045": {"name": "Propionibacterium acnes ATCC 11828", "rank": "Strain"}, "1091042": {"name": "Ralstonia solanacearum K60-1", "rank": "Strain"}, "1157470": {"name": "Enterococcus faecium EnGen0175", "rank": "Strain"}, "1091040": {"name": "Lactococcus garvieae TB25", "rank": "Strain"}, "1091041": {"name": "Bacillus amyloliquefaciens IT-45", "rank": "Strain"}, "1157471": {"name": "Enterococcus faecium EnGen0176", "rank": "Strain"}, "1432551": {"name": "Escherichia coli IS35", "rank": "Strain"}, "1220924": {"name": "Cyphellophora europaea CBS 101466", "rank": "Strain"}, "1388214": {"name": "Staphylococcus aureus M0322", "rank": "Strain"}, "1097677": {"name": "Clavibacter michiganensis subsp. nebraskensis NCPPB 2581", "rank": "Strain"}, "1097676": {"name": "Pseudoalteromonas sp. BSi20429", "rank": "Species"}, "1541887": {"name": "Salmonella phage Chi", "rank": "Species"}, "1097670": {"name": "Streptococcus agalactiae STIR-CD-17", "rank": "Strain"}, "440524": {"name": "Salmonella enterica subsp. enterica serovar 4,5,12:i:-", "rank": "Strain"}, "1422578": {"name": "Staphylococcus aureus VET0313R", "rank": "Strain"}, "1422579": {"name": "Staphylococcus aureus VET0314R", "rank": "Strain"}, "1422574": {"name": "Staphylococcus aureus VET0307R", "rank": "Strain"}, "1422575": {"name": "Staphylococcus aureus VET0308R", "rank": "Strain"}, "1422576": {"name": "Staphylococcus aureus VET0309R", "rank": "Strain"}, "1422577": {"name": "Staphylococcus aureus VET0312R", "rank": "Strain"}, "1422570": {"name": "Staphylococcus aureus VET0303R", "rank": "Strain"}, "220339": {"name": "Topocuvirus", "rank": "Genus"}, "1422572": {"name": "Staphylococcus aureus VET0305R", "rank": "Strain"}, "1422573": {"name": "Staphylococcus aureus VET0306R", "rank": "Strain"}, "1233262": {"name": "Mycoplasma pneumoniae PO1", "rank": "Strain"}, "1248727": {"name": "Endosymbiont of unidentified scaly snail isolate Monju", "rank": "Species"}, "1248726": {"name": "Helicobacter pylori OK310", "rank": "Strain"}, "1248725": {"name": "Helicobacter pylori OK113", "rank": "Strain"}, "1248724": {"name": "Pseudomonas syringae pv. actinidiae ICMP 19455", "rank": "Strain"}, "1122226": {"name": "Mesonia mobilis DSM 19841", "rank": "Strain"}, "748449": {"name": "Halobacteroides halobius DSM 5150", "rank": "Strain"}, "1122224": {"name": "Melitea salexigens DSM 19753", "rank": "Strain"}, "1122223": {"name": "Meiothermus timidus DSM 17022", "rank": "Strain"}, "1122222": {"name": "Meiothermus taiwanensis DSM 14542", "rank": "Strain"}, "1122221": {"name": "Meiothermus cerbereus DSM 11376", "rank": "Strain"}, "1316254": {"name": "Veillonella parvula HSIVP1", "rank": "Strain"}, "11840": {"name": "Gibbon ape leukemia virus", "rank": "Species"}, "568076": {"name": "Metarhizium robertsii", "rank": "Species"}, "1331065": {"name": "Escherichia coli CE549", "rank": "Strain"}, "1331064": {"name": "Escherichia coli CE516", "rank": "Strain"}, "981213": {"name": "Helicobacter pylori NQ1712", "rank": "Strain"}, "1331062": {"name": "Escherichia coli E2265", "rank": "Strain"}, "1331061": {"name": "Escherichia coli E1777", "rank": "Strain"}, "1331060": {"name": "Sphingobium lactosutens DS20", "rank": "Strain"}, "901": {"name": "Desulfovibrio piger", "rank": "Species"}, "209897": {"name": "Afifella pfennigii", "rank": "Species"}, "904": {"name": "Acidaminococcus", "rank": "Genus"}, "905": {"name": "Acidaminococcus fermentans", "rank": "Species"}, "906": {"name": "Megasphaera", "rank": "Genus"}, "907": {"name": "Megasphaera elsdenii", "rank": "Species"}, "55601": {"name": "Vibrio anguillarum", "rank": "Species"}, "55604": {"name": "Mycoplasma primatum", "rank": "Species"}, "1340434": {"name": "Bacillus sp. UNC438CL73TsuS30", "rank": "Species"}, "1340435": {"name": "Chryseobacterium sp. UNC8MFCol", "rank": "Species"}, "1340436": {"name": "Microbacterium sp. UNC423CL45Tsu", "rank": "Species"}, "1340437": {"name": "Agrobacterium sp. UNC420CL41Cvi", "rank": "Species"}, "1340430": {"name": "Bacillus sp. UNC437CL72CviS29", "rank": "Species"}, "282459": {"name": "Staphylococcus aureus subsp. aureus MSSA476", "rank": "Strain"}, "282458": {"name": "Staphylococcus aureus subsp. aureus MRSA252", "rank": "Strain"}, "244599": {"name": "Raphidiopsis", "rank": "Genus"}, "571166": {"name": "Sedimentitalea nanhaiensis DSM 24252", "rank": "Strain"}, "347956": {"name": "Unclassified Deltaretrovirus", "rank": "No rank"}, "347957": {"name": "Unclassified Betaretrovirus", "rank": "No rank"}, "1138308": {"name": "Cronobacter sakazakii ES15", "rank": "Strain"}, "909942": {"name": "Unclassified SAR116 cluster", "rank": "No rank"}, "593909": {"name": "Mesorhizobium opportunistum", "rank": "Species"}, "1111678": {"name": "Lactococcus lactis subsp. cremoris UC509.9", "rank": "Strain"}, "939196": {"name": "Actinobacterium SCGC AAA015-M09", "rank": "Species"}, "939195": {"name": "Actinobacterium SCGC AAA015-D07", "rank": "Species"}, "593907": {"name": "Cellvibrio gilvus ATCC 13127", "rank": "Strain"}, "510685": {"name": "Sneathiellaceae", "rank": "Family"}, "1438705": {"name": "Klebsiella pneumoniae BWH 47", "rank": "Strain"}, "1287640": {"name": "Anaerococcus obesiensis", "rank": "Species"}, "1108974": {"name": "Leuconostoc citreum LBAE C10", "rank": "Strain"}, "347483": {"name": "Rhodanobacter spathiphylli", "rank": "Species"}, "347481": {"name": "Asticcacaulis benevestitus", "rank": "Species"}, "440250": {"name": "Phormidium phage Pf-WMP3", "rank": "Species"}, "981216": {"name": "Helicobacter pylori NQ392", "rank": "Strain"}, "1298630": {"name": "Becurtovirus", "rank": "Genus"}, "1298631": {"name": "Turncurtovirus", "rank": "Genus"}, "1298632": {"name": "Eragrovirus", "rank": "Genus"}, "1298633": {"name": "Aichivirus C", "rank": "Species"}, "645687": {"name": "Astrovirus VA1", "rank": "Species"}, "1412487": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. SA19960848", "rank": "Strain"}, "1412486": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. SA19981857", "rank": "Strain"}, "1412485": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. SA19981522", "rank": "Strain"}, "1412484": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. SA20094521", "rank": "Strain"}, "1412483": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. SA20121703", "rank": "Strain"}, "1412481": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. SA20100239", "rank": "Strain"}, "1412480": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. SA20084644", "rank": "Strain"}, "1412489": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. SA20085285", "rank": "Strain"}, "1412488": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. SA20082034", "rank": "Strain"}, "1447478": {"name": "Mycobacterium tuberculosis MD16765", "rank": "Strain"}, "1447479": {"name": "Mycobacterium tuberculosis MD17656", "rank": "Strain"}, "443254": {"name": "Marinitoga piezophila KA3", "rank": "Strain"}, "1415629": {"name": "Pseudomonas aeruginosa MTB-1", "rank": "Strain"}, "1447470": {"name": "Mycobacterium tuberculosis MD17503", "rank": "Strain"}, "1447471": {"name": "Mycobacterium tuberculosis MD17517", "rank": "Strain"}, "1447472": {"name": "Mycobacterium tuberculosis MD17647", "rank": "Strain"}, "1447473": {"name": "Mycobacterium tuberculosis MD17646", "rank": "Strain"}, "1447474": {"name": "Mycobacterium tuberculosis MD17613", "rank": "Strain"}, "1447475": {"name": "Mycobacterium tuberculosis MD16775", "rank": "Strain"}, "1447476": {"name": "Mycobacterium tuberculosis MD17240", "rank": "Strain"}, "1447477": {"name": "Mycobacterium tuberculosis MD17749", "rank": "Strain"}, "1122959": {"name": "Photobacterium halotolerans DSM 18316", "rank": "Strain"}, "1417990": {"name": "Streptococcus agalactiae 138P", "rank": "Strain"}, "1122951": {"name": "Perlucidibaca piscinae DSM 21586", "rank": "Strain"}, "1121280": {"name": "Chitiniphilus shinanonensis DSM 23277", "rank": "Strain"}, "1121283": {"name": "Chromobacterium haemolyticum DSM 19808", "rank": "Strain"}, "1121285": {"name": "Chryseobacterium caeni DSM 17710", "rank": "Strain"}, "1121286": {"name": "Chryseobacterium daeguense DSM 19388", "rank": "Strain"}, "1121287": {"name": "Chryseobacterium gregarium DSM 19109", "rank": "Strain"}, "1121288": {"name": "Chryseobacterium palustre DSM 21579", "rank": "Strain"}, "1121289": {"name": "Clostridiisalibacter paucivorans DSM 22131", "rank": "Strain"}, "904144": {"name": "Gardnerella vaginalis 101", "rank": "Strain"}, "861914": {"name": "Fibrella", "rank": "Genus"}, "1411539": {"name": "Staphylococcus aureus H64303", "rank": "Strain"}, "861913": {"name": "Fibrisoma", "rank": "Genus"}, "904143": {"name": "Staphylococcus warneri A487", "rank": "Strain"}, "1501329": {"name": "Oribacterium parvum", "rank": "Species"}, "1411536": {"name": "Staphylococcus aureus H57823", "rank": "Strain"}, "1411537": {"name": "Staphylococcus aureus H61003", "rank": "Strain"}, "889951": {"name": "Cyanophage KBS-P-1A", "rank": "Species"}, "51197": {"name": "Syntrophobotulus glycolicus", "rank": "Species"}, "51196": {"name": "Syntrophobotulus", "rank": "Genus"}, "94122": {"name": "Shewanella sp. ANA-3", "rank": "Species"}, "648176": {"name": "SAR202 cluster", "rank": "No rank"}, "1002": {"name": "Flexibacter roseolus", "rank": "Species"}, "997343": {"name": "Salmonella enterica subsp. enterica serovar Newport str. RI_10P069", "rank": "Strain"}, "1382517": {"name": "Burkholderia mallei A188", "rank": "Strain"}, "1382516": {"name": "Burkholderia mallei 2000031281", "rank": "Strain"}, "1382510": {"name": "Salmonella bongori serovar 48:z41:-- str. RKS3044", "rank": "Strain"}, "1577788": {"name": "Methanomassiliicoccaceae", "rank": "Family"}, "490731": {"name": "Kwoniella", "rank": "Genus"}, "1382519": {"name": "Burkholderia mallei China_7", "rank": "Strain"}, "1382518": {"name": "Burkholderia mallei A193", "rank": "Strain"}, "760840": {"name": "Streptococcus pneumoniae GA47522", "rank": "Strain"}, "29460": {"name": "Brucella neotomae", "rank": "Species"}, "29461": {"name": "Brucella suis", "rank": "Species"}, "1033736": {"name": "Brevibacterium senegalense", "rank": "Species"}, "1033737": {"name": "Clostridium senegalense JC122", "rank": "Strain"}, "386456": {"name": "Methanobacterium arcticum", "rank": "Species"}, "29465": {"name": "Veillonella", "rank": "Genus"}, "1033732": {"name": "Alistipes senegalensis JC50", "rank": "Strain"}, "1033733": {"name": "Anaerococcus senegalensis JC48", "rank": "Strain"}, "307521": {"name": "Gracilibacillus boraciitolerans", "rank": "Species"}, "694581": {"name": "Marseillevirus marseillevirus", "rank": "Species"}, "94699": {"name": "Unclassified Luteoviridae", "rank": "No rank"}, "1033738": {"name": "Kurthia sp. Dielmo", "rank": "Species"}, "1033739": {"name": "Kurthia massiliensis", "rank": "Species"}, "155148": {"name": "Salmonella phage HK620", "rank": "Species"}, "11029": {"name": "Ross River virus", "rank": "Species"}, "11027": {"name": "O'nyong-nyong virus", "rank": "Species"}, "11024": {"name": "Highlands J virus", "rank": "Species"}, "11023": {"name": "Middelburg virus", "rank": "Species"}, "11021": {"name": "Eastern equine encephalitis virus", "rank": "Species"}, "11020": {"name": "Barmah Forest virus", "rank": "Species"}, "1172187": {"name": "Methylobacterium sp. 285MFTsu5.1", "rank": "Species"}, "1172186": {"name": "Mycobacterium sp. 360MFTsu5.1", "rank": "Species"}, "1172185": {"name": "Nocardia sp. 348MFTsu5.1", "rank": "Species"}, "1172184": {"name": "Rhodococcus sp. 114MFTsu3.1", "rank": "Species"}, "1172183": {"name": "Streptomyces canus 299MFChir4.1", "rank": "Strain"}, "1172181": {"name": "Streptomyces sp. 303MFCol5.2", "rank": "Species"}, "1172180": {"name": "Streptomyces sp. 351MFTsu5.1", "rank": "Species"}, "1274524": {"name": "Bacillus sonorensis L12", "rank": "Strain"}, "1172188": {"name": "Terracoccus sp. 273MFTsu3.1", "rank": "Species"}, "1001582": {"name": "Bacillus amyloliquefaciens LL3", "rank": "Strain"}, "1001583": {"name": "Lactobacillus brevis KB290", "rank": "Strain"}, "1001586": {"name": "Leptospira interrogans serovar Bulgarica str. Mallika", "rank": "Strain"}, "879212": {"name": "Desulfobacter postgatei 2ac9", "rank": "Strain"}, "1001585": {"name": "Pseudomonas mendocina NK-01", "rank": "Strain"}, "1001588": {"name": "Leptospira interrogans str. 2002000621", "rank": "Strain"}, "1001589": {"name": "Leptospira weilii str. 2006001853", "rank": "Strain"}, "1224144": {"name": "Dickeya sp. CSL RW240", "rank": "Species"}, "1458122": {"name": "Bacillus indicus LMG 22858", "rank": "Strain"}, "2105": {"name": "Mycoplasma leachii", "rank": "Species"}, "2104": {"name": "Mycoplasma pneumoniae", "rank": "Species"}, "2103": {"name": "Mycoplasma mycoides subsp. mycoides", "rank": "Subspecies"}, "2102": {"name": "Mycoplasma mycoides", "rank": "Species"}, "2100": {"name": "Mycoplasma hyorhinis", "rank": "Species"}, "37372": {"name": "Helicobacter bilis", "rank": "Species"}, "2109": {"name": "Mycoplasma synoviae", "rank": "Species"}, "994573": {"name": "Youngiibacter fragilis 232.1", "rank": "Strain"}, "323259": {"name": "Methanospirillum hungatei JF-1", "rank": "Strain"}, "1330070": {"name": "Melegrivirus A", "rank": "Species"}, "1422239": {"name": "Staphylococcus aureus DAR1507", "rank": "Strain"}, "1422238": {"name": "Staphylococcus aureus DAR1492", "rank": "Strain"}, "1422233": {"name": "Staphylococcus aureus DAR1311", "rank": "Strain"}, "1422232": {"name": "Staphylococcus aureus DAR1310", "rank": "Strain"}, "1422231": {"name": "Staphylococcus aureus DAR1295", "rank": "Strain"}, "1422230": {"name": "Staphylococcus aureus DAR1293", "rank": "Strain"}, "1422237": {"name": "Staphylococcus aureus DAR1490", "rank": "Strain"}, "1422236": {"name": "Staphylococcus aureus DAR1370", "rank": "Strain"}, "1422235": {"name": "Staphylococcus aureus DAR1369", "rank": "Strain"}, "1422234": {"name": "Staphylococcus aureus DAR1313", "rank": "Strain"}, "521004": {"name": "Haemophilus influenzae 6P18H1", "rank": "Strain"}, "521005": {"name": "Haemophilus influenzae 7P49H1", "rank": "Strain"}, "521006": {"name": "Neisseria gonorrhoeae NCCP11945", "rank": "Strain"}, "521007": {"name": "Borrelia burgdorferi N40", "rank": "Strain"}, "521000": {"name": "Providencia rettgeri DSM 1131", "rank": "Strain"}, "521002": {"name": "Methanobrevibacter smithii DSM 2374", "rank": "Strain"}, "521003": {"name": "Collinsella intestinalis DSM 13280", "rank": "Strain"}, "521008": {"name": "Borrelia burgdorferi JD1", "rank": "Strain"}, "1159560": {"name": "Cronobacter dublinensis subsp. lausannensis LMG 23824", "rank": "Strain"}, "1246474": {"name": "Nocardiopsis xinjiangensis YIM 90004", "rank": "Strain"}, "498761": {"name": "Heliobacterium modesticaldum Ice1", "rank": "Strain"}, "204428": {"name": "Chlamydiae", "rank": "Phylum"}, "204429": {"name": "Chlamydiia", "rank": "Class"}, "35287": {"name": "Rice tungro spherical virus", "rank": "Species"}, "35286": {"name": "Bamboo mosaic virus", "rank": "Species"}, "35281": {"name": "Paprika mild mottle virus", "rank": "Species"}, "35289": {"name": "Grapevine virus B", "rank": "Species"}, "35288": {"name": "Grapevine virus A", "rank": "Species"}, "1121430": {"name": "Desulfotomaculum thermocisternum DSM 10259", "rank": "Strain"}, "159449": {"name": "Streptomyces scabrisporus", "rank": "Species"}, "1127829": {"name": "Candidatus Brocadiales", "rank": "Order"}, "305785": {"name": "Poinsettia latent virus", "rank": "Species"}, "911598": {"name": "Bifidobacterium animalis subsp. lactis BS 01", "rank": "Strain"}, "1439178": {"name": "Streptococcus pyogenes ABC020048387", "rank": "Strain"}, "1439176": {"name": "Streptococcus pyogenes ABC020048262", "rank": "Strain"}, "1439170": {"name": "Streptococcus pyogenes ABC020048184", "rank": "Strain"}, "1335416": {"name": "Mycobacterium abscessus MAB_110811_1470", "rank": "Strain"}, "1335417": {"name": "Mycobacterium abscessus MAB_110811_2726", "rank": "Strain"}, "1335414": {"name": "Mycobacterium abscessus MAB_091912_2446", "rank": "Strain"}, "1335415": {"name": "Mycobacterium abscessus MAB_091912_2455", "rank": "Strain"}, "1335412": {"name": "Mycobacterium abscessus MAB_082312_2272", "rank": "Strain"}, "1335410": {"name": "Mycobacterium abscessus MAB_030201_1075", "rank": "Strain"}, "1335411": {"name": "Mycobacterium abscessus MAB_082312_2258", "rank": "Strain"}, "796945": {"name": "Oribacterium parvum ACB8", "rank": "Strain"}, "796944": {"name": "Oribacterium asaccharolyticum ACB7", "rank": "Strain"}, "796941": {"name": "Peptostreptococcaceae bacterium OBRC8", "rank": "Species"}, "796940": {"name": "Peptostreptococcaceae bacterium CM5", "rank": "Species"}, "1335418": {"name": "Mycobacterium avium MAV_061107_1842", "rank": "Strain"}, "1335419": {"name": "Mycobacterium avium MAV_120709_2344", "rank": "Strain"}, "370323": {"name": "Haloterrigena limicola", "rank": "Species"}, "1605": {"name": "Lactobacillus animalis", "rank": "Species"}, "1604": {"name": "Lactobacillus amylovorus", "rank": "Species"}, "427926": {"name": "Dethiobacter alkaliphilus", "rank": "Species"}, "427925": {"name": "Dethiobacter", "rank": "Genus"}, "427922": {"name": "Desulfurivibrio", "rank": "Genus"}, "427923": {"name": "Desulfurivibrio alkaliphilus", "rank": "Species"}, "172667": {"name": "Yersinia phage PY54", "rank": "Species"}, "88190": {"name": "Thermus antranikianii", "rank": "Species"}, "146269": {"name": "Lactobacillus phage Lc-Nu", "rank": "Species"}, "593590": {"name": "Vibrio cholerae TMA 21", "rank": "Strain"}, "224419": {"name": "Shiraia", "rank": "Genus"}, "398839": {"name": "Staphylococcus phage CNPH82", "rank": "Species"}, "324057": {"name": "Paenibacillus sp. JDR-2", "rank": "Species"}, "111874": {"name": "Neodiprion sertifer nucleopolyhedrovirus", "rank": "Species"}, "666505": {"name": "Phycisphaerae", "rank": "Class"}, "666507": {"name": "Phycisphaeraceae", "rank": "Family"}, "666506": {"name": "Phycisphaerales", "rank": "Order"}, "666509": {"name": "Planktomarina temperata RCA23", "rank": "Strain"}, "666508": {"name": "Phycisphaera", "rank": "Genus"}, "67385": {"name": "Streptomyces xanthophaeus", "rank": "Species"}, "39113": {"name": "Hepatitis GB virus B", "rank": "Species"}, "39116": {"name": "Leishmania RNA virus 2 - 1", "rank": "Species"}, "409486": {"name": "Hardenbergia mosaic virus", "rank": "Species"}, "511062": {"name": "Oceanimonas sp. GK1", "rank": "Species"}, "31722": {"name": "Blueberry scorch virus", "rank": "Species"}, "31721": {"name": "Beet necrotic yellow vein virus", "rank": "Species"}, "592313": {"name": "Vibrio cholerae 12129(1)", "rank": "Strain"}, "592316": {"name": "Pantoea sp. At-9b", "rank": "Species"}, "219334": {"name": "Lactobacillus casei subsp. casei ATCC 393", "rank": "Strain"}, "871562": {"name": "Bifidobacterium dentium ATCC 27679", "rank": "Strain"}, "507522": {"name": "Klebsiella pneumoniae 342", "rank": "Strain"}, "656372": {"name": "Escherichia coli E1167", "rank": "Strain"}, "656374": {"name": "Escherichia coli E1520", "rank": "Strain"}, "656379": {"name": "Escherichia coli FVEC1302", "rank": "Strain"}, "1485952": {"name": "Enterobacter massiliensis", "rank": "Species"}, "258": {"name": "Sphingobacterium spiritivorum", "rank": "Species"}, "259": {"name": "Sphingobacterium thalpophilum", "rank": "Species"}, "256": {"name": "Myroides odoratus", "rank": "Species"}, "250": {"name": "Chryseobacterium gleum", "rank": "Species"}, "251": {"name": "Psychroflexus gondwanensis", "rank": "Species"}, "253": {"name": "Chryseobacterium indologenes", "rank": "Species"}, "239974": {"name": "Nocardiopsis valliformis", "rank": "Species"}, "180399": {"name": "Melon chlorotic mosaic virus", "rank": "Species"}, "1094489": {"name": "Bartonella australis Aust/NH1", "rank": "Strain"}, "979222": {"name": "Staphylococcus epidermidis NIH04008", "rank": "Strain"}, "797304": {"name": "Natronobacterium gregoryi SP2", "rank": "Strain"}, "1305797": {"name": "Kingella kingae BB631", "rank": "Strain"}, "1348564": {"name": "Pseudomonas aeruginosa LCT-PA220", "rank": "Strain"}, "1305795": {"name": "Kingella kingae PV1748", "rank": "Strain"}, "797300": {"name": "Burkholderia pseudomallei Bp22", "rank": "Strain"}, "1348563": {"name": "Salmonella enterica subsp. enterica serovar Namur str. 05-2929", "rank": "Strain"}, "797302": {"name": "Halovivax ruber XH-70", "rank": "Strain"}, "367928": {"name": "Bifidobacterium adolescentis ATCC 15703", "rank": "Strain"}, "253245": {"name": "Owenweeksia hongkongensis", "rank": "Species"}, "1105280": {"name": "Streptococcus agalactiae BSU447", "rank": "Strain"}, "1105281": {"name": "Streptococcus agalactiae BSU253", "rank": "Strain"}, "1105286": {"name": "Rhodobacter phage RcapMu", "rank": "Species"}, "148960": {"name": "Wallemia sebi", "rank": "Species"}, "1508404": {"name": "Jeotgalibacillus sp. D5", "rank": "Species"}, "1304876": {"name": "Arthrobacter nicotinovorans 231Sha2.1M6", "rank": "Strain"}, "218936": {"name": "Aeromonas simiae", "rank": "Species"}, "1263101": {"name": "Phascolarctobacterium succinatutens CAG:287", "rank": "Strain"}, "1493": {"name": "Clostridium cellulovorans", "rank": "Species"}, "1304872": {"name": "Desulfovibrio cf. magneticus IFRC170", "rank": "Strain"}, "97393": {"name": "Ferroplasma acidarmanus", "rank": "Species"}, "360579": {"name": "Mesta yellow vein mosaic virus", "rank": "Species"}, "1403831": {"name": "Escherichia coli str. K-12 substr. MC4100", "rank": "Strain"}, "310911": {"name": "Amdoparvovirus", "rank": "Genus"}, "1403836": {"name": "Staphylococcus aureus M1338", "rank": "Strain"}, "1403837": {"name": "Staphylococcus aureus M1339", "rank": "Strain"}, "1403838": {"name": "Staphylococcus aureus M1342", "rank": "Strain"}, "1403839": {"name": "Staphylococcus aureus M1343", "rank": "Strain"}, "1281063": {"name": "Escherichia coli HVH 128 (4-7030436)", "rank": "Strain"}, "1001724": {"name": "Mycobacterium abscessus 4S-0116-S", "rank": "Strain"}, "1418434": {"name": "Staphylococcus aureus W45421", "rank": "Strain"}, "1418435": {"name": "Staphylococcus aureus W75242", "rank": "Strain"}, "1418436": {"name": "Staphylococcus aureus W75262", "rank": "Strain"}, "1073373": {"name": "Streptococcus sanguinis CC94A", "rank": "Strain"}, "1418430": {"name": "Staphylococcus aureus W34841", "rank": "Strain"}, "1418431": {"name": "Staphylococcus aureus W34848", "rank": "Strain"}, "1418432": {"name": "Staphylococcus aureus W41757", "rank": "Strain"}, "1418433": {"name": "Staphylococcus aureus W41765", "rank": "Strain"}, "1418438": {"name": "Staphylococcus aureus W80011", "rank": "Strain"}, "1418439": {"name": "Staphylococcus aureus W80013", "rank": "Strain"}, "1073375": {"name": "Ruminococcus gnavus CC55_001C", "rank": "Strain"}, "1255310": {"name": "Erwinia amylovora MR1", "rank": "Strain"}, "99179": {"name": "Bacteroides phage B40-8", "rank": "Species"}, "1001720": {"name": "Mycobacterium abscessus 3A-0930-R", "rank": "Strain"}, "1349818": {"name": "Herminiimonas sp. CN", "rank": "Species"}, "746128": {"name": "Aspergillus fumigatus", "rank": "Species"}, "1073377": {"name": "Aeromonas hydrophila SSU", "rank": "Strain"}, "104087": {"name": "Pseudomonas frederiksbergensis", "rank": "Species"}, "1051662": {"name": "Rhodococcus fascians A44A", "rank": "Strain"}, "1051663": {"name": "Nanohaloarchaea", "rank": "Class"}, "1051660": {"name": "Lactobacillus casei UW1", "rank": "Strain"}, "1051661": {"name": "Lactobacillus casei UW4", "rank": "Strain"}, "1051666": {"name": "Candidatus Nanosalina", "rank": "Genus"}, "1051667": {"name": "Candidatus Nanosalinarum", "rank": "Genus"}, "217686": {"name": "Little cherry virus 1", "rank": "Species"}, "979556": {"name": "Microbacterium testaceum StLB037", "rank": "Strain"}, "64977": {"name": "Oceanospirillum maris", "rank": "Species"}, "64976": {"name": "Oceanospirillum beijerinckii", "rank": "Species"}, "64970": {"name": "Marinobacterium jannaschii", "rank": "Species"}, "64973": {"name": "Terasakiella pusilla", "rank": "Species"}, "992108": {"name": "Helicobacter pylori Hp P-15b", "rank": "Strain"}, "1198976": {"name": "Hapunalikevirus", "rank": "Genus"}, "992106": {"name": "Helicobacter pylori Hp P-11b", "rank": "Strain"}, "992105": {"name": "Helicobacter pylori Hp P-8b", "rank": "Strain"}, "992103": {"name": "Helicobacter pylori Hp P-4d", "rank": "Strain"}, "992102": {"name": "Helicobacter pylori Hp P-4c", "rank": "Strain"}, "992100": {"name": "Helicobacter pylori Hp P-3b", "rank": "Strain"}, "367775": {"name": "Cryptococcus gattii WM276", "rank": "Strain"}, "1177927": {"name": "Enterobacter cloacae subsp. cloacae GS1", "rank": "Strain"}, "1388232": {"name": "Staphylococcus aureus M0349", "rank": "Strain"}, "1388233": {"name": "Staphylococcus aureus M0353", "rank": "Strain"}, "1388230": {"name": "Staphylococcus aureus M0346", "rank": "Strain"}, "74968": {"name": "Ferroplasma", "rank": "Genus"}, "1388236": {"name": "Staphylococcus aureus M0356", "rank": "Strain"}, "1388237": {"name": "Staphylococcus aureus M0357", "rank": "Strain"}, "1388234": {"name": "Staphylococcus aureus M0354", "rank": "Strain"}, "1388235": {"name": "Staphylococcus aureus M0355", "rank": "Strain"}, "1388238": {"name": "Staphylococcus aureus M0358", "rank": "Strain"}, "1388239": {"name": "Staphylococcus aureus M0359", "rank": "Strain"}, "74967": {"name": "Unclassified Thermoplasmatales", "rank": "No rank"}, "1244145": {"name": "Enterococcus faecalis RP2S-4", "rank": "Strain"}, "1244144": {"name": "Enterococcus faecalis WKS-26-18-2", "rank": "Strain"}, "1244143": {"name": "Enterococcus faecalis VC1B-1", "rank": "Strain"}, "1244142": {"name": "Enterococcus faecalis UP2S-6", "rank": "Strain"}, "1244141": {"name": "Enterococcus faecalis SLO2C-1", "rank": "Strain"}, "402612": {"name": "Flavobacterium psychrophilum JIP02/86", "rank": "Strain"}, "1516079": {"name": "HCBI8.215 virus", "rank": "Species"}, "365532": {"name": "Belnapia", "rank": "Genus"}, "1516074": {"name": "Mycobacterium tuberculosis str. Beijing/DS6701", "rank": "Strain"}, "984236": {"name": "Salmonella enterica subsp. enterica serovar Kentucky str. ATCC 9263", "rank": "Strain"}, "984237": {"name": "Salmonella enterica subsp. enterica serovar Mbandaka str. ATCC 51958", "rank": "Strain"}, "934800": {"name": "Chipapillomavirus", "rank": "Genus"}, "984235": {"name": "Salmonella enterica subsp. enterica serovar Gaminara str. ATCC BAA-711", "rank": "Strain"}, "984232": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. 561362 9-7", "rank": "Strain"}, "984233": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. 543463 42-20", "rank": "Strain"}, "934804": {"name": "Dyoiotapapillomavirus", "rank": "Genus"}, "984231": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. 642044 8-1", "rank": "Strain"}, "1454373": {"name": "Actibacterium mucosum KCTC 23349", "rank": "Strain"}, "1454376": {"name": "Bifidobacterium pseudocatenulatum IPLA36007", "rank": "Strain"}, "80366": {"name": "Rachiplusia ou MNPV", "rank": "Strain"}, "1448276": {"name": "Streptococcus phage IC1", "rank": "Species"}, "1448274": {"name": "Streptococcus phage K13", "rank": "Species"}, "1448273": {"name": "Streptococcus phage DCC1738", "rank": "Species"}, "1365009": {"name": "Pseudomonas aeruginosa B3-208", "rank": "Strain"}, "1273266": {"name": "Campylobacter fetus subsp. venerealis cfvi03/293", "rank": "Strain"}, "1363": {"name": "Lactococcus garvieae", "rank": "Species"}, "1360": {"name": "Lactococcus lactis subsp. lactis", "rank": "Subspecies"}, "1366": {"name": "Lactococcus raffinolactis", "rank": "Species"}, "574087": {"name": "Acetohalobium arabaticum DSM 5501", "rank": "Strain"}, "1123319": {"name": "Streptomyces flavidovirens DSM 40150", "rank": "Strain"}, "759350": {"name": "Bifidobacterium longum subsp. longum JDM301", "rank": "Strain"}, "451870": {"name": "Chaetothyriomycetidae", "rank": "Subclass"}, "1257025": {"name": "Leptospira terpstrae serovar Hualin str. LT 11-33 = ATCC 700639", "rank": "Strain"}, "647294": {"name": "Sweet potato badnavirus B", "rank": "Species"}, "1256992": {"name": "Providencia alcalifaciens PAL-2", "rank": "Strain"}, "1256991": {"name": "Providencia alcalifaciens PAL-1", "rank": "Strain"}, "1256990": {"name": "Providencia alcalifaciens RIMD 1656011", "rank": "Strain"}, "1256996": {"name": "Klebsiella oxytoca KA-2", "rank": "Strain"}, "1256995": {"name": "Klebsiella oxytoca OK-1", "rank": "Strain"}, "1238668": {"name": "Brucella abortus F3/01-300", "rank": "Strain"}, "216933": {"name": "Spiroplasma chrysopicola", "rank": "Species"}, "196367": {"name": "Burkholderia sordidicola", "rank": "Species"}, "216936": {"name": "Spiroplasma diminutum", "rank": "Species"}, "216935": {"name": "Spiroplasma culicicola", "rank": "Species"}, "1286827": {"name": "Rhizobium sp. JGI 0001012-L22", "rank": "Species"}, "1286820": {"name": "Clostridium methoxybenzovorans SR3", "rank": "Strain"}, "1164990": {"name": "Richelia intracellularis", "rank": "Species"}, "1448853": {"name": "Staphylococcus aureus 1101-1 2011", "rank": "Strain"}, "1448852": {"name": "Staphylococcus aureus LysK 2 2011", "rank": "Strain"}, "1448851": {"name": "Staphylococcus aureus LysK 1 2011", "rank": "Strain"}, "1448850": {"name": "Staphylococcus warneri Lyso 2 2011", "rank": "Strain"}, "1448857": {"name": "Campylobacter sp. CIT045", "rank": "Species"}, "1448856": {"name": "Staphylococcus aureus 1801-2 2011", "rank": "Strain"}, "1448855": {"name": "Staphylococcus aureus 1801-1 2011", "rank": "Strain"}, "1448854": {"name": "Staphylococcus aureus 1101-2 2011", "rank": "Strain"}, "77698": {"name": "Fiji disease virus", "rank": "Species"}, "1441733": {"name": "Fusobacterium necrophorum DJ-1", "rank": "Strain"}, "1441732": {"name": "Fusobacterium necrophorum BL", "rank": "Strain"}, "1441735": {"name": "Fusobacterium necrophorum DAB", "rank": "Strain"}, "1441734": {"name": "Fusobacterium necrophorum BFTR-1", "rank": "Strain"}, "1441737": {"name": "Fusobacterium necrophorum DJ-2", "rank": "Strain"}, "1441736": {"name": "Fusobacterium necrophorum BFTR-2", "rank": "Strain"}, "92181": {"name": "Bartonella koehlerae", "rank": "Species"}, "103733": {"name": "Saccharothrix syringae", "rank": "Species"}, "647744": {"name": "Indibacter", "rank": "Genus"}, "103731": {"name": "Saccharothrix espanaensis", "rank": "Species"}, "477184": {"name": "Achromobacter arsenitoxydans SY8", "rank": "Strain"}, "590168": {"name": "Thermotoga naphthophila RKU-10", "rank": "Strain"}, "1403053": {"name": "Bordetella pertussis 137", "rank": "Strain"}, "1136162": {"name": "Vibrio cyclitrophicus 1F289", "rank": "Strain"}, "316983": {"name": "Alstroemeria virus x", "rank": "Species"}, "1284392": {"name": "Pseudomonas sp. FH1", "rank": "Species"}, "1284393": {"name": "Pseudomonas sp. FH4", "rank": "Species"}, "93678": {"name": "TTV-like mini virus", "rank": "Species"}, "1136169": {"name": "Vibrio cyclitrophicus ZF65", "rank": "Strain"}, "570509": {"name": "Spiroplasma melliferum KC3", "rank": "Strain"}, "699180": {"name": "Dinovernavirus", "rank": "Genus"}, "249529": {"name": "Caldanaerobacter", "rank": "Genus"}, "570507": {"name": "Streptococcus pneumoniae CCRI 1974", "rank": "Strain"}, "570506": {"name": "Escherichia coli O157:H7 str. FRIK966", "rank": "Strain"}, "699186": {"name": "Enterococcus faecalis R712", "rank": "Strain"}, "1532180": {"name": "Penicillium roqueforti ssRNA mycovirus 1", "rank": "Species"}, "1329795": {"name": "Clostridiaceae bacterium MS3", "rank": "Species"}, "1413416": {"name": "Staphylococcus aureus 12464", "rank": "Strain"}, "1433293": {"name": "Bacillus subtilis B7-s", "rank": "Strain"}, "1352584": {"name": "Mycobacterium tuberculosis PanR0703", "rank": "Strain"}, "1433291": {"name": "Bacillus licheniformis F2-1", "rank": "Strain"}, "1433290": {"name": "Bacillus licheniformis F1-1", "rank": "Strain"}, "1239565": {"name": "Mamastrovirus 1", "rank": "Species"}, "1239567": {"name": "Mamastrovirus 3", "rank": "Species"}, "1239566": {"name": "Mamastrovirus 2", "rank": "Species"}, "189971": {"name": "Unclassified Clostridiaceae", "rank": "No rank"}, "595537": {"name": "Variovorax paradoxus EPS", "rank": "Strain"}, "595536": {"name": "Methylosinus trichosporium OB3b", "rank": "Strain"}, "253839": {"name": "Streptomyces sp. C", "rank": "Species"}, "886293": {"name": "Singulisphaera acidiphila DSM 18658", "rank": "Strain"}, "1232151": {"name": "Escherichia coli O111:H11 str. CFSAN001630", "rank": "Strain"}, "1232150": {"name": "Escherichia coli O26:H11 str. CFSAN001629", "rank": "Strain"}, "1232152": {"name": "Escherichia coli O103:H11", "rank": "Strain"}, "1232154": {"name": "Escherichia coli O111:H8 str. CFSAN001632", "rank": "Strain"}, "10491": {"name": "Chloriridovirus", "rank": "Genus"}, "744979": {"name": "Ahrensia sp. R2A130", "rank": "Species"}, "443906": {"name": "Clavibacter michiganensis subsp. michiganensis NCPPB 382", "rank": "Strain"}, "10493": {"name": "Frog virus 3", "rank": "Species"}, "70177": {"name": "Grapevine leafroll-associated virus 4", "rank": "Species"}, "573059": {"name": "Desulfovibrio vulgaris RCH1", "rank": "Strain"}, "1121957": {"name": "Hymenobacter norwichensis DSM 15439", "rank": "Strain"}, "939844": {"name": "Marinimicrobia bacterium SCGC AAA003-L08", "rank": "Species"}, "1121952": {"name": "Humibacter albus DSM 18994", "rank": "Strain"}, "1121953": {"name": "Hymenobacter aerophilus DSM 13606", "rank": "Strain"}, "573053": {"name": "Ampullaviridae", "rank": "Family"}, "279369": {"name": "Sphingopyxis baekryungensis", "rank": "Species"}, "573055": {"name": "Cervidpoxvirus", "rank": "Genus"}, "573057": {"name": "Unclassified Cervidpoxvirus", "rank": "No rank"}, "930943": {"name": "Sulfolobus islandicus HVE10/4", "rank": "Strain"}, "930942": {"name": "Lactobacillus animalis KCTC 3501 = DSM 20602", "rank": "Strain"}, "989655": {"name": "Encephalitozoon cuniculi EC3", "rank": "Strain"}, "1408419": {"name": "Acidocella facilis ATCC 35904", "rank": "Strain"}, "930944": {"name": "Yersinia enterocolitica subsp. palearctica Y11", "rank": "Strain"}, "1408417": {"name": "Acholeplasma modicum ATCC 29102", "rank": "Strain"}, "1408416": {"name": "Acholeplasma hippikon ATCC 29725", "rank": "Strain"}, "1408415": {"name": "Acholeplasma equifetale ATCC 29724", "rank": "Strain"}, "989654": {"name": "Encephalitozoon cuniculi EC2", "rank": "Strain"}, "224756": {"name": "Methanomicrobia", "rank": "Class"}, "42862": {"name": "Rickettsia felis", "rank": "Species"}, "1438856": {"name": "Mycobacterium tuberculosis 2196MM", "rank": "Strain"}, "138184": {"name": "Alcelaphine herpesvirus 2", "rank": "Species"}, "761701": {"name": "Soybean mild mottle virus", "rank": "Species"}, "1366046": {"name": "Rhodobacteraceae bacterium HIMB11", "rank": "Species"}, "1328447": {"name": "Escherichia coli BIDMC 20B", "rank": "Strain"}, "1328446": {"name": "Escherichia coli BIDMC 20A", "rank": "Strain"}, "1328445": {"name": "Escherichia coli BIDMC 19C", "rank": "Strain"}, "1328444": {"name": "Escherichia coli BIDMC 19B", "rank": "Strain"}, "1328443": {"name": "Escherichia coli BIDMC 19A", "rank": "Strain"}, "1328442": {"name": "Escherichia coli BIDMC 17B", "rank": "Strain"}, "1328441": {"name": "Escherichia coli BIDMC 17A", "rank": "Strain"}, "1328440": {"name": "Escherichia coli BIDMC 15", "rank": "Strain"}, "761702": {"name": "Soybean chlorotic blotch virus", "rank": "Species"}, "1328449": {"name": "Escherichia coli BIDMC 38", "rank": "Strain"}, "1328448": {"name": "Escherichia coli BIDMC 37", "rank": "Strain"}, "1123055": {"name": "Rheinheimera texasensis DSM 17496", "rank": "Strain"}, "1423780": {"name": "Lactobacillus otakiensis DSM 19908 = JCM 15040", "rank": "Strain"}, "935837": {"name": "Bacillus sp. J37", "rank": "Species"}, "1123035": {"name": "Psychroflexus tropicus DSM 15496", "rank": "Strain"}, "1123034": {"name": "Psychrobacter phenylpyruvicus DSM 7000 = NBRC 102152", "rank": "Strain"}, "1123037": {"name": "Psychroserpens burtonensis DSM 12212", "rank": "Strain"}, "1123036": {"name": "Psychromonas arctica DSM 14288", "rank": "Strain"}, "1123033": {"name": "Psychrobacter lutiphocae DSM 21542", "rank": "Strain"}, "1123032": {"name": "Psychrilyobacter atlanticus DSM 19335", "rank": "Strain"}, "866546": {"name": "Schizosaccharomyces cryophilus", "rank": "Species"}, "1422783": {"name": "Staphylococcus aureus VET1245S", "rank": "Strain"}, "1422782": {"name": "Staphylococcus aureus VET1181S", "rank": "Strain"}, "1422781": {"name": "Staphylococcus aureus VET1168S", "rank": "Strain"}, "1422780": {"name": "Staphylococcus aureus VET1104S", "rank": "Strain"}, "1422787": {"name": "Staphylococcus aureus VET1419S", "rank": "Strain"}, "1422786": {"name": "Staphylococcus aureus VET1411S", "rank": "Strain"}, "1422785": {"name": "Staphylococcus aureus VET1373S", "rank": "Strain"}, "1422784": {"name": "Staphylococcus aureus VET1368S", "rank": "Strain"}, "556267": {"name": "Helicobacter winghamensis ATCC BAA-430", "rank": "Strain"}, "1422789": {"name": "Staphylococcus aureus VET1434S", "rank": "Strain"}, "1422788": {"name": "Staphylococcus aureus VET1422S", "rank": "Strain"}, "262768": {"name": "Onion yellows phytoplasma OY-M", "rank": "Strain"}, "697871": {"name": "Pantoea sp. SL1_M5", "rank": "Species"}, "227319": {"name": "Corynebacterium ciconiae", "rank": "Species"}, "1281140": {"name": "Escherichia coli HVH 213 (4-3042928)", "rank": "Strain"}, "1281141": {"name": "Escherichia coli HVH 214 (4-3062198)", "rank": "Strain"}, "1281142": {"name": "Escherichia coli HVH 215 (4-3008371)", "rank": "Strain"}, "1154867": {"name": "Streptococcus agalactiae MRI Z1-025", "rank": "Strain"}, "1246484": {"name": "Halobacillus sp. BAB-2008", "rank": "Species"}, "1246485": {"name": "Nocardiopsis salina YIM 90010", "rank": "Strain"}, "1281146": {"name": "Escherichia coli HVH 220 (4-5876842)", "rank": "Strain"}, "1154863": {"name": "Streptococcus agalactiae MRI Z1-012", "rank": "Strain"}, "1281148": {"name": "Escherichia coli HVH 222 (4-2977443)", "rank": "Strain"}, "1281149": {"name": "Escherichia coli HVH 223 (4-2976528)", "rank": "Strain"}, "28258": {"name": "Cobetia marina", "rank": "Species"}, "1154868": {"name": "Streptococcus agalactiae MRI Z1-035", "rank": "Strain"}, "1154869": {"name": "Streptococcus agalactiae MRI Z1-038", "rank": "Strain"}, "728": {"name": "Avibacterium paragallinarum", "rank": "Species"}, "729": {"name": "Haemophilus parainfluenzae", "rank": "Species"}, "1158156": {"name": "Thioalkalivibrio sp. AKL8", "rank": "Species"}, "1158157": {"name": "Thioalkalivibrio sp. AKL9", "rank": "Species"}, "1158150": {"name": "Thioalkalivibrio sp. ALD1", "rank": "Species"}, "1158151": {"name": "Thioalkalivibrio sp. ARh4", "rank": "Species"}, "1158152": {"name": "Thioalkalivibrio sp. AL21", "rank": "Species"}, "1221327": {"name": "Clostridium botulinum CDC66177", "rank": "Strain"}, "1409766": {"name": "Staphylococcus aureus DAR5842", "rank": "Strain"}, "1409767": {"name": "Staphylococcus aureus DAR5810", "rank": "Strain"}, "1409764": {"name": "Staphylococcus aureus DAR5860", "rank": "Strain"}, "723": {"name": "Actinobacillus ureae", "rank": "Species"}, "724": {"name": "Haemophilus", "rank": "Genus"}, "1409763": {"name": "Staphylococcus aureus DAR5866", "rank": "Strain"}, "726": {"name": "Haemophilus haemolyticus", "rank": "Species"}, "727": {"name": "Haemophilus influenzae", "rank": "Species"}, "1422439": {"name": "Staphylococcus aureus VET0111R", "rank": "Strain"}, "994479": {"name": "Saccharopolyspora spinosa NRRL 18395", "rank": "Strain"}, "439851": {"name": "Salmonella enterica subsp. enterica serovar Dublin str. CT_02021853", "rank": "Strain"}, "40420": {"name": "Bondarzewiaceae", "rank": "Family"}, "1095552": {"name": "Methylobacter luteus IMV-B-3098", "rank": "Strain"}, "1422431": {"name": "Staphylococcus aureus VET0099R", "rank": "Strain"}, "1422430": {"name": "Staphylococcus aureus VET0098R", "rank": "Strain"}, "1422433": {"name": "Staphylococcus aureus VET0102R", "rank": "Strain"}, "1422432": {"name": "Staphylococcus aureus VET0101R", "rank": "Strain"}, "1422435": {"name": "Staphylococcus aureus VET0104R", "rank": "Strain"}, "1422434": {"name": "Staphylococcus aureus VET0103R", "rank": "Strain"}, "1422437": {"name": "Staphylococcus aureus VET0107R", "rank": "Strain"}, "1422436": {"name": "Staphylococcus aureus VET0105R", "rank": "Strain"}, "1076692": {"name": "Bacillus pumilus S-1", "rank": "Strain"}, "223344": {"name": "Tomato leaf curl Bangladesh virus", "rank": "Species"}, "223345": {"name": "Tomato leaf curl Laos virus", "rank": "Species"}, "223346": {"name": "Tomato leaf curl Malaysia virus", "rank": "Species"}, "223347": {"name": "Tomato leaf curl New Delhi virus", "rank": "Species"}, "223342": {"name": "Tomato golden mottle virus", "rank": "Species"}, "575540": {"name": "Isosphaera pallida ATCC 43644", "rank": "Strain"}, "469609": {"name": "Streptococcus sp. 2_1_36FAA", "rank": "Species"}, "469608": {"name": "Klebsiella sp. 1_1_55", "rank": "Species"}, "469605": {"name": "Fusobacterium gonidiaformans 3-1-5R", "rank": "Strain"}, "469604": {"name": "Fusobacterium nucleatum subsp. vincentii 3_1_36A2", "rank": "Strain"}, "469607": {"name": "Fusobacterium nucleatum subsp. animalis 4_8", "rank": "Strain"}, "469606": {"name": "Fusobacterium nucleatum subsp. vincentii 4_1_13", "rank": "Strain"}, "469601": {"name": "Fusobacterium nucleatum subsp. animalis 21_1A", "rank": "Strain"}, "469603": {"name": "Fusobacterium nucleatum subsp. animalis 3_1_33", "rank": "Strain"}, "1333651": {"name": "Bifidobacterium moukalabense", "rank": "Species"}, "490103": {"name": "Enterobacteria phage Phieco32", "rank": "Species"}, "272634": {"name": "Mycoplasma pneumoniae M129", "rank": "Strain"}, "272635": {"name": "Mycoplasma pulmonis UAB CTIP", "rank": "Strain"}, "272632": {"name": "Mycoplasma mycoides subsp. mycoides SC str. PG1", "rank": "Strain"}, "272633": {"name": "Mycoplasma penetrans HF-2", "rank": "Strain"}, "272630": {"name": "Methylobacterium extorquens AM1", "rank": "Strain"}, "272631": {"name": "Mycobacterium leprae TN", "rank": "Strain"}, "490109": {"name": "Bracorhabdovirus", "rank": "Genus"}, "1388007": {"name": "Staphylococcus aureus M0031", "rank": "Strain"}, "396389": {"name": "Aestuariimicrobium kwangyangense", "rank": "Species"}, "396388": {"name": "Aestuariimicrobium", "rank": "Genus"}, "1423472": {"name": "Mycobacterium tuberculosis BTB07-300", "rank": "Strain"}, "1423473": {"name": "Mycobacterium tuberculosis BTB07-314", "rank": "Strain"}, "1423470": {"name": "Mycobacterium tuberculosis BTB07-283", "rank": "Strain"}, "1423471": {"name": "Mycobacterium tuberculosis BTB07-299", "rank": "Strain"}, "1423476": {"name": "Mycobacterium tuberculosis BTB07-325", "rank": "Strain"}, "1423477": {"name": "Mycobacterium tuberculosis BTB07-327", "rank": "Strain"}, "1423474": {"name": "Mycobacterium tuberculosis BTB07-323", "rank": "Strain"}, "1423475": {"name": "Mycobacterium tuberculosis BTB07-324", "rank": "Strain"}, "1423478": {"name": "Mycobacterium tuberculosis BTB07-354", "rank": "Strain"}, "1423479": {"name": "Mycobacterium tuberculosis BTB08-001", "rank": "Strain"}, "1125648": {"name": "Escherichia coli P0299483.1", "rank": "Strain"}, "51336": {"name": "Cabbage leaf curl virus", "rank": "Species"}, "660027": {"name": "Fusarium oxysporum Fo47", "rank": "Strain"}, "905826": {"name": "Marine Group I", "rank": "No rank"}, "905828": {"name": "Duck astrovirus GII.A", "rank": "Species"}, "335992": {"name": "Candidatus Pelagibacter ubique HTCC1062", "rank": "Strain"}, "187978": {"name": "Peru tomato mosaic virus", "rank": "Species"}, "187979": {"name": "Mitsuokella jalaludinii", "rank": "Species"}, "1123389": {"name": "Thermus islandicus DSM 21543", "rank": "Strain"}, "1123388": {"name": "Thermus igniterrae ATCC 700962", "rank": "Strain"}, "1123386": {"name": "Thermus antranikianii DSM 12462", "rank": "Strain"}, "1076524": {"name": "Rhodanobacter sp. OR92", "rank": "Species"}, "1076525": {"name": "Rhodanobacter sp. OR444", "rank": "Species"}, "1123383": {"name": "Thermotoga elfii DSM 9442", "rank": "Strain"}, "1076523": {"name": "Rhodanobacter sp. OR87", "rank": "Species"}, "1427317": {"name": "Mycobacterium tuberculosis XTB13-249", "rank": "Strain"}, "1427316": {"name": "Mycobacterium tuberculosis XTB13-247", "rank": "Strain"}, "558690": {"name": "Cucurbit chlorotic yellows virus", "rank": "Species"}, "220697": {"name": "Thalassospira xiamenensis", "rank": "Species"}, "979210": {"name": "Staphylococcus epidermidis NIHLM037", "rank": "Strain"}, "338565": {"name": "Erwinia tasmaniensis", "rank": "Species"}, "1428438": {"name": "Oenococcus oeni S14", "rank": "Strain"}, "936588": {"name": "Veillonella sp. ACP1", "rank": "Species"}, "1351817": {"name": "Acinetobacter baumannii 1605", "rank": "Strain"}, "1539298": {"name": "Treponema sp. OMZ 838", "rank": "Species"}, "1524215": {"name": "Anaeromyxobacteraceae", "rank": "Family"}, "1299429": {"name": "Yualikevirus", "rank": "Genus"}, "446470": {"name": "Stackebrandtia nassauensis DSM 44728", "rank": "Strain"}, "596323": {"name": "Leptotrichia goodfellowii F0264", "rank": "Strain"}, "596322": {"name": "Streptococcus salivarius SK126", "rank": "Strain"}, "596320": {"name": "Neisseria flavescens SK114", "rank": "Strain"}, "596327": {"name": "Porphyromonas uenonis 60-3", "rank": "Strain"}, "596325": {"name": "Lactobacillus jensenii 269-3", "rank": "Strain"}, "596324": {"name": "Treponema vincentii ATCC 35580", "rank": "Strain"}, "1349767": {"name": "Janthinobacterium agaricidamnosum NBRC 102515 = DSM 9628", "rank": "Strain"}, "533240": {"name": "Cylindrospermopsis raciborskii CS-505", "rank": "Strain"}, "596329": {"name": "Peptostreptococcus anaerobius 653-L", "rank": "Strain"}, "596328": {"name": "Mobiluncus mulieris 28-1", "rank": "Strain"}, "533247": {"name": "Raphidiopsis brookii D9", "rank": "Strain"}, "1425337": {"name": "Listeria monocytogenes Lm_1823", "rank": "Strain"}, "1425336": {"name": "Listeria monocytogenes Lm_1840", "rank": "Strain"}, "1425335": {"name": "Listeria monocytogenes Lm_1880", "rank": "Strain"}, "1123963": {"name": "Unclassified Bicaudaviridae", "rank": "No rank"}, "1134836": {"name": "Enterococcus faecium R496", "rank": "Strain"}, "1123967": {"name": "Porticoccus", "rank": "Genus"}, "1425339": {"name": "Listeria monocytogenes Lm_1886", "rank": "Strain"}, "1123964": {"name": "Sulfolobus virus STSV2", "rank": "Species"}, "53318": {"name": "Desulfocapsa", "rank": "Genus"}, "128710": {"name": "His2 virus", "rank": "Species"}, "697303": {"name": "Thermoanaerobacter wiegelii Rt8.B1", "rank": "Strain"}, "903510": {"name": "Vibrio furnissii NCTC 11218", "rank": "Strain"}, "1005704": {"name": "Streptococcus oralis SK255", "rank": "Strain"}, "1005705": {"name": "Streptococcus infantis SK1076", "rank": "Strain"}, "1005706": {"name": "Streptococcus dysgalactiae subsp. equisimilis SK1250", "rank": "Strain"}, "1240764": {"name": "Escherichia coli O104:H4 str. Ec11-4988", "rank": "Strain"}, "1240763": {"name": "Escherichia coli O104:H4 str. Ec11-4987", "rank": "Strain"}, "1240762": {"name": "Escherichia coli O104:H4 str. Ec11-4986", "rank": "Strain"}, "857149": {"name": "Streptococcus mutans 3SN1", "rank": "Strain"}, "1005703": {"name": "Propionibacterium sp. CC003-HC2", "rank": "Species"}, "857147": {"name": "Streptococcus mutans 11SSST2", "rank": "Strain"}, "857146": {"name": "Streptococcus mutans 4VF1", "rank": "Strain"}, "857145": {"name": "Streptococcus mutans 15VF2", "rank": "Strain"}, "857144": {"name": "Streptococcus mutans 2VS1", "rank": "Strain"}, "857143": {"name": "Streptococcus mutans 11VS1", "rank": "Strain"}, "857142": {"name": "Streptococcus mutans 5SM3", "rank": "Strain"}, "857141": {"name": "Streptococcus mutans NFSM2", "rank": "Strain"}, "857140": {"name": "Streptococcus mutans NVAB", "rank": "Strain"}, "761659": {"name": "Salinibacter ruber M8", "rank": "Strain"}, "1211707": {"name": "Xanthomonas campestris pv. campestris str. Xca5", "rank": "Strain"}, "1211706": {"name": "Paenisporosarcina sp. TG20", "rank": "Species"}, "1211705": {"name": "Vibrio parahaemolyticus BB22OP", "rank": "Strain"}, "1154848": {"name": "Streptococcus agalactiae STIR-CD-14", "rank": "Strain"}, "1417220": {"name": "Staphylococcus aureus W83140", "rank": "Strain"}, "1154849": {"name": "Streptococcus agalactiae STIR-CD-21", "rank": "Strain"}, "1417223": {"name": "Staphylococcus aureus W89268", "rank": "Strain"}, "698936": {"name": "Sinorhizobium meliloti BL225C", "rank": "Strain"}, "999542": {"name": "Salinispora pacifica DSM 45543", "rank": "Strain"}, "999543": {"name": "Salinispora pacifica DSM 45544", "rank": "Strain"}, "999541": {"name": "Burkholderia gladioli BSR3", "rank": "Strain"}, "999546": {"name": "Salinispora arenicola DSM 45545", "rank": "Strain"}, "999547": {"name": "Leisingera daeponensis DSM 23529", "rank": "Strain"}, "688701": {"name": "Chiltepin yellow mosaic virus", "rank": "Species"}, "999545": {"name": "Salinispora pacifica DSM 45549", "rank": "Strain"}, "1225191": {"name": "Streptococcus mutans B107SM-B", "rank": "Strain"}, "1268333": {"name": "Burkholderia sp. JGI 0001021-N20", "rank": "Species"}, "999548": {"name": "Phaeobacter inhibens DSM 16374", "rank": "Strain"}, "999549": {"name": "Leisingera caerulea DSM 24564", "rank": "Strain"}, "1225195": {"name": "Streptococcus mutans B102SM-B", "rank": "Strain"}, "1268337": {"name": "Burkholderia sp. JGI 0001021-E12", "rank": "Species"}, "1225197": {"name": "Streptococcus mutans B04Sm5", "rank": "Strain"}, "1225196": {"name": "Streptococcus mutans B112SM-A", "rank": "Strain"}, "1212548": {"name": "Pseudomonas stutzeri NF13", "rank": "Strain"}, "1003188": {"name": "Salmonella enterica subsp. enterica serovar Agona str. SA-4", "rank": "Strain"}, "1003189": {"name": "Salmonella enterica subsp. enterica serovar Agona str. SA-5", "rank": "Strain"}, "1009421": {"name": "Verrucomicrobia bacterium SCGC AAA164-P11", "rank": "Species"}, "1009425": {"name": "Gamma proteobacterium SCGC AAA168-I18", "rank": "Species"}, "1281168": {"name": "Escherichia coli KOEGE 71 (186a)", "rank": "Strain"}, "864051": {"name": "Burkholderiales bacterium JOSHI_001", "rank": "Species"}, "1009426": {"name": "Gamma proteobacterium SCGC AAA168-P09", "rank": "Species"}, "1281169": {"name": "Escherichia coli KOEGE 73 (195a)", "rank": "Strain"}, "885382": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. CDC_2010K_1010", "rank": "Strain"}, "1041809": {"name": "Candidatus Arthromitus sp. SFB-mouse-Yit", "rank": "Strain"}, "42471": {"name": "Desulfotomaculum thermocisternum", "rank": "Species"}, "1281167": {"name": "Escherichia coli KOEGE 70 (185a)", "rank": "Strain"}, "42478": {"name": "Saccharomyces cerevisiae virus L-BC (La)", "rank": "Species"}, "1281164": {"name": "Escherichia coli KOEGE 61 (174a)", "rank": "Strain"}, "885381": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. CDC_2010K_1018", "rank": "Strain"}, "1281162": {"name": "Escherichia coli KOEGE 56 (169a)", "rank": "Strain"}, "1281163": {"name": "Escherichia coli KOEGE 58 (171a)", "rank": "Strain"}, "1297860": {"name": "Afipia sp. OHSU_II-C1", "rank": "Species"}, "1297861": {"name": "Afipia sp. OHSU_II-C2", "rank": "Species"}, "1297862": {"name": "Afipia sp. OHSU_I-uncloned", "rank": "Species"}, "1297863": {"name": "Afipia sp. OHSU_I-C4", "rank": "Species"}, "1297864": {"name": "Afipia sp. OHSU_I-C6", "rank": "Species"}, "1297865": {"name": "Bradyrhizobium sp. OHSU_III", "rank": "Species"}, "1297866": {"name": "Bacillus anthracis str. Sen2Col2", "rank": "Strain"}, "1297867": {"name": "Bacillus anthracis str. Sen3", "rank": "Strain"}, "1297868": {"name": "Bacillus anthracis str. Gmb1", "rank": "Strain"}, "1281161": {"name": "Escherichia coli KOEGE 44 (106a)", "rank": "Strain"}, "576789": {"name": "Enterobacteria phage JSE", "rank": "Species"}, "1295790": {"name": "Mycobacterium tuberculosis TKK_02_0074", "rank": "Strain"}, "1458862": {"name": "Shewanella sp. phage 1/44", "rank": "Species"}, "1458861": {"name": "Shewanella sp. phage 1/41", "rank": "Species"}, "1458860": {"name": "Shewanella sp. phage 1/40", "rank": "Species"}, "31973": {"name": "Eggerthia catenaformis", "rank": "Species"}, "1295795": {"name": "Mycobacterium tuberculosis TKK_02_0079", "rank": "Strain"}, "31971": {"name": "Eubacterium dolichum", "rank": "Species"}, "246786": {"name": "Bacillus indicus", "rank": "Species"}, "1295798": {"name": "Mycobacterium tuberculosis OFXR-3", "rank": "Strain"}, "1295799": {"name": "Mycobacterium tuberculosis OFXR-4", "rank": "Strain"}, "585394": {"name": "Roseburia hominis A2-183", "rank": "Strain"}, "79264": {"name": "Paenibacillus ehimensis", "rank": "Species"}, "31979": {"name": "Clostridiaceae", "rank": "Family"}, "1394709": {"name": "Candidate division SR1 bacterium RAAC1_SR1_1", "rank": "Species"}, "1394706": {"name": "Vibrio parahaemolyticus S174", "rank": "Strain"}, "1394705": {"name": "Vibrio parahaemolyticus S173", "rank": "Strain"}, "1394704": {"name": "Vibrio parahaemolyticus S172", "rank": "Strain"}, "1394703": {"name": "Vibrio parahaemolyticus S171", "rank": "Strain"}, "1394702": {"name": "Vibrio parahaemolyticus S170", "rank": "Strain"}, "1394701": {"name": "Vibrio parahaemolyticus S168", "rank": "Strain"}, "1394700": {"name": "Vibrio parahaemolyticus S167", "rank": "Strain"}, "550773": {"name": "Ureaplasma urealyticum serovar 9 str. ATCC 33175", "rank": "Strain"}, "293826": {"name": "Alkaliphilus metalliredigens QYMF", "rank": "Strain"}, "257438": {"name": "Gluconobacter thailandicus", "rank": "Species"}, "111470": {"name": "Diaporthe ambigua RNA virus 1", "rank": "Species"}, "694427": {"name": "Paludibacter propionicigenes WB4", "rank": "Strain"}, "713008": {"name": "Parvimonas sp. oral taxon 393", "rank": "Species"}, "109265": {"name": "Dolichospermum circinale", "rank": "Species"}, "694429": {"name": "Pyrolobus fumarii 1A", "rank": "Strain"}, "375546": {"name": "Hydrangea chlorotic mottle virus", "rank": "Species"}, "1479239": {"name": "Porphyrobacter sp. HL-46", "rank": "Species"}, "1479238": {"name": "Oceanicaulis sp. HL-87", "rank": "Species"}, "1479237": {"name": "Marinobacter sp. HL-58", "rank": "Species"}, "1479235": {"name": "Halomonas sp. HL-48", "rank": "Species"}, "87280": {"name": "Umbilicaria muehlenbergii", "rank": "Species"}, "196162": {"name": "Nocardioides sp. JS614", "rank": "Species"}, "520962": {"name": "Ralstonia phage RSM3", "rank": "Species"}, "173707": {"name": "Temperate phage phiNIH1.1", "rank": "Species"}, "167554": {"name": "Prochlorococcus marinus str. SS51", "rank": "Strain"}, "167555": {"name": "Prochlorococcus marinus str. NATL1A", "rank": "Strain"}, "167556": {"name": "Prochlorococcus marinus str. LG", "rank": "Strain"}, "167550": {"name": "Prochlorococcus marinus str. MIT 9322", "rank": "Strain"}, "167551": {"name": "Prochlorococcus marinus str. MIT 9401", "rank": "Strain"}, "167552": {"name": "Prochlorococcus marinus str. SS2", "rank": "Strain"}, "167553": {"name": "Prochlorococcus marinus str. SS35", "rank": "Strain"}, "248039": {"name": "Mucispirillum schaedleri", "rank": "Species"}, "248038": {"name": "Mucispirillum", "rank": "Genus"}, "1070990": {"name": "Mycobacterium phage Lilac", "rank": "Species"}, "1293497": {"name": "Nitrospinae", "rank": "Phylum"}, "1183438": {"name": "Gloeobacter kilaueensis JS1", "rank": "Strain"}, "1293499": {"name": "Nitrospinales", "rank": "Order"}, "1293498": {"name": "Nitrospinia", "rank": "Class"}, "852": {"name": "Fusobacterium perfoetens", "rank": "Species"}, "853": {"name": "Faecalibacterium prausnitzii", "rank": "Species"}, "850": {"name": "Fusobacterium mortiferum", "rank": "Species"}, "851": {"name": "Fusobacterium nucleatum", "rank": "Species"}, "856": {"name": "Fusobacterium varium", "rank": "Species"}, "1438806": {"name": "Klebsiella pneumoniae UCI 61", "rank": "Strain"}, "854": {"name": "Fusobacterium russii", "rank": "Species"}, "1438804": {"name": "Klebsiella pneumoniae UCI 59", "rank": "Strain"}, "1438809": {"name": "Klebsiella pneumoniae UCI 64", "rank": "Strain"}, "859": {"name": "Fusobacterium necrophorum", "rank": "Species"}, "6029": {"name": "Microsporidia", "rank": "Phylum"}, "1297799": {"name": "Meiothermus ruber H328", "rank": "Strain"}, "1400178": {"name": "Klebsiella pneumoniae UCI 33", "rank": "Strain"}, "1400179": {"name": "Klebsiella pneumoniae UCI 34", "rank": "Strain"}, "1400174": {"name": "Klebsiella pneumoniae UCI 21", "rank": "Strain"}, "946046": {"name": "Ugandan cassava brown streak virus", "rank": "Species"}, "557289": {"name": "Burkholderia phage KS10", "rank": "Species"}, "1400177": {"name": "Klebsiella pneumoniae UCI 26", "rank": "Strain"}, "1400170": {"name": "Klebsiella pneumoniae UCI 17", "rank": "Strain"}, "1400171": {"name": "Klebsiella pneumoniae UCI 18", "rank": "Strain"}, "1400172": {"name": "Klebsiella pneumoniae UCI 19", "rank": "Strain"}, "1400173": {"name": "Klebsiella pneumoniae UCI 20", "rank": "Strain"}, "240557": {"name": "Tomato yellow leaf curl China alphasatellite", "rank": "Species"}, "240555": {"name": "Ectropis obliqua picorna-like virus", "rank": "Strain"}, "240558": {"name": "Tomato yellow leaf curl Thailand virus associated DNA 1", "rank": "Species"}, "240559": {"name": "Tobacco leaf curl Yunnan virus associated DNA 1", "rank": "Species"}, "68887": {"name": "Torque teno virus", "rank": "Species"}, "68889": {"name": "Boletales", "rank": "Order"}, "37659": {"name": "Clostridium algidicarnis", "rank": "Species"}, "114777": {"name": "Natrialba phage PhiCh1", "rank": "Species"}, "1412769": {"name": "Staphylococcus aureus M80992", "rank": "Strain"}, "88388": {"name": "Ophiostoma mitovirus 5", "rank": "Species"}, "88389": {"name": "Ophiostoma mitovirus 6", "rank": "Species"}, "1434006": {"name": "Fretibacterium", "rank": "Genus"}, "1439033": {"name": "Streptococcus pyogenes ABC020021452", "rank": "Strain"}, "1181748": {"name": "Escherichia coli KTE202", "rank": "Strain"}, "1434002": {"name": "Falsirhodobacter", "rank": "Genus"}, "88382": {"name": "Promicromonospora sukumoe", "rank": "Species"}, "11768": {"name": "Feline leukemia virus", "rank": "Species"}, "329289": {"name": "Malvastrum leaf curl virus-associated defective DNA beta", "rank": "Strain"}, "1459044": {"name": "Long Island tick rhabdovirus", "rank": "Species"}, "1136877": {"name": "Propionibacterium acnes PRP-38", "rank": "Strain"}, "1306162": {"name": "Xenorhabdus nematophila F1", "rank": "Strain"}, "763922": {"name": "Salmonella enterica subsp. enterica serovar Montevideo str. 80959-06", "rank": "Strain"}, "763921": {"name": "Salmonella enterica subsp. enterica serovar Montevideo str. 42N", "rank": "Strain"}, "763920": {"name": "Salmonella enterica subsp. enterica serovar Montevideo str. 29N", "rank": "Strain"}, "2330": {"name": "Halanaerobium", "rank": "Genus"}, "2331": {"name": "Halanaerobium praevalens", "rank": "Species"}, "1414851": {"name": "Pelistega sp. HM-7", "rank": "Species"}, "2335": {"name": "Thermotoga", "rank": "Genus"}, "2336": {"name": "Thermotoga maritima", "rank": "Species"}, "2337": {"name": "Thermotoga neapolitana", "rank": "Species"}, "64288": {"name": "Royal Farm virus", "rank": "Species"}, "64287": {"name": "Karshi virus", "rank": "Strain"}, "64286": {"name": "Usutu virus", "rank": "Species"}, "64285": {"name": "Rio Bravo virus", "rank": "Species"}, "64283": {"name": "Entebbe bat virus", "rank": "Species"}, "64280": {"name": "Apoi virus", "rank": "Species"}, "218872": {"name": "Fibrobacterales", "rank": "Order"}, "74313": {"name": "Brevundimonas subvibrioides", "rank": "Species"}, "686831": {"name": "Chromobacterium piscinae", "rank": "Species"}, "940557": {"name": "Granulicella", "rank": "Genus"}, "940550": {"name": "Gilvimarinus", "rank": "Genus"}, "1331250": {"name": "Bordetella bronchiseptica 345", "rank": "Strain"}, "578457": {"name": "Serpula lacrymans var. lacrymans S7.9", "rank": "Strain"}, "1282967": {"name": "Halovirus PH1", "rank": "Species"}, "1323525": {"name": "White clover cryptic virus 2", "rank": "Species"}, "1268072": {"name": "Paenibacillus sabinae T27", "rank": "Strain"}, "1268075": {"name": "Aeromonas hydrophila 116", "rank": "Strain"}, "1268074": {"name": "Aeromonas hydrophila 14", "rank": "Strain"}, "1268077": {"name": "Aeromonas hydrophila 187", "rank": "Strain"}, "1268076": {"name": "Aeromonas hydrophila 173", "rank": "Strain"}, "1268079": {"name": "Aeromonas hydrophila 259", "rank": "Strain"}, "1268078": {"name": "Aeromonas hydrophila 226", "rank": "Strain"}, "196937": {"name": "Nimaviridae", "rank": "Family"}, "637390": {"name": "Acidithiobacillus thiooxidans ATCC 19377", "rank": "Strain"}, "908247": {"name": "Staphylococcus aureus 16K", "rank": "Strain"}, "1484898": {"name": "Methyloceanibacter", "rank": "Genus"}, "872024": {"name": "Desulfitobacterium hafniense TCP-A", "rank": "Strain"}, "979982": {"name": "Leuconostoc sp. C2", "rank": "Species"}, "1167637": {"name": "Gillisia marina", "rank": "Species"}, "1167635": {"name": "Agrobacterium sp. 224MFTsu3.1", "rank": "Species"}, "1167632": {"name": "Staphylococcus vitulinus F1028", "rank": "Strain"}, "1167631": {"name": "Oenococcus oeni AWRIB318", "rank": "Strain"}, "1167638": {"name": "Campylobacter fetus subsp. venerealis B6", "rank": "Strain"}, "915437": {"name": "Saccharibacillus sacchari DSM 19268", "rank": "Strain"}, "511691": {"name": "Streptococcus mutans NN2025", "rank": "Strain"}, "1482319": {"name": "Casuarina virus", "rank": "Species"}, "915438": {"name": "Prevotella oryzae DSM 17970", "rank": "Strain"}, "1322343": {"name": "Mycobacterium tuberculosis EAI/OSDD271", "rank": "Strain"}, "1322346": {"name": "Haemophilus parasuis ZJ0906", "rank": "Strain"}, "1322347": {"name": "Bifidobacterium longum E18", "rank": "Strain"}, "1322345": {"name": "Escherichia coli ATCC 25922", "rank": "Strain"}, "504832": {"name": "Oligotropha carboxidovorans OM5", "rank": "Strain"}, "1454788": {"name": "Candidatus Calescibacterium nevadense", "rank": "Species"}, "92682": {"name": "Halothece cluster", "rank": "No rank"}, "1235815": {"name": "Prevotella enoeca JCM 12259", "rank": "Strain"}, "1235814": {"name": "Bacteroides acidifaciens JCM 10556", "rank": "Strain"}, "1235816": {"name": "Bacteroides fragilis JCM 11017", "rank": "Strain"}, "1235811": {"name": "Prevotella disiens JCM 6334 = ATCC 29426", "rank": "Strain"}, "747682": {"name": "Mycoplasma alligatoris A21JP2", "rank": "Strain"}, "217090": {"name": "Paenibacillus pasadenensis", "rank": "Species"}, "203494": {"name": "Verrucomicrobiae", "rank": "Class"}, "1049962": {"name": "Leptospira kirschneri serovar Mozdok str. Brem 166", "rank": "Strain"}, "1049963": {"name": "Leptospira kirschneri serovar Sokoine", "rank": "Strain"}, "1049964": {"name": "Leptospira kirschneri serovar Sokoine str. RM1", "rank": "Strain"}, "1049966": {"name": "Leptospira kirschneri str. H1", "rank": "Strain"}, "1049967": {"name": "Leptospira kirschneri serovar Valbuzzi", "rank": "Strain"}, "1049968": {"name": "Leptospira kirschneri serovar Valbuzzi str. 200702274", "rank": "Strain"}, "1049969": {"name": "Leptospira kirschneri serovar Valbuzzi str. Brem 179", "rank": "Strain"}, "78327": {"name": "Pseudomonas mosselii", "rank": "Species"}, "236097": {"name": "Alcanivorax sp. DG881", "rank": "Species"}, "1409926": {"name": "Acinetobacter baumannii MRSN 58", "rank": "Strain"}, "1158149": {"name": "Thioalkalivibrio sp. AL5", "rank": "Species"}, "1409922": {"name": "Acinetobacter baumannii MRSN 3405", "rank": "Strain"}, "1214230": {"name": "Turkey gallivirus", "rank": "Strain"}, "430556": {"name": "Francisella tularensis subsp. holarctica FSC022", "rank": "Strain"}, "1567496": {"name": "Brucella suis bv. 3", "rank": "Strain"}, "1010817": {"name": "Escherichia coli C691-71 (14b)", "rank": "Strain"}, "1457141": {"name": "Chlamydia avium", "rank": "Species"}, "335204": {"name": "Fragaria chiloensis cryptic virus", "rank": "Species"}, "1313067": {"name": "Williamsia sp. D3", "rank": "Species"}, "38284": {"name": "Corynebacterium accolens", "rank": "Species"}, "1344581": {"name": "Staphylococcus aureus S94", "rank": "Strain"}, "1193119": {"name": "Alkalibacillus haloalkaliphilus C5", "rank": "Strain"}, "575788": {"name": "Vibrio tasmaniensis LGP32", "rank": "Strain"}, "1245910": {"name": "Borrelia chilensis", "rank": "Species"}, "403779": {"name": "Anaplasma marginale str. Virginia", "rank": "Strain"}, "1188256": {"name": "Rhodovulum sulfidophilum DSM 1374", "rank": "Strain"}, "1188257": {"name": "Vibrio breoganii ZF-29", "rank": "Strain"}, "1188252": {"name": "Vibrio rumoiensis 1S-45", "rank": "Strain"}, "1188253": {"name": "Vibrio breoganii ZF-55", "rank": "Strain"}, "591153": {"name": "Pseudomonas syringae pv. syringae FF5", "rank": "Strain"}, "591154": {"name": "Methylacidiphilum fumariolicum", "rank": "Species"}, "591157": {"name": "Streptomyces sp. SPB78", "rank": "Species"}, "229193": {"name": "Yersinia pestis biovar Microtus str. 91001", "rank": "Strain"}, "591158": {"name": "Streptomyces sp. AA4", "rank": "Species"}, "1193807": {"name": "Dehalococcoides mccartyi DCMB5", "rank": "Strain"}, "1193806": {"name": "Dehalococcoides mccartyi BTF08", "rank": "Strain"}, "697227": {"name": "Enterobacteria phage IME08", "rank": "Species"}, "1402608": {"name": "Staphylococcus aureus M1052", "rank": "Strain"}, "1402609": {"name": "Staphylococcus aureus M1072", "rank": "Strain"}, "1402600": {"name": "Mycobacterium tuberculosis OFXR-31", "rank": "Strain"}, "1402601": {"name": "Mycobacterium tuberculosis OFXR-32", "rank": "Strain"}, "1402602": {"name": "Mycobacterium tuberculosis OFXR-33", "rank": "Strain"}, "1402603": {"name": "Staphylococcus aureus M0977", "rank": "Strain"}, "1402604": {"name": "Staphylococcus aureus M0986", "rank": "Strain"}, "1402605": {"name": "Staphylococcus aureus M1001", "rank": "Strain"}, "1402606": {"name": "Staphylococcus aureus M1020", "rank": "Strain"}, "1402607": {"name": "Staphylococcus aureus M1042", "rank": "Strain"}, "208435": {"name": "Streptococcus agalactiae 2603V/R", "rank": "Strain"}, "208434": {"name": "Milkweed yellows phytoplasma", "rank": "Species"}, "1446718": {"name": "Escherichia coli O26:H11 str. 2010C-3051", "rank": "Strain"}, "1446719": {"name": "Escherichia coli O26:H11 str. 2010C-3472", "rank": "Strain"}, "208439": {"name": "Amycolatopsis japonica", "rank": "Species"}, "1446717": {"name": "Escherichia coli O26:H11 str. 2009C-4826", "rank": "Strain"}, "1446714": {"name": "Escherichia coli O26:H11 str. 2009C-3996", "rank": "Strain"}, "1446715": {"name": "Escherichia coli O26:H1 str. 2009C-4747", "rank": "Strain"}, "1446712": {"name": "Escherichia coli O26:H11 str. 2009C-3612", "rank": "Strain"}, "471853": {"name": "Beutenbergia cavernae DSM 12333", "rank": "Strain"}, "1446710": {"name": "Escherichia coli O26:H11 str. 03-3500", "rank": "Strain"}, "1446711": {"name": "Escherichia coli O26:H11 str. 06-3464", "rank": "Strain"}, "1214186": {"name": "Streptococcus suis YS10", "rank": "Strain"}, "1214187": {"name": "Streptococcus suis YS12", "rank": "Strain"}, "1214184": {"name": "Streptococcus suis 22083", "rank": "Strain"}, "1214185": {"name": "Streptococcus suis YS1", "rank": "Strain"}, "1214182": {"name": "Streptococcus suis 8074", "rank": "Strain"}, "1214183": {"name": "Streptococcus suis 14636", "rank": "Strain"}, "1214180": {"name": "Streptococcus suis 11538", "rank": "Strain"}, "1214181": {"name": "Streptococcus suis 2524", "rank": "Strain"}, "1391494": {"name": "Enterococcus faecalis EnGen0424", "rank": "Strain"}, "1214188": {"name": "Streptococcus suis YS14", "rank": "Strain"}, "1391495": {"name": "Enterococcus faecalis EnGen0425", "rank": "Strain"}, "1388401": {"name": "Staphylococcus aureus M0605", "rank": "Strain"}, "1388400": {"name": "Staphylococcus aureus M0604", "rank": "Strain"}, "1388403": {"name": "Staphylococcus aureus M0609", "rank": "Strain"}, "1388402": {"name": "Staphylococcus aureus M0607", "rank": "Strain"}, "1388405": {"name": "Staphylococcus aureus M0611", "rank": "Strain"}, "1388404": {"name": "Staphylococcus aureus M0610", "rank": "Strain"}, "1388407": {"name": "Staphylococcus aureus M0613", "rank": "Strain"}, "1388406": {"name": "Staphylococcus aureus M0612", "rank": "Strain"}, "1388409": {"name": "Staphylococcus aureus M0616", "rank": "Strain"}, "1388408": {"name": "Staphylococcus aureus M0615", "rank": "Strain"}, "471856": {"name": "Jonesia denitrificans DSM 20603", "rank": "Strain"}, "939568": {"name": "Deltaproteobacteria bacterium SCGC AAA003-F15", "rank": "Species"}, "186165": {"name": "Euprosterna elaeasa virus", "rank": "Species"}, "1169274": {"name": "Staphylococcus aureus M1309", "rank": "Strain"}, "407019": {"name": "Sphingomonas astaxanthinifaciens", "rank": "Species"}, "260149": {"name": "Aeromonas phage 65", "rank": "Species"}, "1151117": {"name": "Thermococcus zilligii AN1", "rank": "Strain"}, "1574409": {"name": "Mesorhizobium sp. F7", "rank": "Species"}, "1403897": {"name": "Staphylococcus aureus M1515", "rank": "Strain"}, "544447": {"name": "Unclassified Erysipelotrichaceae (miscellaneous)", "rank": "No rank"}, "1151115": {"name": "Campylobacter jejuni subsp. jejuni P854", "rank": "Strain"}, "451507": {"name": "Mucoromycotina", "rank": "Subphylum"}, "1151114": {"name": "Ochrobactrum anthropi CTS-325", "rank": "Strain"}, "1151113": {"name": "Mycobacterium tuberculosis XDR1219", "rank": "Strain"}, "187303": {"name": "Methylocystis sp. SC2", "rank": "Species"}, "418702": {"name": "Azonexus hydrophilus", "rank": "Species"}, "187304": {"name": "Labrenzia aggregata", "rank": "Species"}, "1315313": {"name": "Vibrio fluvialis 539", "rank": "Strain"}, "1315312": {"name": "Vibrio fluvialis 560", "rank": "Strain"}, "1315311": {"name": "Streptococcus pneumoniae MNZ85", "rank": "Strain"}, "1315310": {"name": "Streptococcus pneumoniae MNZ41", "rank": "Strain"}, "1315314": {"name": "Vibrio cholerae VCC19", "rank": "Strain"}, "130309": {"name": "Human mastadenovirus F", "rank": "Species"}, "130308": {"name": "Human mastadenovirus E", "rank": "Species"}, "86331": {"name": "Mogibacterium", "rank": "Genus"}, "10702": {"name": "Streptomyces phage VWB", "rank": "Species"}, "10704": {"name": "Rhizobium phage 16-3", "rank": "Species"}, "1208918": {"name": "Candidatus Kinetoplastibacterium crithidii TCC036E", "rank": "Strain"}, "10708": {"name": "Pseudomonas phage D3112", "rank": "Species"}, "591487": {"name": "Mycobacterium phage Phlyer", "rank": "Species"}, "1246448": {"name": "Nocardiopsis valliformis DSM 45023", "rank": "Strain"}, "1151118": {"name": "Arthrobacter sp. 161MFSha2.1", "rank": "Species"}, "707757": {"name": "Klebsiella phage KP15", "rank": "Species"}, "1163389": {"name": "Francisella noatunensis subsp. orientalis str. Toba 04", "rank": "Strain"}, "931972": {"name": "Murine adenovirus 2", "rank": "Strain"}, "1163386": {"name": "Escherichia coli LCT-EC106", "rank": "Strain"}, "1163385": {"name": "Peanut witches'-broom phytoplasma NTU2011", "rank": "Strain"}, "118562": {"name": "Arthrospira platensis", "rank": "Species"}, "679198": {"name": "Aggregatibacter aphrophilus F0387", "rank": "Strain"}, "679199": {"name": "Alloprevotella rava F0323", "rank": "Strain"}, "1391180": {"name": "Mycobacterium phage Nala", "rank": "Species"}, "1391181": {"name": "Mycobacterium phage PhatBacter", "rank": "Species"}, "679192": {"name": "Bulleidia extructa W1219", "rank": "Strain"}, "679193": {"name": "Propionibacterium acnes SK182", "rank": "Strain"}, "938615": {"name": "Alpha proteobacterium SCGC AAA023-L09", "rank": "Species"}, "679191": {"name": "Prevotella amnii CRIS 21A-A", "rank": "Strain"}, "679196": {"name": "Lactobacillus gasseri 224-1", "rank": "Strain"}, "679197": {"name": "Segniliparus rugosus ATCC BAA-974", "rank": "Strain"}, "679194": {"name": "Propionibacterium acnes J139", "rank": "Strain"}, "679195": {"name": "Propionibacterium acnes J165", "rank": "Strain"}, "287484": {"name": "Melitea salexigens", "rank": "Species"}, "287487": {"name": "Haliea salexigens", "rank": "Species"}, "134821": {"name": "Ureaplasma parvum", "rank": "Species"}, "1094506": {"name": "Salmonella enterica subsp. enterica serovar Cerro FSL R8-0235", "rank": "Strain"}, "1336744": {"name": "Sphingomonas sp. YL-JM2C", "rank": "Species"}, "1094502": {"name": "Bartonella vinsonii subsp. berkhoffii str. Tweed", "rank": "Strain"}, "1094508": {"name": "Thermoanaerobacterium saccharolyticum JW/SL-YS485", "rank": "Strain"}, "1333998": {"name": "Alpha proteobacterium MA2", "rank": "Species"}, "5583": {"name": "Exophiala", "rank": "Genus"}, "5580": {"name": "Aureobasidium pullulans", "rank": "Species"}, "5581": {"name": "Beauveria", "rank": "Genus"}, "50948": {"name": "Enterobacteria phage RB49", "rank": "Species"}, "1123326": {"name": "Sulfurospirillum arcachonense DSM 9755", "rank": "Strain"}, "1422088": {"name": "Mycobacterium tuberculosis TB_RSA172", "rank": "Strain"}, "1422089": {"name": "Mycobacterium tuberculosis TB_RSA173", "rank": "Strain"}, "1121859": {"name": "Echinicola pacifica DSM 19836", "rank": "Strain"}, "1422085": {"name": "Mycobacterium tuberculosis TB_RSA169", "rank": "Strain"}, "1422086": {"name": "Mycobacterium tuberculosis TB_RSA170", "rank": "Strain"}, "1422087": {"name": "Mycobacterium tuberculosis TB_RSA171", "rank": "Strain"}, "307110": {"name": "Cotton leaf curl Bangalore virus", "rank": "Species"}, "307111": {"name": "Cotton leaf curl Bangalore betasatellite", "rank": "Species"}, "1422082": {"name": "Mycobacterium tuberculosis TB_RSA166", "rank": "Strain"}, "106181": {"name": "Unclassified Ehrlichia", "rank": "No rank"}, "1409618": {"name": "Staphylococcus aureus AMMC6106", "rank": "Strain"}, "1409619": {"name": "Staphylococcus aureus KINW6023", "rank": "Strain"}, "619631": {"name": "Pedilanthus leaf curl virus", "rank": "Species"}, "28141": {"name": "Cronobacter sakazakii", "rank": "Species"}, "28142": {"name": "Salmonella enterica subsp. enterica serovar Berta", "rank": "Strain"}, "342451": {"name": "Staphylococcus saprophyticus subsp. saprophyticus ATCC 15305", "rank": "Strain"}, "28144": {"name": "Salmonella enterica subsp. enterica serovar Derby", "rank": "Strain"}, "28147": {"name": "Salmonella enterica subsp. enterica serovar Oranienburg", "rank": "Strain"}, "193462": {"name": "Streptomyces niveus", "rank": "Species"}, "193461": {"name": "Streptomyces aureus", "rank": "Species"}, "125614": {"name": "Thiothrix disciformis", "rank": "Species"}, "336276": {"name": "Olleya", "rank": "Genus"}, "1409612": {"name": "Staphylococcus aureus SJUD6120", "rank": "Strain"}, "546899": {"name": "Bradyrhizobium sp. USDA 3384", "rank": "Species"}, "1409610": {"name": "Staphylococcus aureus UCIM6076", "rank": "Strain"}, "1340830": {"name": "Mycobacterium phage KayaCho", "rank": "Species"}, "1340831": {"name": "Mycobacterium phage Dylan", "rank": "Species"}, "5320": {"name": "Pleurotus", "rank": "Genus"}, "1340833": {"name": "Mycobacterium phage Contagion", "rank": "Species"}, "1340836": {"name": "Mycobacterium phage Crossroads", "rank": "Species"}, "5325": {"name": "Trametes versicolor", "rank": "Species"}, "1409616": {"name": "Staphylococcus aureus WMCA6024", "rank": "Strain"}, "1422064": {"name": "Mycobacterium tuberculosis TB_RSA148", "rank": "Strain"}, "1080311": {"name": "Legionella pneumophila subsp. pneumophila Lp02", "rank": "Strain"}, "1409614": {"name": "Staphylococcus aureus SJOS6139", "rank": "Strain"}, "1409615": {"name": "Staphylococcus aureus SJUD6124", "rank": "Strain"}, "1422668": {"name": "Staphylococcus aureus VET0452R", "rank": "Strain"}, "1422669": {"name": "Staphylococcus aureus VET0454R", "rank": "Strain"}, "1385938": {"name": "Bifidobacterium breve 12L", "rank": "Strain"}, "1385939": {"name": "Bifidobacterium breve JCM 7017", "rank": "Strain"}, "227292": {"name": "Sinorhizobium/Ensifer group", "rank": "No rank"}, "227290": {"name": "Rhizobium/Agrobacterium group", "rank": "No rank"}, "1422660": {"name": "Staphylococcus aureus VET0438R", "rank": "Strain"}, "1422661": {"name": "Staphylococcus aureus VET0439R", "rank": "Strain"}, "1385930": {"name": "Burkholderia dolosa PC543", "rank": "Strain"}, "1422663": {"name": "Staphylococcus aureus VET0442R", "rank": "Strain"}, "1422664": {"name": "Staphylococcus aureus VET0443R", "rank": "Strain"}, "1422665": {"name": "Staphylococcus aureus VET0444R", "rank": "Strain"}, "1422666": {"name": "Staphylococcus aureus VET0446R", "rank": "Strain"}, "1422667": {"name": "Staphylococcus aureus VET0451R", "rank": "Strain"}, "136466": {"name": "Brevidensovirus", "rank": "Genus"}, "229636": {"name": "Tomato leaf curl China virus", "rank": "Species"}, "883155": {"name": "Myroides odoratimimus CIP 103059", "rank": "Strain"}, "229634": {"name": "Papaya leaf curl China virus", "rank": "Species"}, "264199": {"name": "Streptococcus thermophilus LMG 18311", "rank": "Strain"}, "1343563": {"name": "Burkholderia pseudomallei str. NCTC 13392 substr. morphotype_8", "rank": "Strain"}, "1343562": {"name": "Burkholderia pseudomallei str. NCTC 13392 substr. morphotype_7", "rank": "Strain"}, "1343561": {"name": "Burkholderia pseudomallei str. NCTC 13392 substr. morphotype_6", "rank": "Strain"}, "1343560": {"name": "Burkholderia pseudomallei str. NCTC 13392 substr. morphotype_5", "rank": "Strain"}, "1343565": {"name": "Burkholderia pseudomallei str. NCTC 13392 substr. morphotype_10", "rank": "Strain"}, "1343564": {"name": "Burkholderia pseudomallei str. NCTC 13392 substr. morphotype_9", "rank": "Strain"}, "245014": {"name": "Butyrate-producing bacterium SS3/4", "rank": "Species"}, "1158050": {"name": "Arthrobacter sp. 135MFCol5.1", "rank": "Species"}, "245012": {"name": "Butyrate-producing bacterium SM4/1", "rank": "Species"}, "518": {"name": "Bordetella bronchiseptica", "rank": "Species"}, "517": {"name": "Bordetella", "rank": "Genus"}, "245018": {"name": "Butyrate-producing bacterium SSC/2", "rank": "Species"}, "511": {"name": "Alcaligenes faecalis", "rank": "Species"}, "207597": {"name": "Vibrio phage VHML", "rank": "Species"}, "31559": {"name": "Cacao swollen shoot virus", "rank": "Species"}, "207599": {"name": "Solirubrobacter", "rank": "Genus"}, "53371": {"name": "Pilimelia anulata", "rank": "Species"}, "53370": {"name": "Pilimelia", "rank": "Genus"}, "1302650": {"name": "Bacillus subtilis subsp. subtilis str. BAB-1", "rank": "Strain"}, "1367203": {"name": "Hemileuca sp. nucleopolyhedrovirus", "rank": "Species"}, "1367204": {"name": "Choristoneura occidentalis alphabaculovirus", "rank": "Species"}, "1367205": {"name": "Choristoneura rosaceana alphabaculovirus", "rank": "Species"}, "883158": {"name": "Prevotella micans F0438", "rank": "Strain"}, "1748": {"name": "Propionibacterium acidipropionici", "rank": "Species"}, "1749": {"name": "Propionibacterium jensenii", "rank": "Species"}, "1744": {"name": "Propionibacterium freudenreichii", "rank": "Species"}, "1747": {"name": "Propionibacterium acnes", "rank": "Species"}, "1740": {"name": "Thermodesulfobacterium", "rank": "Genus"}, "1741": {"name": "Thermodesulfobacterium commune", "rank": "Species"}, "1743": {"name": "Propionibacterium", "rank": "Genus"}, "1463869": {"name": "Streptomyces sp. NRRL F-5681", "rank": "Species"}, "1463868": {"name": "Streptomyces sp. NRRL F-5650", "rank": "Species"}, "644007": {"name": "Streptococcus phage PH10", "rank": "Species"}, "1463865": {"name": "Streptomyces sp. NRRL F-5635", "rank": "Species"}, "1463864": {"name": "Streptomyces sp. NRRL F-5630", "rank": "Species"}, "1463867": {"name": "Streptomyces sp. NRRL F-5639", "rank": "Species"}, "1463866": {"name": "Streptomyces sp. NRRL F-5638", "rank": "Species"}, "1463861": {"name": "Streptomyces sp. NRRL F-525", "rank": "Species"}, "1463860": {"name": "Streptomyces sp. NRRL F-5193", "rank": "Species"}, "1463863": {"name": "Streptomyces sp. NRRL F-5555", "rank": "Species"}, "1463862": {"name": "Streptomyces sp. NRRL F-5527", "rank": "Species"}, "417295": {"name": "Unclassified Verrucomicrobia (miscellaneous)", "rank": "No rank"}, "163325": {"name": "Capsicum chlorosis virus", "rank": "Species"}, "552364": {"name": "Unclassified virophages", "rank": "No rank"}, "555864": {"name": "Unclassified Bornaviridae", "rank": "No rank"}, "1439348": {"name": "Penicillium paneum FM227", "rank": "Strain"}, "1267211": {"name": "Sediminibacterium sp. C3", "rank": "Species"}, "112074": {"name": "Unclassified Acidobacteriaceae", "rank": "No rank"}, "157239": {"name": "Haemophilus phage HP2", "rank": "Species"}, "178440": {"name": "Opitutus", "rank": "Genus"}, "2757": {"name": "Brochothrix campestris", "rank": "Species"}, "877418": {"name": "Treponema bryantii NK4A124", "rank": "Strain"}, "877415": {"name": "Erysipelotrichaceae bacterium NK3D112", "rank": "Species"}, "877414": {"name": "Clostridiales bacterium NK3B98", "rank": "Species"}, "160674": {"name": "Raoultella", "rank": "Genus"}, "877411": {"name": "Ruminococcus sp. NK3A76", "rank": "Species"}, "321614": {"name": "Phaeosphaeria nodorum SN15", "rank": "Strain"}, "1513268": {"name": "Deltapapillomavirus 6", "rank": "Species"}, "1380346": {"name": "Streptomyces sp. URHA0041", "rank": "Species"}, "1380347": {"name": "Geodermatophilaceae bacterium URHB0048", "rank": "Species"}, "1108963": {"name": "Lactobacillus salivarius SMXD51", "rank": "Strain"}, "1513262": {"name": "Gammapapillomavirus 17", "rank": "Species"}, "1513261": {"name": "Gammapapillomavirus 16", "rank": "Species"}, "1513260": {"name": "Gammapapillomavirus 15", "rank": "Species"}, "1108968": {"name": "Pseudomonas syringae pv. actinidiae CH2010-6", "rank": "Strain"}, "41791": {"name": "Desulfovibrio acrylicus", "rank": "Species"}, "1268299": {"name": "Beta proteobacterium JGI 0001013-N12", "rank": "Species"}, "1268298": {"name": "Beta proteobacterium JGI 0001001-A11", "rank": "Species"}, "999440": {"name": "Treponema denticola US-Trep", "rank": "Strain"}, "389214": {"name": "Ranid herpesvirus 2", "rank": "Species"}, "1229752": {"name": "Campylobacter phage CP30A", "rank": "Species"}, "1268295": {"name": "Bacteroidetes bacterium JGI 0001001-A08", "rank": "Species"}, "180434": {"name": "Morganella morganii subsp. morganii", "rank": "Subspecies"}, "85698": {"name": "Achromobacter xylosoxidans", "rank": "Species"}, "911045": {"name": "Pseudovibrio sp. FO-BEG1", "rank": "Species"}, "1356852": {"name": "Hymenobacter sp. APR13", "rank": "Species"}, "1356854": {"name": "Alicyclobacillus acidoterrestris ATCC 49025", "rank": "Strain"}, "515264": {"name": "Caloramator australicus", "rank": "Species"}, "1165944": {"name": "Escherichia coli O111:H8 str. CVM9634", "rank": "Strain"}, "216591": {"name": "Burkholderia cenocepacia J2315", "rank": "Strain"}, "1165942": {"name": "Escherichia coli O111:H8 str. CVM9602", "rank": "Strain"}, "1165941": {"name": "Escherichia coli O103:H2 str. CVM9450", "rank": "Strain"}, "1165940": {"name": "Escherichia coli O103:H25 str. CVM9340", "rank": "Strain"}, "1035377": {"name": "Yersinia pestis A1122", "rank": "Strain"}, "710128": {"name": "Mycoplasma gallisepticum str. R(high)", "rank": "Strain"}, "710127": {"name": "Mycoplasma gallisepticum str. R(low)", "rank": "Strain"}, "1291379": {"name": "Treponema pedis str. T A4", "rank": "Strain"}, "491918": {"name": "Leucobacter chironomi", "rank": "Species"}, "1104619": {"name": "Hydrogenedentes bacterium JGI 0000077-D07", "rank": "Species"}, "1104610": {"name": "Microgenomates bacterium SCGC AAA011-B20", "rank": "Species"}, "1104614": {"name": "Microgenomates bacterium SCGC AAA011-I21", "rank": "Species"}, "1104615": {"name": "Microgenomates bacterium SCGC AAA011-L05", "rank": "Species"}, "491919": {"name": "Brachymonas chironomi", "rank": "Species"}, "1150989": {"name": "Vibrio phage pVp-1", "rank": "Species"}, "945692": {"name": "Gordonia neofelifaecis", "rank": "Species"}, "1310783": {"name": "Acinetobacter baumannii 214216", "rank": "Strain"}, "1310782": {"name": "Acinetobacter baumannii 1170863", "rank": "Strain"}, "1310781": {"name": "Acinetobacter baumannii 277047", "rank": "Strain"}, "1310780": {"name": "Acinetobacter baumannii 1117819", "rank": "Strain"}, "1310787": {"name": "Acinetobacter baumannii 70136", "rank": "Strain"}, "1310786": {"name": "Acinetobacter baumannii 541915", "rank": "Strain"}, "1310785": {"name": "Acinetobacter baumannii 466215", "rank": "Strain"}, "1310784": {"name": "Acinetobacter baumannii 1007214", "rank": "Strain"}, "1310789": {"name": "Acinetobacter baumannii 145660", "rank": "Strain"}, "1310788": {"name": "Acinetobacter baumannii 225588", "rank": "Strain"}, "1210884": {"name": "Gemmata sp. IIL30", "rank": "Species"}, "292563": {"name": "Cyanobacterium stanieri PCC 7202", "rank": "Strain"}, "292564": {"name": "Cyanobium gracile PCC 6307", "rank": "Strain"}, "1521388": {"name": "McMurdo Ice Shelf pond-associated circular DNA virus-4", "rank": "Species"}, "292566": {"name": "Dactylococcopsis salina", "rank": "Species"}, "1521385": {"name": "McMurdo Ice Shelf pond-associated circular DNA virus-1", "rank": "Species"}, "1521387": {"name": "McMurdo Ice Shelf pond-associated circular DNA virus-3", "rank": "Species"}, "1521386": {"name": "McMurdo Ice Shelf pond-associated circular DNA virus-2", "rank": "Species"}, "1406948": {"name": "Candida glabrata CCTCC M202019", "rank": "Strain"}, "541229": {"name": "Bacillus thuringiensis serovar chinensis CT-43", "rank": "Strain"}, "63958": {"name": "Demetria", "rank": "Genus"}, "394751": {"name": "Pseudoalteromonas arctica", "rank": "Species"}, "364412": {"name": "Unclassified Iteravirus", "rank": "No rank"}, "85569": {"name": "Salmonella enterica subsp. enterica serovar Typhimurium str. DT104", "rank": "Strain"}, "316435": {"name": "Escherichia coli Nissle 1917", "rank": "Strain"}, "721929": {"name": "Jaapiaceae", "rank": "Family"}, "373903": {"name": "Halothermothrix orenii H 168", "rank": "Strain"}, "1388557": {"name": "Staphylococcus aureus M0059", "rank": "Strain"}, "1388556": {"name": "Staphylococcus aureus M0047", "rank": "Strain"}, "1388555": {"name": "Staphylococcus aureus M0032", "rank": "Strain"}, "1388554": {"name": "Staphylococcus aureus M0023", "rank": "Strain"}, "1388553": {"name": "Staphylococcus aureus M0015", "rank": "Strain"}, "1388552": {"name": "Staphylococcus aureus M0002", "rank": "Strain"}, "1388551": {"name": "Staphylococcus aureus M0238", "rank": "Strain"}, "1388550": {"name": "Staphylococcus aureus M0222", "rank": "Strain"}, "1388559": {"name": "Staphylococcus aureus M0088", "rank": "Strain"}, "1388558": {"name": "Staphylococcus aureus M0078", "rank": "Strain"}, "310297": {"name": "Bacteroides plebeius", "rank": "Species"}, "70109": {"name": "Penicillium paxilli", "rank": "Species"}, "909952": {"name": "Propionibacterium acnes 266", "rank": "Strain"}, "310298": {"name": "Bacteroides coprocola", "rank": "Species"}, "1293047": {"name": "Halopiger sp. IIH2", "rank": "Species"}, "1444190": {"name": "Escherichia coli 1-110-08_S3_C3", "rank": "Strain"}, "1293048": {"name": "Halopiger sp. IIH3", "rank": "Species"}, "1407638": {"name": "Circo-like virus-Brazil", "rank": "Species"}, "1143004": {"name": "Methyloferula", "rank": "Genus"}, "547468": {"name": "Enterococcus faecium U0317", "rank": "Strain"}, "1388089": {"name": "Staphylococcus aureus M0142", "rank": "Strain"}, "1388088": {"name": "Staphylococcus aureus M0141", "rank": "Strain"}, "1388085": {"name": "Staphylococcus aureus M0136", "rank": "Strain"}, "1388084": {"name": "Staphylococcus aureus M0135", "rank": "Strain"}, "1388087": {"name": "Staphylococcus aureus M0138", "rank": "Strain"}, "1388086": {"name": "Staphylococcus aureus M0137", "rank": "Strain"}, "1388081": {"name": "Staphylococcus aureus M0132", "rank": "Strain"}, "1388080": {"name": "Staphylococcus aureus M0131", "rank": "Strain"}, "1388083": {"name": "Staphylococcus aureus M0134", "rank": "Strain"}, "1388082": {"name": "Staphylococcus aureus M0133", "rank": "Strain"}, "1215104": {"name": "Pseudomonas japonica NBRC 103040 = DSM 22348", "rank": "Strain"}, "351187": {"name": "Salinispora pacifica", "rank": "Species"}, "1448398": {"name": "Mycobacterium tuberculosis TKK_03_0037", "rank": "Strain"}, "1448399": {"name": "Mycobacterium tuberculosis TKK_03_0038", "rank": "Strain"}, "1215102": {"name": "Pseudomonas fulva NBRC 16637 = DSM 17717", "rank": "Strain"}, "1448394": {"name": "Mycobacterium tuberculosis TKK_03_0023", "rank": "Strain"}, "1448395": {"name": "Mycobacterium tuberculosis TKK_03_0024", "rank": "Strain"}, "1448396": {"name": "Mycobacterium tuberculosis TKK_03_0028", "rank": "Strain"}, "1448397": {"name": "Mycobacterium tuberculosis TKK_03_0035", "rank": "Strain"}, "1448390": {"name": "Mycobacterium tuberculosis TKK_03_0012", "rank": "Strain"}, "1215108": {"name": "Pseudomonas mendocina NBRC 14162", "rank": "Strain"}, "1448392": {"name": "Mycobacterium tuberculosis TKK_03_0015", "rank": "Strain"}, "1448393": {"name": "Mycobacterium tuberculosis TKK_03_0021", "rank": "Strain"}, "182788": {"name": "Penaeus monodon hepatopancreatic parvovirus", "rank": "Species"}, "290847": {"name": "Helicobacter pylori 51", "rank": "Strain"}, "1212579": {"name": "Shigella boydii 248-1B", "rank": "Strain"}, "1212578": {"name": "Shigella flexneri MT1457", "rank": "Strain"}, "1426": {"name": "Geobacillus thermoglucosidasius", "rank": "Species"}, "1421": {"name": "Lysinibacillus sphaericus", "rank": "Species"}, "1423": {"name": "Bacillus subtilis", "rank": "Species"}, "1422": {"name": "Geobacillus stearothermophilus", "rank": "Species"}, "1212571": {"name": "Shigella flexneri S7737", "rank": "Strain"}, "1212570": {"name": "Shigella boydii S7334", "rank": "Strain"}, "1212573": {"name": "Shigella boydii 08-0280", "rank": "Strain"}, "1212575": {"name": "Shigella boydii 08-2675", "rank": "Strain"}, "1212574": {"name": "Shigella boydii 08-2671", "rank": "Strain"}, "1212577": {"name": "Shigella boydii 09-0344", "rank": "Strain"}, "1212576": {"name": "Shigella boydii 08-6341", "rank": "Strain"}, "1244869": {"name": "Magnetospirillum sp. SO-1", "rank": "Species"}, "1168289": {"name": "Marinilabilia salmonicolor JCM 21150", "rank": "Strain"}, "1168288": {"name": "Mycobacterium sp. H4Y", "rank": "Species"}, "1168281": {"name": "Vibrio phage VvAW1", "rank": "Species"}, "230105": {"name": "Methylophaga aminisulfidivorans", "rank": "Species"}, "1168287": {"name": "Mycobacterium sp. MOTT36Y", "rank": "Species"}, "1168286": {"name": "Rickettsia conorii subsp. israelensis ISTT CDC1", "rank": "Strain"}, "1078471": {"name": "Serinicoccus profundi", "rank": "Species"}, "42054": {"name": "Chromohalobacter", "rank": "Genus"}, "712630": {"name": "Streptococcus sp. oral taxon 071", "rank": "Species"}, "1157634": {"name": "Streptomyces sp. Amel2xE9", "rank": "Species"}, "1157635": {"name": "Streptomyces sp. ATexAB-D23", "rank": "Species"}, "1157636": {"name": "Streptomyces sp. SolWspMP-sol2th", "rank": "Species"}, "1157637": {"name": "Streptomyces sp. BoleA5", "rank": "Species"}, "1157632": {"name": "Streptomyces sp. LaPpAH-95", "rank": "Species"}, "1157633": {"name": "Streptomyces sp. KhCrAH-244", "rank": "Species"}, "1157638": {"name": "Streptomyces sp. PsTaAH-124", "rank": "Species"}, "1157639": {"name": "Streptomyces sp. FxanaD5", "rank": "Species"}, "985008": {"name": "Aggregatibacter aphrophilus ATCC 33389", "rank": "Strain"}, "985002": {"name": "Staphylococcus aureus subsp. aureus MSHR1132", "rank": "Strain"}, "1427215": {"name": "Mycobacterium tuberculosis XTB13-124", "rank": "Strain"}, "985006": {"name": "Staphylococcus aureus subsp. aureus LGA251", "rank": "Strain"}, "1446648": {"name": "Escherichia coli O157:H7 str. 2011EL-2289", "rank": "Strain"}, "1446649": {"name": "Escherichia coli O157:H7 str. 2011EL-2290", "rank": "Strain"}, "1446644": {"name": "Escherichia coli O157:H7 str. 2011EL-2114", "rank": "Strain"}, "1446645": {"name": "Escherichia coli O157:H7 str. 2011EL-2286", "rank": "Strain"}, "1446646": {"name": "Escherichia coli O157:H7 str. 2011EL-2287", "rank": "Strain"}, "1446647": {"name": "Escherichia coli O157:H7 str. 2011EL-2288", "rank": "Strain"}, "1446640": {"name": "Escherichia coli O157:H7 str. 2011EL-2109", "rank": "Strain"}, "549685": {"name": "Bavariicoccus seileri", "rank": "Species"}, "1446642": {"name": "Escherichia coli O157:H7 str. 2011EL-2112", "rank": "Strain"}, "1446643": {"name": "Escherichia coli O157:H7 str. 2011EL-2113", "rank": "Strain"}, "1261058": {"name": "Gardnerella vaginalis JCP7276", "rank": "Strain"}, "1261059": {"name": "Gardnerella vaginalis JCP7659", "rank": "Strain"}, "118168": {"name": "Coleofasciculus chthonoplastes PCC 7420", "rank": "Strain"}, "118166": {"name": "Nodosilinea nodulosa PCC 7104", "rank": "Strain"}, "118163": {"name": "Pleurocapsa sp. PCC 7327", "rank": "Strain"}, "261726": {"name": "Vibrio phage VP882", "rank": "Species"}, "118161": {"name": "Pleurocapsa sp. PCC 7319", "rank": "Species"}, "1261057": {"name": "Gardnerella vaginalis JCP7275", "rank": "Strain"}, "1445607": {"name": "Bacteroides reticulotermitis JCM 10512", "rank": "Strain"}, "1445606": {"name": "Mycobacterium tuberculosis str. Kurono", "rank": "Strain"}, "11569": {"name": "Thogoto virus", "rank": "Species"}, "590062": {"name": "Bacillaceae bacterium MTCC 10057", "rank": "Species"}, "590061": {"name": "Halomonas sp. KM-1", "rank": "Species"}, "1472682": {"name": "Psychrobacter sp. 310(2012)", "rank": "Species"}, "1118060": {"name": "Enorma massiliensis phI", "rank": "Strain"}, "1118061": {"name": "Bacteroidales bacterium ph8", "rank": "Species"}, "1118062": {"name": "Peptoniphilus obesi ph1", "rank": "Strain"}, "1118063": {"name": "Staphylococcus phage SpaA1", "rank": "Species"}, "54260": {"name": "Ferroglobus", "rank": "Genus"}, "203691": {"name": "Spirochaetes", "rank": "Phylum"}, "72293": {"name": "Helicobacteraceae", "rank": "Family"}, "749494": {"name": "Enterococcus faecalis TX4244", "rank": "Strain"}, "72294": {"name": "Campylobacteraceae", "rank": "Family"}, "749493": {"name": "Enterococcus faecalis TX4000", "rank": "Strain"}, "1296569": {"name": "Andean potato mild mosaic virus", "rank": "Species"}, "1116189": {"name": "Escherichia coli P0304816.13", "rank": "Strain"}, "1116188": {"name": "Escherichia coli P0304816.12", "rank": "Strain"}, "1300343": {"name": "Dokdonia donghaensis DSW-1", "rank": "Strain"}, "1116185": {"name": "Escherichia coli P0304816.9", "rank": "Strain"}, "1116184": {"name": "Escherichia coli P0304816.8", "rank": "Strain"}, "1116187": {"name": "Escherichia coli P0304816.11", "rank": "Strain"}, "1116186": {"name": "Escherichia coli P0304816.10", "rank": "Strain"}, "1116181": {"name": "Escherichia coli P0304816.5", "rank": "Strain"}, "1116180": {"name": "Escherichia coli P0304816.4", "rank": "Strain"}, "1116183": {"name": "Escherichia coli P0304816.7", "rank": "Strain"}, "1116182": {"name": "Escherichia coli P0304816.6", "rank": "Strain"}, "454601": {"name": "Maritalea myrionectae", "rank": "Species"}, "454600": {"name": "Gracilimonas tropica", "rank": "Species"}, "228398": {"name": "Streptacidiphilus", "rank": "Genus"}, "228399": {"name": "Actinobacillus pleuropneumoniae serovar 1 str. 4074", "rank": "Strain"}, "1198679": {"name": "Brucella melitensis CNGB 1076", "rank": "Strain"}, "1198678": {"name": "Brucella ovis F8/05B", "rank": "Strain"}, "1125979": {"name": "Rhizobium sp. PDO1-076", "rank": "Species"}, "1125976": {"name": "Peptoclostridium difficile CD37", "rank": "Strain"}, "1125977": {"name": "Pseudomonas sp. PAMC 25886", "rank": "Species"}, "1125974": {"name": "Thermoanaerobacter indiensis", "rank": "Species"}, "1198676": {"name": "Streptococcus mutans GS-5", "rank": "Strain"}, "1125972": {"name": "Amycolatopsis alba DSM 44262", "rank": "Strain"}, "1125973": {"name": "Bosea sp. 117", "rank": "Species"}, "1198673": {"name": "Pseudomonas syringae pv. theae ICMP 3923", "rank": "Strain"}, "1125971": {"name": "Amycolatopsis orientalis DSM 40040 = KCTC 9412", "rank": "Strain"}, "71366": {"name": "Staphylococcus phage PVL", "rank": "Species"}, "1283313": {"name": "Alloprevotella", "rank": "Genus"}, "1283312": {"name": "Sphingomonas sp. DC-6", "rank": "Species"}, "1434186": {"name": "Shigella flexneri 2002142", "rank": "Strain"}, "259898": {"name": "Sheldgoose hepatitis B virus", "rank": "Species"}, "1434184": {"name": "Shigella flexneri 2002127", "rank": "Strain"}, "1434185": {"name": "Shigella flexneri 2002141", "rank": "Strain"}, "1434182": {"name": "Shigella flexneri 2001048", "rank": "Strain"}, "1434183": {"name": "Shigella flexneri 2002035", "rank": "Strain"}, "1434180": {"name": "Shigella flexneri 2001025", "rank": "Strain"}, "1434181": {"name": "Shigella flexneri 2001027", "rank": "Strain"}, "82986": {"name": "Tatumella", "rank": "Genus"}, "82987": {"name": "Tatumella ptyseos", "rank": "Species"}, "82980": {"name": "Leminorella", "rank": "Genus"}, "82981": {"name": "Leminorella grimontii", "rank": "Species"}, "1530186": {"name": "Maribius sp. MOLA 401", "rank": "Species"}, "186818": {"name": "Planococcaceae", "rank": "Family"}, "723171": {"name": "Vibrio genomosp. F10", "rank": "Species"}, "186813": {"name": "Unclassified Clostridiales", "rank": "No rank"}, "186814": {"name": "Thermoanaerobacteraceae", "rank": "Family"}, "186817": {"name": "Bacillaceae", "rank": "Family"}, "229545": {"name": "Aster yellows witches'-broom phytoplasma", "rank": "Species"}, "564643": {"name": "Blosnavirus", "rank": "Genus"}, "564645": {"name": "Globulovirus", "rank": "Genus"}, "229549": {"name": "Streptococcus minor", "rank": "Species"}, "545243": {"name": "Clostridium arbusti SL206", "rank": "Strain"}, "1125644": {"name": "Escherichia coli P0305260.1", "rank": "Strain"}, "1125645": {"name": "Escherichia coli P0305260.2", "rank": "Strain"}, "657316": {"name": "Megamonas hypermegale ART12/1", "rank": "Strain"}, "337090": {"name": "Chlorobium chlorochromatii", "rank": "Species"}, "147467": {"name": "Staphylococcus sciuri subsp. sciuri", "rank": "Subspecies"}, "1125647": {"name": "Escherichia coli P0301904.3", "rank": "Strain"}, "1125640": {"name": "Escherichia coli P0298942.4", "rank": "Strain"}, "1163399": {"name": "Stenotrophomonas maltophilia D457", "rank": "Strain"}, "657313": {"name": "Ruminococcus torques L2-14", "rank": "Strain"}, "939909": {"name": "Verrucomicrobia bacterium SCGC AAA300-K03", "rank": "Species"}, "741161": {"name": "Paenibacillus larvae subsp. larvae B-3650", "rank": "Strain"}, "1542468": {"name": "Enterobacter sp. UCD-UG_FMILLET", "rank": "Species"}, "1284789": {"name": "Klebsiella pneumoniae UHKPC28", "rank": "Strain"}, "1284788": {"name": "Klebsiella pneumoniae UHKPC23", "rank": "Strain"}, "1409691": {"name": "Staphylococcus aureus GGMC6026", "rank": "Strain"}, "205872": {"name": "Mycobacterium phage Che9c", "rank": "Species"}, "768494": {"name": "Bacillus anthracis str. H9401", "rank": "Strain"}, "768492": {"name": "Serratia plymuthica AS9", "rank": "Strain"}, "768493": {"name": "Serratia sp. AS13", "rank": "Species"}, "768490": {"name": "Serratia sp. AS12", "rank": "Species"}, "1125649": {"name": "Escherichia coli P0299483.2", "rank": "Strain"}, "1280666": {"name": "Butyrivibrio sp. AE3009", "rank": "Species"}, "1280667": {"name": "Butyrivibrio sp. VCB2001", "rank": "Species"}, "1280664": {"name": "Butyrivibrio sp. VCD2006", "rank": "Species"}, "1280665": {"name": "Butyrivibrio sp. XPD2002", "rank": "Species"}, "1280663": {"name": "Butyrivibrio sp. AE2015", "rank": "Species"}, "76630": {"name": "Mycoplasma iners", "rank": "Species"}, "76632": {"name": "Thermobacillus", "rank": "Genus"}, "133924": {"name": "Leisingera methylohalidivorans", "rank": "Species"}, "133925": {"name": "Olsenella", "rank": "Genus"}, "133926": {"name": "Olsenella uli", "rank": "Species"}, "1280669": {"name": "Dorea sp. AGR2135", "rank": "Species"}, "963": {"name": "Herbaspirillum", "rank": "Genus"}, "1571816": {"name": "Enterobacter sp. FB", "rank": "Species"}, "964": {"name": "Herbaspirillum seropedicae", "rank": "Species"}, "965": {"name": "Oceanospirillum", "rank": "Genus"}, "935938": {"name": "Bacillus ginsengihumi J57", "rank": "Strain"}, "936370": {"name": "Capnocytophaga sp. CM59", "rank": "Species"}, "936375": {"name": "Mogibacterium sp. CM50", "rank": "Species"}, "44013": {"name": "Polynucleobacter", "rank": "Genus"}, "139870": {"name": "Lactobacillus prophage Lj965", "rank": "Species"}, "139871": {"name": "Lactobacillus prophage Lj771", "rank": "Species"}, "139872": {"name": "Lactobacillus prophage Lj928", "rank": "Species"}, "1126899": {"name": "Escherichia coli C354_03B", "rank": "Strain"}, "1204471": {"name": "Pseudomonas syringae BRIP34876", "rank": "Strain"}, "2208": {"name": "Methanosarcina barkeri", "rank": "Species"}, "1204476": {"name": "Fusobacterium nucleatum CTI-3", "rank": "Strain"}, "1204475": {"name": "Fusobacterium nucleatum CTI-2", "rank": "Strain"}, "1204474": {"name": "Fusobacterium nucleatum CTI-1", "rank": "Strain"}, "1126890": {"name": "Escherichia coli C260_92", "rank": "Strain"}, "1126891": {"name": "Escherichia coli C262_10", "rank": "Strain"}, "1126892": {"name": "Escherichia coli C283_09", "rank": "Strain"}, "1126893": {"name": "Escherichia coli C295_10", "rank": "Strain"}, "1126895": {"name": "Escherichia coli C341_10", "rank": "Strain"}, "1126896": {"name": "Escherichia coli C343_08", "rank": "Strain"}, "1126897": {"name": "Escherichia coli C347_93", "rank": "Strain"}, "1444273": {"name": "Escherichia coli 1-176-05_S4_C3", "rank": "Strain"}, "1281004": {"name": "Escherichia coli HVH 58 (4-2839709)", "rank": "Strain"}, "1444271": {"name": "Escherichia coli 8-415-05_S4_C3", "rank": "Strain"}, "1444270": {"name": "Escherichia coli 7-233-03_S4_C3", "rank": "Strain"}, "1409667": {"name": "Staphylococcus aureus FVRH6076", "rank": "Strain"}, "1281000": {"name": "Escherichia coli HVH 53 (4-0631051)", "rank": "Strain"}, "1444275": {"name": "Escherichia coli 1-392-07_S4_C3", "rank": "Strain"}, "1444274": {"name": "Escherichia coli 1-182-04_S4_C3", "rank": "Strain"}, "28985": {"name": "Kluyveromyces lactis", "rank": "Species"}, "1444279": {"name": "Escherichia coli 3-373-03_S4_C3", "rank": "Strain"}, "1409668": {"name": "Staphylococcus aureus FVRH6065", "rank": "Strain"}, "1281009": {"name": "Escherichia coli HVH 68 (4-0888028)", "rank": "Strain"}, "1281008": {"name": "Escherichia coli HVH 65 (4-2262045)", "rank": "Strain"}, "28983": {"name": "Sclerotiniaceae", "rank": "Family"}, "1429768": {"name": "Erwinia phage Ea35-70", "rank": "Species"}, "645512": {"name": "Jonquetella anthropi E3_33 E1", "rank": "Strain"}, "1117720": {"name": "Candidatus Haloredivivus", "rank": "No rank"}, "645516": {"name": "Polemovirus", "rank": "Genus"}, "1422516": {"name": "Staphylococcus aureus VET0221R", "rank": "Strain"}, "1422517": {"name": "Staphylococcus aureus VET0222R", "rank": "Strain"}, "1422514": {"name": "Staphylococcus aureus VET0218R", "rank": "Strain"}, "1422515": {"name": "Staphylococcus aureus VET0219R", "rank": "Strain"}, "1422512": {"name": "Staphylococcus aureus VET0216R", "rank": "Strain"}, "1422513": {"name": "Staphylococcus aureus VET0217R", "rank": "Strain"}, "1422510": {"name": "Staphylococcus aureus VET0214R", "rank": "Strain"}, "1422511": {"name": "Staphylococcus aureus VET0215R", "rank": "Strain"}, "1333537": {"name": "Escherichia coli NCTC 50110", "rank": "Strain"}, "1333536": {"name": "Escherichia coli 95NR1", "rank": "Strain"}, "1333535": {"name": "Escherichia coli 95JB1", "rank": "Strain"}, "34010": {"name": "Azospirillum halopraeferens", "rank": "Species"}, "1333539": {"name": "Ralstonia solanacearum SD54", "rank": "Strain"}, "592031": {"name": "Eubacterium saphenum ATCC 49989", "rank": "Strain"}, "34018": {"name": "Rhodospirillum centenum", "rank": "Species"}, "575607": {"name": "Lactobacillus jensenii SJ-7A-US", "rank": "Strain"}, "578234": {"name": "Lactobacillus phage Lv-1", "rank": "Species"}, "575605": {"name": "Lactobacillus jensenii 115-3-CHN", "rank": "Strain"}, "575604": {"name": "Lactobacillus gasseri SV-16A-US", "rank": "Strain"}, "575603": {"name": "Lactobacillus gasseri SJ-9E-US", "rank": "Strain"}, "53182": {"name": "Feline foamy virus", "rank": "Species"}, "53181": {"name": "Hibiscus chlorotic ringspot virus", "rank": "Species"}, "575609": {"name": "Peptoniphilus sp. oral taxon 386 str. F0131", "rank": "Strain"}, "575608": {"name": "Staphylococcus phage phiSauS-IPLA88", "rank": "Species"}, "1122249": {"name": "Mycoplasma sturni DSM 22021", "rank": "Strain"}, "1122248": {"name": "Mycoplasma gallinarum DSM 19816", "rank": "Strain"}, "272751": {"name": "Dendrolimus punctatus tetravirus", "rank": "Species"}, "43595": {"name": "Halanaerobium saccharolyticum", "rank": "Species"}, "1122240": {"name": "Microvirgula aerodenitrificans DSM 15089", "rank": "Strain"}, "1122243": {"name": "Moraxella boevrei DSM 14165", "rank": "Strain"}, "1122244": {"name": "Moraxella caprae DSM 19149", "rank": "Strain"}, "1122247": {"name": "Mycobacterium hassiacum DSM 44199", "rank": "Strain"}, "52584": {"name": "Brachyspira pilosicoli", "rank": "Species"}, "864803": {"name": "Clostridium beijerinckii ATCC 35702", "rank": "Strain"}, "400835": {"name": "Tomato leaf curl Guangdong virus", "rank": "Species"}, "187857": {"name": "Aquificae", "rank": "Class"}, "639282": {"name": "Deferribacter desulfuricans SSM1", "rank": "Strain"}, "639283": {"name": "Starkeya novella DSM 506", "rank": "Strain"}, "444515": {"name": "Maribacter forsetii", "rank": "Species"}, "1388254": {"name": "Staphylococcus aureus M0383", "rank": "Strain"}, "1081094": {"name": "Legionella pneumophila subsp. pneumophila str. Hextuple_2q", "rank": "Strain"}, "1081095": {"name": "Legionella pneumophila subsp. pneumophila str. Hextuple_3a", "rank": "Strain"}, "1081093": {"name": "Salmonella enterica subsp. enterica serovar Gallinarum/pullorum str. RKS5078", "rank": "Strain"}, "1331008": {"name": "Staphylococcus aureus subsp. aureus CBD-635", "rank": "Strain"}, "1331007": {"name": "Agarivorans albus MKT 106", "rank": "Strain"}, "357276": {"name": "Bacteroides dorei", "rank": "Species"}, "1348660": {"name": "Serratia plymuthica S13", "rank": "Strain"}, "1348663": {"name": "Kitasatospora cheerisanensis KCTC 2395", "rank": "Strain"}, "1348662": {"name": "Corynebacterium argentoratense DSM 44202", "rank": "Strain"}, "1269760": {"name": "Lactobacillus delbrueckii subsp. lactis CRL581", "rank": "Strain"}, "12844": {"name": "Sweet potato feathery mottle virus", "rank": "Species"}, "157783": {"name": "Pseudomonas cremoricolorata", "rank": "Species"}, "157784": {"name": "Pseudomonas thermotolerans", "rank": "Species"}, "320856": {"name": "Bidens mosaic virus", "rank": "Species"}, "320850": {"name": "Staphylococcus phage X2", "rank": "Strain"}, "1418382": {"name": "Staphylococcus aureus F48422", "rank": "Strain"}, "191579": {"name": "Fluviicola taffensis", "rank": "Species"}, "191577": {"name": "Epilithonimonas tenax", "rank": "Species"}, "1446727": {"name": "Escherichia coli O26:H11 str. 2010EL-1699", "rank": "Strain"}, "563188": {"name": "Salinisphaera hydrothermalis", "rank": "Species"}, "1418380": {"name": "Staphylococcus aureus F38211", "rank": "Strain"}, "1446726": {"name": "Escherichia coli O26:H11 str. 2010C-5028", "rank": "Strain"}, "1430432": {"name": "Salmonella enterica subsp. enterica serovar Bovismorbificans str. Sal680", "rank": "Strain"}, "1430430": {"name": "Salmonella enterica subsp. enterica serovar Bovismorbificans str. Sal678", "rank": "Strain"}, "1430431": {"name": "Salmonella enterica subsp. enterica serovar Bovismorbificans str. Sal679", "rank": "Strain"}, "1430436": {"name": "Salmonella enterica subsp. enterica serovar Bovismorbificans str. Sal610", "rank": "Strain"}, "1430437": {"name": "Salmonella enterica subsp. enterica serovar Bovismorbificans str. Sal615", "rank": "Strain"}, "1430434": {"name": "Salmonella enterica subsp. enterica serovar Bovismorbificans str. Sal676", "rank": "Strain"}, "1095646": {"name": "Vibrio cholerae O1 str. EM-1536", "rank": "Strain"}, "1430438": {"name": "Salmonella enterica subsp. enterica serovar Bovismorbificans str. Sal616", "rank": "Strain"}, "1430439": {"name": "Salmonella enterica subsp. enterica serovar Bovismorbificans str. Sal617", "rank": "Strain"}, "135618": {"name": "Methylococcales", "rank": "Order"}, "135619": {"name": "Oceanospirillales", "rank": "Order"}, "75659": {"name": "Duganella zoogloeoides", "rank": "Species"}, "406552": {"name": "Natrinema sp. J7-2", "rank": "Species"}, "135613": {"name": "Chromatiales", "rank": "Order"}, "135614": {"name": "Xanthomonadales", "rank": "Order"}, "135615": {"name": "Cardiobacteriales", "rank": "Order"}, "75654": {"name": "Duganella", "rank": "Genus"}, "135617": {"name": "Thiotrichaceae", "rank": "Family"}, "1177185": {"name": "Bacillus siamensis KCTC 13613", "rank": "Strain"}, "1177186": {"name": "Bacillus amyloliquefaciens subsp. plantarum M27", "rank": "Strain"}, "1446728": {"name": "Escherichia coli O26:H11 str. 2011C-3270", "rank": "Strain"}, "1410768": {"name": "Staphylococcus aureus H84507", "rank": "Strain"}, "1410769": {"name": "Staphylococcus aureus F40814", "rank": "Strain"}, "1410764": {"name": "Staphylococcus aureus T41081", "rank": "Strain"}, "1410765": {"name": "Staphylococcus aureus T28847", "rank": "Strain"}, "1410766": {"name": "Staphylococcus aureus H84489", "rank": "Strain"}, "1410767": {"name": "Staphylococcus aureus H84492", "rank": "Strain"}, "876142": {"name": "Encephalitozoon intestinalis ATCC 50506", "rank": "Strain"}, "414684": {"name": "Rhodospirillum centenum SW", "rank": "Strain"}, "1410762": {"name": "Staphylococcus aureus W24216", "rank": "Strain"}, "1410763": {"name": "Staphylococcus aureus H81437", "rank": "Strain"}, "1310652": {"name": "Acinetobacter baumannii 1475718", "rank": "Strain"}, "1421885": {"name": "Staphylococcus aureus T13127", "rank": "Strain"}, "1421884": {"name": "Staphylococcus aureus T13126", "rank": "Strain"}, "1421887": {"name": "Staphylococcus aureus T32086", "rank": "Strain"}, "926028": {"name": "Escherichia coli O157:H- str. H 2687", "rank": "Strain"}, "1421881": {"name": "Staphylococcus aureus M86943", "rank": "Strain"}, "1421880": {"name": "Staphylococcus aureus M86940", "rank": "Strain"}, "1421883": {"name": "Staphylococcus aureus T13125", "rank": "Strain"}, "1421882": {"name": "Staphylococcus aureus M90388", "rank": "Strain"}, "329639": {"name": "Canine minute virus", "rank": "Strain"}, "1421888": {"name": "Staphylococcus aureus T32092", "rank": "Strain"}, "521674": {"name": "Planctomyces limnophilus DSM 3776", "rank": "Strain"}, "1308896": {"name": "Staphylococcus phage StauST398-4", "rank": "Species"}, "1308897": {"name": "Staphylococcus phage StauST398-5", "rank": "Species"}, "37840": {"name": "Pestalotiopsis", "rank": "Genus"}, "10358": {"name": "Cytomegalovirus", "rank": "Genus"}, "10359": {"name": "Human herpesvirus 5", "rank": "Species"}, "1500386": {"name": "Staphylococcus phage 6ec", "rank": "Species"}, "10353": {"name": "Saimiriine herpesvirus 1", "rank": "Species"}, "10357": {"name": "Betaherpesvirinae", "rank": "Subfamily"}, "135624": {"name": "Aeromonadales", "rank": "Order"}, "247269": {"name": "Human papillomavirus type 96", "rank": "Strain"}, "1121267": {"name": "Campylobacter cuniculorum DSM 23162", "rank": "Strain"}, "1121268": {"name": "Campylobacter curvus DSM 6644", "rank": "Strain"}, "1121269": {"name": "Campylobacter upsaliensis DSM 5365", "rank": "Strain"}, "1500284": {"name": "Chryseobacterium sp. CF299", "rank": "Species"}, "83557": {"name": "Chlamydophila caviae", "rank": "Species"}, "416591": {"name": "Thermotoga lettingae TMO", "rank": "Strain"}, "1381596": {"name": "Marinimicrobium sp. LS-A18", "rank": "Species"}, "1381597": {"name": "Sphingomonas sp. ERG5", "rank": "Species"}, "302449": {"name": "Corynebacterium tuscaniense", "rank": "Species"}, "1416758": {"name": "Morganella morganii H1r", "rank": "Strain"}, "1525718": {"name": "Paracoccus sp. 39524", "rank": "Species"}, "1525716": {"name": "Paracoccus sp. 10990", "rank": "Species"}, "1525717": {"name": "Paracoccus sp. 5503", "rank": "Species"}, "1525715": {"name": "Paracoccus sp. 4681", "rank": "Species"}, "1440058": {"name": "Clostridium botulinum C/D str. Sp77", "rank": "Strain"}, "499": {"name": "Thermomicrobium", "rank": "Genus"}, "1295527": {"name": "Enterococcus faecium CRL1879", "rank": "Strain"}, "490": {"name": "Neisseria sicca", "rank": "Species"}, "491": {"name": "Neisseria meningitidis serogroup B", "rank": "Strain"}, "496": {"name": "Neisseria macacae", "rank": "Species"}, "497": {"name": "Psychrobacter", "rank": "Genus"}, "495": {"name": "Neisseria elongata", "rank": "Species"}, "1157432": {"name": "Enterococcus faecium EnGen0137", "rank": "Strain"}, "1157433": {"name": "Enterococcus faecium EnGen0138", "rank": "Strain"}, "1157430": {"name": "Enterococcus faecium EnGen0132", "rank": "Strain"}, "1157431": {"name": "Enterococcus faecium EnGen0136", "rank": "Strain"}, "108819": {"name": "Coprothermobacter platensis", "rank": "Species"}, "1157437": {"name": "Enterococcus faecium EnGen0142", "rank": "Strain"}, "1157435": {"name": "Enterococcus faecium EnGen0140", "rank": "Strain"}, "1412686": {"name": "Staphylococcus aureus T16676", "rank": "Strain"}, "2160": {"name": "Methanobacterium", "rank": "Genus"}, "2162": {"name": "Methanobacterium formicicum", "rank": "Species"}, "1440054": {"name": "Vibrio sp. OY15", "rank": "Species"}, "549446": {"name": "Pseudomonas phage LMA2", "rank": "Species"}, "549445": {"name": "Pseudomonas phage LBL3", "rank": "Species"}, "35772": {"name": "Peanut witches'-broom phytoplasma", "rank": "Species"}, "1388714": {"name": "Staphylococcus aureus M0951", "rank": "Strain"}, "1388717": {"name": "Staphylococcus aureus M0955", "rank": "Strain"}, "5322": {"name": "Pleurotus ostreatus", "rank": "Species"}, "1388711": {"name": "Staphylococcus aureus M0948", "rank": "Strain"}, "1388710": {"name": "Staphylococcus aureus M0947", "rank": "Strain"}, "1388713": {"name": "Staphylococcus aureus M0950", "rank": "Strain"}, "1388712": {"name": "Staphylococcus aureus M0949", "rank": "Strain"}, "69965": {"name": "Macrococcus", "rank": "Genus"}, "415229": {"name": "Pseudoxanthomonas spadix", "rank": "Species"}, "69966": {"name": "Macrococcus caseolyticus", "rank": "Species"}, "1388719": {"name": "Staphylococcus aureus M0957", "rank": "Strain"}, "1388718": {"name": "Staphylococcus aureus M0956", "rank": "Strain"}, "358220": {"name": "Acidovorax sp. KKS102", "rank": "Species"}, "1411578": {"name": "Staphylococcus aureus T82627", "rank": "Strain"}, "1411579": {"name": "Staphylococcus aureus T86006", "rank": "Strain"}, "650055": {"name": "Yersinia pestis G1670", "rank": "Strain"}, "1411572": {"name": "Staphylococcus aureus T72876", "rank": "Strain"}, "1411573": {"name": "Staphylococcus aureus T72889", "rank": "Strain"}, "1411570": {"name": "Staphylococcus aureus T69716", "rank": "Strain"}, "1411571": {"name": "Staphylococcus aureus T69721", "rank": "Strain"}, "1411576": {"name": "Staphylococcus aureus T76030", "rank": "Strain"}, "1411577": {"name": "Staphylococcus aureus T79159", "rank": "Strain"}, "1411574": {"name": "Staphylococcus aureus T76010", "rank": "Strain"}, "1411575": {"name": "Staphylococcus aureus T76018", "rank": "Strain"}, "204440": {"name": "Mamestra configurata nucleopolyhedrovirus B", "rank": "Species"}, "204441": {"name": "Rhodospirillales", "rank": "Order"}, "204447": {"name": "Skermanella", "rank": "Genus"}, "692605": {"name": "Batrachovirus", "rank": "Genus"}, "692606": {"name": "Cyprinivirus", "rank": "Genus"}, "749949": {"name": "Salmonella enterica subsp. enterica serovar Montevideo str. NC_MB110209-0054", "rank": "Strain"}, "749948": {"name": "Salmonella enterica subsp. enterica serovar Montevideo str. LQC 10", "rank": "Strain"}, "749947": {"name": "Salmonella enterica subsp. enterica serovar Montevideo str. SARB30", "rank": "Strain"}, "327822": {"name": "Unclassified Vesiculovirus", "rank": "No rank"}, "1035196": {"name": "Peptostreptococcus anaerobius VPI 4330 = DSM 2949", "rank": "Strain"}, "1035197": {"name": "Prevotella sp. oral taxon 473 str. F0040", "rank": "Strain"}, "1035194": {"name": "Aggregatibacter actinomycetemcomitans Y4", "rank": "Strain"}, "1035195": {"name": "Corynebacterium durum F0235", "rank": "Strain"}, "1035193": {"name": "Capnocytophaga sp. oral taxon 326 str. F0382", "rank": "Strain"}, "1035190": {"name": "Streptococcus oralis SK313", "rank": "Strain"}, "631454": {"name": "Lutibaculum baratangense AMV1", "rank": "Strain"}, "196015": {"name": "Caldimonas manganoxidans", "rank": "Species"}, "114248": {"name": "Tepidimonas", "rank": "Genus"}, "1439115": {"name": "Streptococcus pyogenes ABC020039391", "rank": "Strain"}, "1439111": {"name": "Streptococcus pyogenes ABC020039031", "rank": "Strain"}, "431947": {"name": "Porphyromonas gingivalis ATCC 33277", "rank": "Strain"}, "431946": {"name": "Escherichia coli SE15", "rank": "Strain"}, "431944": {"name": "Magnetospirillum gryphiswaldense MSR-1", "rank": "Strain"}, "431943": {"name": "Clostridium kluyveri DSM 555", "rank": "Strain"}, "502108": {"name": "Bovine respiratory coronavirus AH187", "rank": "Species"}, "327794": {"name": "Unclassified Phlebovirus", "rank": "No rank"}, "1243": {"name": "Leuconostoc", "rank": "Genus"}, "452339": {"name": "Gloeophyllales", "rank": "Order"}, "452338": {"name": "Corticiales", "rank": "Order"}, "798299": {"name": "Streptococcus pyogenes serotype M59", "rank": "Strain"}, "224471": {"name": "Burkholderiales Genera incertae sedis", "rank": "No rank"}, "1392073": {"name": "Staphylococcus aureus M1074", "rank": "Strain"}, "1392072": {"name": "Staphylococcus aureus M1073", "rank": "Strain"}, "1392071": {"name": "Staphylococcus aureus M1071", "rank": "Strain"}, "1392070": {"name": "Staphylococcus aureus M1070", "rank": "Strain"}, "666563": {"name": "Aquimarina macrocephali", "rank": "Species"}, "1392076": {"name": "Staphylococcus aureus M1079", "rank": "Strain"}, "1392075": {"name": "Staphylococcus aureus M1077", "rank": "Strain"}, "1392074": {"name": "Staphylococcus aureus M1075", "rank": "Strain"}, "1392079": {"name": "Staphylococcus aureus M1082", "rank": "Strain"}, "1392078": {"name": "Staphylococcus aureus M1081", "rank": "Strain"}, "1196835": {"name": "Pseudomonas stutzeri CCUG 29243", "rank": "Strain"}, "1324269": {"name": "Mycobacterium sp. TKK-01-0059", "rank": "Species"}, "1324268": {"name": "Mycobacterium tuberculosis TKK-01-0058", "rank": "Strain"}, "1324267": {"name": "Mycobacterium tuberculosis TKK-01-0057", "rank": "Strain"}, "1324266": {"name": "Mycobacterium tuberculosis TKK-01-0056", "rank": "Strain"}, "1324265": {"name": "Mycobacterium tuberculosis TKK-01-0055", "rank": "Strain"}, "1324264": {"name": "Mycobacterium tuberculosis TKK-01-0054", "rank": "Strain"}, "1324263": {"name": "Mycobacterium tuberculosis TKK-01-0053", "rank": "Strain"}, "1324262": {"name": "Mycobacterium tuberculosis TKK-01-0052", "rank": "Strain"}, "1324261": {"name": "Mycobacterium tuberculosis TKK-01-0051", "rank": "Strain"}, "1324260": {"name": "Mycobacterium tuberculosis TKK-01-0050", "rank": "Strain"}, "665912": {"name": "Bipolaris sorokiniana ND90Pr", "rank": "Strain"}, "656393": {"name": "Escherichia coli H299", "rank": "Strain"}, "85010": {"name": "Pseudonocardineae", "rank": "Suborder"}, "656390": {"name": "Escherichia coli H263", "rank": "Strain"}, "1354130": {"name": "Mycobacterium tuberculosis MAL020152", "rank": "Strain"}, "1086033": {"name": "Burkholderia pseudomallei 1258b", "rank": "Strain"}, "1086032": {"name": "Burkholderia pseudomallei 1258a", "rank": "Strain"}, "656398": {"name": "Escherichia coli H397", "rank": "Strain"}, "76890": {"name": "Asticcacaulis", "rank": "Genus"}, "1086036": {"name": "Burkholderia pseudomallei 354e", "rank": "Strain"}, "84531": {"name": "Lysobacter antibioticus", "rank": "Species"}, "699266": {"name": "Marinimicrobia bacterium SCGC AAA003-E22", "rank": "Species"}, "216427": {"name": "Mesoplasma chauliocola", "rank": "Species"}, "699262": {"name": "Microgenomates bacterium SCGC AAA011-L6", "rank": "Species"}, "699263": {"name": "Microgenomates bacterium SCGC AAA040-P11", "rank": "Species"}, "699261": {"name": "Microgenomates bacterium SCGC AAA011-F5", "rank": "Species"}, "81475": {"name": "Frateuria aurantia", "rank": "Species"}, "1354132": {"name": "Mycobacterium tuberculosis MAL020157", "rank": "Strain"}, "1419324": {"name": "Lactobacillus kunkeei EFB6", "rank": "Strain"}, "1167756": {"name": "Variovorax sp. JGI 001013-H06", "rank": "Species"}, "1167751": {"name": "Rhizobium sp. JGI 001014-O06", "rank": "Species"}, "460517": {"name": "Komagataella", "rank": "Genus"}, "1407055": {"name": "Thaumarchaeota archaeon N4", "rank": "Species"}, "1407053": {"name": "Brucella ceti TE28753-12", "rank": "Strain"}, "160358": {"name": "Pepper yellow mosaic virus", "rank": "Species"}, "1407059": {"name": "Pseudomonas aeruginosa PA38182", "rank": "Strain"}, "1173431": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN000199", "rank": "Strain"}, "182623": {"name": "Smithella", "rank": "Genus"}, "1370118": {"name": "Mycobacterium sp. UM_RHS", "rank": "Species"}, "1394569": {"name": "Vibrio parahaemolyticus S022", "rank": "Strain"}, "1178777": {"name": "Halomonas zincidurans", "rank": "Species"}, "331117": {"name": "Neosartorya fischeri NRRL 181", "rank": "Strain"}, "1394560": {"name": "Vibrio parahaemolyticus S013", "rank": "Strain"}, "1394567": {"name": "Vibrio parahaemolyticus S020", "rank": "Strain"}, "1394566": {"name": "Vibrio parahaemolyticus S019", "rank": "Strain"}, "331113": {"name": "Simkania negevensis Z", "rank": "Strain"}, "1394564": {"name": "Vibrio parahaemolyticus S017", "rank": "Strain"}, "1458863": {"name": "Shewanella sp. phage 3/49", "rank": "Species"}, "945712": {"name": "Corynebacterium ulcerans BR-AD22", "rank": "Strain"}, "945713": {"name": "Ignavibacterium album JCM 16511", "rank": "Strain"}, "945711": {"name": "Corynebacterium ulcerans 809", "rank": "Strain"}, "1150869": {"name": "Escherichia phage P13374", "rank": "Species"}, "1169237": {"name": "Brucella suis F5/03-2", "rank": "Strain"}, "1169236": {"name": "Brucella suis F5/05-10", "rank": "Strain"}, "1169231": {"name": "Brucella ovis 80/125", "rank": "Strain"}, "1169230": {"name": "Brucella ovis 63/96", "rank": "Strain"}, "1169233": {"name": "Brucella sp. F5/06", "rank": "Species"}, "1169232": {"name": "Brucella ovis 81/8", "rank": "Strain"}, "1007096": {"name": "Oscillibacter ruminantium GH1", "rank": "Strain"}, "1150862": {"name": "Pseudomonas fuscovaginae UPB0736", "rank": "Strain"}, "682522": {"name": "Ilumatobacter", "rank": "Genus"}, "1169239": {"name": "Brucella suis F7/06-1", "rank": "Strain"}, "1169238": {"name": "Brucella suis F5/05-4", "rank": "Strain"}, "1150867": {"name": "Kingella kingae PYKK081", "rank": "Strain"}, "1310668": {"name": "Acinetobacter baumannii 754286", "rank": "Strain"}, "1310669": {"name": "Acinetobacter baumannii 6112", "rank": "Strain"}, "1310660": {"name": "Acinetobacter baumannii 983759", "rank": "Strain"}, "1310661": {"name": "Acinetobacter baumannii 855125", "rank": "Strain"}, "1310662": {"name": "Acinetobacter baumannii 50595", "rank": "Strain"}, "1310663": {"name": "Acinetobacter baumannii 1440750", "rank": "Strain"}, "1310665": {"name": "Acinetobacter baumannii 1525283", "rank": "Strain"}, "1310666": {"name": "Acinetobacter baumannii 1552818", "rank": "Strain"}, "983706": {"name": "Bifidobacterium reuteri", "rank": "Species"}, "1379858": {"name": "Mucispirillum schaedleri ASF457", "rank": "Strain"}, "662480": {"name": "Haloferax sulfurifontis ATCC BAA-897", "rank": "Strain"}, "1388012": {"name": "Staphylococcus aureus M0039", "rank": "Strain"}, "359812": {"name": "Homalodisca coagulata virus-1", "rank": "Species"}, "394096": {"name": "Hyalangium minutum", "rank": "Species"}, "69576": {"name": "Ovine enzootic nasal tumor virus", "rank": "Species"}, "69577": {"name": "Banana streak virus", "rank": "Species"}, "1532906": {"name": "Aphanizomenon flos-aquae 2012/KM/D3", "rank": "Strain"}, "69578": {"name": "Cryobacterium", "rank": "Genus"}, "92830": {"name": "Xanthomonas axonopodis pv. glycines", "rank": "Strain"}, "632772": {"name": "Rhodococcus opacus B4", "rank": "Strain"}, "263820": {"name": "Picrophilus torridus DSM 9790", "rank": "Strain"}, "1443109": {"name": "Clostridium sp. K25", "rank": "Species"}, "1443104": {"name": "Snodgrassella alvi SCGC AB-598-P14", "rank": "Strain"}, "1443105": {"name": "Pseudomonas aeruginosa SG17M", "rank": "Strain"}, "1443103": {"name": "Snodgrassella alvi SCGC AB-598-O02", "rank": "Strain"}, "630199": {"name": "Grapevine Syrah virus 1", "rank": "Species"}, "314343": {"name": "Sideroxydans", "rank": "Genus"}, "314345": {"name": "Mariprofundus ferrooxydans PV-1", "rank": "Strain"}, "314344": {"name": "Mariprofundus ferrooxydans", "rank": "Species"}, "1052684": {"name": "Paenibacillus polymyxa M1", "rank": "Strain"}, "1155954": {"name": "Paenibacillus sp. 1-49", "rank": "Species"}, "1052680": {"name": "Pseudomonas syringae pv. actinidiae str. NCPPB 3871", "rank": "Strain"}, "1438822": {"name": "Mycobacterium bovis B2 7505", "rank": "Strain"}, "1438825": {"name": "Mycobacterium tuberculosis Kc 32216", "rank": "Strain"}, "1438824": {"name": "Mycobacterium tuberculosis D 4155", "rank": "Strain"}, "335341": {"name": "Influenza A virus (A/New York/392/2004(H3N2))", "rank": "Strain"}, "47589": {"name": "Rickettsia peacockii", "rank": "Species"}, "1005408": {"name": "Escherichia coli 95.0943", "rank": "Strain"}, "1244121": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20111175", "rank": "Strain"}, "402676": {"name": "Schizosaccharomyces japonicus yFS275", "rank": "Strain"}, "1005405": {"name": "Escherichia coli 94.0618", "rank": "Strain"}, "1005404": {"name": "Escherichia coli 93.0056", "rank": "Strain"}, "1005403": {"name": "Escherichia coli 93.0055", "rank": "Strain"}, "1005402": {"name": "Escherichia coli 90.2281", "rank": "Strain"}, "1005401": {"name": "Escherichia coli 90.0039", "rank": "Strain"}, "742739": {"name": "Clostridium perfringens WAL-14572", "rank": "Strain"}, "742738": {"name": "Clostridium orbiscindens 1_3_50AFAA", "rank": "Strain"}, "742737": {"name": "Clostridium hathewayi WAL-18680", "rank": "Strain"}, "742735": {"name": "Clostridium clostridioforme 2_1_49FAA", "rank": "Strain"}, "742733": {"name": "Clostridium citroniae WAL-17108", "rank": "Strain"}, "742730": {"name": "Citrobacter freundii 4_7_47CFAA", "rank": "Strain"}, "984250": {"name": "Salmonella enterica subsp. enterica serovar Newport str. 637564_17", "rank": "Strain"}, "1049283": {"name": "Acinetobacter phage ZZ1", "rank": "Species"}, "984254": {"name": "Salmonella enterica subsp. enterica serovar Virchow str. ATCC 51955", "rank": "Strain"}, "988776": {"name": "Human gyrovirus type 1", "rank": "Species"}, "988775": {"name": "Unclassified Gyrovirus", "rank": "No rank"}, "1169189": {"name": "Salinispora pacifica CNS996", "rank": "Strain"}, "1169188": {"name": "Salinispora pacifica CNT124", "rank": "Strain"}, "1169187": {"name": "Salinispora pacifica CNR942", "rank": "Strain"}, "1439314": {"name": "Streptococcus pyogenes ABC020064181", "rank": "Strain"}, "1169185": {"name": "Salinispora arenicola CNY237", "rank": "Strain"}, "1169184": {"name": "Salinispora pacifica CNT609", "rank": "Strain"}, "1169182": {"name": "Salinispora pacifica CNS055", "rank": "Strain"}, "1169181": {"name": "Salinispora pacifica CNY331", "rank": "Strain"}, "1169180": {"name": "Salinispora pacifica CNT851", "rank": "Strain"}, "1050199": {"name": "Salinispora pacifica DSM 45547", "rank": "Strain"}, "1050198": {"name": "Salinispora pacifica DSM 45546", "rank": "Strain"}, "1260282": {"name": "Enterobacter hormaechei YT3", "rank": "Strain"}, "1151290": {"name": "Peptoclostridium difficile CD149", "rank": "Strain"}, "1439317": {"name": "Acinetobacter baumanii BIDMC 57", "rank": "Strain"}, "574930": {"name": "Parabacteroides gordonii", "rank": "Species"}, "1388014": {"name": "Staphylococcus aureus M0041", "rank": "Strain"}, "743974": {"name": "Moraxella bovoculi 237", "rank": "Strain"}, "743972": {"name": "Actinobacillus suis ATCC 33415", "rank": "Strain"}, "543540": {"name": "Staphylococcus aureus subsp. aureus CGS03", "rank": "Strain"}, "595593": {"name": "Arthrobacter sp. A3", "rank": "Species"}, "743971": {"name": "Mycoplasma flocculare ATCC 27399", "rank": "Strain"}, "189918": {"name": "Mycobacterium sp. KMS", "rank": "Species"}, "450396": {"name": "Pseudomonas viridiflava UASWS0038", "rank": "Strain"}, "671622": {"name": "Microbacterium yannicii", "rank": "Species"}, "450394": {"name": "Staphylococcus aureus subsp. aureus USA300_TCH959", "rank": "Strain"}, "1158499": {"name": "Staphylococcus aureus M1521", "rank": "Strain"}, "1158498": {"name": "Staphylococcus aureus M1520", "rank": "Strain"}, "357347": {"name": "Burkholderia pseudomallei 1106b", "rank": "Strain"}, "357348": {"name": "Burkholderia pseudomallei 1106a", "rank": "Strain"}, "1158490": {"name": "Staphylococcus aureus M1367", "rank": "Strain"}, "1158493": {"name": "Staphylococcus aureus M1450", "rank": "Strain"}, "1158492": {"name": "Staphylococcus aureus M1394", "rank": "Strain"}, "1158495": {"name": "Staphylococcus aureus M1462", "rank": "Strain"}, "1158494": {"name": "Staphylococcus aureus M1451", "rank": "Strain"}, "1158497": {"name": "Staphylococcus aureus M1481", "rank": "Strain"}, "1158496": {"name": "Staphylococcus aureus M1463", "rank": "Strain"}, "1402749": {"name": "Staphylococcus aureus M1258", "rank": "Strain"}, "1402748": {"name": "Staphylococcus aureus M1254", "rank": "Strain"}, "1402745": {"name": "Staphylococcus aureus M1250", "rank": "Strain"}, "1402744": {"name": "Staphylococcus aureus M1249", "rank": "Strain"}, "1402747": {"name": "Staphylococcus aureus M1252", "rank": "Strain"}, "1402746": {"name": "Staphylococcus aureus M1251", "rank": "Strain"}, "1402741": {"name": "Staphylococcus aureus M1245", "rank": "Strain"}, "1402740": {"name": "Staphylococcus aureus M1243", "rank": "Strain"}, "1402743": {"name": "Staphylococcus aureus M1247", "rank": "Strain"}, "1402742": {"name": "Staphylococcus aureus M1246", "rank": "Strain"}, "105751": {"name": "Aeromonas bestiarum", "rank": "Species"}, "1441460": {"name": "Pseudomonas aeruginosa C1913C", "rank": "Strain"}, "1441462": {"name": "Pseudomonas aeruginosa C2159M", "rank": "Strain"}, "330396": {"name": "Listeria phage B025", "rank": "Species"}, "330397": {"name": "Listeria phage B054", "rank": "Species"}, "330398": {"name": "Listeria phage P35", "rank": "Species"}, "330399": {"name": "Listeria phage A006", "rank": "Species"}, "1112246": {"name": "Chlamydia psittaci 08-2626_L3", "rank": "Strain"}, "689759": {"name": "Tremovirus", "rank": "Genus"}, "1441796": {"name": "Black medic leafroll alphasatellite 1", "rank": "Species"}, "1219080": {"name": "Vibrio ezurae NBRC 102218", "rank": "Strain"}, "1328420": {"name": "Klebsiella pneumoniae BIDMC 25", "rank": "Strain"}, "1328423": {"name": "Klebsiella pneumoniae BIDMC 34", "rank": "Strain"}, "1219083": {"name": "Thermotoga elfii NBRC 107921", "rank": "Strain"}, "1328425": {"name": "Klebsiella pneumoniae BIDMC 36", "rank": "Strain"}, "1328424": {"name": "Klebsiella pneumoniae BIDMC 35", "rank": "Strain"}, "1328427": {"name": "Klebsiella pneumoniae BIDMC 41", "rank": "Strain"}, "1328426": {"name": "Klebsiella pneumoniae BIDMC 40", "rank": "Strain"}, "1328429": {"name": "Klebsiella oxytoca MGH 28", "rank": "Strain"}, "1328428": {"name": "Klebsiella oxytoca MGH 27", "rank": "Strain"}, "226910": {"name": "Pseudomonas batumici", "rank": "Species"}, "418443": {"name": "Erwinia amylovora phage Era103", "rank": "Species"}, "499551": {"name": "Methanolinea", "rank": "Genus"}, "1472761": {"name": "Enorma massiliensis", "rank": "Species"}, "1472762": {"name": "Enorma", "rank": "Genus"}, "1472763": {"name": "Kallipyga", "rank": "Genus"}, "1472764": {"name": "Kallipyga massiliensis", "rank": "Species"}, "1472765": {"name": "Peptoniphilus obesi", "rank": "Species"}, "936550": {"name": "Atopobium sp. BS2", "rank": "Species"}, "862971": {"name": "Streptococcus anginosus C238", "rank": "Strain"}, "936556": {"name": "Peptostreptococcaceae bacterium AS15", "rank": "Species"}, "936554": {"name": "Campylobacter sp. FOBRC14", "rank": "Species"}, "1176147": {"name": "Sigmapapillomavirus 1", "rank": "Species"}, "1176146": {"name": "Rhopapillomavirus 1", "rank": "Species"}, "1176145": {"name": "Pipapillomavirus 2", "rank": "Species"}, "926447": {"name": "Flavobacterium sp. MS220-5C", "rank": "Species"}, "1176149": {"name": "Upsilonpapillomavirus 2", "rank": "Species"}, "1176148": {"name": "Taupapillomavirus 1", "rank": "Species"}, "634994": {"name": "Leptotrichia hofstadii F0254", "rank": "Strain"}, "634997": {"name": "Mycoplasma hyorhinis DBS 1050", "rank": "Strain"}, "634996": {"name": "Mycoplasma hyorhinis ATCC 17981", "rank": "Strain"}, "1145142": {"name": "Neisseria meningitidis NM604", "rank": "Strain"}, "573615": {"name": "Lupine mosaic virus", "rank": "Species"}, "299261": {"name": "Tateyamaria", "rank": "Genus"}, "930781": {"name": "Listeria monocytogenes J1816", "rank": "Strain"}, "930780": {"name": "Cronobacter sakazakii E899", "rank": "Strain"}, "1434269": {"name": "Saccharomyces cerevisiae UFMG A-905", "rank": "Strain"}, "930782": {"name": "Listeria monocytogenes J1-220", "rank": "Strain"}, "1434267": {"name": "Pseudomonas aeruginosa VRFPA08", "rank": "Strain"}, "47251": {"name": "Leptolyngbya", "rank": "Genus"}, "40443": {"name": "Gloeophyllum", "rank": "Genus"}, "1422498": {"name": "Staphylococcus aureus VET0198R", "rank": "Strain"}, "1422493": {"name": "Staphylococcus aureus VET0193R", "rank": "Strain"}, "1540257": {"name": "Clostridium sp. KNHs214", "rank": "Species"}, "1422491": {"name": "Staphylococcus aureus VET0191R", "rank": "Strain"}, "1422490": {"name": "Staphylococcus aureus VET0190R", "rank": "Strain"}, "1422497": {"name": "Staphylococcus aureus VET0197R", "rank": "Strain"}, "1422495": {"name": "Staphylococcus aureus VET0195R", "rank": "Strain"}, "1422494": {"name": "Staphylococcus aureus VET0194R", "rank": "Strain"}, "1218357": {"name": "Chlamydia psittaci M56", "rank": "Strain"}, "1218356": {"name": "Chlamydia psittaci WS/RT/E30", "rank": "Strain"}, "1218355": {"name": "Chlamydia psittaci VS225", "rank": "Strain"}, "1218354": {"name": "Chlamydia psittaci MN", "rank": "Strain"}, "1218353": {"name": "Chlamydia psittaci GR9", "rank": "Strain"}, "1218352": {"name": "Pseudomonas stutzeri KOS6", "rank": "Strain"}, "1218358": {"name": "Chlamydia psittaci WC", "rank": "Strain"}, "1427241": {"name": "Mycobacterium tuberculosis XTB13-155", "rank": "Strain"}, "574557": {"name": "Melitea", "rank": "Genus"}, "1531429": {"name": "Coriobacteriaceae bacterium 68-1-3", "rank": "Species"}, "863767": {"name": "Listeria monocytogenes serotype 7 str. SLCC2482", "rank": "Strain"}, "1427240": {"name": "Mycobacterium tuberculosis XTB13-154", "rank": "Strain"}, "208084": {"name": "Grapevine Algerian latent virus", "rank": "Species"}, "1275969": {"name": "Haemophilus parasuis 84-15995", "rank": "Strain"}, "272134": {"name": "Leptolyngbya boryana PCC 6306", "rank": "Strain"}, "1121934": {"name": "Gulosibacter molinativorax DSM 13485", "rank": "Strain"}, "1121935": {"name": "Hahella ganghwensis DSM 17046", "rank": "Strain"}, "279303": {"name": "Actinoplanes phage phiAsp2", "rank": "Species"}, "1121933": {"name": "Granulicoccus phenolivorans DSM 17626", "rank": "Strain"}, "1121930": {"name": "Gracilimonas tropica DSM 19535", "rank": "Strain"}, "1121931": {"name": "Gramella echinicola DSM 19838", "rank": "Strain"}, "1275967": {"name": "Haemophilus parasuis MN-H", "rank": "Strain"}, "1275966": {"name": "Haemophilus parasuis SW114", "rank": "Strain"}, "1408478": {"name": "Vibrio cholerae ATCC 14035", "rank": "Strain"}, "1408471": {"name": "Mycoplasma testudinis ATCC 43263", "rank": "Strain"}, "1408470": {"name": "Mycoplasma spumans ATCC 19526", "rank": "Strain"}, "1408473": {"name": "Prolixibacter bellariivorans ATCC BAA-1284", "rank": "Strain"}, "1408472": {"name": "Prevotella brevis ATCC 19188", "rank": "Strain"}, "1408475": {"name": "Taylorella asinigenitalis ATCC 700933", "rank": "Strain"}, "1408477": {"name": "Vibrio albensis ATCC 14547", "rank": "Strain"}, "1408476": {"name": "Ureaplasma canigenitalium ATCC 51252", "rank": "Strain"}, "619599": {"name": "Okra mottle virus", "rank": "Species"}, "95658": {"name": "Ureaplasma urealyticum serovar 4", "rank": "Strain"}, "28088": {"name": "Legionella wadsworthii", "rank": "Species"}, "619591": {"name": "Monkeypox virus Zaire-96-I-16", "rank": "Strain"}, "95656": {"name": "Ureaplasma parvum serovar 1", "rank": "Strain"}, "95657": {"name": "Ureaplasma urealyticum serovar 2", "rank": "Strain"}, "28080": {"name": "Campylobacter upsaliensis", "rank": "Species"}, "28082": {"name": "Legionella anisa", "rank": "Species"}, "220638": {"name": "Blattella germanica densovirus 1", "rank": "Strain"}, "193568": {"name": "Nanoarchaeum", "rank": "Genus"}, "211759": {"name": "Serratia marcescens subsp. marcescens", "rank": "Subspecies"}, "193567": {"name": "Streptococcus pyogenes SSI-1", "rank": "Strain"}, "794851": {"name": "Helicobacter pylori Sat464", "rank": "Strain"}, "483514": {"name": "Schizosaccharomyces octosporus yFS286", "rank": "Strain"}, "1413405": {"name": "Staphylococcus aureus 18439-62", "rank": "Strain"}, "1413406": {"name": "Staphylococcus aureus 27999-3", "rank": "Strain"}, "1413407": {"name": "Staphylococcus aureus 56824-2", "rank": "Strain"}, "2419": {"name": "Thermotogales", "rank": "Order"}, "1413401": {"name": "Staphylococcus aureus 150211/pool 1", "rank": "Strain"}, "1413402": {"name": "Staphylococcus aureus 18439-17", "rank": "Strain"}, "1413408": {"name": "Staphylococcus aureus 56824-5", "rank": "Strain"}, "1413409": {"name": "Staphylococcus aureus 56824-7", "rank": "Strain"}, "1409432": {"name": "Staphylococcus aureus LPIH6021", "rank": "Strain"}, "1409433": {"name": "Staphylococcus aureus OCMM6045", "rank": "Strain"}, "1409430": {"name": "Staphylococcus aureus SJOS6100", "rank": "Strain"}, "1409431": {"name": "Staphylococcus aureus WMCS6038", "rank": "Strain"}, "1281210": {"name": "Escherichia coli UMEA 3190-1", "rank": "Strain"}, "1409437": {"name": "Staphylococcus aureus OCMM6049", "rank": "Strain"}, "1409434": {"name": "Staphylococcus aureus OCMM6046", "rank": "Strain"}, "1409435": {"name": "Staphylococcus aureus OCMM6047", "rank": "Strain"}, "1409438": {"name": "Staphylococcus aureus AMMC6070", "rank": "Strain"}, "1409439": {"name": "Staphylococcus aureus AMMC6071", "rank": "Strain"}, "1281218": {"name": "Escherichia coli UMEA 3212-1", "rank": "Strain"}, "1281219": {"name": "Escherichia coli UMEA 3215-1", "rank": "Strain"}, "1205751": {"name": "Pseudomonas syringae BRIP34881", "rank": "Strain"}, "1205750": {"name": "Pseudomonas fluorescens BRIP34879", "rank": "Strain"}, "1205753": {"name": "Xanthomonas translucens DAR61454", "rank": "Strain"}, "1205752": {"name": "Pseudomonas syringae BRIP39023", "rank": "Strain"}, "1422769": {"name": "Staphylococcus aureus VET1024S", "rank": "Strain"}, "1422768": {"name": "Staphylococcus aureus VET1020S", "rank": "Strain"}, "1422765": {"name": "Staphylococcus aureus VET0889S", "rank": "Strain"}, "1422764": {"name": "Staphylococcus aureus VET0810S", "rank": "Strain"}, "1422767": {"name": "Staphylococcus aureus VET0920S", "rank": "Strain"}, "1422766": {"name": "Staphylococcus aureus VET0919S", "rank": "Strain"}, "1422761": {"name": "Staphylococcus aureus VET0787S", "rank": "Strain"}, "1422760": {"name": "Staphylococcus aureus VET0779S", "rank": "Strain"}, "1422763": {"name": "Staphylococcus aureus VET0809S", "rank": "Strain"}, "1422762": {"name": "Staphylococcus aureus VET0798S", "rank": "Strain"}, "754079": {"name": "Escherichia coli 2534-86", "rank": "Strain"}, "1154806": {"name": "Streptococcus agalactiae FSL S3-003", "rank": "Strain"}, "1154807": {"name": "Streptococcus agalactiae CCUG 19094", "rank": "Strain"}, "1154804": {"name": "Streptococcus agalactiae FSL S3-005", "rank": "Strain"}, "1246461": {"name": "Nocardiopsis alkaliphila YIM 80379", "rank": "Strain"}, "1154802": {"name": "Streptococcus agalactiae FSL S3-268", "rank": "Strain"}, "1154803": {"name": "Streptococcus agalactiae FSL F2-338", "rank": "Strain"}, "1154800": {"name": "Streptococcus agalactiae FSL F2-343", "rank": "Strain"}, "1154801": {"name": "Streptococcus agalactiae FSL S3-137", "rank": "Strain"}, "1400929": {"name": "Mycobacterium tuberculosis KT-0092", "rank": "Strain"}, "1154808": {"name": "Streptococcus agalactiae CCUG 24810", "rank": "Strain"}, "1154809": {"name": "Streptococcus agalactiae CCUG 25532", "rank": "Strain"}, "91352": {"name": "Campylobacter hyointestinalis subsp. hyointestinalis", "rank": "Subspecies"}, "1400928": {"name": "Mycobacterium tuberculosis KT-0091", "rank": "Strain"}, "747": {"name": "Pasteurella multocida", "rank": "Species"}, "1158138": {"name": "Thermomyces lanuginosus SSBP", "rank": "Strain"}, "745": {"name": "Pasteurella", "rank": "Genus"}, "66834": {"name": "Rhopalosiphum padi virus", "rank": "Species"}, "66831": {"name": "Facklamia", "rank": "Genus"}, "453459": {"name": "Cryptococcus pinus", "rank": "Species"}, "85022": {"name": "Jonesiaceae", "rank": "Family"}, "711393": {"name": "Streptomyces sp. GXT6", "rank": "Species"}, "1400922": {"name": "Mycobacterium tuberculosis KT-0079", "rank": "Strain"}, "85020": {"name": "Dermabacteraceae", "rank": "Family"}, "1412759": {"name": "Staphylococcus aureus M16552", "rank": "Strain"}, "1400920": {"name": "Mycobacterium tuberculosis KT-0077", "rank": "Strain"}, "1412753": {"name": "Staphylococcus aureus H87628", "rank": "Strain"}, "1412752": {"name": "Staphylococcus aureus H85008", "rank": "Strain"}, "1412751": {"name": "Staphylococcus aureus H85003", "rank": "Strain"}, "1412750": {"name": "Staphylococcus aureus H84980", "rank": "Strain"}, "1412757": {"name": "Staphylococcus aureus M13060", "rank": "Strain"}, "1412756": {"name": "Staphylococcus aureus M13048", "rank": "Strain"}, "1412755": {"name": "Staphylococcus aureus H91384", "rank": "Strain"}, "469660": {"name": "Thalassomonas phage BA3", "rank": "Species"}, "85025": {"name": "Nocardiaceae", "rank": "Family"}, "1331218": {"name": "Bordetella bronchiseptica M85/00/2", "rank": "Strain"}, "1331219": {"name": "Bordetella bronchiseptica MBORD591", "rank": "Strain"}, "1331210": {"name": "Bordetella holmesii CDC-H719-BH", "rank": "Strain"}, "1331211": {"name": "Bordetella holmesii CDC-H785-BH", "rank": "Strain"}, "1331212": {"name": "Bordetella holmesii CDC-H809-BH", "rank": "Strain"}, "1331213": {"name": "Bordetella bronchiseptica F2", "rank": "Strain"}, "1331214": {"name": "Bordetella bronchiseptica F4563", "rank": "Strain"}, "1331215": {"name": "Bordetella bronchiseptica GA96-01", "rank": "Strain"}, "1331216": {"name": "Bordetella bronchiseptica CA90 BB02", "rank": "Strain"}, "1182190": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN000960", "rank": "Strain"}, "634177": {"name": "Komagataeibacter medellinensis NBRC 3288", "rank": "Strain"}, "634176": {"name": "Aggregatibacter aphrophilus NJ8700", "rank": "Strain"}, "1076588": {"name": "Thiolapillus brandeum", "rank": "Species"}, "1247731": {"name": "Campylobacter coli BIGS0006", "rank": "Strain"}, "1247730": {"name": "Campylobacter coli BIGS0005", "rank": "Strain"}, "1247733": {"name": "Campylobacter coli BIGS0008", "rank": "Strain"}, "1247732": {"name": "Campylobacter coli BIGS0007", "rank": "Strain"}, "1247735": {"name": "Campylobacter coli BIGS0010", "rank": "Strain"}, "1247734": {"name": "Campylobacter coli BIGS0009", "rank": "Strain"}, "1247737": {"name": "Campylobacter coli BIGS0012", "rank": "Strain"}, "1247736": {"name": "Campylobacter coli BIGS0011", "rank": "Strain"}, "1247738": {"name": "Campylobacter coli BIGS0015", "rank": "Strain"}, "228400": {"name": "Haemophilus somnus 2336", "rank": "Strain"}, "393034": {"name": "Siegesbeckia yellow vein virus-associated DNA beta", "rank": "Species"}, "228405": {"name": "Hyphomonas neptunium ATCC 15444", "rank": "Strain"}, "1365653": {"name": "Campylobacter jejuni 10186", "rank": "Strain"}, "1263410": {"name": "Salmonella enterica subsp. enterica serovar Agona str. SH11G1113", "rank": "Strain"}, "1365655": {"name": "Campylobacter jejuni 30286", "rank": "Strain"}, "1365654": {"name": "Campylobacter jejuni 20176", "rank": "Strain"}, "1365657": {"name": "Campylobacter jejuni Cj1", "rank": "Strain"}, "328429": {"name": "Unclassified Polerovirus", "rank": "No rank"}, "1365656": {"name": "Campylobacter jejuni 30318", "rank": "Strain"}, "989499": {"name": "Vibrio anguillarum RV22", "rank": "Strain"}, "1128180": {"name": "Bradyrhizobium sp. CCBAU 15635", "rank": "Species"}, "562729": {"name": "Rheinheimera nanhaiensis E407-8", "rank": "Strain"}, "1494960": {"name": "Listeria aquatica", "rank": "Species"}, "1577900": {"name": "Leisingera sp. ANG-M6", "rank": "Species"}, "1577901": {"name": "Leisingera sp. ANG-S5", "rank": "Species"}, "1577902": {"name": "Leisingera sp. ANG-M7", "rank": "Species"}, "1302615": {"name": "Salmonella enterica subsp. enterica serovar Aqua", "rank": "Strain"}, "1577904": {"name": "Ruegeria sp. ANG-S4", "rank": "Species"}, "1577905": {"name": "Tateyamaria sp. ANG-S1", "rank": "Species"}, "43763": {"name": "Redspotted grouper nervous necrosis virus", "rank": "Species"}, "1068618": {"name": "Escherichia coli O104:H4 str. 11-4632 C2", "rank": "Strain"}, "656408": {"name": "Escherichia coli H591", "rank": "Strain"}, "43767": {"name": "Rhodococcus equi", "rank": "Species"}, "43765": {"name": "Corynebacterium amycolatum", "rank": "Species"}, "43764": {"name": "Tiger puffer nervous necrosis virus", "rank": "Species"}, "43769": {"name": "Corynebacterium propinquum", "rank": "Species"}, "43768": {"name": "Corynebacterium matruchotii", "rank": "Species"}, "1464048": {"name": "Micromonospora parva", "rank": "Species"}, "656404": {"name": "Escherichia coli H489", "rank": "Strain"}, "435842": {"name": "Streptococcus sp. C150", "rank": "Species"}, "190729": {"name": "Betasatellites", "rank": "No rank"}, "1357687": {"name": "Umbelopsis isabellina B7317", "rank": "Strain"}, "423476": {"name": "Streptococcus phage phi3396", "rank": "Species"}, "1035839": {"name": "Haemophilus sputorum CCUG 13788", "rank": "Strain"}, "247490": {"name": "Planctomycete KSU-1", "rank": "Species"}, "1265816": {"name": "Listeria riparia FSL S10-1204", "rank": "Strain"}, "1265817": {"name": "Listeria floridensis FSL S10-1187", "rank": "Strain"}, "1265818": {"name": "Listeria aquatica FSL S10-1188", "rank": "Strain"}, "1265819": {"name": "Listeria grandensis FSL F6-971", "rank": "Strain"}, "1421922": {"name": "Mycobacterium tuberculosis TB_RSA06", "rank": "Strain"}, "1421923": {"name": "Mycobacterium tuberculosis TB_RSA07", "rank": "Strain"}, "1421920": {"name": "Mycobacterium tuberculosis TB_RSA04", "rank": "Strain"}, "108015": {"name": "Bradyrhizobium yuanmingense", "rank": "Species"}, "1421926": {"name": "Mycobacterium tuberculosis TB_RSA10", "rank": "Strain"}, "1421927": {"name": "Mycobacterium tuberculosis TB_RSA11", "rank": "Strain"}, "1421924": {"name": "Mycobacterium tuberculosis TB_RSA08", "rank": "Strain"}, "1421925": {"name": "Mycobacterium tuberculosis TB_RSA09", "rank": "Strain"}, "1421928": {"name": "Mycobacterium tuberculosis TB_RSA12", "rank": "Strain"}, "1421929": {"name": "Mycobacterium tuberculosis TB_RSA13", "rank": "Strain"}, "292713": {"name": "Silanimonas", "rank": "Genus"}, "191394": {"name": "Deferribacteraceae", "rank": "Family"}, "891413": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. 607307-6", "rank": "Strain"}, "1354138": {"name": "Mycobacterium tuberculosis MAL020120", "rank": "Strain"}, "1354139": {"name": "Mycobacterium tuberculosis MAL020131", "rank": "Strain"}, "1354134": {"name": "Mycobacterium tuberculosis MAL020162", "rank": "Strain"}, "1354135": {"name": "Mycobacterium tuberculosis MAL020167", "rank": "Strain"}, "1354136": {"name": "Mycobacterium tuberculosis MAL020172", "rank": "Strain"}, "1354137": {"name": "Mycobacterium tuberculosis MAL020110", "rank": "Strain"}, "339670": {"name": "Burkholderia ambifaria AMMD", "rank": "Strain"}, "754520": {"name": "Rhizobium leguminosarum bv. trifolii CC283b", "rank": "Strain"}, "754523": {"name": "Rhizobium leguminosarum bv. trifolii WSM1689", "rank": "Strain"}, "754522": {"name": "Rhizobium leguminosarum bv. trifolii WSM2012", "rank": "Strain"}, "359387": {"name": "Xanthomonas alfalfae subsp. alfalfae", "rank": "Subspecies"}, "359385": {"name": "Xanthomonas campestris pv. raphani", "rank": "Strain"}, "1427298": {"name": "Mycobacterium tuberculosis XTB13-227", "rank": "Strain"}, "1427299": {"name": "Mycobacterium tuberculosis XTB13-228", "rank": "Strain"}, "1427296": {"name": "Mycobacterium avium XTB13-223", "rank": "Strain"}, "1427297": {"name": "Mycobacterium tuberculosis XTB13-225", "rank": "Strain"}, "1427294": {"name": "Mycobacterium tuberculosis XTB13-218", "rank": "Strain"}, "1427295": {"name": "Mycobacterium tuberculosis XTB13-219", "rank": "Strain"}, "1427292": {"name": "Mycobacterium tuberculosis XTB13-216", "rank": "Strain"}, "1427293": {"name": "Mycobacterium tuberculosis XTB13-217", "rank": "Strain"}, "1036735": {"name": "Bifidobacterium breve CECT 7263", "rank": "Strain"}, "1427291": {"name": "Mycobacterium tuberculosis XTB13-214", "rank": "Strain"}, "1295772": {"name": "Mycobacterium tuberculosis TKK_02_0056", "rank": "Strain"}, "1002339": {"name": "Psychrobacter sp. 1501(2011)", "rank": "Species"}, "1295771": {"name": "Mycobacterium tuberculosis TKK_02_0055", "rank": "Strain"}, "1295776": {"name": "Mycobacterium tuberculosis TKK_02_0060", "rank": "Strain"}, "1295774": {"name": "Mycobacterium tuberculosis TKK_02_0058", "rank": "Strain"}, "1295775": {"name": "Mycobacterium tuberculosis TKK_02_0059", "rank": "Strain"}, "204873": {"name": "Xenopus laevis endogenous retrovirus Xen1", "rank": "Species"}, "111418": {"name": "Zucchini green mottle mosaic virus", "rank": "Species"}, "411235": {"name": "Streptacidiphilus melanogenes", "rank": "Species"}, "945550": {"name": "Vibrio sinaloensis DSM 21326", "rank": "Strain"}, "717646": {"name": "Baudoinia compniacensis UAMH 10762", "rank": "Strain"}, "1407463": {"name": "Helicobacter pylori BM012S", "rank": "Strain"}, "945555": {"name": "Acinetobacter baumannii WM99c", "rank": "Strain"}, "945556": {"name": "Acinetobacter baumannii D1279779", "rank": "Strain"}, "1354791": {"name": "Halorhodospira halochloris str. A", "rank": "Strain"}, "1511749": {"name": "Geobacillus thermodenitrificans subsp. thermodenitrificans", "rank": "Subspecies"}, "1511746": {"name": "Thermoanaerobacter sp. YS13", "rank": "Species"}, "1395101": {"name": "Thaumarchaeota archaeon JGI OTU-2", "rank": "Species"}, "120576": {"name": "Brucella pinnipedialis", "rank": "Species"}, "196180": {"name": "Anoxybacillus kamchatkensis", "rank": "Species"}, "65467": {"name": "Cherry green ring mottle virus", "rank": "Species"}, "1279": {"name": "Staphylococcus", "rank": "Genus"}, "1274": {"name": "Dermacoccus nishinomiyaensis", "rank": "Species"}, "104174": {"name": "Oscillochloridaceae", "rank": "Family"}, "1276": {"name": "Kytococcus sedentarius", "rank": "Species"}, "104176": {"name": "Oscillochloris trichoides", "rank": "Species"}, "1270": {"name": "Micrococcus luteus", "rank": "Species"}, "1415657": {"name": "Endosymbiont of Llaveia axin axin", "rank": "Species"}, "659243": {"name": "Bacillus siamensis", "rank": "Species"}, "318829": {"name": "Magnaporthe oryzae", "rank": "Species"}, "1281193": {"name": "Escherichia coli UMEA 3150-1", "rank": "Strain"}, "1859": {"name": "Frankia alni", "rank": "Species"}, "1850": {"name": "Actinopolyspora halophila", "rank": "Species"}, "1851": {"name": "Saccharomonospora", "rank": "Genus"}, "1852": {"name": "Saccharomonospora viridis", "rank": "Species"}, "1112270": {"name": "Chlamydia psittaci 09DC79", "rank": "Strain"}, "1854": {"name": "Frankia", "rank": "Genus"}, "1112274": {"name": "Methylophilus sp. 5", "rank": "Species"}, "1027248": {"name": "Bovine astrovirus B76/HK", "rank": "Species"}, "47416": {"name": "Satsuma dwarf virus", "rank": "Species"}, "1027245": {"name": "Bovine astrovirus B18/HK", "rank": "Species"}, "1027244": {"name": "Bovine astrovirus B170/HK", "rank": "Species"}, "1027247": {"name": "Bovine astrovirus B76-2/HK", "rank": "Species"}, "345201": {"name": "Invertebrate iridescent virus 3", "rank": "Species"}, "314724": {"name": "Borrelia turicatae 91E135", "rank": "Strain"}, "1438796": {"name": "Klebsiella pneumoniae MGH 73", "rank": "Strain"}, "1415608": {"name": "Cardamom bushy dwarf virus satellite", "rank": "Species"}, "1439091": {"name": "Streptococcus pyogenes ABC020035446", "rank": "Strain"}, "1439090": {"name": "Streptococcus pyogenes ABC020035427", "rank": "Strain"}, "1388726": {"name": "Staphylococcus aureus M0966", "rank": "Strain"}, "1439095": {"name": "Streptococcus pyogenes ABC020037542", "rank": "Strain"}, "314722": {"name": "Pseudoxanthomonas suwonensis", "rank": "Species"}, "1438794": {"name": "Klebsiella pneumoniae MGH 71", "rank": "Strain"}, "1122971": {"name": "Porphyromonas bennonis DSM 23058 = JCM 16335", "rank": "Strain"}, "1388720": {"name": "Staphylococcus aureus M0959", "rank": "Strain"}, "222464": {"name": "Cotton leaf curl Kokhran virus", "rank": "Species"}, "4911": {"name": "Kluyveromyces marxianus", "rank": "Species"}, "1388721": {"name": "Staphylococcus aureus M0960", "rank": "Strain"}, "997892": {"name": "Bacteroides xylanisolvens CL03T12C04", "rank": "Strain"}, "142554": {"name": "Prochlorococcus marinus subsp. marinus", "rank": "Subspecies"}, "997890": {"name": "Bacteroides uniformis CL03T12C37", "rank": "Strain"}, "997891": {"name": "Bacteroides vulgatus CL09T03C04", "rank": "Strain"}, "997896": {"name": "Clostridium bolteae 90B7", "rank": "Strain"}, "997897": {"name": "Clostridium bolteae 90B8", "rank": "Strain"}, "997894": {"name": "Clostridium bolteae 90A9", "rank": "Strain"}, "997895": {"name": "Clostridium bolteae 90B3", "rank": "Strain"}, "146073": {"name": "Walrus calicivirus", "rank": "Species"}, "997898": {"name": "Clostridium butyricum 60E.3", "rank": "Strain"}, "1438790": {"name": "Klebsiella pneumoniae MGH 67", "rank": "Strain"}, "1239783": {"name": "Bacillus atrophaeus UCMB-5137", "rank": "Strain"}, "685040": {"name": "Salmonella enterica subsp. enterica serovar Gallinarum str. 9184", "rank": "Strain"}, "255204": {"name": "Pseudoclavibacter", "rank": "Genus"}, "1437599": {"name": "Bifidobacterium coryneforme DSM 20216", "rank": "Strain"}, "1037523": {"name": "Tuber aestivum mitovirus", "rank": "Species"}, "1224924": {"name": "Staphylococcus aureus M0270", "rank": "Strain"}, "446681": {"name": "Eudoraea adriatica", "rank": "Species"}, "511678": {"name": "Aliivibrio", "rank": "Genus"}, "219182": {"name": "Ottowia thiooxydans", "rank": "Species"}, "675389": {"name": "Avian bornavirus", "rank": "Species"}, "1348912": {"name": "Pseudomonas phage PAK_P2", "rank": "Species"}, "1348911": {"name": "Coprobacter", "rank": "Genus"}, "59816": {"name": "Yellowtail ascites virus", "rank": "Species"}, "59817": {"name": "Faba bean necrotic yellows virus", "rank": "Species"}, "59814": {"name": "Pantoea dispersa", "rank": "Species"}, "82203": {"name": "Centipeda periodontii", "rank": "Species"}, "82202": {"name": "Centipeda", "rank": "Genus"}, "1287270": {"name": "Mesorhizobium sp. LNJC386A00", "rank": "Species"}, "1294121": {"name": "Unclassified Nanoarchaeota", "rank": "No rank"}, "1482738": {"name": "Geobacillus sp. CAMR12739", "rank": "Species"}, "1482739": {"name": "Geobacillus sp. CAMR5420", "rank": "Species"}, "1294122": {"name": "Nanoarchaeote Nst1", "rank": "Species"}, "1191100": {"name": "Equine polyomavirus", "rank": "Species"}, "1294123": {"name": "Sulfolobales archaeon Acd1", "rank": "Species"}, "51676": {"name": "Macroptilium golden mosaic virus", "rank": "Species"}, "1221449": {"name": "Soybean Putnam virus", "rank": "Species"}, "434270": {"name": "Actinobacillus pleuropneumoniae serovar 3", "rank": "Strain"}, "434271": {"name": "Actinobacillus pleuropneumoniae serovar 3 str. JL03", "rank": "Strain"}, "1439369": {"name": "Carp picornavirus 1", "rank": "Species"}, "293071": {"name": "Leptospira santarosai serovar Shermani", "rank": "Strain"}, "293070": {"name": "Leptospira yanagawae serovar Saopaulo", "rank": "Strain"}, "293073": {"name": "Leptospira noguchii serovar Panama", "rank": "Strain"}, "293072": {"name": "Leptospira fainei serovar Hurstbridge", "rank": "Strain"}, "293075": {"name": "Leptospira terpstrae", "rank": "Species"}, "293077": {"name": "Leptospira meyeri serovar Hardjo", "rank": "Strain"}, "293076": {"name": "Leptospira terpstrae serovar Hualin", "rank": "Strain"}, "90627": {"name": "Gallionellaceae", "rank": "Family"}, "487975": {"name": "Streptococcus pyogenes serotype M53", "rank": "Strain"}, "45103": {"name": "Oat golden stripe virus", "rank": "Species"}, "884107": {"name": "Schleiferia thermophila", "rank": "Species"}, "102106": {"name": "Collinsella", "rank": "Genus"}, "1163751": {"name": "Candidatus Hamiltonella defensa MED (Bemisia tabaci)", "rank": "Strain"}, "102109": {"name": "Desulfovibrio inopinatus", "rank": "Species"}, "754048": {"name": "Psychrobacter phage pOW20-A", "rank": "Species"}, "754049": {"name": "Vibrio phage pYD21-A", "rank": "Species"}, "754042": {"name": "Synechococcus phage S-SKS1", "rank": "Species"}, "754043": {"name": "Sulfitobacter phage pCB2047-C", "rank": "Species"}, "1288358": {"name": "Tench rhabdovirus S64", "rank": "Species"}, "754041": {"name": "Synechococcus phage S-RIP1", "rank": "Species"}, "754046": {"name": "Sulfitobacter phage phiCB2047-B", "rank": "Species"}, "754044": {"name": "Loktanella phage pCB2051-A", "rank": "Species"}, "754045": {"name": "Sulfitobacter phage pCB2047-A", "rank": "Species"}, "1400938": {"name": "Mycobacterium tuberculosis KT-0107", "rank": "Strain"}, "1400939": {"name": "Mycobacterium tuberculosis KT-0108", "rank": "Strain"}, "1104584": {"name": "Candidatus Altimarinus pacificus JGI 0000068-E11", "rank": "Strain"}, "1104582": {"name": "Parcubacteria bacterium SCGC AB-164-E21", "rank": "Species"}, "1315139": {"name": "Acinetobacter baumannii TG15234", "rank": "Strain"}, "1315138": {"name": "Acinetobacter baumannii TG15233", "rank": "Strain"}, "1315137": {"name": "Acinetobacter baumannii TG07725", "rank": "Strain"}, "1315136": {"name": "Acinetobacter baumannii TG02017", "rank": "Strain"}, "1400932": {"name": "Mycobacterium tuberculosis KT-0098", "rank": "Strain"}, "1315134": {"name": "Acinetobacter baumannii TG00314", "rank": "Strain"}, "1400934": {"name": "Mycobacterium tuberculosis KT-0100", "rank": "Strain"}, "1400935": {"name": "Mycobacterium tuberculosis KT-0102", "rank": "Strain"}, "1400936": {"name": "Mycobacterium tuberculosis KT-0104", "rank": "Strain"}, "1400937": {"name": "Mycobacterium tuberculosis KT-0106", "rank": "Strain"}, "1463854": {"name": "Streptomyces sp. NRRL F-5053", "rank": "Species"}, "84980": {"name": "Desulfotalea psychrophila", "rank": "Species"}, "1050407": {"name": "Grapevine vein-clearing virus", "rank": "Species"}, "1091232": {"name": "Meyerozyma caribbica MG20W", "rank": "Strain"}, "1437002": {"name": "Burkholderia pseudomallei MSHR3335", "rank": "Strain"}, "1437003": {"name": "Burkholderia pseudomallei MSHR3458", "rank": "Strain"}, "1437000": {"name": "Burkholderia pseudomallei MSHR1153", "rank": "Strain"}, "1437001": {"name": "Burkholderia pseudomallei MSHR1000", "rank": "Strain"}, "1437006": {"name": "Bacillus subtilis QH-1", "rank": "Strain"}, "1437007": {"name": "Streptococcus pyogenes STAB902", "rank": "Strain"}, "1437004": {"name": "Burkholderia pseudomallei MSHR3709", "rank": "Strain"}, "1437005": {"name": "Burkholderia pseudomallei MSHR640", "rank": "Strain"}, "1437008": {"name": "Streptococcus pyogenes STAB1102", "rank": "Strain"}, "432331": {"name": "Sulfurihydrogenibium yellowstonense SS-5", "rank": "Strain"}, "432330": {"name": "Tumebacillus", "rank": "Genus"}, "1463855": {"name": "Streptomyces sp. NRRL F-5065", "rank": "Species"}, "1151342": {"name": "Peptoclostridium difficile DA00196", "rank": "Strain"}, "1151343": {"name": "Peptoclostridium difficile DA00197", "rank": "Strain"}, "1151340": {"name": "Peptoclostridium difficile DA00193", "rank": "Strain"}, "1151341": {"name": "Peptoclostridium difficile DA00195", "rank": "Strain"}, "1151346": {"name": "Peptoclostridium difficile DA00211", "rank": "Strain"}, "1151347": {"name": "Peptoclostridium difficile DA00212", "rank": "Strain"}, "1151344": {"name": "Peptoclostridium difficile DA00203", "rank": "Strain"}, "1151345": {"name": "Peptoclostridium difficile DA00210", "rank": "Strain"}, "1151348": {"name": "Peptoclostridium difficile DA00215", "rank": "Strain"}, "1151349": {"name": "Peptoclostridium difficile DA00216", "rank": "Strain"}, "1154925": {"name": "Streptococcus agalactiae GB00640", "rank": "Strain"}, "486621": {"name": "Bacillus anthracis str. A0442", "rank": "Strain"}, "1154927": {"name": "Streptococcus agalactiae GB00653", "rank": "Strain"}, "486623": {"name": "Bacillus anthracis str. A0389", "rank": "Strain"}, "486624": {"name": "Bacillus anthracis str. A0488", "rank": "Strain"}, "1154920": {"name": "Streptococcus agalactiae GB00557", "rank": "Strain"}, "1154923": {"name": "Streptococcus agalactiae GB00601", "rank": "Strain"}, "1154922": {"name": "Streptococcus agalactiae GB00588", "rank": "Strain"}, "1398149": {"name": "Eel picornavirus 1", "rank": "Species"}, "1154929": {"name": "Streptococcus agalactiae GB00663", "rank": "Strain"}, "1463856": {"name": "Streptomyces sp. NRRL F-5123", "rank": "Species"}, "546340": {"name": "Enterococcus faecium E1679", "rank": "Strain"}, "1450439": {"name": "Bacteroides sp. UW", "rank": "Species"}, "546342": {"name": "Staphylococcus aureus subsp. aureus str. JKD6008", "rank": "Strain"}, "546343": {"name": "Staphylococcus aureus subsp. aureus str. JKD6009", "rank": "Strain"}, "1327987": {"name": "Cellulophaga phage phi12a:1", "rank": "Species"}, "1327986": {"name": "Campylobacter jejuni 10227", "rank": "Strain"}, "1327985": {"name": "Cellulophaga phage phi46:3", "rank": "Species"}, "1327983": {"name": "Cellulophaga phage phi18:3", "rank": "Species"}, "1327982": {"name": "Cellulophaga phage phi18:1", "rank": "Species"}, "1327981": {"name": "Cellulophaga phage phi10:1", "rank": "Species"}, "1327980": {"name": "Cellulophaga phage phi17:1", "rank": "Species"}, "1454725": {"name": "Candidatus Caldatribacteirum", "rank": "Genus"}, "1327989": {"name": "Serratia sp. FS14", "rank": "Species"}, "1327988": {"name": "Lactobacillus plantarum 16", "rank": "Strain"}, "1159093": {"name": "Streptococcus pneumoniae PNI0076", "rank": "Strain"}, "396034": {"name": "Bacillus virus 1", "rank": "Species"}, "1294039": {"name": "Tropheryma whipplei str. Bcu26", "rank": "Strain"}, "62088": {"name": "Borrelia valaisiana", "rank": "Species"}, "742013": {"name": "Delftia sp. Cs1-4", "rank": "Species"}, "1246994": {"name": "Elizabethkingia anophelis R26", "rank": "Strain"}, "1246995": {"name": "Actinoplanes friuliensis DSM 7358", "rank": "Strain"}, "433462": {"name": "Canna yellow streak virus", "rank": "Species"}, "1049983": {"name": "Leptospira santarosai str. HAI821", "rank": "Strain"}, "1049980": {"name": "Leptospira santarosai str. HAI134", "rank": "Strain"}, "1049981": {"name": "Leptospira santarosai str. HAI1349", "rank": "Strain"}, "1049986": {"name": "Leptospira weilii str. Ecochallenge", "rank": "Strain"}, "311413": {"name": "Lettuce big-vein associated virus", "rank": "Species"}, "1049984": {"name": "Leptospira santarosai str. MOR084", "rank": "Strain"}, "1049985": {"name": "Leptospira santarosai str. ZUN179", "rank": "Strain"}, "1449049": {"name": "Caulobacter sp. UNC358MFTsu5.1", "rank": "Species"}, "1449048": {"name": "Mycobacterium sp. UNC280MFTsu5.1", "rank": "Species"}, "1449047": {"name": "Bacillus sp. UNC69MF", "rank": "Species"}, "1449046": {"name": "Bacillus sp. UNC41MFS5", "rank": "Species"}, "1449045": {"name": "Bacillus sp. UNC322MFChir4.1", "rank": "Species"}, "1052095": {"name": "Granulibacter bethesdensis CGDNIH4", "rank": "Strain"}, "314262": {"name": "Roseobacter sp. MED193", "rank": "Species"}, "314263": {"name": "Roseovarius nubinhibens", "rank": "Species"}, "314260": {"name": "Parvularcula bermudensis HTCC2503", "rank": "Strain"}, "314266": {"name": "Sphingomonas sp. SKA58", "rank": "Species"}, "883067": {"name": "Actinobaculum schaalii FB123-CNA-2", "rank": "Strain"}, "314264": {"name": "Roseovarius sp. 217", "rank": "Species"}, "314265": {"name": "Pelagibaca bermudensis HTCC2601", "rank": "Strain"}, "789642": {"name": "Salmonella enterica subsp. enterica serovar Newport str. CVM 35185", "rank": "Strain"}, "789643": {"name": "Salmonella enterica subsp. enterica serovar Newport str. CVM 35199", "rank": "Strain"}, "264203": {"name": "Zymomonas mobilis subsp. mobilis ZM4 = ATCC 31821", "rank": "Strain"}, "789646": {"name": "Salmonella enterica subsp. enterica serovar Newport str. CVM 35188", "rank": "Strain"}, "789647": {"name": "Salmonella enterica subsp. enterica serovar Newport str. CVM 21559", "rank": "Strain"}, "789644": {"name": "Salmonella enterica subsp. enterica serovar Newport str. CVM 21539", "rank": "Strain"}, "789645": {"name": "Salmonella enterica subsp. enterica serovar Newport str. CVM 33953", "rank": "Strain"}, "646442": {"name": "Sweet potato badnavirus A", "rank": "Species"}, "981369": {"name": "Streptacidiphilus rugosus AM-16", "rank": "Strain"}, "981368": {"name": "Xanthomonas axonopodis pv. citrumelo F1", "rank": "Strain"}, "981367": {"name": "Escherichia fergusonii ECD227", "rank": "Strain"}, "1217695": {"name": "Acinetobacter sp. NIPH 1859", "rank": "Species"}, "1417106": {"name": "Staphylococcus aureus M45704", "rank": "Strain"}, "1417101": {"name": "Staphylococcus aureus H43986", "rank": "Strain"}, "1221266": {"name": "Acinetobacter baumannii AB_908-12", "rank": "Strain"}, "931244": {"name": "Alphapapillomavirus 14", "rank": "Species"}, "1417103": {"name": "Staphylococcus aureus H44015", "rank": "Strain"}, "1217690": {"name": "Acinetobacter calcoaceticus ANC 3811", "rank": "Strain"}, "453050": {"name": "Sweet potato virus 2", "rank": "Species"}, "92395": {"name": "Black queen cell virus", "rank": "Species"}, "889249": {"name": "Campylobacter jejuni subsp. jejuni LMG 9217", "rank": "Strain"}, "889248": {"name": "Campylobacter jejuni subsp. jejuni LMG 9081", "rank": "Strain"}, "889243": {"name": "Campylobacter jejuni subsp. jejuni LMG 23264", "rank": "Strain"}, "889242": {"name": "Campylobacter jejuni subsp. jejuni LMG 23263", "rank": "Strain"}, "889241": {"name": "Campylobacter jejuni subsp. jejuni LMG 23223", "rank": "Strain"}, "889240": {"name": "Campylobacter jejuni subsp. jejuni LMG 23218", "rank": "Strain"}, "889247": {"name": "Campylobacter jejuni subsp. jejuni ATCC 33560", "rank": "Strain"}, "889246": {"name": "Campylobacter jejuni subsp. jejuni LMG 23357", "rank": "Strain"}, "889245": {"name": "Campylobacter jejuni subsp. jejuni LMG 9879", "rank": "Strain"}, "889244": {"name": "Campylobacter jejuni subsp. jejuni LMG 23269", "rank": "Strain"}, "1054966": {"name": "Salmonella enterica subsp. enterica serovar Heidelberg str. N653", "rank": "Strain"}, "1054967": {"name": "Unclassified Phieco32likevirus", "rank": "No rank"}, "1054963": {"name": "Salmonella enterica subsp. enterica serovar Heidelberg str. N4403", "rank": "Strain"}, "1054960": {"name": "Salmonella enterica subsp. enterica serovar Heidelberg str. N4496", "rank": "Strain"}, "1286348": {"name": "Escherichia coli TOP2522-1", "rank": "Strain"}, "1417109": {"name": "Staphylococcus aureus H47171", "rank": "Strain"}, "1286345": {"name": "Escherichia coli TOP2396-2", "rank": "Strain"}, "1286344": {"name": "Escherichia coli TOP2396-1", "rank": "Strain"}, "1286343": {"name": "Escherichia coli TOP2386", "rank": "Strain"}, "1286342": {"name": "Escherichia coli TOP550-4", "rank": "Strain"}, "1054968": {"name": "Salmonella phage 7-11", "rank": "Species"}, "1286340": {"name": "Escherichia coli TOP550-2", "rank": "Strain"}, "1260361": {"name": "Enterococcus faecalis B83616-1", "rank": "Strain"}, "1260360": {"name": "Enterococcus faecalis 06-MB-S-10", "rank": "Strain"}, "1260363": {"name": "Enterococcus faecalis 02-MB-BW-10", "rank": "Strain"}, "1260362": {"name": "Enterococcus faecalis D811610-10", "rank": "Strain"}, "1260365": {"name": "Enterococcus faecalis 02-MB-P-10", "rank": "Strain"}, "1260364": {"name": "Enterococcus faecalis 20-SD-BW-06", "rank": "Strain"}, "1260366": {"name": "Enterococcus faecalis KI-6-1-110608-1", "rank": "Strain"}, "1089454": {"name": "Gordonia terrae NBRC 100016", "rank": "Strain"}, "1089455": {"name": "Mobilicoccus pelagius NBRC 104925", "rank": "Strain"}, "1089456": {"name": "Pseudomonas aeruginosa NCGM2.S1", "rank": "Strain"}, "1089451": {"name": "Fusarium oxysporum f. sp. cubense tropical race 4 54006", "rank": "Strain"}, "1089453": {"name": "Gordonia sputi NBRC 100414", "rank": "Strain"}, "33986": {"name": "Exiguobacterium", "rank": "Genus"}, "1159095": {"name": "Streptococcus pneumoniae PNI0159", "rank": "Strain"}, "10659": {"name": "Corticoviridae", "rank": "Family"}, "10658": {"name": "Enterobacteria phage PRD1", "rank": "Species"}, "10653": {"name": "Commelina yellow mottle virus", "rank": "Species"}, "10652": {"name": "Badnavirus", "rank": "Genus"}, "43989": {"name": "Cyanothece sp. ATCC 51142", "rank": "Species"}, "43988": {"name": "Cyanothece", "rank": "Genus"}, "10657": {"name": "Tectivirus", "rank": "Genus"}, "10656": {"name": "Tectiviridae", "rank": "Family"}, "10654": {"name": "Rice tungro bacilliform virus", "rank": "Species"}, "1121103": {"name": "Balneatrix alpica DSM 16621", "rank": "Strain"}, "1121102": {"name": "Campylobacter ureolyticus DSM 20703", "rank": "Strain"}, "1121101": {"name": "Bacteroides salyersiae WAL 10018 = DSM 18765 = JCM 12988", "rank": "Strain"}, "1121100": {"name": "Bacteroides pyogenes DSM 20611 = JCM 6294", "rank": "Strain"}, "1121107": {"name": "Bifidobacterium choerinum DSM 20434", "rank": "Strain"}, "1121106": {"name": "Belnapia moabensis DSM 16746", "rank": "Strain"}, "1121105": {"name": "Bavariicoccus seileri DSM 19936", "rank": "Strain"}, "1121104": {"name": "Balneola vulgaris DSM 17893", "rank": "Strain"}, "1121109": {"name": "Bifidobacterium minimum DSM 20102", "rank": "Strain"}, "1121108": {"name": "Bifidobacterium magnum DSM 20222", "rank": "Strain"}, "11308": {"name": "Orthomyxoviridae", "rank": "Family"}, "11306": {"name": "Nucleorhabdovirus", "rank": "Genus"}, "483266": {"name": "Haemophilus phage SuMu", "rank": "Species"}, "483265": {"name": "Unclassified Mu-like viruses", "rank": "No rank"}, "11305": {"name": "Cytorhabdovirus", "rank": "Genus"}, "11303": {"name": "Bovine ephemeral fever virus", "rank": "Species"}, "935199": {"name": "Rhodococcus sp. p52", "rank": "Species"}, "935198": {"name": "Clostridium botulinum B str. Eklund 17B (NRP)", "rank": "Strain"}, "400667": {"name": "Acinetobacter baumannii ATCC 17978", "rank": "Strain"}, "400668": {"name": "Marinomonas sp. MWYL1", "rank": "Species"}, "1158622": {"name": "Enterococcus faecalis EnGen0241", "rank": "Strain"}, "1158623": {"name": "Enterococcus faecalis EnGen0242", "rank": "Strain"}, "1158620": {"name": "Enterococcus faecalis EnGen0239", "rank": "Strain"}, "1158621": {"name": "Enterococcus faecalis EnGen0240", "rank": "Strain"}, "1158626": {"name": "Enterococcus faecalis EnGen0245", "rank": "Strain"}, "1158627": {"name": "Enterococcus faecalis EnGen0246", "rank": "Strain"}, "1158624": {"name": "Enterococcus faecalis EnGen0243", "rank": "Strain"}, "1158625": {"name": "Enterococcus faecalis EnGen0244", "rank": "Strain"}, "1158628": {"name": "Enterococcus faecalis EnGen0247", "rank": "Strain"}, "1158629": {"name": "Enterococcus faecalis EnGen0248", "rank": "Strain"}, "97344": {"name": "Periplaneta fuliginosa densovirus", "rank": "Strain"}, "748224": {"name": "Faecalibacterium cf. prausnitzii KLE1255", "rank": "Strain"}, "301447": {"name": "Streptococcus pyogenes serotype M1", "rank": "Strain"}, "596707": {"name": "Sinomonas", "rank": "Genus"}, "301448": {"name": "Streptococcus pyogenes serotype M3", "rank": "Strain"}, "301449": {"name": "Streptococcus pyogenes serotype M5", "rank": "Strain"}, "933356": {"name": "Enterococcus faecium E4452", "rank": "Strain"}, "1519399": {"name": "Sewage-associated gemycircularvirus-4", "rank": "Species"}, "451764": {"name": "Microbacterium luticocti", "rank": "Species"}, "1327765": {"name": "Mycobacterium phage Fishburne", "rank": "Species"}, "1327764": {"name": "Mycobacterium phage Dumbo", "rank": "Species"}, "864570": {"name": "Streptococcus sp. oral taxon 071 str. 73H25AP", "rank": "Strain"}, "1327762": {"name": "Mycobacterium phage Astraea", "rank": "Species"}, "1327760": {"name": "Streptomyces phage Zemlya", "rank": "Species"}, "1161927": {"name": "Pseudomonas phage Lu11", "rank": "Species"}, "40989": {"name": "Saccharomonospora cyanea", "rank": "Species"}, "858215": {"name": "Thermoanaerobacterium xylanolyticum LX-11", "rank": "Strain"}, "1504322": {"name": "Actinobacterium acIB-AMD-7", "rank": "Species"}, "1504320": {"name": "Actinobacterium acAcidi", "rank": "Species"}, "1504321": {"name": "Actinobacterium acIB-AMD-6", "rank": "Species"}, "585891": {"name": "Staphylococcus aureus subsp. aureus Mu50-omega", "rank": "Strain"}, "904320": {"name": "Staphylococcus epidermidis VCU041", "rank": "Strain"}, "904321": {"name": "Staphylococcus epidermidis VCU045", "rank": "Strain"}, "904322": {"name": "Staphylococcus epidermidis VCU050", "rank": "Strain"}, "904323": {"name": "Staphylococcus epidermidis VCU057", "rank": "Strain"}, "904324": {"name": "Staphylococcus epidermidis VCU065", "rank": "Strain"}, "904325": {"name": "Staphylococcus epidermidis VCU071", "rank": "Strain"}, "904326": {"name": "Staphylococcus epidermidis VCU081", "rank": "Strain"}, "12657": {"name": "Equid herpesvirus 2", "rank": "Species"}, "498803": {"name": "Emilia yellow vein virus", "rank": "Species"}, "260398": {"name": "Exiguobacterium sp. GIC31", "rank": "Species"}, "498805": {"name": "Emilia yellow vein virus-Fz1", "rank": "Strain"}, "1207542": {"name": "Bifidobacterium bifidum LMG 13195", "rank": "Strain"}, "1444081": {"name": "Escherichia coli 1-392-07_S1_C2", "rank": "Strain"}, "1444082": {"name": "Escherichia coli 3-020-07_S1_C2", "rank": "Strain"}, "1444083": {"name": "Escherichia coli 3-073-06_S1_C2", "rank": "Strain"}, "1444084": {"name": "Escherichia coli 3-105-05_S1_C2", "rank": "Strain"}, "1444085": {"name": "Escherichia coli 3-267-03_S1_C2", "rank": "Strain"}, "1444086": {"name": "Escherichia coli 3-373-03_S1_C2", "rank": "Strain"}, "1444087": {"name": "Escherichia coli 3-475-03_S1_C2", "rank": "Strain"}, "1444088": {"name": "Escherichia coli 4-203-08_S1_C2", "rank": "Strain"}, "1444089": {"name": "Escherichia coli 6-175-07_S1_C2", "rank": "Strain"}, "926569": {"name": "Anaerolinea thermophila UNI-1", "rank": "Strain"}, "926566": {"name": "Terriglobus roseus DSM 18391", "rank": "Strain"}, "936456": {"name": "Desulfurispirillum indicum", "rank": "Species"}, "936455": {"name": "Bradyrhizobium genosp. SA-4 str. CB756", "rank": "Strain"}, "926565": {"name": "Sporocytophaga myxococcoides DSM 11118", "rank": "Strain"}, "926562": {"name": "Owenweeksia hongkongensis DSM 17368", "rank": "Strain"}, "926560": {"name": "Meiothermus chliarophilus DSM 9957", "rank": "Strain"}, "926561": {"name": "Orenia marismortui DSM 5156", "rank": "Strain"}, "232800": {"name": "Varroa destructor virus-1", "rank": "Species"}, "1195243": {"name": "Porphyromonas gingivalis JCVI SC001", "rank": "Strain"}, "1195246": {"name": "Alishewanella agri BL06", "rank": "Strain"}, "1195244": {"name": "Gallibacterium anatis 12656/12", "rank": "Strain"}, "1391726": {"name": "Helicobacter pylori 26695-1", "rank": "Strain"}, "1391727": {"name": "Helicobacter pylori 26695-1CL", "rank": "Strain"}, "1249653": {"name": "Ehrlichia chaffeensis str. Liberty", "rank": "Strain"}, "882378": {"name": "Burkholderia rhizoxinica HKI 454", "rank": "Strain"}, "882379": {"name": "Aliagarivorans", "rank": "Genus"}, "334735": {"name": "Sporosarcina koreensis", "rank": "Species"}, "1391728": {"name": "Helicobacter pylori 26695-1CH", "rank": "Strain"}, "1391729": {"name": "Brevundimonas abyssalis TAR-001", "rank": "Strain"}, "1422596": {"name": "Staphylococcus aureus VET0337R", "rank": "Strain"}, "1422597": {"name": "Staphylococcus aureus VET0338R", "rank": "Strain"}, "1422594": {"name": "Staphylococcus aureus VET0335R", "rank": "Strain"}, "1422595": {"name": "Staphylococcus aureus VET0336R", "rank": "Strain"}, "1422592": {"name": "Staphylococcus aureus VET0332R", "rank": "Strain"}, "1155071": {"name": "Streptococcus mutans LJ23", "rank": "Strain"}, "1422590": {"name": "Staphylococcus aureus VET0329R", "rank": "Strain"}, "1422591": {"name": "Staphylococcus aureus VET0331R", "rank": "Strain"}, "36630": {"name": "Neosartorya fischeri", "rank": "Species"}, "1422598": {"name": "Staphylococcus aureus VET0339R", "rank": "Strain"}, "1422599": {"name": "Staphylococcus aureus VET0340R", "rank": "Strain"}, "497738": {"name": "Streptococcus pneumoniae SV35", "rank": "Strain"}, "1159200": {"name": "Mycoplasma gallisepticum NY01_2001.047-5-1P", "rank": "Strain"}, "1130345": {"name": "Cloacimonetes bacterium JGI 0000014-D06", "rank": "Species"}, "696406": {"name": "Escherichia coli UMNK88", "rank": "Strain"}, "444158": {"name": "Methanococcus maripaludis C6", "rank": "Strain"}, "50817": {"name": "Broad bean wilt virus 1", "rank": "Species"}, "489653": {"name": "Neisseria lactamica 020-06", "rank": "Strain"}, "1290553": {"name": "Halocynthiibacter namhaensis", "rank": "Species"}, "300180": {"name": "Mopeia Lassa virus reassortant 29", "rank": "Species"}, "300186": {"name": "Acidianus filamentous virus 2", "rank": "Species"}, "1413527": {"name": "Staphylococcus aureus GD2010-110", "rank": "Strain"}, "1413526": {"name": "Staphylococcus aureus GD2010-090", "rank": "Strain"}, "1413525": {"name": "Staphylococcus aureus GD2010-177", "rank": "Strain"}, "1413524": {"name": "Staphylococcus aureus 2011-60-1490-31", "rank": "Strain"}, "1413523": {"name": "Staphylococcus aureus 2011-60-2078-5", "rank": "Strain"}, "1413522": {"name": "Staphylococcus aureus 2011-60-2275-7", "rank": "Strain"}, "1413521": {"name": "Staphylococcus aureus 2011-60-2275-1", "rank": "Strain"}, "1203561": {"name": "Corynebacterium sp. KPL1824", "rank": "Species"}, "1413529": {"name": "Staphylococcus aureus GD2010-115", "rank": "Strain"}, "1413528": {"name": "Staphylococcus aureus GD2010-107", "rank": "Strain"}, "563843": {"name": "Rhodothermaceae", "rank": "Family"}, "1409379": {"name": "Staphylococcus aureus SMMC0005", "rank": "Strain"}, "1409378": {"name": "Staphylococcus aureus AMMC6054", "rank": "Strain"}, "1203562": {"name": "Corynebacterium sp. KPL1855", "rank": "Species"}, "1409375": {"name": "Staphylococcus aureus COAS6025", "rank": "Strain"}, "1409374": {"name": "Staphylococcus aureus SJOS6072", "rank": "Strain"}, "1409377": {"name": "Staphylococcus aureus SMMC6007", "rank": "Strain"}, "1409376": {"name": "Staphylococcus aureus WMCS6011", "rank": "Strain"}, "1409371": {"name": "Staphylococcus aureus GGMC6010", "rank": "Strain"}, "1409370": {"name": "Staphylococcus aureus AMMC6051", "rank": "Strain"}, "1409373": {"name": "Staphylococcus aureus PLAC6012", "rank": "Strain"}, "1409372": {"name": "Staphylococcus aureus CHAP6049", "rank": "Strain"}, "661410": {"name": "Methylobacterium extorquens DM4", "rank": "Strain"}, "1216470": {"name": "Enterobacter sp. SST3", "rank": "Species"}, "2284": {"name": "Sulfolobus", "rank": "Genus"}, "2285": {"name": "Sulfolobus acidocaldarius", "rank": "Species"}, "2287": {"name": "Sulfolobus solfataricus", "rank": "Species"}, "2280": {"name": "Staphylothermus marinus", "rank": "Species"}, "2281": {"name": "Sulfolobales", "rank": "Order"}, "1538640": {"name": "Smithella sp. F21", "rank": "Species"}, "2289": {"name": "Desulfobacter", "rank": "Genus"}, "1538644": {"name": "Sphingobacterium sp. ML3W", "rank": "Species"}, "28905": {"name": "Caedibacter", "rank": "Genus"}, "1004151": {"name": "Photorhabdus temperata subsp. khanii NC19", "rank": "Strain"}, "28901": {"name": "Salmonella enterica", "rank": "Species"}, "28903": {"name": "Mycoplasma bovis", "rank": "Species"}, "55193": {"name": "Malassezia", "rank": "Genus"}, "55197": {"name": "Flavobacterium branchiophilum", "rank": "Species"}, "1281089": {"name": "Escherichia coli HVH 156 (4-3206505)", "rank": "Strain"}, "1281088": {"name": "Escherichia coli HVH 155 (4-4509048)", "rank": "Strain"}, "1281085": {"name": "Escherichia coli HVH 152 (4-3447545)", "rank": "Strain"}, "1281084": {"name": "Escherichia coli HVH 151 (4-5755573)", "rank": "Strain"}, "1281087": {"name": "Escherichia coli HVH 154 (4-5636698)", "rank": "Strain"}, "1281086": {"name": "Escherichia coli HVH 153 (3-9344314)", "rank": "Strain"}, "1281081": {"name": "Escherichia coli HVH 148 (4-3192490)", "rank": "Strain"}, "1281080": {"name": "Escherichia coli HVH 147 (4-5893887)", "rank": "Strain"}, "1281083": {"name": "Escherichia coli HVH 150 (4-3258106)", "rank": "Strain"}, "1281082": {"name": "Escherichia coli HVH 149 (4-4451880)", "rank": "Strain"}, "941843": {"name": "Unclassified Rhodospirillales (miscellaneous)", "rank": "No rank"}, "1412656": {"name": "Staphylococcus aureus H58191", "rank": "Strain"}, "1412657": {"name": "Staphylococcus aureus H58198", "rank": "Strain"}, "1412654": {"name": "Staphylococcus aureus H58177", "rank": "Strain"}, "1412655": {"name": "Staphylococcus aureus H58183", "rank": "Strain"}, "1412652": {"name": "Staphylococcus aureus H51158", "rank": "Strain"}, "515608": {"name": "Ureaplasma parvum serovar 1 str. ATCC 27813", "rank": "Strain"}, "1412650": {"name": "Staphylococcus aureus F88405", "rank": "Strain"}, "34098": {"name": "Blattabacterium", "rank": "Genus"}, "34093": {"name": "Simkania", "rank": "Genus"}, "133539": {"name": "Nitrosococcus halophilus", "rank": "Species"}, "1412658": {"name": "Staphylococcus aureus H64941", "rank": "Strain"}, "34090": {"name": "Pelodictyon phaeoclathratiforme", "rank": "Species"}, "132475": {"name": "Yaba-like disease virus", "rank": "Strain"}, "132474": {"name": "Streptomyces rimosus subsp. rimosus", "rank": "Subspecies"}, "132477": {"name": "Kalanchoe latent virus", "rank": "Species"}, "260714": {"name": "Campylobacter insulaenigrae", "rank": "Species"}, "1417068": {"name": "Staphylococcus aureus H35283", "rank": "Strain"}, "1417069": {"name": "Staphylococcus aureus F70077", "rank": "Strain"}, "1417066": {"name": "Staphylococcus aureus T77618", "rank": "Strain"}, "997761": {"name": "Paenibacillus mucilaginosus K02", "rank": "Strain"}, "1417064": {"name": "Staphylococcus aureus M32688", "rank": "Strain"}, "1417065": {"name": "Staphylococcus aureus T77565", "rank": "Strain"}, "1417062": {"name": "Staphylococcus aureus M32669", "rank": "Strain"}, "997765": {"name": "Mycoplasma ovipneumoniae SC01", "rank": "Strain"}, "1417060": {"name": "Staphylococcus aureus M32567", "rank": "Strain"}, "1417061": {"name": "Staphylococcus aureus F63712", "rank": "Strain"}, "1410878": {"name": "Staphylococcus aureus F27254", "rank": "Strain"}, "1410879": {"name": "Staphylococcus aureus H71781", "rank": "Strain"}, "1410874": {"name": "Staphylococcus aureus H57815", "rank": "Strain"}, "1410875": {"name": "Staphylococcus aureus W76127", "rank": "Strain"}, "1410876": {"name": "Staphylococcus aureus H71785", "rank": "Strain"}, "1410877": {"name": "Staphylococcus aureus F27253", "rank": "Strain"}, "1410870": {"name": "Staphylococcus aureus S11444", "rank": "Strain"}, "1410871": {"name": "Staphylococcus aureus T16281", "rank": "Strain"}, "1410872": {"name": "Staphylococcus aureus W82303", "rank": "Strain"}, "1410873": {"name": "Staphylococcus aureus W82310", "rank": "Strain"}, "1154953": {"name": "Streptococcus agalactiae GB00929", "rank": "Strain"}, "44575": {"name": "Nitrosomonas cryotolerans", "rank": "Species"}, "56426": {"name": "Bartonella clarridgeiae", "rank": "Species"}, "1154955": {"name": "Streptococcus agalactiae GB00933", "rank": "Strain"}, "1154956": {"name": "Streptococcus agalactiae GB00940", "rank": "Strain"}, "1125723": {"name": "Porphyromonas sp. oral taxon 279 str. F0450", "rank": "Strain"}, "1125722": {"name": "Porphyromonas gingivalis W50", "rank": "Strain"}, "1125721": {"name": "Capnocytophaga sp. oral taxon 412 str. F0487", "rank": "Strain"}, "1339239": {"name": "Cetobacterium sp. ZOR0034", "rank": "Species"}, "151081": {"name": "Pseudoalteromonas ruthenica", "rank": "Species"}, "1125724": {"name": "Rothia aeria F0474", "rank": "Strain"}, "1154958": {"name": "Streptococcus agalactiae GB00951", "rank": "Strain"}, "644968": {"name": "Desulfovibrio sp. FW1012B", "rank": "Species"}, "1151354": {"name": "Peptoclostridium difficile DA00246", "rank": "Strain"}, "1151357": {"name": "Peptoclostridium difficile DA00273", "rank": "Strain"}, "1339249": {"name": "Vibrio cholerae ZWU0020", "rank": "Strain"}, "1151351": {"name": "Peptoclostridium difficile DA00238", "rank": "Strain"}, "1151389": {"name": "Peptoclostridium difficile Y358", "rank": "Strain"}, "1339233": {"name": "Microbacterium sp. ZOR0019", "rank": "Species"}, "1151386": {"name": "Peptoclostridium difficile Y307", "rank": "Strain"}, "1151353": {"name": "Peptoclostridium difficile DA00245", "rank": "Strain"}, "1151387": {"name": "Peptoclostridium difficile Y312", "rank": "Strain"}, "1151352": {"name": "Peptoclostridium difficile DA00244", "rank": "Strain"}, "1027869": {"name": "Switchgrass mosaic virus", "rank": "Species"}, "1046935": {"name": "BRC1 bacterium SCGC AAA257-C11", "rank": "Species"}, "85108": {"name": "Halorhodospira", "rank": "Genus"}, "1085028": {"name": "Halophilic archaeon J07HX64", "rank": "Species"}, "1151382": {"name": "Peptoclostridium difficile Y231", "rank": "Strain"}, "1288026": {"name": "Arcticibacter", "rank": "Genus"}, "85106": {"name": "Adeno-associated virus - 1", "rank": "Strain"}, "1151380": {"name": "Peptoclostridium difficile Y202", "rank": "Strain"}, "1339240": {"name": "Vibrio furnissii ZOR0035", "rank": "Strain"}, "1234883": {"name": "Dragonfly cyclovirus 5", "rank": "Species"}, "1305764": {"name": "Pseudozyma hubeiensis SY62", "rank": "Strain"}, "1414719": {"name": "Corynebacterium sp. JCB", "rank": "Species"}, "1414718": {"name": "Bacillus sp. JCA", "rank": "Species"}, "1464127": {"name": "Staphylococcus phage DW2", "rank": "Species"}, "1151218": {"name": "Escherichia coli B28-2", "rank": "Strain"}, "1151219": {"name": "Escherichia coli B29-1", "rank": "Strain"}, "1151214": {"name": "Escherichia coli B107", "rank": "Strain"}, "1151215": {"name": "Escherichia coli B7-1", "rank": "Strain"}, "1151216": {"name": "Escherichia coli B7-2", "rank": "Strain"}, "1151217": {"name": "Escherichia coli B28-1", "rank": "Strain"}, "1151210": {"name": "Enterococcus faecalis EnGen0068", "rank": "Strain"}, "1151211": {"name": "Enterococcus faecalis EnGen0069", "rank": "Strain"}, "1355100": {"name": "Escherichia coli JJ1886", "rank": "Strain"}, "1151213": {"name": "Escherichia coli B102", "rank": "Strain"}, "1311018": {"name": "Acinetobacter baumannii 25493_4", "rank": "Strain"}, "1311019": {"name": "Acinetobacter baumannii 25493_5", "rank": "Strain"}, "1311015": {"name": "Acinetobacter baumannii 25493_1", "rank": "Strain"}, "1311016": {"name": "Acinetobacter baumannii 25493_2", "rank": "Strain"}, "1311017": {"name": "Acinetobacter baumannii 25493_3", "rank": "Strain"}, "1311010": {"name": "Acinetobacter baumannii 25681_6", "rank": "Strain"}, "1311012": {"name": "Acinetobacter baumannii 25681_8", "rank": "Strain"}, "1311013": {"name": "Acinetobacter baumannii 25681_9", "rank": "Strain"}, "1182737": {"name": "Escherichia coli KTE170", "rank": "Strain"}, "1182736": {"name": "Escherichia coli KTE169", "rank": "Strain"}, "1182735": {"name": "Escherichia coli KTE165", "rank": "Strain"}, "1182734": {"name": "Escherichia coli KTE162", "rank": "Strain"}, "1182733": {"name": "Escherichia coli KTE161", "rank": "Strain"}, "1182732": {"name": "Escherichia sp. KTE159", "rank": "Species"}, "1182731": {"name": "Escherichia coli KTE158", "rank": "Strain"}, "1182730": {"name": "Escherichia coli KTE156", "rank": "Strain"}, "1131257": {"name": "Staphylococcus saprophyticus subsp. saprophyticus KACC 16562", "rank": "Strain"}, "1131253": {"name": "Gluconobacter oxydans WSH-003", "rank": "Strain"}, "1182738": {"name": "Escherichia coli KTE171", "rank": "Strain"}, "117207": {"name": "Sphingopyxis alaskensis", "rank": "Species"}, "539742": {"name": "Bacillales Family XII. Incertae Sedis", "rank": "No rank"}, "292459": {"name": "Symbiobacterium thermophilum IAM 14863", "rank": "Strain"}, "1382357": {"name": "Geobacillus subterraneus PSS2", "rank": "Strain"}, "1382356": {"name": "Thermomicrobiales bacterium KI4", "rank": "Species"}, "1382355": {"name": "Unclassified Thermomicrobiales", "rank": "No rank"}, "1382359": {"name": "Acidobacterium sp. PMMR2", "rank": "Species"}, "1382358": {"name": "Anoxybacillus tepidamans PS2", "rank": "Strain"}, "999288": {"name": "Sweet potato leaf curl South Carolina virus", "rank": "Species"}, "1281028": {"name": "Escherichia coli HVH 91 (4-4638751)", "rank": "Strain"}, "866913": {"name": "Salmonella enterica subsp. enterica serovar 4,5,12:i:- str. 08-1736", "rank": "Strain"}, "1500308": {"name": "Caulobacter sp. OV484", "rank": "Species"}, "1500309": {"name": "Rhizobium sp. YR060", "rank": "Species"}, "1354277": {"name": "Virgibacillus sp. CM-4", "rank": "Species"}, "1500301": {"name": "Rhizobium sp. CF097", "rank": "Species"}, "1074252": {"name": "Staphylococcus aureus subsp. aureus HO 5096 0412", "rank": "Strain"}, "1500305": {"name": "Rhizobium sp. OK665", "rank": "Species"}, "1500306": {"name": "Rhizobium sp. OK494", "rank": "Species"}, "754441": {"name": "Chaetoceros lorenzianus DNA virus", "rank": "Species"}, "182093": {"name": "Unclassified Vesivirus", "rank": "No rank"}, "866914": {"name": "Salmonella enterica subsp. enterica serovar 4,5,12:i:- str. 08-1700", "rank": "Strain"}, "1196325": {"name": "Pseudomonas putida DOT-T1E", "rank": "Strain"}, "1196324": {"name": "Bacillus macauensis ZFHKF-1", "rank": "Strain"}, "1196327": {"name": "Coxiella burnetii cb109", "rank": "Strain"}, "1196323": {"name": "Paenibacillus sp. OSY-SE", "rank": "Species"}, "1196322": {"name": "Clostridium sp. Maddingley MBC34-26", "rank": "Species"}, "1278971": {"name": "Avibacterium paragallinarum 221", "rank": "Strain"}, "1221877": {"name": "Chlamydia psittaci 01DC12", "rank": "Strain"}, "1077257": {"name": "Chthonomonadetes", "rank": "Class"}, "588605": {"name": "Robinsoniella", "rank": "Genus"}, "1288313": {"name": "Gluconobacter oxydans DSM 3504", "rank": "Strain"}, "351348": {"name": "Marinobacter hydrocarbonoclasticus VT8", "rank": "Strain"}, "1422258": {"name": "Staphylococcus aureus DAR1938", "rank": "Strain"}, "294746": {"name": "Meyerozyma guilliermondii ATCC 6260", "rank": "Strain"}, "1187078": {"name": "Cecembia", "rank": "Genus"}, "1284223": {"name": "Lactobacillus plantarum UCMA 3037", "rank": "Strain"}, "111519": {"name": "Caldanaerobacter subterraneus subsp. yonseiensis", "rank": "Subspecies"}, "1385367": {"name": "Snodgrassella alvi SCGC AB-598-J21", "rank": "Strain"}, "1385369": {"name": "Skermanella stibiiresistens SB22", "rank": "Strain"}, "550694": {"name": "Escherichia fergusonii B253", "rank": "Strain"}, "413": {"name": "Methylococcus", "rank": "Genus"}, "454602": {"name": "Spongiibacter tropicus", "rank": "Species"}, "416": {"name": "Methylomonas", "rank": "Genus"}, "414": {"name": "Methylococcus capsulatus", "rank": "Species"}, "415": {"name": "Methylobacter luteus", "rank": "Species"}, "249199": {"name": "Mandarivirus", "rank": "Genus"}, "1486473": {"name": "Mycobacterium phage OkiRoe", "rank": "Species"}, "269673": {"name": "Sporolactobacillus terrae", "rank": "Species"}, "102618": {"name": "Helicobacter pylori NCTC 11637 = CCUG 17874", "rank": "Strain"}, "102616": {"name": "Helicobacter pylori N6", "rank": "Strain"}, "1116074": {"name": "Escherichia coli P0302293.3", "rank": "Strain"}, "1296100": {"name": "Cryptococcus bestiolae CBS 10118", "rank": "Strain"}, "1310835": {"name": "Acinetobacter baumannii 24860_1", "rank": "Strain"}, "1310834": {"name": "Acinetobacter baumannii 263903-2", "rank": "Strain"}, "1310837": {"name": "Acinetobacter baumannii 24860_3", "rank": "Strain"}, "1310836": {"name": "Acinetobacter baumannii 24860_2", "rank": "Strain"}, "1310831": {"name": "Acinetobacter baumannii 1042969-1197", "rank": "Strain"}, "1198219": {"name": "Sweet potato leaf curl China virus", "rank": "Species"}, "1310839": {"name": "Acinetobacter baumannii 24860_5", "rank": "Strain"}, "1310838": {"name": "Acinetobacter baumannii 24860_4", "rank": "Strain"}, "1293572": {"name": "Mythimna separata entomopoxvirus 'L'", "rank": "Species"}, "1293576": {"name": "Borrelia hermsii YOR", "rank": "Strain"}, "1293577": {"name": "Candidate division SR1 bacterium MGEHA", "rank": "Species"}, "1293574": {"name": "Acinetobacter baumannii 48055", "rank": "Strain"}, "1293575": {"name": "Borrelia crocidurae DOU", "rank": "Strain"}, "1505933": {"name": "Mesorhizobium sp. ORS3359", "rank": "Species"}, "1438748": {"name": "Klebsiella pneumoniae CHS 42", "rank": "Strain"}, "1438749": {"name": "Klebsiella pneumoniae CHS 43", "rank": "Strain"}, "1041": {"name": "Erythrobacter", "rank": "Genus"}, "979226": {"name": "Cohnella panacarvi Gsoil 349", "rank": "Strain"}, "979221": {"name": "Staphylococcus epidermidis NIH05001", "rank": "Strain"}, "1046": {"name": "Chromatiaceae", "rank": "Family"}, "1044": {"name": "Erythrobacter longus", "rank": "Species"}, "1438740": {"name": "Klebsiella pneumoniae CHS 34", "rank": "Strain"}, "1438741": {"name": "Klebsiella pneumoniae CHS 35", "rank": "Strain"}, "1049": {"name": "Allochromatium vinosum", "rank": "Species"}, "1438743": {"name": "Klebsiella pneumoniae CHS 37", "rank": "Strain"}, "1438744": {"name": "Klebsiella pneumoniae CHS 38", "rank": "Strain"}, "1438745": {"name": "Klebsiella pneumoniae CHS 39", "rank": "Strain"}, "1438746": {"name": "Klebsiella pneumoniae CHS 40", "rank": "Strain"}, "1438747": {"name": "Klebsiella pneumoniae CHS 41", "rank": "Strain"}, "492502": {"name": "Rose cryptic virus 1", "rank": "Species"}, "566552": {"name": "Bifidobacterium catenulatum DSM 16992 = JCM 1194 = LMG 11043", "rank": "Strain"}, "566551": {"name": "Cedecea davisae DSM 4568", "rank": "Strain"}, "1035116": {"name": "Vibrio vulnificus E64MW", "rank": "Strain"}, "1954": {"name": "Streptomyces brasiliensis", "rank": "Species"}, "1957": {"name": "Streptomyces sclerotialus", "rank": "Species"}, "267736": {"name": "Halanaerobium saccharolyticum subsp. saccharolyticum", "rank": "Subspecies"}, "1951": {"name": "Streptomyces purpureus", "rank": "Species"}, "1950": {"name": "Streptomyces peucetius", "rank": "Species"}, "1280972": {"name": "Escherichia coli HVH 21 (4-4517873)", "rank": "Strain"}, "1280973": {"name": "Escherichia coli HVH 22 (4-2258986)", "rank": "Strain"}, "1280970": {"name": "Escherichia coli HVH 19 (4-7154984)", "rank": "Strain"}, "1280971": {"name": "Escherichia coli HVH 20 (4-5865042)", "rank": "Strain"}, "1280976": {"name": "Escherichia coli HVH 25 (4-5851939)", "rank": "Strain"}, "1280977": {"name": "Escherichia coli HVH 26 (4-5703913)", "rank": "Strain"}, "1280974": {"name": "Escherichia coli HVH 23 (4-6066488)", "rank": "Strain"}, "368811": {"name": "Rheinheimera perlucida", "rank": "Species"}, "1439196": {"name": "Streptococcus pyogenes ABC020051161", "rank": "Strain"}, "1439197": {"name": "Streptococcus pyogenes ABC020051269", "rank": "Strain"}, "1439194": {"name": "Streptococcus pyogenes ABC020050818", "rank": "Strain"}, "1439192": {"name": "Streptococcus pyogenes ABC020050193", "rank": "Strain"}, "1439193": {"name": "Streptococcus pyogenes ABC020050731", "rank": "Strain"}, "1439190": {"name": "Streptococcus pyogenes ABC020049540", "rank": "Strain"}, "5129": {"name": "Hypocreaceae", "rank": "Family"}, "1216966": {"name": "Edwardsiella hoshinae NBRC 105699 = ATCC 33379", "rank": "Strain"}, "1216967": {"name": "Elizabethkingia meningoseptica ATCC 13253 = NBRC 12535", "rank": "Strain"}, "1433131": {"name": "Escherichia coli IS1", "rank": "Strain"}, "1216962": {"name": "Helicobacter heilmannii ASB1.4", "rank": "Strain"}, "1216961": {"name": "Aeromonas sp. 159", "rank": "Species"}, "109232": {"name": "Rickettsia monacensis", "rank": "Species"}, "862512": {"name": "Corynebacterium accolens ATCC 49726", "rank": "Strain"}, "1203554": {"name": "Sutterella wadsworthensis HGA0223", "rank": "Strain"}, "1325130": {"name": "Helicobacter fennelliae MRY12-0050", "rank": "Strain"}, "862513": {"name": "Neisseria meningitidis ATCC 13091", "rank": "Strain"}, "211114": {"name": "Allokutzneria albata", "rank": "Species"}, "1437839": {"name": "Mycobacterium phage Echild", "rank": "Species"}, "1437838": {"name": "Listeria monocytogenes R479a", "rank": "Strain"}, "936134": {"name": "Ensifer sp. USDA 6670", "rank": "Species"}, "267889": {"name": "Colwelliaceae", "rank": "Family"}, "267888": {"name": "Pseudoalteromonadaceae", "rank": "Family"}, "862516": {"name": "Staphylococcus aureus subsp. aureus ATCC BAA-39", "rank": "Strain"}, "1304833": {"name": "Hassallia byssoidea VB512170", "rank": "Strain"}, "1515334": {"name": "Ponticoccus sp. UMTAT08", "rank": "Species"}, "1267577": {"name": "Candidatus Kinetoplastibacterium crithidii (ex Angomonas deanei ATCC 30255)", "rank": "Strain"}, "137758": {"name": "Cassava brown streak virus", "rank": "Species"}, "1470577": {"name": "Paenirhodobacter", "rank": "Genus"}, "1280390": {"name": "Paenibacillaceae bacterium G5", "rank": "Species"}, "1409400": {"name": "Staphylococcus aureus WMCS6016", "rank": "Strain"}, "137757": {"name": "Ipomovirus", "rank": "Genus"}, "85265": {"name": "Phaeospirillum", "rank": "Genus"}, "312279": {"name": "Emticicia oligotrophica", "rank": "Species"}, "312278": {"name": "Emticicia", "rank": "Genus"}, "312273": {"name": "Scrophularia mottle virus", "rank": "Species"}, "312277": {"name": "Flavobacterium indicum", "rank": "Species"}, "312275": {"name": "Anagyris vein yellowing virus", "rank": "Species"}, "312274": {"name": "Plantago mottle virus", "rank": "Species"}, "933115": {"name": "Planococcus donghaensis MPA1U2", "rank": "Strain"}, "1350429": {"name": "Cyclobacterium qasimii", "rank": "Species"}, "1402549": {"name": "Pseudomonas aeruginosa BL08", "rank": "Strain"}, "1379697": {"name": "Candidate division ZIXI", "rank": "Species"}, "1379698": {"name": "Candidate division ZIXI bacterium RBG-1", "rank": "Strain"}, "1402546": {"name": "Pseudomonas aeruginosa BL05", "rank": "Strain"}, "1402545": {"name": "Pseudomonas aeruginosa BL04", "rank": "Strain"}, "1402544": {"name": "Pseudomonas aeruginosa BL03", "rank": "Strain"}, "1402543": {"name": "Pseudomonas aeruginosa BL02", "rank": "Strain"}, "1402542": {"name": "Pseudomonas aeruginosa BL01", "rank": "Strain"}, "1402541": {"name": "Pseudomonas aeruginosa Z61", "rank": "Strain"}, "1402540": {"name": "Pseudomonas aeruginosa BWHPSA048", "rank": "Strain"}, "1049945": {"name": "Leptospira kirschneri serovar Grippotyphosa str. Moskva", "rank": "Strain"}, "1310163": {"name": "Campylobacter jejuni subsp. jejuni HN-CJD07035", "rank": "Strain"}, "1187887": {"name": "Nitritalea", "rank": "Genus"}, "1310161": {"name": "Corynebacterium glutamicum MB001", "rank": "Strain"}, "1049943": {"name": "Leptospira kirschneri serovar Grippotyphosa str. 'Brem 127 Duyster'", "rank": "Strain"}, "1281150": {"name": "Escherichia coli HVH 225 (4-1273116)", "rank": "Strain"}, "71657": {"name": "Lonsdalea quercina", "rank": "Species"}, "71655": {"name": "Brenneria", "rank": "Genus"}, "1422463": {"name": "Staphylococcus aureus VET0150R", "rank": "Strain"}, "545626": {"name": "Planktothrix prolifica NIVA-CYA 406", "rank": "Strain"}, "1439141": {"name": "Streptococcus pyogenes ABC020046264", "rank": "Strain"}, "130760": {"name": "Influenza A virus (A/Hong Kong/1073/99(H9N2))", "rank": "Strain"}, "1284679": {"name": "Actinomyces urogenitalis S6-C4", "rank": "Strain"}, "1284678": {"name": "Unclassified Clostridiales Family XIII. Incertae Sedis", "rank": "No rank"}, "573993": {"name": "Chaetoceros socialis f. radians RNA virus 01", "rank": "Species"}, "1281157": {"name": "Escherichia coli KOEGE 32 (66a)", "rank": "Strain"}, "1160507": {"name": "Saccharomyces arboricola H-6", "rank": "Strain"}, "1052844": {"name": "Parcubacteria bacterium SCGC AAA040-L21", "rank": "Species"}, "1052841": {"name": "Aigarchaeota archaeon JGI 0000001-H6", "rank": "Species"}, "58103": {"name": "Leishmania RNA virus 1 - 1", "rank": "Species"}, "1052848": {"name": "Parcubacteria bacterium SCGC AAA036-E14", "rank": "Species"}, "904795": {"name": "Staphylococcus aureus subsp. aureus CO-23", "rank": "Strain"}, "419186": {"name": "Natrinema gari", "rank": "Species"}, "1271528": {"name": "Propionibacterium acnes HL201PA1", "rank": "Strain"}, "1281155": {"name": "Escherichia coli KOEGE 10 (25a)", "rank": "Strain"}, "1001734": {"name": "Mycobacterium abscessus 5S-1215", "rank": "Strain"}, "1397282": {"name": "Pseudomonas sp. PH1b", "rank": "Species"}, "1397280": {"name": "Pseudomonas sp. H1h", "rank": "Species"}, "1397285": {"name": "Serratia sp. H1w", "rank": "Species"}, "1397284": {"name": "Serratia sp. H1n", "rank": "Species"}, "1094168": {"name": "Klebsiella pneumoniae subsp. pneumoniae KPNIH8", "rank": "Strain"}, "1094169": {"name": "Klebsiella pneumoniae subsp. pneumoniae KPNIH9", "rank": "Strain"}, "1126928": {"name": "Escherichia coli C82_11", "rank": "Strain"}, "1126929": {"name": "Escherichia coli C824_10", "rank": "Strain"}, "1126924": {"name": "Escherichia coli C796_10", "rank": "Strain"}, "1126925": {"name": "Escherichia coli C799_92", "rank": "Strain"}, "1408226": {"name": "Vagococcus lutrae LBD1", "rank": "Strain"}, "1126927": {"name": "Escherichia coli C807_09", "rank": "Strain"}, "1094167": {"name": "Klebsiella pneumoniae subsp. pneumoniae KPNIH7", "rank": "Strain"}, "1435983": {"name": "Burkholderia pseudomallei MSHR332", "rank": "Strain"}, "1408223": {"name": "Rhizobium leguminosarum bv. phaseoli CCGM1", "rank": "Strain"}, "1256199": {"name": "Lactobacillus paracasei subsp. paracasei Lpp74", "rank": "Strain"}, "1256198": {"name": "Lactobacillus paracasei subsp. paracasei Lpp70", "rank": "Strain"}, "1398958": {"name": "Acinetobacter baumannii UH16008", "rank": "Strain"}, "1398959": {"name": "Acinetobacter baumannii UH16108", "rank": "Strain"}, "1398956": {"name": "Acinetobacter baumannii UH14508", "rank": "Strain"}, "1398957": {"name": "Acinetobacter baumannii UH15208", "rank": "Strain"}, "1398954": {"name": "Acinetobacter baumannii UH12808", "rank": "Strain"}, "1398955": {"name": "Acinetobacter baumannii UH13908", "rank": "Strain"}, "1256197": {"name": "Lactobacillus paracasei subsp. paracasei Lpp229", "rank": "Strain"}, "1256196": {"name": "Lactobacillus paracasei subsp. paracasei Lpp219", "rank": "Strain"}, "1398950": {"name": "Acinetobacter baumannii UH11608", "rank": "Strain"}, "1398951": {"name": "Acinetobacter baumannii UH12208", "rank": "Strain"}, "1235460": {"name": "Salmonella enterica subsp. enterica serovar Thompson str. 2010K-1863", "rank": "Strain"}, "1235461": {"name": "Sinorhizobium meliloti GR4", "rank": "Strain"}, "1089551": {"name": "Geminicoccus roseus DSM 18922", "rank": "Strain"}, "1089550": {"name": "Salisaeta longa DSM 21114", "rank": "Strain"}, "1089553": {"name": "Thermacetogenium phaeum DSM 12270", "rank": "Strain"}, "1089552": {"name": "Rhodovibrio salinarum DSM 9154", "rank": "Strain"}, "1343063": {"name": "Klebsiella pneumoniae subsp. pneumoniae UKKV901664", "rank": "Strain"}, "1343064": {"name": "Staphylococcus aureus subsp. aureus ST772-MRSA-V", "rank": "Strain"}, "942165": {"name": "Pseudomonas phage phiIBB-PF7A", "rank": "Species"}, "138982": {"name": "Potato latent virus", "rank": "Species"}, "1428454": {"name": "Clostridium pasteurianum NRRL B-598", "rank": "Strain"}, "575599": {"name": "Lactobacillus fermentum 28-3-CHN", "rank": "Strain"}, "575598": {"name": "Lactobacillus crispatus SJ-3C-US", "rank": "Strain"}, "403181": {"name": "Haloferax mucosum", "rank": "Species"}, "575593": {"name": "Lachnospiraceae oral taxon 107 str. F0167", "rank": "Strain"}, "575591": {"name": "Brucella abortus NCTC 8038", "rank": "Strain"}, "575590": {"name": "Bacteroidetes oral taxon 274 str. F0058", "rank": "Strain"}, "575597": {"name": "Lactobacillus crispatus MV-3A-US", "rank": "Strain"}, "575596": {"name": "Lactobacillus crispatus MV-1A-US", "rank": "Strain"}, "575595": {"name": "Lactobacillus crispatus 125-2-CHN", "rank": "Strain"}, "575594": {"name": "Lactobacillus coleohominis 101-4-CHN", "rank": "Strain"}, "1325953": {"name": "Mycobacterium phage PegLeg", "rank": "Species"}, "1216472": {"name": "Bat hepevirus", "rank": "Species"}, "1566868": {"name": "Eimeria tenella RNA virus 1", "rank": "Species"}, "1529056": {"name": "Penaeus monodon nudivirus", "rank": "Species"}, "406124": {"name": "Bacillus sp. m3-13", "rank": "Species"}, "1408889": {"name": "Clostridium tyrobutyricum DIVETGP", "rank": "Strain"}, "1281023": {"name": "Escherichia coli HVH 86 (4-7026218)", "rank": "Strain"}, "1408880": {"name": "Borrelia burgdorferi IPT132", "rank": "Strain"}, "1408881": {"name": "Borrelia burgdorferi IPT137", "rank": "Strain"}, "1408882": {"name": "Borrelia burgdorferi IPT141", "rank": "Strain"}, "349124": {"name": "Halorhodospira halophila SL1", "rank": "Strain"}, "349123": {"name": "Lactobacillus reuteri 100-23", "rank": "Strain"}, "1408885": {"name": "Borrelia afzelii IPT138", "rank": "Strain"}, "1408887": {"name": "Brucella canis str. Oliveri", "rank": "Strain"}, "1178482": {"name": "Halomonas sp. BJGMM-B45", "rank": "Species"}, "444862": {"name": "Prochlorococcus phage P-RSM4", "rank": "Species"}, "145856": {"name": "Human picobirnavirus", "rank": "Species"}, "1145179": {"name": "Neisseria meningitidis 2005172", "rank": "Strain"}, "1231048": {"name": "Pseudomonas phage vB_PaeM_C2-10_Ab1", "rank": "Species"}, "1448445": {"name": "Mycobacterium tuberculosis TKK_03_0111", "rank": "Strain"}, "1492737": {"name": "Flavobacterium sp. EM1308", "rank": "Species"}, "134632": {"name": "American plum line pattern virus", "rank": "Species"}, "189778": {"name": "Nitrospirales", "rank": "Order"}, "189779": {"name": "Nitrospiraceae", "rank": "Family"}, "189774": {"name": "Unclassified Chloroflexi (miscellaneous)", "rank": "No rank"}, "189775": {"name": "Thermomicrobia", "rank": "Class"}, "189776": {"name": "Thermomicrobiales", "rank": "Order"}, "189777": {"name": "Thermomicrobiaceae", "rank": "Family"}, "189770": {"name": "Chrysiogenaceae", "rank": "Family"}, "189772": {"name": "Herpetosiphonales", "rank": "Order"}, "189773": {"name": "Herpetosiphonaceae", "rank": "Family"}, "1005487": {"name": "Escherichia coli PA2", "rank": "Strain"}, "1005486": {"name": "Escherichia coli NE098", "rank": "Strain"}, "1448529": {"name": "Mycobacterium tuberculosis TKK_05SA_0014", "rank": "Strain"}, "1448528": {"name": "Mycobacterium tuberculosis TKK_05SA_0012", "rank": "Strain"}, "1005483": {"name": "Escherichia coli FRIK920", "rank": "Strain"}, "1005482": {"name": "Escherichia coli FRIK523", "rank": "Strain"}, "68335": {"name": "Coprothermobacter", "rank": "Genus"}, "1005480": {"name": "Escherichia coli FRIK1997", "rank": "Strain"}, "1448523": {"name": "Mycobacterium tuberculosis TKK_05MA_2008", "rank": "Strain"}, "1009709": {"name": "Alpha proteobacterium SCGC AAA536-K22", "rank": "Species"}, "1448521": {"name": "Mycobacterium tuberculosis TKK_05MA_0058", "rank": "Strain"}, "357808": {"name": "Roseiflexus sp. RS-1", "rank": "Species"}, "1448527": {"name": "Mycobacterium tuberculosis TKK_05SA_0011", "rank": "Strain"}, "1448526": {"name": "Mycobacterium tuberculosis TKK_05SA_0010", "rank": "Strain"}, "1005489": {"name": "Escherichia coli PA4", "rank": "Strain"}, "1448524": {"name": "Mycobacterium tuberculosis TKK_05MA_2015", "rank": "Strain"}, "1154971": {"name": "Streptococcus agalactiae GB01004", "rank": "Strain"}, "391606": {"name": "Caldanaerobacter subterraneus subsp. pacificus DSM 12653", "rank": "Strain"}, "401472": {"name": "Corynebacterium ureicelerivorans", "rank": "Species"}, "401473": {"name": "Bifidobacterium dentium Bd1", "rank": "Strain"}, "391603": {"name": "Flavobacteriales bacterium ALC-1", "rank": "Species"}, "1463908": {"name": "Streptomyces sp. NRRL S-455", "rank": "Species"}, "391601": {"name": "Stenotrophomonas sp. SKA14", "rank": "Species"}, "391600": {"name": "Brevundimonas sp. BAL3", "rank": "Species"}, "44887": {"name": "Unclassified Oscillatoriales", "rank": "No rank"}, "708248": {"name": "Mycoplasma suis KI3806", "rank": "Strain"}, "1463909": {"name": "Streptomyces sp. NRRL S-474", "rank": "Species"}, "1500261": {"name": "Methylibium sp. CF059", "rank": "Species"}, "1492738": {"name": "Flavobacterium sp. EM1321", "rank": "Species"}, "1247963": {"name": "Parvularcula oceani", "rank": "Species"}, "717227": {"name": "Treponema primitia ZAS-1", "rank": "Strain"}, "856846": {"name": "Salinivibrio socompensis S34", "rank": "Strain"}, "404404": {"name": "Coleus vein necrosis virus", "rank": "Species"}, "649715": {"name": "Yersinia pestis G3768", "rank": "Strain"}, "1101440": {"name": "Escherichia coli O103:H25 str. NIPH-11060424", "rank": "Strain"}, "1213729": {"name": "Staphylococcus aureus M0871", "rank": "Strain"}, "1213728": {"name": "Staphylococcus aureus M0831", "rank": "Strain"}, "1213723": {"name": "Staphylococcus aureus M0663", "rank": "Strain"}, "1213722": {"name": "Staphylococcus aureus M0660", "rank": "Strain"}, "1213721": {"name": "Staphylococcus aureus M0648", "rank": "Strain"}, "1213720": {"name": "Stomatobaculum", "rank": "Genus"}, "1213727": {"name": "Staphylococcus aureus M0822", "rank": "Strain"}, "1213726": {"name": "Staphylococcus aureus M0792", "rank": "Strain"}, "1213725": {"name": "Staphylococcus aureus M0695", "rank": "Strain"}, "1213724": {"name": "Staphylococcus aureus M0673", "rank": "Strain"}, "203492": {"name": "Fusobacteriaceae", "rank": "Family"}, "203490": {"name": "Fusobacteriia", "rank": "Class"}, "203491": {"name": "Fusobacteriales", "rank": "Order"}, "563191": {"name": "Acidaminococcus sp. D21", "rank": "Species"}, "563192": {"name": "Bilophila wadsworthia 3_1_6", "rank": "Strain"}, "563193": {"name": "Parabacteroides sp. D13", "rank": "Species"}, "131111": {"name": "Actinomyces turicensis", "rank": "Species"}, "225979": {"name": "Staphylococcus phage phiN315", "rank": "Species"}, "866768": {"name": "Escherichia coli 'BL21-Gold(DE3)pLysS AG'", "rank": "Strain"}, "1446473": {"name": "Paracoccus yeei ATCC BAA-599", "rank": "Strain"}, "1446475": {"name": "Halomonas zincidurans B6", "rank": "Strain"}, "1120953": {"name": "Aestuariibacter salexigens DSM 15300", "rank": "Strain"}, "1120952": {"name": "Aerococcus urinaeequi DSM 20341", "rank": "Strain"}, "1120951": {"name": "Aequorivita capsosiphonis DSM 23843", "rank": "Strain"}, "1120950": {"name": "Actinopolymorpha alba DSM 45243", "rank": "Strain"}, "1120957": {"name": "Aggregatibacter actinomycetemcomitans DSM 8324", "rank": "Strain"}, "1094941": {"name": "Sphingomonas sp. JGI 0001002-C18", "rank": "Species"}, "1094942": {"name": "Sphingomonas sp. JGI 0001002-D21", "rank": "Species"}, "1120954": {"name": "Aestuariimicrobium kwangyangense DSM 21549", "rank": "Strain"}, "584892": {"name": "Bacillus phage Bcp1", "rank": "Species"}, "1120959": {"name": "Agromyces italicus DSM 16388", "rank": "Strain"}, "1120958": {"name": "Agrococcus lahaulensis DSM 17612", "rank": "Strain"}, "1094948": {"name": "Rhizobium sp. JGI 0001003-M22", "rank": "Species"}, "638358": {"name": "Eragrostis curvula streak virus", "rank": "Species"}, "1047038": {"name": "Aminicenantes bacterium SCGC AAA255-A06", "rank": "Species"}, "10266": {"name": "Sheeppox virus", "rank": "Species"}, "1047035": {"name": "Aminicenantes bacterium SCGC AAA252-O19", "rank": "Species"}, "10264": {"name": "Pigeonpox virus", "rank": "Species"}, "10265": {"name": "Capripoxvirus", "rank": "Genus"}, "1047030": {"name": "Aminicenantes bacterium SCGC AAA252-N06", "rank": "Species"}, "1047031": {"name": "Aminicenantes bacterium SCGC AAA252-N07", "rank": "Species"}, "10260": {"name": "Avipoxvirus", "rank": "Genus"}, "10261": {"name": "Fowlpox virus", "rank": "Species"}, "319705": {"name": "Mycobacterium abscessus subsp. bolletii", "rank": "Subspecies"}, "1120045": {"name": "Rhizobium grahamii", "rank": "Species"}, "43229": {"name": "Capronia coronata", "rank": "Species"}, "319700": {"name": "Streptococcus pyogenes serotype M28", "rank": "Strain"}, "319701": {"name": "Streptococcus pyogenes MGAS6180", "rank": "Strain"}, "764030": {"name": "Pigeon adenovirus 1", "rank": "Strain"}, "451442": {"name": "Rhizophydiales", "rank": "Order"}, "1033978": {"name": "Plectosphaerellaceae", "rank": "Family"}, "226991": {"name": "Cyphellophora", "rank": "Genus"}, "388259": {"name": "Natronorubrum sulfidifaciens", "rank": "Species"}, "184064": {"name": "Thermodesulfobium narugense", "rank": "Species"}, "413497": {"name": "Cronobacter dublinensis", "rank": "Species"}, "413496": {"name": "Cronobacter", "rank": "Genus"}, "413499": {"name": "Cronobacter dublinensis subsp. lactaridi", "rank": "Subspecies"}, "413498": {"name": "Cronobacter dublinensis subsp. dublinensis", "rank": "Subspecies"}, "10849": {"name": "Enterobacteria phage alpha3", "rank": "Species"}, "1208310": {"name": "Porcine partetravirus", "rank": "Species"}, "262806": {"name": "Jonesia quinghaiensis", "rank": "Species"}, "10842": {"name": "Microvirus", "rank": "Genus"}, "10840": {"name": "Beet curly top virus", "rank": "Species"}, "10841": {"name": "Microviridae", "rank": "Family"}, "1208630": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN001115", "rank": "Strain"}, "1495286": {"name": "Escherichia phage e4/1c", "rank": "Species"}, "10845": {"name": "Enterobacteria phage St-1", "rank": "Species"}, "11135": {"name": "Feline infectious peritonitis virus", "rank": "Strain"}, "11137": {"name": "Human coronavirus 229E", "rank": "Species"}, "1081943": {"name": "Bacillus anthracis str. Heroin Ba4599", "rank": "Strain"}, "1081940": {"name": "Pseudomonas putida B6-2", "rank": "Strain"}, "1043184": {"name": "Blackberry virus E", "rank": "Species"}, "210408": {"name": "Thiorhodococcus drewsii", "rank": "Species"}, "1155131": {"name": "Staphylococcus epidermidis NIH051668", "rank": "Strain"}, "1155130": {"name": "Staphylococcus epidermidis NIH051475", "rank": "Strain"}, "1155133": {"name": "Staphylococcus epidermidis NIH05003", "rank": "Strain"}, "1155132": {"name": "Staphylococcus epidermidis NIH04003", "rank": "Strain"}, "1155135": {"name": "Staphylococcus epidermidis NIH08001", "rank": "Strain"}, "1155134": {"name": "Staphylococcus epidermidis NIH06004", "rank": "Strain"}, "1559979": {"name": "Sulfuricellales", "rank": "Order"}, "723287": {"name": "Anncaliia algerae", "rank": "Species"}, "5644": {"name": "Stereum", "rank": "Genus"}, "54120": {"name": "Methanolacinia petrolearia", "rank": "Species"}, "1498504": {"name": "Tomato leaf curl Barka virus", "rank": "Species"}, "106649": {"name": "Acinetobacter guillouiae", "rank": "Species"}, "106648": {"name": "Acinetobacter bereziniae", "rank": "Species"}, "1160161": {"name": "Brucella abortus NI518", "rank": "Strain"}, "453962": {"name": "Halomonas lutea", "rank": "Species"}, "585035": {"name": "Escherichia coli S88", "rank": "Strain"}, "585034": {"name": "Escherichia coli IAI1", "rank": "Strain"}, "871699": {"name": "Passerivirus A1", "rank": "Strain"}, "1438996": {"name": "Streptococcus pyogenes ABC020006345", "rank": "Strain"}, "868129": {"name": "Prevotella bivia DSM 20514", "rank": "Strain"}, "1438991": {"name": "Streptococcus pyogenes ABC020005887", "rank": "Strain"}, "156978": {"name": "Corynebacterium imitans", "rank": "Species"}, "58842": {"name": "Sagittula", "rank": "Genus"}, "156974": {"name": "Dysgonomonas gadei", "rank": "Species"}, "156973": {"name": "Dysgonomonas", "rank": "Genus"}, "58840": {"name": "Unclassified Rhodobacteraceae", "rank": "No rank"}, "172088": {"name": "Bradyrhizobium sp. th.b2", "rank": "Species"}, "1137264": {"name": "Salinispora arenicola CNT849", "rank": "Strain"}, "1137266": {"name": "Salinispora pacifica CNT855", "rank": "Strain"}, "1137261": {"name": "Salinispora pacifica CNR894", "rank": "Strain"}, "1137260": {"name": "Salinispora pacifica CNR114", "rank": "Strain"}, "1137263": {"name": "Salinispora pacifica CNT569", "rank": "Strain"}, "1137262": {"name": "Salinispora pacifica CNS103", "rank": "Strain"}, "1137269": {"name": "Streptomyces sp. CNH099", "rank": "Species"}, "1137268": {"name": "Nocardiopsis sp. CNT312", "rank": "Species"}, "1330521": {"name": "Enterovirus J", "rank": "Species"}, "1330520": {"name": "Enterovirus F", "rank": "Species"}, "871963": {"name": "Desulfitobacterium dichloroeliminans LMG P-21439", "rank": "Strain"}, "1330525": {"name": "Enterococcus raffinosus cftri2200", "rank": "Strain"}, "1330524": {"name": "Salivirus A", "rank": "Species"}, "871968": {"name": "Desulfitobacterium metallireducens DSM 15288", "rank": "Strain"}, "1036177": {"name": "Lactobacillus plantarum subsp. plantarum NC8", "rank": "Strain"}, "1036171": {"name": "Paenibacillus polymyxa ATCC 842", "rank": "Strain"}, "1036172": {"name": "Arcobacter butzleri 7h1h", "rank": "Strain"}, "760838": {"name": "Streptococcus pneumoniae GA47461", "rank": "Strain"}, "760839": {"name": "Streptococcus pneumoniae GA47502", "rank": "Strain"}, "760830": {"name": "Streptococcus pneumoniae GA47210", "rank": "Strain"}, "760831": {"name": "Streptococcus pneumoniae GA47281", "rank": "Strain"}, "760832": {"name": "Streptococcus pneumoniae GA47283", "rank": "Strain"}, "760833": {"name": "Streptococcus pneumoniae GA47360", "rank": "Strain"}, "760834": {"name": "Streptococcus pneumoniae GA47368", "rank": "Strain"}, "760835": {"name": "Streptococcus pneumoniae GA47373", "rank": "Strain"}, "760837": {"name": "Streptococcus pneumoniae GA47388", "rank": "Strain"}, "20": {"name": "Phenylobacterium", "rank": "Genus"}, "1134509": {"name": "Bartonella henselae str. Zeus", "rank": "Strain"}, "1134508": {"name": "Bartonella henselae JK 53", "rank": "Strain"}, "1300028": {"name": "Gyalolechia", "rank": "Genus"}, "1134505": {"name": "Bartonella quintana JK 63", "rank": "Strain"}, "1134504": {"name": "Bartonella quintana JK 56", "rank": "Strain"}, "1134507": {"name": "Bartonella quintana JK 19", "rank": "Strain"}, "1134506": {"name": "Bartonella quintana JK 31", "rank": "Strain"}, "1134501": {"name": "Bartonella quintana JK 39", "rank": "Strain"}, "1134503": {"name": "Bartonella quintana JK 68", "rank": "Strain"}, "1134502": {"name": "Bartonella quintana JK 67", "rank": "Strain"}, "996802": {"name": "Leptospira interrogans str. 2002000624", "rank": "Strain"}, "996803": {"name": "Leptospira interrogans str. 2002000626", "rank": "Strain"}, "996804": {"name": "Leptospira weilii str. 2006001855", "rank": "Strain"}, "996805": {"name": "Leptospira santarosai str. 2000030832", "rank": "Strain"}, "996808": {"name": "Leptospira licerasiae serovar Varillal str. MMD0835", "rank": "Strain"}, "996809": {"name": "Leptospira interrogans serovar Canicola str. HAI0024", "rank": "Strain"}, "129876": {"name": "Siadenovirus", "rank": "Genus"}, "511051": {"name": "Caldisericum exile AZM16c01", "rank": "Strain"}, "152180": {"name": "Ahrensia", "rank": "Genus"}, "935849": {"name": "Paracoccus sp. J55", "rank": "Species"}, "888051": {"name": "Actinomyces sp. oral taxon 178 str. F0338", "rank": "Strain"}, "888050": {"name": "Actinomyces cardiffensis F0333", "rank": "Strain"}, "1071505": {"name": "Mycobacterium phage GUmbie", "rank": "Species"}, "1071504": {"name": "Mycobacterium phage Turbido", "rank": "Species"}, "1071506": {"name": "Mycobacterium phage RidgeCB", "rank": "Species"}, "1160201": {"name": "Brucella abortus levi gila", "rank": "Strain"}, "1071503": {"name": "Mycobacterium phage Trixie", "rank": "Species"}, "1160200": {"name": "Brucella abortus 65/157", "rank": "Strain"}, "1513188": {"name": "Lepidopteran ambidensovirus 1", "rank": "Species"}, "1513189": {"name": "Orthopteran ambidensovirus 1", "rank": "Species"}, "1513186": {"name": "Dipteran ambidensovirus 1", "rank": "Species"}, "225849": {"name": "Shewanella piezotolerans WP3", "rank": "Strain"}, "1513184": {"name": "Blattodean ambidensovirus 1", "rank": "Species"}, "1513185": {"name": "Blattodean ambidensovirus 2", "rank": "Species"}, "1160206": {"name": "Brucella abortus 877/67", "rank": "Strain"}, "1123360": {"name": "Thalassobacter arenae DSM 19593", "rank": "Strain"}, "207656": {"name": "Bacillus phage phiNIT1", "rank": "Species"}, "1123365": {"name": "Thalassospira lucentensis MCCC 1A00383 = DSM 14000", "rank": "Strain"}, "1123364": {"name": "Thalassobaculum salexigens DSM 19539", "rank": "Strain"}, "1123367": {"name": "Thauera linaloolentis 47Lol = DSM 12138", "rank": "Strain"}, "34425": {"name": "Mitosporic Ceratobasidiaceae", "rank": "No rank"}, "83455": {"name": "Myxococcus stipitatus", "rank": "Species"}, "1123368": {"name": "Thermithiobacillus tepidarius DSM 3134", "rank": "Strain"}, "1410933": {"name": "Salmonella enterica subsp. enterica serovar Muenster str. CFSAN004344", "rank": "Strain"}, "1160204": {"name": "Brucella abortus LEVI237", "rank": "Strain"}, "83451": {"name": "Cystobacter violaceus", "rank": "Species"}, "1410937": {"name": "Salmonella enterica subsp. enterica serovar Typhimurium var. 5- str. CFSAN004345", "rank": "Strain"}, "1410936": {"name": "Salmonella enterica subsp. enterica serovar Montevideo str. CFSAN004346", "rank": "Strain"}, "1196095": {"name": "Gilliamella apicola", "rank": "Species"}, "1196094": {"name": "Snodgrassella alvi wkB2", "rank": "Strain"}, "580254": {"name": "Raphanus sativus cryptic virus 3", "rank": "Species"}, "1263492": {"name": "Curvularia lunata CX-3", "rank": "Strain"}, "722438": {"name": "Mycoplasma pneumoniae FH", "rank": "Strain"}, "57499": {"name": "Kytococcus", "rank": "Genus"}, "57494": {"name": "Nesterenkonia", "rank": "Genus"}, "362663": {"name": "Escherichia coli 536", "rank": "Strain"}, "271420": {"name": "Pseudomonas xanthomarina", "rank": "Species"}, "795359": {"name": "Thermodesulfobacterium geofontis OPF15", "rank": "Strain"}, "57493": {"name": "Kocuria", "rank": "Genus"}, "572545": {"name": "Ruminiclostridium thermocellum DSM 2360", "rank": "Strain"}, "496833": {"name": "Mycoplasma fermentans PG18", "rank": "Strain"}, "572544": {"name": "Ilyobacter polytropus DSM 2926", "rank": "Strain"}, "572547": {"name": "Aminobacterium colombiense DSM 12261", "rank": "Strain"}, "377615": {"name": "Thermobacillus composti", "rank": "Species"}, "572546": {"name": "Archaeoglobus profundus DSM 5631", "rank": "Strain"}, "467481": {"name": "Azospirillum phage Cd", "rank": "Species"}, "399387": {"name": "Tomato leaf curl Hsinchu virus", "rank": "Species"}, "33154": {"name": "Opisthokonta", "rank": "No rank"}, "1284708": {"name": "Clostridiales bacterium S7-1-4", "rank": "Species"}, "1349785": {"name": "Tenacibaculum maritimum NBRC 15946", "rank": "Strain"}, "1349789": {"name": "Sulfurospirillum arsenophilum NBRC 109478", "rank": "Strain"}, "1349788": {"name": "Sulfurospirillum cavolei NBRC 109482", "rank": "Strain"}, "626929": {"name": "Bacteroides clarus", "rank": "Species"}, "322865": {"name": "Leptolyngbya valderiana", "rank": "Species"}, "322866": {"name": "Leptolyngbya valderiana BDU 20041", "rank": "Strain"}, "1075085": {"name": "Chlamydia trachomatis L2b/Canada1", "rank": "Strain"}, "1075086": {"name": "Chlamydia trachomatis L2b/Canada2", "rank": "Strain"}, "1075087": {"name": "Chlamydia trachomatis L1/1322/p2", "rank": "Strain"}, "1075088": {"name": "Corynebacterium glutamicum S9114", "rank": "Strain"}, "1075089": {"name": "Pasteurella multocida 36950", "rank": "Strain"}, "1393724": {"name": "Staphylococcus aureus M0759", "rank": "Strain"}, "1393725": {"name": "Staphylococcus aureus M0760", "rank": "Strain"}, "1393726": {"name": "Staphylococcus aureus M0761", "rank": "Strain"}, "1393727": {"name": "Staphylococcus aureus M0762", "rank": "Strain"}, "1393720": {"name": "Staphylococcus aureus M0754", "rank": "Strain"}, "1393721": {"name": "Staphylococcus aureus M0755", "rank": "Strain"}, "1393722": {"name": "Staphylococcus aureus M0757", "rank": "Strain"}, "1393723": {"name": "Staphylococcus aureus M0758", "rank": "Strain"}, "936061": {"name": "Omegapapillomavirus", "rank": "Genus"}, "1393728": {"name": "Staphylococcus aureus M0763", "rank": "Strain"}, "1393729": {"name": "Staphylococcus aureus M0764", "rank": "Strain"}, "1562701": {"name": "Bacterium endosymbiont of Mortierella elongata FMR23-6", "rank": "Species"}, "194699": {"name": "Bordetella phage BPP-1", "rank": "Species"}, "1001601": {"name": "Leptospira interrogans serovar Zanoni str. LT2156", "rank": "Strain"}, "1001603": {"name": "Leptospira interrogans serovar Copenhageni str. Fiocruz R154", "rank": "Strain"}, "1001602": {"name": "Leptospira interrogans serovar Copenhageni str. Fiocruz LV2756C6", "rank": "Strain"}, "555461": {"name": "Mycobacterium tuberculosis '98-R604 INH-RIF-EM'", "rank": "Strain"}, "945083": {"name": "Edwardsiella phage eiAU", "rank": "Species"}, "1397913": {"name": "Mycobacterium tuberculosis TKK_04_0017", "rank": "Strain"}, "1397912": {"name": "Mycobacterium tuberculosis TKK_04_0015", "rank": "Strain"}, "1397911": {"name": "Mycobacterium tuberculosis TKK_04_0014", "rank": "Strain"}, "592377": {"name": "Kocuria atrinae", "rank": "Species"}, "42": {"name": "Cystobacter", "rank": "Genus"}, "1397916": {"name": "Mycobacterium tuberculosis TKK_04_0021", "rank": "Strain"}, "1397915": {"name": "Mycobacterium tuberculosis TKK_04_0019", "rank": "Strain"}, "41": {"name": "Stigmatella aurantiaca", "rank": "Species"}, "1397919": {"name": "Mycobacterium tuberculosis TKK_04_0024", "rank": "Strain"}, "1397918": {"name": "Mycobacterium tuberculosis TKK_04_0023", "rank": "Strain"}, "1302627": {"name": "Listeria monocytogenes SHL007", "rank": "Strain"}, "49": {"name": "Polyangiaceae", "rank": "Family"}, "292792": {"name": "Canis familiaris papillomavirus 2", "rank": "Strain"}, "1416614": {"name": "Gloeobacter kilaueensis", "rank": "Species"}, "1411647": {"name": "Morganella morganii IS15", "rank": "Strain"}, "1310578": {"name": "Acinetobacter baumannii 34001", "rank": "Strain"}, "89373": {"name": "Cytophagaceae", "rank": "Family"}, "1310574": {"name": "Acinetobacter baumannii 1042969-1265", "rank": "Strain"}, "1310575": {"name": "Acinetobacter baumannii 6935", "rank": "Strain"}, "760011": {"name": "Sphaerochaeta coccoides DSM 17374", "rank": "Strain"}, "1310570": {"name": "Acinetobacter baumannii 1046051", "rank": "Strain"}, "1310571": {"name": "Acinetobacter baumannii 1032241", "rank": "Strain"}, "54010": {"name": "Pseudonocardia asaccharolytica", "rank": "Species"}, "1145118": {"name": "Helicobacter pylori R056a", "rank": "Strain"}, "1145119": {"name": "Neisseria meningitidis 69155", "rank": "Strain"}, "119864": {"name": "Marinomonas mediterranea", "rank": "Species"}, "1145112": {"name": "Helicobacter pylori R32b", "rank": "Strain"}, "1145113": {"name": "Helicobacter pylori R036d", "rank": "Strain"}, "1145110": {"name": "Helicobacter pylori R018c", "rank": "Strain"}, "1145111": {"name": "Helicobacter pylori R030b", "rank": "Strain"}, "1145116": {"name": "Helicobacter pylori R046Wa", "rank": "Strain"}, "1145117": {"name": "Helicobacter pylori R055a", "rank": "Strain"}, "1145114": {"name": "Helicobacter pylori R037c", "rank": "Strain"}, "1145115": {"name": "Helicobacter pylori R038b", "rank": "Strain"}, "167927": {"name": "Sugarcane striate mosaic-associated virus", "rank": "Species"}, "1448729": {"name": "Mycobacterium tuberculosis M1929", "rank": "Strain"}, "1448728": {"name": "Mycobacterium tuberculosis M1928", "rank": "Strain"}, "1046624": {"name": "Lactococcus lactis subsp. lactis IO-1", "rank": "Strain"}, "80634": {"name": "Coniophoraceae", "rank": "Family"}, "1448720": {"name": "Mycobacterium tuberculosis M1822", "rank": "Strain"}, "1448723": {"name": "Mycobacterium tuberculosis M1895", "rank": "Strain"}, "1448722": {"name": "Mycobacterium tuberculosis M1893", "rank": "Strain"}, "1448725": {"name": "Mycobacterium tuberculosis M1913", "rank": "Strain"}, "1448724": {"name": "Mycobacterium tuberculosis M1906", "rank": "Strain"}, "1448727": {"name": "Mycobacterium tuberculosis M1926", "rank": "Strain"}, "1448726": {"name": "Mycobacterium tuberculosis M1914", "rank": "Strain"}, "359303": {"name": "Shewanella loihica", "rank": "Species"}, "1053248": {"name": "Bacillus cereus VDM034", "rank": "Strain"}, "1053249": {"name": "Bacillus cereus VDM053", "rank": "Strain"}, "1053246": {"name": "Bacillus cereus VDM019", "rank": "Strain"}, "1053247": {"name": "Bacillus cereus VDM022", "rank": "Strain"}, "1053244": {"name": "Bacillus cereus VD200", "rank": "Strain"}, "1053245": {"name": "Bacillus cereus VD214", "rank": "Strain"}, "1053242": {"name": "Bacillus cereus VD184", "rank": "Strain"}, "871585": {"name": "Acinetobacter calcoaceticus PHEA-2", "rank": "Strain"}, "1053240": {"name": "Bacillus cereus VD166", "rank": "Strain"}, "1053241": {"name": "Bacillus cereus VD169", "rank": "Strain"}, "103441": {"name": "Pseudonocardia spinosispora", "rank": "Species"}, "103442": {"name": "Triatoma virus", "rank": "Species"}, "103449": {"name": "Vavraia culicis", "rank": "Species"}, "1388320": {"name": "Staphylococcus aureus M0482", "rank": "Strain"}, "1388321": {"name": "Staphylococcus aureus M0483", "rank": "Strain"}, "1388322": {"name": "Staphylococcus aureus M0484", "rank": "Strain"}, "1388323": {"name": "Staphylococcus aureus M0486", "rank": "Strain"}, "1388324": {"name": "Staphylococcus aureus M0487", "rank": "Strain"}, "1388325": {"name": "Staphylococcus aureus M0488", "rank": "Strain"}, "1388326": {"name": "Staphylococcus aureus M0490", "rank": "Strain"}, "1388327": {"name": "Staphylococcus aureus M0491", "rank": "Strain"}, "1388328": {"name": "Staphylococcus aureus M0495", "rank": "Strain"}, "1388329": {"name": "Staphylococcus aureus M0496", "rank": "Strain"}, "1427218": {"name": "Mycobacterium tuberculosis XTB13-127", "rank": "Strain"}, "159743": {"name": "Paenibacillus terrae", "rank": "Species"}, "1151423": {"name": "Peptoclostridium difficile P48", "rank": "Strain"}, "1511879": {"name": "Gorilla bocavirus", "rank": "Strain"}, "1151421": {"name": "Peptoclostridium difficile P45", "rank": "Strain"}, "128941": {"name": "Tomato curly stunt virus", "rank": "Species"}, "1151427": {"name": "Peptoclostridium difficile P53", "rank": "Strain"}, "1151426": {"name": "Peptoclostridium difficile P51", "rank": "Strain"}, "1151425": {"name": "Peptoclostridium difficile P50", "rank": "Strain"}, "519989": {"name": "Ectothiorhodospira sp. PHS-1", "rank": "Species"}, "1511871": {"name": "Primate bocaparvovirus 1", "rank": "Species"}, "196765": {"name": "Cladonia macilenta", "rank": "Species"}, "1151428": {"name": "Peptoclostridium difficile P59", "rank": "Strain"}, "1511874": {"name": "Ungulate bocaparvovirus 2", "rank": "Species"}, "1511877": {"name": "Ungulate bocaparvovirus 5", "rank": "Species"}, "1418346": {"name": "Staphylococcus aureus T52649", "rank": "Strain"}, "1418347": {"name": "Staphylococcus aureus T55950", "rank": "Strain"}, "1418344": {"name": "Staphylococcus aureus T49201", "rank": "Strain"}, "1418345": {"name": "Staphylococcus aureus T52642", "rank": "Strain"}, "1418342": {"name": "Staphylococcus aureus T47161", "rank": "Strain"}, "1418343": {"name": "Staphylococcus aureus T49198", "rank": "Strain"}, "1418340": {"name": "Staphylococcus aureus T45836", "rank": "Strain"}, "1418341": {"name": "Staphylococcus aureus T45839", "rank": "Strain"}, "1418348": {"name": "Staphylococcus aureus T55954", "rank": "Strain"}, "1418349": {"name": "Staphylococcus aureus T59618", "rank": "Strain"}, "188626": {"name": "Dermacoccus sp. Ellin185", "rank": "Species"}, "1454008": {"name": "Aeromonas sp. HZM", "rank": "Species"}, "1454001": {"name": "Candidatus Accumulibacter sp. SK-12", "rank": "Species"}, "1454000": {"name": "Candidatus Accumulibacter sp. SK-11", "rank": "Species"}, "1454003": {"name": "Candidatus Accumulibacter sp. BA-92", "rank": "Species"}, "1454005": {"name": "Candidatus Accumulibacter sp. BA-94", "rank": "Species"}, "1454004": {"name": "Candidatus Accumulibacter sp. BA-93", "rank": "Species"}, "1404244": {"name": "Corynebacterium glycinophilum", "rank": "Species"}, "1404245": {"name": "Corynebacterium glycinophilum AJ 3170", "rank": "Strain"}, "195907": {"name": "Gillisia limnaea", "rank": "Species"}, "1391179": {"name": "Mycobacterium phage Bruin", "rank": "Species"}, "1206776": {"name": "Serratia plymuthica A30", "rank": "Strain"}, "1206777": {"name": "Pseudomonas sp. Lz4W", "rank": "Species"}, "1206774": {"name": "Oenococcus oeni AWRIB568", "rank": "Strain"}, "1206775": {"name": "Oenococcus oeni AWRIB576", "rank": "Strain"}, "1206772": {"name": "Oenococcus oeni AWRIB548", "rank": "Strain"}, "1206773": {"name": "Oenococcus oeni AWRIB553", "rank": "Strain"}, "1206770": {"name": "Oenococcus oeni AWRIB419", "rank": "Strain"}, "1206771": {"name": "Oenococcus oeni AWRIB422", "rank": "Strain"}, "360920": {"name": "Pseudomonas savastanoi pv. savastanoi", "rank": "Strain"}, "47880": {"name": "Pseudomonas fulva", "rank": "Species"}, "1052197": {"name": "Calescamantes", "rank": "Phylum"}, "109760": {"name": "Spizellomyces punctatus", "rank": "Species"}, "1509404": {"name": "Rhizobium sp. R2-400B4", "rank": "Species"}, "1509405": {"name": "Rhizobium sp. R1-200B4", "rank": "Species"}, "1227263": {"name": "Actinomyces sp. oral taxon 877", "rank": "Species"}, "1227262": {"name": "Actinomyces johnsonii F0510", "rank": "Strain"}, "1227265": {"name": "Capnocytophaga sp. oral taxon 863", "rank": "Species"}, "1227264": {"name": "Actinomyces sp. oral taxon 877 str. F0543", "rank": "Strain"}, "1227267": {"name": "Leptotrichia sp. oral taxon 879", "rank": "Species"}, "1227266": {"name": "Capnocytophaga sp. oral taxon 863 str. F0517", "rank": "Strain"}, "1227269": {"name": "Porphyromonas gingivalis F0568", "rank": "Strain"}, "1227268": {"name": "Leptotrichia sp. oral taxon 879 str. F0557", "rank": "Strain"}, "935705": {"name": "Salmonella enterica subsp. enterica serovar Thompson str. ATCC 8391", "rank": "Strain"}, "935702": {"name": "Salmonella enterica subsp. enterica serovar Agona str. ATCC 51957", "rank": "Strain"}, "935703": {"name": "Salmonella enterica subsp. enterica serovar Agona str. ATCC BAA-707", "rank": "Strain"}, "105841": {"name": "Anaerostipes caccae", "rank": "Species"}, "1214179": {"name": "Streptococcus suis 6407", "rank": "Strain"}, "1214178": {"name": "Streptococcus suis 92-4172", "rank": "Strain"}, "1214177": {"name": "Streptococcus suis 92-1400", "rank": "Strain"}, "1214176": {"name": "Streptococcus suis 4961", "rank": "Strain"}, "1214175": {"name": "Streptococcus suis 92-1191", "rank": "Strain"}, "1214174": {"name": "Streptococcus suis 89-590", "rank": "Strain"}, "1214173": {"name": "Streptococcus suis 89-5259", "rank": "Strain"}, "1214172": {"name": "Streptococcus suis 89-4109-1", "rank": "Strain"}, "1214171": {"name": "Streptococcus suis 89-3576-3", "rank": "Strain"}, "141863": {"name": "Circular single stranded RNA satellites", "rank": "No rank"}, "1453079": {"name": "Unclassified Babu- and nanovirus-associated alphasatellites", "rank": "No rank"}, "1192560": {"name": "Salmonella enterica subsp. enterica serovar Cubana str. 76814", "rank": "Strain"}, "857132": {"name": "Streptococcus mutans T4", "rank": "Strain"}, "47763": {"name": "Streptomyces lydicus", "rank": "Species"}, "47761": {"name": "Streptomyces ochraceiscleroticus", "rank": "Species"}, "1116220": {"name": "Staphylococcus aureus subsp. aureus VRS7", "rank": "Strain"}, "1116221": {"name": "Staphylococcus aureus subsp. aureus VRS8", "rank": "Strain"}, "1116222": {"name": "Staphylococcus aureus subsp. aureus VRS9", "rank": "Strain"}, "1116223": {"name": "Staphylococcus aureus subsp. aureus VRS10", "rank": "Strain"}, "1116224": {"name": "Staphylococcus aureus subsp. aureus VRS11a", "rank": "Strain"}, "1116225": {"name": "Staphylococcus aureus subsp. aureus VRS11b", "rank": "Strain"}, "1116229": {"name": "Glarea lozoyensis ATCC 20868", "rank": "Strain"}, "267671": {"name": "Leptospira interrogans serovar Copenhageni str. Fiocruz L1-130", "rank": "Strain"}, "1190581": {"name": "Neisseria meningitidis NM2866", "rank": "Strain"}, "1190580": {"name": "Neisseria meningitidis NM3230", "rank": "Strain"}, "361210": {"name": "Unclassified Porphyromonadaceae", "rank": "No rank"}, "180903": {"name": "Pineapple mealybug wilt-associated virus 1", "rank": "Species"}, "1471542": {"name": "Mycobacterium phage MosMoris", "rank": "Species"}, "47490": {"name": "Thermoanaerobacterium aotearoense", "rank": "Species"}, "714359": {"name": "Bacillus thuringiensis BMB171", "rank": "Strain"}, "1283299": {"name": "Conexibacter woesei Iso977N", "rank": "Strain"}, "1363568": {"name": "Unclassified Solirubrobacterales", "rank": "No rank"}, "1406779": {"name": "Acinetobacter phage Petty", "rank": "Species"}, "1283292": {"name": "Pseudomonas sp. URMO17WK12:I4", "rank": "Species"}, "1283293": {"name": "Pseudomonas sp. URIL14HWK12:I6", "rank": "Species"}, "1283291": {"name": "Pseudomonas sp. URMO17WK12:I11", "rank": "Species"}, "1283296": {"name": "Delta proteobacterium JGI 0000059-O15", "rank": "Species"}, "1283297": {"name": "Delta proteobacterium JGI 0000059-J07", "rank": "Species"}, "395019": {"name": "Burkholderia multivorans ATCC 17616", "rank": "Strain"}, "1367443": {"name": "Campylobacter jejuni Cj5", "rank": "Strain"}, "344889": {"name": "Unclassified Erythrovirus", "rank": "No rank"}, "344881": {"name": "Flavobacterium soli", "rank": "Species"}, "344884": {"name": "Algoriphagus terrigena", "rank": "Species"}, "1122175": {"name": "Leucobacter chironomi DSM 19883", "rank": "Strain"}, "1588": {"name": "Lactobacillus hilgardii", "rank": "Species"}, "1589": {"name": "Lactobacillus pentosus", "rank": "Species"}, "1582": {"name": "Lactobacillus casei", "rank": "Species"}, "1583": {"name": "Weissella confusa", "rank": "Species"}, "1580": {"name": "Lactobacillus brevis", "rank": "Species"}, "1581": {"name": "Lactobacillus buchneri", "rank": "Species"}, "1587": {"name": "Lactobacillus helveticus", "rank": "Species"}, "1584": {"name": "Lactobacillus delbrueckii", "rank": "Species"}, "1585": {"name": "Lactobacillus delbrueckii subsp. bulgaricus", "rank": "Subspecies"}, "12178": {"name": "Cymbidium mosaic virus", "rank": "Species"}, "12179": {"name": "Foxtail mosaic virus", "rank": "Species"}, "885276": {"name": "Escherichia coli str. 'clone D i2'", "rank": "Strain"}, "95149": {"name": "Helicobacter pametensis", "rank": "Species"}, "885274": {"name": "Campylobacter jejuni subsp. jejuni H22082", "rank": "Strain"}, "885275": {"name": "Escherichia coli str. 'clone D i14'", "rank": "Strain"}, "12172": {"name": "Shallot latent virus", "rank": "Species"}, "12173": {"name": "Lily symptomless virus", "rank": "Species"}, "12174": {"name": "Capillovirus", "rank": "Genus"}, "12175": {"name": "Apple chlorotic leaf spot virus", "rank": "Species"}, "12176": {"name": "Potexvirus", "rank": "Genus"}, "12177": {"name": "Clover yellow mosaic virus", "rank": "Species"}, "1105101": {"name": "Rickettsia rickettsii str. Hlp#2", "rank": "Strain"}, "1105100": {"name": "Rickettsia rickettsii str. Hino", "rank": "Strain"}, "1105103": {"name": "Rickettsia rickettsii str. Hauke", "rank": "Strain"}, "1105102": {"name": "Rickettsia rickettsii str. Colombia", "rank": "Strain"}, "1105105": {"name": "Rickettsia rickettsii str. Arizona", "rank": "Strain"}, "1105104": {"name": "Rickettsia rickettsii str. Brazil", "rank": "Strain"}, "1105107": {"name": "Rickettsia canadensis str. CA410", "rank": "Strain"}, "1105106": {"name": "Rickettsia philipii", "rank": "Species"}, "1105109": {"name": "Rickettsia slovaca str. D-CWPP", "rank": "Strain"}, "1105108": {"name": "Rickettsia parkeri str. Portsmouth", "rank": "Strain"}, "1545702": {"name": "Lactobacillus sp. wkB8", "rank": "Species"}, "1545701": {"name": "Lactobacillus sp. wkB10", "rank": "Species"}, "740933": {"name": "Turkey parvovirus 1078", "rank": "Species"}, "1422309": {"name": "Staphylococcus aureus DAR5869", "rank": "Strain"}, "1422308": {"name": "Staphylococcus aureus DAR5870", "rank": "Strain"}, "1422307": {"name": "Staphylococcus aureus DAR5871", "rank": "Strain"}, "1422306": {"name": "Staphylococcus aureus DAR5872", "rank": "Strain"}, "1422305": {"name": "Staphylococcus aureus DAR5881", "rank": "Strain"}, "1422304": {"name": "Staphylococcus aureus DAR5884", "rank": "Strain"}, "1422303": {"name": "Staphylococcus aureus DAR5885", "rank": "Strain"}, "73044": {"name": "Streptomyces seoulensis", "rank": "Species"}, "1422301": {"name": "Staphylococcus aureus DAR5887", "rank": "Strain"}, "1127483": {"name": "Cupriavidus basilensis OR16", "rank": "Strain"}, "1191279": {"name": "Helicobacter pylori FD423", "rank": "Strain"}, "582514": {"name": "Rubidibacter lacunae", "rank": "Species"}, "1124904": {"name": "Salmonella enterica subsp. enterica serovar Soerenga", "rank": "Strain"}, "1124906": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 266757-1", "rank": "Strain"}, "1124907": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 432613", "rank": "Strain"}, "1124908": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 467481", "rank": "Strain"}, "1124909": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 557928", "rank": "Strain"}, "1156935": {"name": "Agrobacterium albertimagni AOL15", "rank": "Strain"}, "1158550": {"name": "Enterococcus faecium EnGen0261", "rank": "Strain"}, "1158551": {"name": "Enterococcus faecium EnGen0262", "rank": "Strain"}, "1507808": {"name": "Pectobacterium carotovorum subsp. actinidiae", "rank": "Subspecies"}, "1158553": {"name": "Enterococcus faecium EnGen0263", "rank": "Strain"}, "1158554": {"name": "Enterococcus faecium EnGen0264", "rank": "Strain"}, "1158555": {"name": "Enterococcus faecium EnGen0265", "rank": "Strain"}, "1507806": {"name": "Campylobacter fetus subsp. testudinum", "rank": "Subspecies"}, "225196": {"name": "Geopsychrobacter electrodiphilus", "rank": "Species"}, "225194": {"name": "Geobacter bemidjiensis", "rank": "Species"}, "1051352": {"name": "Escherichia coli PA35", "rank": "Strain"}, "1051353": {"name": "Escherichia coli ATCC 700728", "rank": "Strain"}, "1051350": {"name": "Escherichia coli PA13", "rank": "Strain"}, "1051351": {"name": "Escherichia coli PA19", "rank": "Strain"}, "1285597": {"name": "Megabirnavirus", "rank": "Genus"}, "1285596": {"name": "Megabirnaviridae", "rank": "Family"}, "1285595": {"name": "Musca hytrovirus", "rank": "Species"}, "1285594": {"name": "Glossina hytrovirus", "rank": "Species"}, "1285593": {"name": "Muscavirus", "rank": "Genus"}, "1285591": {"name": "Glossinavirus", "rank": "Genus"}, "1285590": {"name": "Hytrosaviridae", "rank": "Family"}, "1121888": {"name": "Flavobacterium denitrificans DSM 15936", "rank": "Strain"}, "1121889": {"name": "Flavobacterium filum DSM 17961", "rank": "Strain"}, "1379719": {"name": "Circoviridae 15 LDMD-2013", "rank": "Species"}, "1379718": {"name": "Circoviridae 14 LDMD-2013", "rank": "Species"}, "1379717": {"name": "Circoviridae 13 LDMD-2013", "rank": "Species"}, "1121887": {"name": "Flavobacterium daejeonense DSM 17708", "rank": "Strain"}, "240426": {"name": "Squirrelpox virus", "rank": "Species"}, "74318": {"name": "Maricaulis maris", "rank": "Species"}, "74319": {"name": "Hyphomonas polymorpha", "rank": "Species"}, "74311": {"name": "Brevundimonas bacteroides", "rank": "Species"}, "1519464": {"name": "Chlorobium sp. GBChlB", "rank": "Species"}, "74317": {"name": "Maricaulis", "rank": "Genus"}, "548915": {"name": "Tomato leaf curl Kumasi virus", "rank": "Species"}, "914139": {"name": "Streptococcus pneumoniae 2070005", "rank": "Strain"}, "98439": {"name": "Fischerella thermalis PCC 7521", "rank": "Strain"}, "55096": {"name": "Ippy virus", "rank": "Species"}, "1028806": {"name": "Haemophilus haemolyticus M21639", "rank": "Strain"}, "538123": {"name": "Mammalian orthoreovirus 3", "rank": "Strain"}, "1028804": {"name": "Haemophilus haemolyticus M21127", "rank": "Strain"}, "887827": {"name": "Chickpea redleaf virus", "rank": "Species"}, "180230": {"name": "Cyprinid herpesvirus 3", "rank": "Species"}, "679201": {"name": "Selenomonas infelix ATCC 43532", "rank": "Strain"}, "459532": {"name": "Terribacillus", "rank": "Genus"}, "914134": {"name": "Streptococcus pneumoniae 2070768", "rank": "Strain"}, "765105": {"name": "Propionibacterium acnes HL001PA1", "rank": "Strain"}, "1124": {"name": "Chlorogloeopsis fritschii", "rank": "Species"}, "1385984": {"name": "Exiguobacterium pavilionensis", "rank": "Species"}, "914136": {"name": "Streptococcus pneumoniae 2072047", "rank": "Strain"}, "1218150": {"name": "Salmonella enterica subsp. enterica serovar Typhimurium str. STm10", "rank": "Strain"}, "765103": {"name": "Propionibacterium acnes HL030PA1", "rank": "Strain"}, "914137": {"name": "Streptococcus pneumoniae 2081074", "rank": "Strain"}, "1423489": {"name": "Mycobacterium tuberculosis BTB08-288", "rank": "Strain"}, "765102": {"name": "Propionibacterium acnes HL050PA3", "rank": "Strain"}, "1423488": {"name": "Mycobacterium tuberculosis BTB08-283", "rank": "Strain"}, "354242": {"name": "Campylobacter jejuni subsp. jejuni 81-176", "rank": "Strain"}, "43657": {"name": "Pseudoalteromonas luteoviolacea", "rank": "Species"}, "43655": {"name": "Pseudoalteromonas citrea", "rank": "Species"}, "1122169": {"name": "Legionella shakespearei DSM 23087", "rank": "Strain"}, "1122164": {"name": "Legionella lansingensis DSM 19556 = ATCC 49751", "rank": "Strain"}, "1122165": {"name": "Legionella moravica DSM 19234", "rank": "Strain"}, "576947": {"name": "Unclassified Lagovirus", "rank": "No rank"}, "576946": {"name": "Deinococcus xibeiensis", "rank": "Species"}, "1122160": {"name": "Legionella cherrii DSM 19213", "rank": "Strain"}, "1122161": {"name": "Legionella geestiana DSM 21217", "rank": "Strain"}, "43658": {"name": "Pseudoalteromonas rubra", "rank": "Species"}, "1339288": {"name": "Bacteroides fragilis str. 3988 T1", "rank": "Strain"}, "1244513": {"name": "Luteimonas huabeiensis", "rank": "Species"}, "1339283": {"name": "Bacteroides fragilis str. 3996 N(B) 6", "rank": "Strain"}, "1339282": {"name": "Bacteroides fragilis str. 2-F-2 #7", "rank": "Strain"}, "1339281": {"name": "Bacteroides fragilis str. 2-F-2 #5", "rank": "Strain"}, "1339280": {"name": "Bacteroides fragilis str. 2-F-2 #4", "rank": "Strain"}, "1339287": {"name": "Bacteroides fragilis str. 3986 T(B)9", "rank": "Strain"}, "1339286": {"name": "Bacteroides fragilis str. 3725 D9 ii", "rank": "Strain"}, "1339285": {"name": "Bacteroides fragilis str. 3998 T(B) 4", "rank": "Strain"}, "747763": {"name": "Streptomyces phage phiSASD1", "rank": "Species"}, "1239934": {"name": "Borrelia afzelii HLJ01", "rank": "Strain"}, "1111676": {"name": "Mycoplasma haemocanis str. Illinois", "rank": "Strain"}, "1111677": {"name": "Enterococcus faecalis M7", "rank": "Strain"}, "1111674": {"name": "Helicobacter pylori P79", "rank": "Strain"}, "1333704": {"name": "Helicobacter pylori HPARG8G", "rank": "Strain"}, "1256218": {"name": "Lactobacillus paracasei subsp. paracasei Lpp122", "rank": "Strain"}, "1412844": {"name": "Bacillus anthracis 52-G", "rank": "Strain"}, "1412843": {"name": "Bacillus anthracis 8903-G", "rank": "Strain"}, "1412842": {"name": "Bacillus anthracis 9080-G", "rank": "Strain"}, "1412841": {"name": "Anaplasma marginale str. Dawn", "rank": "Strain"}, "1412840": {"name": "Anaplasma marginale str. Gypsy Plains", "rank": "Strain"}, "272548": {"name": "Actinomyces dentalis", "rank": "Species"}, "1089128": {"name": "Mycobacterium phage Kugel", "rank": "Species"}, "1481224": {"name": "Pseudomonas phage JD024", "rank": "Species"}, "1256219": {"name": "Lactobacillus paracasei subsp. paracasei Lpp230", "rank": "Strain"}, "1160733": {"name": "Salmonella enterica subsp. enterica serovar 9,12:l,v:-", "rank": "Strain"}, "52774": {"name": "Actinomyces slackii", "rank": "Species"}, "1422170": {"name": "Staphylococcus aureus DAR3790", "rank": "Strain"}, "1607839": {"name": "Leuconostoc gelidum subsp. gelidum", "rank": "Subspecies"}, "1047171": {"name": "Zymoseptoria tritici", "rank": "Species"}, "1121433": {"name": "Desulfovermiculus halophilus DSM 18834", "rank": "Strain"}, "1176649": {"name": "Agrobacterium fabrum", "rank": "Species"}, "79967": {"name": "Erwinia pyrifoliae", "rank": "Species"}, "1121436": {"name": "Desulfovibrio alaskensis DSM 16109", "rank": "Strain"}, "1121435": {"name": "Desulfovibrio africanus subsp. africanus DSM 2603", "rank": "Strain"}, "1121434": {"name": "Desulfovibrio acrylicus DSM 10141", "rank": "Strain"}, "1121439": {"name": "Desulfovibrio alkalitolerans DSM 16529", "rank": "Strain"}, "1121438": {"name": "Desulfovibrio alcoholivorans DSM 5433", "rank": "Strain"}, "904759": {"name": "Staphylococcus aureus subsp. aureus 21305", "rank": "Strain"}, "904758": {"name": "Staphylococcus aureus subsp. aureus 21304", "rank": "Strain"}, "266825": {"name": "Thermus yunnanensis", "rank": "Species"}, "904751": {"name": "Staphylococcus aureus subsp. aureus 21275", "rank": "Strain"}, "904750": {"name": "Staphylococcus aureus subsp. aureus 21272", "rank": "Strain"}, "904753": {"name": "Staphylococcus aureus subsp. aureus 21282", "rank": "Strain"}, "690566": {"name": "Sphingobium chlorophenolicum L-1", "rank": "Strain"}, "904754": {"name": "Staphylococcus aureus subsp. aureus 21283", "rank": "Strain"}, "889378": {"name": "Spirochaeta africana DSM 8902", "rank": "Strain"}, "1499679": {"name": "Virgibacillus sp. SK-1", "rank": "Species"}, "74829": {"name": "Pseudomonas balearica", "rank": "Species"}, "873447": {"name": "Streptococcus parauberis NCFD 2020", "rank": "Strain"}, "1506995": {"name": "Streptomyces sp. CNS654", "rank": "Species"}, "1506994": {"name": "Butyrivibrio sp. AE3004", "rank": "Species"}, "266799": {"name": "Tomato yellow leaf curl Kanchanaburi virus", "rank": "Species"}, "1539142": {"name": "Cupriavidus sp. IDO", "rank": "Species"}, "1539143": {"name": "Cupriavidus sp. SHE", "rank": "Species"}, "451871": {"name": "Eurotiomycetidae", "rank": "Subclass"}, "931436": {"name": "Staphylococcus aureus subsp. aureus CIG1242", "rank": "Strain"}, "1291233": {"name": "Leptospira kirschneri serovar Mozdok 1 str. Vehlefans 2", "rank": "Strain"}, "1298599": {"name": "Vibrio sp. JCM 18904", "rank": "Species"}, "1298598": {"name": "Gracilibacillus boraciitolerans JCM 21714", "rank": "Strain"}, "1298593": {"name": "Thalassolituus oleivorans MIL-1", "rank": "Strain"}, "595498": {"name": "Burkholderia pseudomallei Pakistan 9", "rank": "Strain"}, "595499": {"name": "Candidatus Sulcia muelleri SMDSEM", "rank": "Strain"}, "879462": {"name": "Escherichia coli str. K-12 substr. MG1655star", "rank": "Strain"}, "10492": {"name": "Ranavirus", "rank": "Genus"}, "10494": {"name": "Lymphocystivirus", "rank": "Genus"}, "10497": {"name": "African swine fever virus", "rank": "Species"}, "314607": {"name": "Beta proteobacterium KB13", "rank": "Species"}, "314608": {"name": "Shewanella benthica KT99", "rank": "Strain"}, "595494": {"name": "Tolumonas auensis DSM 9187", "rank": "Strain"}, "595495": {"name": "Escherichia coli KO11FL", "rank": "Strain"}, "595496": {"name": "Escherichia coli BW2952", "rank": "Strain"}, "595497": {"name": "Brucella ceti str. Cudo", "rank": "Strain"}, "170652": {"name": "Vibrio brasiliensis", "rank": "Species"}, "329864": {"name": "Salmonella phage SE1", "rank": "Species"}, "329861": {"name": "Unclassified Norovirus", "rank": "No rank"}, "999417": {"name": "Parabacteroides distasonis CL09T03C24", "rank": "Strain"}, "1111077": {"name": "Claviceps purpurea 20.1", "rank": "Strain"}, "446471": {"name": "Xylanimonas cellulosilytica DSM 15894", "rank": "Strain"}, "1124578": {"name": "Bacillus phage phIS3501", "rank": "Species"}, "213810": {"name": "Ruminococcus champanellensis 18P13 = JCM 17042", "rank": "Strain"}, "1124577": {"name": "Tomato mild yellow leaf curl Aragua virus", "rank": "Species"}, "1202538": {"name": "Candidatus Carsonella ruddii HC isolate Thao2000", "rank": "Strain"}, "1202539": {"name": "Candidatus Carsonella ruddii HT isolate Thao2000", "rank": "Strain"}, "1202531": {"name": "Verticillium dahliae JR2", "rank": "Strain"}, "1202532": {"name": "Flavobacterium sp. F52", "rank": "Species"}, "1202533": {"name": "Bacillus nealsonii AAU1", "rank": "Strain"}, "1202534": {"name": "Clostridium sartagoforme AAU1", "rank": "Strain"}, "1202536": {"name": "Candidatus Carsonella ruddii CE isolate Thao2000", "rank": "Strain"}, "1202537": {"name": "Candidatus Carsonella ruddii CS isolate Thao2000", "rank": "Strain"}, "1354509": {"name": "Mycobacterium phage Bane2", "rank": "Species"}, "1265302": {"name": "Staphylococcus aureus subsp. aureus PB32", "rank": "Strain"}, "1001994": {"name": "Candidatus Nitrosoarchaeum koreensis MY1", "rank": "Strain"}, "1397896": {"name": "Mycobacterium tuberculosis TKK_03_0030", "rank": "Strain"}, "29560": {"name": "Mycoplasma imitans", "rank": "Species"}, "1181749": {"name": "Escherichia coli KTE203", "rank": "Strain"}, "29562": {"name": "Mycoplasma ovipneumoniae", "rank": "Species"}, "329288": {"name": "Ageratum yellow vein China betasatellite", "rank": "Species"}, "1181746": {"name": "Escherichia coli KTE200", "rank": "Strain"}, "1181745": {"name": "Escherichia coli KTE199", "rank": "Strain"}, "1181744": {"name": "Escherichia coli KTE198", "rank": "Strain"}, "1181743": {"name": "Escherichia coli KTE197", "rank": "Strain"}, "1181742": {"name": "Escherichia coli KTE196", "rank": "Strain"}, "1181741": {"name": "Escherichia coli KTE195", "rank": "Strain"}, "1181740": {"name": "Escherichia coli KTE194", "rank": "Strain"}, "1310634": {"name": "Acinetobacter baumannii 4749", "rank": "Strain"}, "1482734": {"name": "Duck picornavirus GL/12", "rank": "Species"}, "1169208": {"name": "Brucella abortus 63/138", "rank": "Strain"}, "1169209": {"name": "Brucella abortus 63/144", "rank": "Strain"}, "578454": {"name": "Candida parapsilosis CDC317", "rank": "Strain"}, "1069533": {"name": "Streptococcus infantarius subsp. infantarius CJ18", "rank": "Strain"}, "578456": {"name": "Tremella mesenterica DSM 1558", "rank": "Strain"}, "1069534": {"name": "Lactobacillus ruminis ATCC 27782", "rank": "Strain"}, "578458": {"name": "Schizophyllum commune H4-8", "rank": "Strain"}, "1439210": {"name": "Streptococcus pyogenes ABC020052291", "rank": "Strain"}, "168927": {"name": "Escherichia coli O111:H-", "rank": "Strain"}, "166318": {"name": "Synechococcus sp. WH 8016", "rank": "Species"}, "1169203": {"name": "Brucella abortus 225/65", "rank": "Strain"}, "166314": {"name": "Synechococcus sp. WH 8109", "rank": "Species"}, "1110502": {"name": "Tistrella mobilis KA081020-065", "rank": "Strain"}, "336871": {"name": "Unclassified Paramyxoviridae", "rank": "No rank"}, "743713": {"name": "Pseudomonas fluorescens R124", "rank": "Strain"}, "1381121": {"name": "Klebsiella pneumoniae 303K", "rank": "Strain"}, "1173264": {"name": "Leptolyngbya sp. PCC 6406", "rank": "Species"}, "1381123": {"name": "Aliihoeflea sp. 2WW", "rank": "Species"}, "1381122": {"name": "Rhodococcus erythropolis DN1", "rank": "Strain"}, "1381124": {"name": "Lactobacillus fermentum 3872", "rank": "Strain"}, "1173263": {"name": "Synechococcus sp. PCC 7502", "rank": "Species"}, "563773": {"name": "Vibrio parahaemolyticus AN-5034", "rank": "Strain"}, "1110505": {"name": "Corynebacterium casei UCMA 3821", "rank": "Strain"}, "292486": {"name": "Avibacterium", "rank": "Genus"}, "558152": {"name": "Chryseobacterium piperi", "rank": "Species"}, "1110504": {"name": "Mycoplasma agalactiae 14628", "rank": "Strain"}, "1064551": {"name": "Salmonella enterica subsp. enterica serovar Thompson str. RM6836", "rank": "Strain"}, "12232": {"name": "Zucchini yellow mosaic virus", "rank": "Species"}, "658600": {"name": "Chlamydia muridarum MopnTet14", "rank": "Strain"}, "12235": {"name": "Cucumber green mottle mosaic virus", "rank": "Species"}, "12234": {"name": "Tobamovirus", "rank": "Genus"}, "12239": {"name": "Pepper mild mottle virus", "rank": "Species"}, "12238": {"name": "Odontoglossum ringspot virus", "rank": "Species"}, "1352511": {"name": "Thin paspalum asymptomatic virus", "rank": "Species"}, "1422066": {"name": "Mycobacterium tuberculosis TB_RSA150", "rank": "Strain"}, "1422067": {"name": "Mycobacterium tuberculosis TB_RSA151", "rank": "Strain"}, "66269": {"name": "Pantoea stewartii", "rank": "Species"}, "1422065": {"name": "Mycobacterium tuberculosis TB_RSA149", "rank": "Strain"}, "1422062": {"name": "Mycobacterium tuberculosis TB_RSA146", "rank": "Strain"}, "1422063": {"name": "Mycobacterium tuberculosis TB_RSA147", "rank": "Strain"}, "1422060": {"name": "Mycobacterium tuberculosis TB_RSA144", "rank": "Strain"}, "1422061": {"name": "Mycobacterium tuberculosis TB_RSA145", "rank": "Strain"}, "66266": {"name": "Rice grassy stunt virus", "rank": "Species"}, "1422068": {"name": "Mycobacterium tuberculosis TB_RSA152", "rank": "Strain"}, "1422069": {"name": "Mycobacterium tuberculosis TB_RSA153", "rank": "Strain"}, "1402680": {"name": "Staphylococcus aureus M1169", "rank": "Strain"}, "53457": {"name": "Janibacter", "rank": "Genus"}, "209841": {"name": "Actinobacillus pleuropneumoniae serovar 7", "rank": "Strain"}, "53452": {"name": "Lamprocystis", "rank": "Genus"}, "1402681": {"name": "Staphylococcus aureus M1171", "rank": "Strain"}, "651591": {"name": "Bacteroidetes bacterium oral taxon 272", "rank": "Species"}, "1286": {"name": "Staphylococcus simulans", "rank": "Species"}, "1402684": {"name": "Staphylococcus aureus M1175", "rank": "Strain"}, "1280": {"name": "Staphylococcus aureus", "rank": "Species"}, "2752": {"name": "Carnobacterium funditum", "rank": "Species"}, "2753": {"name": "Synergistes", "rank": "Genus"}, "2750": {"name": "Carnobacterium mobile", "rank": "Species"}, "2751": {"name": "Carnobacterium maltaromaticum", "rank": "Species"}, "2756": {"name": "Brochothrix thermosphacta", "rank": "Species"}, "1283": {"name": "Staphylococcus haemolyticus", "rank": "Species"}, "2754": {"name": "Synergistes jonesii", "rank": "Species"}, "2755": {"name": "Brochothrix", "rank": "Genus"}, "2759": {"name": "Eukaryota", "rank": "Superkingdom"}, "525255": {"name": "Anaerococcus tetradius ATCC 35098", "rank": "Strain"}, "525254": {"name": "Anaerococcus lactolyticus ATCC 51172", "rank": "Strain"}, "525257": {"name": "Chryseobacterium gleum ATCC 35910", "rank": "Strain"}, "525256": {"name": "Atopobium vaginae DSM 15829", "rank": "Strain"}, "525259": {"name": "Peptoclostridium difficile NAP08", "rank": "Strain"}, "525258": {"name": "Peptoclostridium difficile NAP07", "rank": "Strain"}, "929051": {"name": "Tomato leaf curl Togo betasatellite-Togo:2006", "rank": "Species"}, "430066": {"name": "Brucella abortus S19", "rank": "Strain"}, "413997": {"name": "Escherichia coli B str. REL606", "rank": "Strain"}, "413999": {"name": "Clostridium botulinum A str. ATCC 3502", "rank": "Strain"}, "579922": {"name": "Indibacter alkaliphilus", "rank": "Species"}, "263374": {"name": "Bordetella phage BMP-1", "rank": "Species"}, "1423139": {"name": "Bacillus thuringiensis JM-Mgvxx-63", "rank": "Strain"}, "1423138": {"name": "Bacillus amyloliquefaciens SQR9", "rank": "Strain"}, "179628": {"name": "Clostridium colicanis", "rank": "Species"}, "1105273": {"name": "Streptococcus agalactiae LMG 15083", "rank": "Strain"}, "1105272": {"name": "Streptococcus agalactiae LMG 15081", "rank": "Strain"}, "1105271": {"name": "Streptococcus agalactiae CCUG 49100", "rank": "Strain"}, "1105270": {"name": "Streptococcus agalactiae CCUG 49086", "rank": "Strain"}, "1105277": {"name": "Streptococcus agalactiae BSU252", "rank": "Strain"}, "1105276": {"name": "Streptococcus agalactiae LMG 15090", "rank": "Strain"}, "1105275": {"name": "Streptococcus agalactiae LMG 15089", "rank": "Strain"}, "1105274": {"name": "Streptococcus agalactiae LMG 15084", "rank": "Strain"}, "1030843": {"name": "Porphyromonas gingivalis TDC60", "rank": "Strain"}, "1030842": {"name": "Ruminococcus flavefaciens 17", "rank": "Strain"}, "1030841": {"name": "Neisseria wadsworthii 9715", "rank": "Strain"}, "1105278": {"name": "Streptococcus agalactiae BSU454", "rank": "Strain"}, "710239": {"name": "Capnocytophaga sp. oral taxon 338", "rank": "Species"}, "710238": {"name": "Actinomyces sp. oral taxon 178", "rank": "Species"}, "1300345": {"name": "Lysobacter dokdonensis DS-58", "rank": "Strain"}, "1350466": {"name": "Lactobacillus plantarum WJL", "rank": "Strain"}, "1350467": {"name": "Lactobacillus brevis EW", "rank": "Strain"}, "1350465": {"name": "Pseudomonas aeruginosa VRFPA03", "rank": "Strain"}, "1350462": {"name": "Helicobacter pylori wls-5-3", "rank": "Strain"}, "1350461": {"name": "Synechococcus sp. UTEX 2973", "rank": "Species"}, "1350468": {"name": "Bacillus pumilus CCMA-560", "rank": "Strain"}, "1350469": {"name": "Achromobacter xylosoxidans X02736", "rank": "Strain"}, "460073": {"name": "Segetibacter", "rank": "Genus"}, "417192": {"name": "Honeysuckle yellow vein mosaic disease associated satellite DNA beta", "rank": "Species"}, "555088": {"name": "Dethiobacter alkaliphilus AHT 1", "rank": "Strain"}, "65741": {"name": "Pseudomonas knackmussii", "rank": "Species"}, "65743": {"name": "Blackcurrant reversion virus", "rank": "Species"}, "516086": {"name": "Clostridiisalibacter", "rank": "Genus"}, "1506568": {"name": "Cyclovirus ZM36a", "rank": "Species"}, "666144": {"name": "Cleome leaf crumple virus", "rank": "Species"}, "377629": {"name": "Teredinibacter turnerae T7901", "rank": "Strain"}, "83559": {"name": "Chlamydia suis", "rank": "Species"}, "88724": {"name": "Natrinema versiforme", "rank": "Species"}, "33169": {"name": "Eremothecium gossypii", "rank": "Species"}, "190478": {"name": "Clostridium phage phi3626", "rank": "Species"}, "88723": {"name": "Natrinema", "rank": "Genus"}, "1159870": {"name": "Bordetella sp. FB-8", "rank": "Species"}, "83551": {"name": "Parachlamydia", "rank": "Genus"}, "83552": {"name": "Parachlamydia acanthamoebae", "rank": "Species"}, "83553": {"name": "Chlamydophila", "rank": "Genus"}, "83554": {"name": "Chlamydia psittaci", "rank": "Species"}, "83555": {"name": "Chlamydophila abortus", "rank": "Species"}, "83556": {"name": "Chlamydophila felis", "rank": "Species"}, "33165": {"name": "Kluyveromyces aestuarii", "rank": "Species"}, "213769": {"name": "Lactococcus phage 712", "rank": "Strain"}, "979525": {"name": "Vibrio phage ICP1", "rank": "Species"}, "992177": {"name": "Yersinia pestis PY-95", "rank": "Strain"}, "992175": {"name": "Yersinia pestis PY-93", "rank": "Strain"}, "375286": {"name": "Janthinobacterium sp. Marseille", "rank": "Species"}, "375288": {"name": "Parabacteroides", "rank": "Genus"}, "84588": {"name": "Synechococcus sp. WH 8102", "rank": "Species"}, "84589": {"name": "Salmon pancreas disease virus", "rank": "Species"}, "767465": {"name": "Mycoplasma bovis HB0801", "rank": "Strain"}, "767462": {"name": "Lactobacillus helveticus H10", "rank": "Strain"}, "767463": {"name": "Streptococcus thermophilus ND03", "rank": "Strain"}, "767468": {"name": "Lactobacillus plantarum subsp. plantarum P-8", "rank": "Strain"}, "284592": {"name": "Debaryomyces hansenii CBS767", "rank": "Strain"}, "465543": {"name": "Streptomyces sp. SPB74", "rank": "Species"}, "465541": {"name": "Streptomyces sp. Mg1", "rank": "Species"}, "63426": {"name": "Unclassified Pestivirus", "rank": "No rank"}, "1267981": {"name": "Arthrobacter sp. H20", "rank": "Species"}, "1124925": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. ATCC 9115", "rank": "Strain"}, "219584": {"name": "Pike fry rhabdovirus", "rank": "Species"}, "1388179": {"name": "Staphylococcus aureus M0275", "rank": "Strain"}, "1388178": {"name": "Staphylococcus aureus M0272", "rank": "Strain"}, "1388171": {"name": "Staphylococcus aureus M0262", "rank": "Strain"}, "1388170": {"name": "Staphylococcus aureus M0259", "rank": "Strain"}, "1388173": {"name": "Staphylococcus aureus M0264", "rank": "Strain"}, "1388172": {"name": "Staphylococcus aureus M0263", "rank": "Strain"}, "1388175": {"name": "Staphylococcus aureus M0267", "rank": "Strain"}, "1388174": {"name": "Staphylococcus aureus M0265", "rank": "Strain"}, "1388177": {"name": "Staphylococcus aureus M0271", "rank": "Strain"}, "1388176": {"name": "Staphylococcus aureus M0269", "rank": "Strain"}, "1151294": {"name": "Peptoclostridium difficile CD166", "rank": "Strain"}, "1151295": {"name": "Peptoclostridium difficile CD169", "rank": "Strain"}, "1151296": {"name": "Peptoclostridium difficile CD170", "rank": "Strain"}, "1260251": {"name": "Spiribacter salinus M19-40", "rank": "Strain"}, "1151291": {"name": "Peptoclostridium difficile CD159", "rank": "Strain"}, "1151292": {"name": "Peptoclostridium difficile CD160", "rank": "Strain"}, "1151293": {"name": "Peptoclostridium difficile CD165", "rank": "Strain"}, "1151298": {"name": "Peptoclostridium difficile CD178", "rank": "Strain"}, "1151299": {"name": "Peptoclostridium difficile CD181", "rank": "Strain"}, "1311095": {"name": "Acinetobacter baumannii 45075_8", "rank": "Strain"}, "1311096": {"name": "Acinetobacter baumannii 45075_9", "rank": "Strain"}, "1311097": {"name": "Acinetobacter baumannii 45075_10", "rank": "Strain"}, "1311090": {"name": "Acinetobacter baumannii 45075_3", "rank": "Strain"}, "1311091": {"name": "Acinetobacter baumannii 45075_4", "rank": "Strain"}, "1311092": {"name": "Acinetobacter baumannii 45075_5", "rank": "Strain"}, "1311093": {"name": "Acinetobacter baumannii 45075_6", "rank": "Strain"}, "1311098": {"name": "Acinetobacter baumannii 16553_1", "rank": "Strain"}, "1311099": {"name": "Acinetobacter baumannii 16553_2", "rank": "Strain"}, "368797": {"name": "Unclassified Murine leukemia virus", "rank": "Strain"}, "555500": {"name": "Galbibacter marinus", "rank": "Species"}, "1045009": {"name": "Citricoccus sp. CH26A", "rank": "Species"}, "1481112": {"name": "Serratia phage PS2", "rank": "Species"}, "1045004": {"name": "Oenococcus kitaharae DSM 17330", "rank": "Strain"}, "1265757": {"name": "Candidatus Pelagibacter ubique HTCC1013", "rank": "Strain"}, "1265756": {"name": "Candidatus Pelagibacter ubique HTCC9022", "rank": "Strain"}, "928214": {"name": "Gorilla gorilla gorilla polyomavirus 1", "rank": "Species"}, "256847": {"name": "Lentisphaera araneosa", "rank": "Species"}, "256846": {"name": "Lentisphaera", "rank": "Genus"}, "256845": {"name": "Lentisphaerae", "rank": "Phylum"}, "1112204": {"name": "Gordonia polyisoprenivorans VH2", "rank": "Strain"}, "351581": {"name": "Francisella tularensis subsp. holarctica FSC200", "rank": "Strain"}, "716541": {"name": "Enterobacter cloacae subsp. cloacae ATCC 13047", "rank": "Strain"}, "112023": {"name": "Streptococcus phage 7201", "rank": "Species"}, "2724": {"name": "Hirschia baltica", "rank": "Species"}, "1392996": {"name": "Candidatus Methanoperedenaceae", "rank": "Family"}, "1392997": {"name": "Candidatus Methanoperedens", "rank": "Genus"}, "1392998": {"name": "Candidatus Methanoperedens nitroreducens", "rank": "Species"}, "1413516": {"name": "Staphylococcus aureus 2010-60-6063-39", "rank": "Strain"}, "1448804": {"name": "Mycobacterium tuberculosis H1329", "rank": "Strain"}, "1448805": {"name": "Mycobacterium tuberculosis H1578", "rank": "Strain"}, "1448806": {"name": "Mycobacterium tuberculosis H1580", "rank": "Strain"}, "1448807": {"name": "Mycobacterium tuberculosis H1589", "rank": "Strain"}, "1448800": {"name": "Mycobacterium tuberculosis M2144", "rank": "Strain"}, "1448801": {"name": "Mycobacterium tuberculosis M2479", "rank": "Strain"}, "1448802": {"name": "Mycobacterium tuberculosis M2384", "rank": "Strain"}, "1448803": {"name": "Mycobacterium tuberculosis M2508", "rank": "Strain"}, "97050": {"name": "Ruegeria", "rank": "Genus"}, "1136731": {"name": "Bacillus phage BPS13", "rank": "Species"}, "1448808": {"name": "Mycobacterium tuberculosis H1856", "rank": "Strain"}, "76892": {"name": "Caulobacteraceae", "rank": "Family"}, "1413518": {"name": "Staphylococcus aureus 2010-60-6511-5", "rank": "Strain"}, "1413519": {"name": "Staphylococcus aureus 2009-60-561-1", "rank": "Strain"}, "1157389": {"name": "Enterococcus faecalis EnGen0207", "rank": "Strain"}, "291484": {"name": "Hepeviridae", "rank": "Family"}, "797473": {"name": "Cardiobacterium valvarum F0432", "rank": "Strain"}, "1046572": {"name": "Abutilon mosaic Brazil virus", "rank": "Species"}, "1046573": {"name": "West African Asystasia virus 1", "rank": "Species"}, "1046571": {"name": "Sida mosaic Alagoas virus", "rank": "Species"}, "432200": {"name": "Enterobacteria phage HK542", "rank": "Species"}, "481139": {"name": "Bartonella rattaustraliani", "rank": "Species"}, "420889": {"name": "Lactococcus garvieae ATCC 49156", "rank": "Strain"}, "1131702": {"name": "Persea americana endornavirus", "rank": "Species"}, "1131703": {"name": "Sphaerochaeta globosa", "rank": "Species"}, "1131707": {"name": "Sphaerochaeta pleomorpha", "rank": "Species"}, "1195378": {"name": "Tomato dwarf leaf virus", "rank": "Species"}, "252356": {"name": "Maribacter", "rank": "Genus"}, "537210": {"name": "Mycobacterium tuberculosis T17", "rank": "Strain"}, "187145": {"name": "Caldithrix abyssi", "rank": "Species"}, "187144": {"name": "Caldithrix", "rank": "Genus"}, "883069": {"name": "Actinomyces europaeus ACS-120-V-Col10b", "rank": "Strain"}, "883062": {"name": "Bifidobacterium bifidum S17", "rank": "Strain"}, "883064": {"name": "Clostridium perfringens F262", "rank": "Strain"}, "264202": {"name": "Chlamydophila felis Fe/C-56", "rank": "Strain"}, "883066": {"name": "Actinobaculum massiliae ACS-171-V-Col2", "rank": "Strain"}, "1217697": {"name": "Acinetobacter sp. NIPH 1847", "rank": "Species"}, "1217696": {"name": "Acinetobacter sp. NIPH 2036", "rank": "Species"}, "1333": {"name": "Streptococcus criceti", "rank": "Species"}, "1217694": {"name": "Acinetobacter sp. CIP 64.2", "rank": "Species"}, "1217693": {"name": "Acinetobacter sp. NIPH 2171", "rank": "Species"}, "1217692": {"name": "Acinetobacter sp. NIPH 298", "rank": "Species"}, "1217691": {"name": "Acinetobacter pittii ANC 4050", "rank": "Strain"}, "1336": {"name": "Streptococcus equi", "rank": "Species"}, "1339": {"name": "Streptococcus macacae", "rank": "Species"}, "1338": {"name": "Streptococcus intermedius", "rank": "Species"}, "716546": {"name": "Leotiomyceta", "rank": "No rank"}, "1217699": {"name": "Acinetobacter sp. CIP 110321", "rank": "Species"}, "1217698": {"name": "Acinetobacter sp. NIPH 3623", "rank": "Species"}, "1198291": {"name": "Bacillus amyloliquefaciens subsp. amyloliquefaciens DC-12", "rank": "Strain"}, "712961": {"name": "Lactobacillus salivarius CECT 5713", "rank": "Strain"}, "234292": {"name": "Unclassified Streptomycetaceae", "rank": "No rank"}, "196398": {"name": "Southern cowpea mosaic virus", "rank": "Species"}, "196399": {"name": "Arabis mosaic virus small satellite RNA", "rank": "Species"}, "235985": {"name": "Streptacidiphilus jiangxiensis", "rank": "Species"}, "133814": {"name": "Marine Group II", "rank": "No rank"}, "1487185": {"name": "Heliconius erato iflavirus", "rank": "Species"}, "83219": {"name": "Sulfitobacter mediterraneus", "rank": "Species"}, "1116079": {"name": "Escherichia coli P0302293.10", "rank": "Strain"}, "1116078": {"name": "Escherichia coli P0302293.9", "rank": "Strain"}, "428411": {"name": "Candidatus Riesia pediculischaeffi", "rank": "Species"}, "1341645": {"name": "Pseudomonas aeruginosa WS394", "rank": "Strain"}, "1116070": {"name": "Escherichia coli P0301867.7", "rank": "Strain"}, "1116073": {"name": "Escherichia coli P0302293.2", "rank": "Strain"}, "1116072": {"name": "Escherichia coli P0301867.11", "rank": "Strain"}, "1116075": {"name": "Escherichia coli P0302293.4", "rank": "Strain"}, "1341646": {"name": "Mycobacterium septicum DSM 44393", "rank": "Strain"}, "1116077": {"name": "Escherichia coli P0302293.8", "rank": "Strain"}, "1116076": {"name": "Escherichia coli P0302293.6", "rank": "Strain"}, "562019": {"name": "Rickettsia peacockii str. Rustic", "rank": "Strain"}, "1203559": {"name": "Corynebacterium sp. KPL1818", "rank": "Species"}, "1203558": {"name": "Corynebacterium sp. KPL1817", "rank": "Species"}, "316068": {"name": "Leadbetterella byssophila", "rank": "Species"}, "5125": {"name": "Hypocreales", "rank": "Order"}, "5127": {"name": "Fusarium fujikuroi", "rank": "Species"}, "448385": {"name": "Sorangium cellulosum So ce56", "rank": "Strain"}, "1203550": {"name": "Prevotella oralis HGA0225", "rank": "Strain"}, "1203553": {"name": "Staphylococcus aureus subsp. aureus KPL1845", "rank": "Strain"}, "1203552": {"name": "Staphylococcus aureus subsp. aureus KPL1828", "rank": "Strain"}, "1203555": {"name": "Acidaminococcus sp. HPA0509", "rank": "Species"}, "316067": {"name": "Geobacter daltonii FRC-32", "rank": "Strain"}, "1203557": {"name": "Corynebacterium sp. KPL1814", "rank": "Species"}, "1203556": {"name": "Actinomyces sp. HPA0247", "rank": "Species"}, "1409719": {"name": "Staphylococcus aureus WAMC6060", "rank": "Strain"}, "1409718": {"name": "Staphylococcus aureus OCMM6140", "rank": "Strain"}, "1409717": {"name": "Staphylococcus aureus OCMM6137", "rank": "Strain"}, "1409716": {"name": "Staphylococcus aureus FVRH6132", "rank": "Strain"}, "1409715": {"name": "Staphylococcus aureus COAS6114", "rank": "Strain"}, "1409714": {"name": "Staphylococcus aureus COAS6112", "rank": "Strain"}, "1409713": {"name": "Staphylococcus aureus PLAC6044", "rank": "Strain"}, "1409712": {"name": "Staphylococcus aureus FVRH6131", "rank": "Strain"}, "1409711": {"name": "Staphylococcus aureus FVRH6130", "rank": "Strain"}, "1409710": {"name": "Staphylococcus aureus FVRH6129", "rank": "Strain"}, "1422468": {"name": "Staphylococcus aureus VET0156R", "rank": "Strain"}, "1422469": {"name": "Staphylococcus aureus VET0157R", "rank": "Strain"}, "1238885": {"name": "Bacillus thuringiensis serovar aizawai str. Hu4-2", "rank": "Strain"}, "1238886": {"name": "Unclassified Torradovirus", "rank": "No rank"}, "1422462": {"name": "Staphylococcus aureus VET0148R", "rank": "Strain"}, "562016": {"name": "Streptococcus pyogenes AA216", "rank": "Strain"}, "1422460": {"name": "Staphylococcus aureus VET0140R", "rank": "Strain"}, "1422461": {"name": "Staphylococcus aureus VET0141R", "rank": "Strain"}, "1422466": {"name": "Staphylococcus aureus VET0154R", "rank": "Strain"}, "1422467": {"name": "Staphylococcus aureus VET0155R", "rank": "Strain"}, "1422464": {"name": "Staphylococcus aureus VET0151R", "rank": "Strain"}, "1422465": {"name": "Staphylococcus aureus VET0152R", "rank": "Strain"}, "456163": {"name": "Thermus sp. RL", "rank": "Species"}, "28568": {"name": "Trichocomaceae", "rank": "Family"}, "1207070": {"name": "Oceaniovalibus", "rank": "Genus"}, "1207071": {"name": "Bacterium UW 659-2-F09", "rank": "Species"}, "1207076": {"name": "Pseudomonas luteola XLDN4-9", "rank": "Strain"}, "1207075": {"name": "Pseudomonas sp. UW4", "rank": "Species"}, "36742": {"name": "Mycoplasma leonicaptivi", "rank": "Species"}, "1150423": {"name": "Bifidobacterium dentium JCM 1195 = DSM 20436", "rank": "Strain"}, "59753": {"name": "Alcanivorax", "rank": "Genus"}, "59754": {"name": "Alcanivorax borkumensis", "rank": "Species"}, "352165": {"name": "Pyramidobacter piscolens W5455", "rank": "Strain"}, "352162": {"name": "Unclassified Pneumovirus", "rank": "No rank"}, "553568": {"name": "Staphylococcus aureus A6224", "rank": "Strain"}, "553567": {"name": "Staphylococcus aureus A5948", "rank": "Strain"}, "553565": {"name": "Staphylococcus aureus A5937", "rank": "Strain"}, "1076550": {"name": "Pantoea rwandensis", "rank": "Species"}, "444608": {"name": "Gryllotalpicola ginsengisoli", "rank": "Species"}, "418853": {"name": "Sneathiella glossodoripedis", "rank": "Species"}, "136084": {"name": "Roseobacter phage SIO1", "rank": "Species"}, "418855": {"name": "Streptomyces sp. CNQ-525", "rank": "Species"}, "418856": {"name": "Nevskia soli", "rank": "Species"}, "370554": {"name": "Streptococcus pyogenes MGAS10750", "rank": "Strain"}, "370552": {"name": "Streptococcus pyogenes MGAS10270", "rank": "Strain"}, "370553": {"name": "Streptococcus pyogenes MGAS2096", "rank": "Strain"}, "370551": {"name": "Streptococcus pyogenes MGAS9429", "rank": "Strain"}, "1571920": {"name": "Lysinibacillus sp. A1", "rank": "Species"}, "58180": {"name": "Desulfovibrio alaskensis", "rank": "Species"}, "979202": {"name": "Staphylococcus epidermidis NIHLM070", "rank": "Strain"}, "1423732": {"name": "Lactobacillus casei DSM 20011 = JCM 1134", "rank": "Strain"}, "1423734": {"name": "Lactobacillus composti DSM 18527 = JCM 14202", "rank": "Strain"}, "935845": {"name": "Paenibacillus sp. J14", "rank": "Species"}, "221822": {"name": "Phaeobacter inhibens", "rank": "Species"}, "22": {"name": "Shewanella", "rank": "Genus"}, "23": {"name": "Shewanella colwelliana", "rank": "Species"}, "24": {"name": "Shewanella putrefaciens", "rank": "Species"}, "935840": {"name": "Chelativorans sp. J32", "rank": "Species"}, "866536": {"name": "Belliella baltica DSM 15883", "rank": "Strain"}, "29": {"name": "Myxococcales", "rank": "Order"}, "419109": {"name": "Vibrio parahaemolyticus AQ3810", "rank": "Strain"}, "935848": {"name": "Paracoccus sp. J39", "rank": "Species"}, "82676": {"name": "Omikronpapillomavirus 1", "rank": "Species"}, "451640": {"name": "Catenibacterium mitsuokai DSM 15897", "rank": "Strain"}, "1438852": {"name": "Mycobacterium tuberculosis 2100HD", "rank": "Strain"}, "56804": {"name": "Glaciecola punicea", "rank": "Species"}, "261825": {"name": "Agarivorans", "rank": "Genus"}, "56807": {"name": "Glaciecola pallidula", "rank": "Species"}, "459472": {"name": "Planomicrobium glaciei", "rank": "Species"}, "718217": {"name": "Cyanobacterium endosymbiont of Epithemia turgida", "rank": "Species"}, "56112": {"name": "Dehalobacter", "rank": "Genus"}, "56110": {"name": "Oscillatoria acuminata PCC 6304", "rank": "Strain"}, "183763": {"name": "Streptomonospora alba", "rank": "Species"}, "102886": {"name": "Streptococcus didelphis", "rank": "Species"}, "198251": {"name": "Candidatus Pelagibacter", "rank": "Genus"}, "857138": {"name": "Streptococcus mutans N29", "rank": "Strain"}, "857139": {"name": "Streptococcus mutans A9", "rank": "Strain"}, "857136": {"name": "Streptococcus mutans A19", "rank": "Strain"}, "857137": {"name": "Streptococcus mutans NMT4863", "rank": "Strain"}, "857134": {"name": "Streptococcus mutans G123", "rank": "Strain"}, "857135": {"name": "Streptococcus mutans U138", "rank": "Strain"}, "349215": {"name": "Micavibrio aeruginosavorus EPB", "rank": "Strain"}, "857133": {"name": "Streptococcus mutans M21", "rank": "Strain"}, "857130": {"name": "Streptococcus mutans NFSM1", "rank": "Strain"}, "857131": {"name": "Streptococcus mutans N34", "rank": "Strain"}, "198252": {"name": "Candidatus Pelagibacter ubique", "rank": "Species"}, "1156938": {"name": "Paenibacillus polymyxa OSY-DF", "rank": "Strain"}, "1156939": {"name": "Streptococcus agalactiae ZQ0910", "rank": "Strain"}, "1111133": {"name": "Peptoniphilus sp. BV3AC2", "rank": "Species"}, "1111135": {"name": "Coriobacteriaceae bacterium BV3Ac1", "rank": "Species"}, "1111134": {"name": "Peptoniphilus sp. BV3C26", "rank": "Species"}, "1111137": {"name": "Slackia sp. CM382", "rank": "Species"}, "553973": {"name": "Clostridium hylemonae DSM 15053", "rank": "Strain"}, "1156937": {"name": "Methylacidiphilum fumariolicum SolV", "rank": "Strain"}, "452283": {"name": "Exobasidiomycetes", "rank": "Class"}, "332937": {"name": "Chimpanzee alpha-1 herpesvirus", "rank": "Species"}, "641853": {"name": "Elusimicrobia", "rank": "Class"}, "641854": {"name": "Elusimicrobiales", "rank": "Order"}, "1464546": {"name": "Acidiphilium sp. JA12-A1", "rank": "Species"}, "452284": {"name": "Ustilaginomycotina", "rank": "Subphylum"}, "1423483": {"name": "Mycobacterium tuberculosis BTB08-072", "rank": "Strain"}, "1423482": {"name": "Mycobacterium tuberculosis BTB08-043", "rank": "Strain"}, "1423481": {"name": "Mycobacterium tuberculosis BTB08-022", "rank": "Strain"}, "1423480": {"name": "Mycobacterium tuberculosis BTB08-014", "rank": "Strain"}, "1423487": {"name": "Mycobacterium tuberculosis BTB08-221", "rank": "Strain"}, "1423486": {"name": "Mycobacterium tuberculosis BTB08-183", "rank": "Strain"}, "1423485": {"name": "Mycobacterium tuberculosis BTB08-148", "rank": "Strain"}, "1423484": {"name": "Mycobacterium tuberculosis BTB08-093", "rank": "Strain"}, "1218151": {"name": "Salmonella enterica subsp. enterica serovar Typhimurium str. STm11", "rank": "Strain"}, "748770": {"name": "Dolichospermum", "rank": "Genus"}, "1218153": {"name": "Salmonella enterica subsp. enterica serovar Typhimurium str. STm5", "rank": "Strain"}, "1218152": {"name": "Salmonella enterica subsp. enterica serovar Typhimurium str. STm12", "rank": "Strain"}, "335928": {"name": "Xanthobacteraceae", "rank": "Family"}, "335929": {"name": "Erythrobacteraceae", "rank": "Family"}, "184882": {"name": "Knoellia subterranea", "rank": "Species"}, "1349": {"name": "Streptococcus uberis", "rank": "Species"}, "1497020": {"name": "Neosynechococcus sphagnicola sy1", "rank": "Strain"}, "931432": {"name": "Staphylococcus aureus subsp. aureus CIG1057", "rank": "Strain"}, "931433": {"name": "Staphylococcus aureus subsp. aureus CIG1114", "rank": "Strain"}, "931434": {"name": "Staphylococcus aureus subsp. aureus CIG1165", "rank": "Strain"}, "931435": {"name": "Staphylococcus aureus subsp. aureus CIG1214", "rank": "Strain"}, "373638": {"name": "Bartonella tamiae", "rank": "Species"}, "931437": {"name": "Staphylococcus aureus subsp. aureus CIG1500", "rank": "Strain"}, "931438": {"name": "Staphylococcus aureus subsp. aureus CIG1605", "rank": "Strain"}, "931439": {"name": "Staphylococcus aureus subsp. aureus CIG1750", "rank": "Strain"}, "866895": {"name": "Halobacillus halophilus DSM 2266", "rank": "Strain"}, "1273711": {"name": "Synechococcus phage S-CBP1", "rank": "Species"}, "1273712": {"name": "Staphylococcus phage JS01", "rank": "Species"}, "1273713": {"name": "Acinetobacter phage AB3", "rank": "Species"}, "1340": {"name": "Streptococcus porcinus", "rank": "Species"}, "379546": {"name": "Aciduliprofundum", "rank": "Genus"}, "379547": {"name": "Aciduliprofundum boonei", "rank": "Species"}, "1341": {"name": "Streptococcus ratti", "rank": "Species"}, "1397868": {"name": "Mycobacterium tuberculosis TKK_02_0025", "rank": "Strain"}, "104263": {"name": "Hop latent virus", "rank": "Species"}, "1071390": {"name": "Acinetobacter sp. NBRC 100985", "rank": "Species"}, "1412641": {"name": "Staphylococcus aureus F77967", "rank": "Strain"}, "743718": {"name": "Isoptericola variabilis 225", "rank": "Strain"}, "743719": {"name": "Paenibacillus lactis 154", "rank": "Strain"}, "1071395": {"name": "Bacillus coagulans XZL4", "rank": "Strain"}, "1412640": {"name": "Staphylococcus aureus F77960", "rank": "Strain"}, "1234171": {"name": "Sauropus leaf curl disease associated DNA beta", "rank": "Species"}, "563771": {"name": "Vibrio parahaemolyticus Peru-466", "rank": "Strain"}, "743710": {"name": "Bacillus atrophaeus ATCC 49822-1", "rank": "Strain"}, "743711": {"name": "Bacillus atrophaeus ATCC 49822-2", "rank": "Strain"}, "563775": {"name": "Myotis polyomavirus VM-2008", "rank": "Strain"}, "191373": {"name": "Pelotomaculum", "rank": "Genus"}, "104264": {"name": "Cellulophaga", "rank": "Genus"}, "1476202": {"name": "Rosellinia necatrix fusarivirus 1", "rank": "Species"}, "1412642": {"name": "Staphylococcus aureus F77974", "rank": "Strain"}, "38301": {"name": "Corynebacterium minutissimum", "rank": "Species"}, "1276290": {"name": "Caldibacillus", "rank": "Genus"}, "1333582": {"name": "Serratia marcescens MC460", "rank": "Strain"}, "441960": {"name": "Talaromyces marneffei ATCC 18224", "rank": "Strain"}, "1476208": {"name": "Sicinivirus 1", "rank": "Species"}, "1412644": {"name": "Staphylococcus aureus F81389", "rank": "Strain"}, "1333580": {"name": "Serratia marcescens MC458", "rank": "Strain"}, "380704": {"name": "Aspergillus niger ATCC 1015", "rank": "Strain"}, "439375": {"name": "Ochrobactrum anthropi ATCC 49188", "rank": "Strain"}, "1412646": {"name": "Staphylococcus aureus F84763", "rank": "Strain"}, "380703": {"name": "Aeromonas hydrophila subsp. hydrophila ATCC 7966", "rank": "Strain"}, "515616": {"name": "Mycobacterium tuberculosis 02_1987", "rank": "Strain"}, "444875": {"name": "Cyanophage 9515-10a", "rank": "Species"}, "651822": {"name": "Fretibacterium fastidiosum", "rank": "Species"}, "1412648": {"name": "Staphylococcus aureus F88375", "rank": "Strain"}, "1233735": {"name": "Unclassified Orthoretrovirinae", "rank": "No rank"}, "1354746": {"name": "Ordospora colligata OC4", "rank": "Strain"}, "338192": {"name": "Nitrosopumilus maritimus", "rank": "Species"}, "338190": {"name": "Nitrosopumilaceae", "rank": "Family"}, "338191": {"name": "Nitrosopumilus", "rank": "Genus"}, "29350": {"name": "Thermoanaerobacter thermocopriae", "rank": "Species"}, "1333589": {"name": "Escherichia coli AB42410445-isolate1", "rank": "Strain"}, "29354": {"name": "Clostridium celerecrescens", "rank": "Species"}, "29355": {"name": "Clostridium cellobioparum", "rank": "Species"}, "424718": {"name": "Shigella flexneri 5a", "rank": "Strain"}, "302069": {"name": "Begomovirus-associated DNA-II", "rank": "Species"}, "424716": {"name": "Salmonella phage Vi II-E1", "rank": "Species"}, "41976": {"name": "Porphyromonas catoniae", "rank": "Species"}, "179878": {"name": "Sphingomonas elodea", "rank": "Species"}, "1279043": {"name": "Cladophialophora carrionii CBS 160.54", "rank": "Strain"}, "1279040": {"name": "Klebsiella pneumoniae PR04", "rank": "Strain"}, "379097": {"name": "Vibrio sinaloensis", "rank": "Species"}, "1438858": {"name": "Mycobacterium tuberculosis 2228BH", "rank": "Strain"}, "1438859": {"name": "Mycobacterium tuberculosis 2229BH", "rank": "Strain"}, "1438854": {"name": "Mycobacterium tuberculosis 2104HD", "rank": "Strain"}, "946034": {"name": "Salmonella enterica subsp. enterica serovar Typhimurium str. TN061786", "rank": "Strain"}, "1438850": {"name": "Mycobacterium tuberculosis 2097HD", "rank": "Strain"}, "1438851": {"name": "Mycobacterium tuberculosis 2099HD", "rank": "Strain"}, "1397861": {"name": "Mycobacterium tuberculosis TKK_02_0016", "rank": "Strain"}, "1438853": {"name": "Mycobacterium tuberculosis 2101HD", "rank": "Strain"}, "1232460": {"name": "Clostridiales bacterium VE202-28", "rank": "Species"}, "1303024": {"name": "Mycobacterium abscessus subsp. bolletii 50594", "rank": "Strain"}, "626531": {"name": "Escherichia coli O157:H43", "rank": "Strain"}, "33748": {"name": "Simian T-lymphotropic virus 2", "rank": "Strain"}, "33743": {"name": "Kyasanur forest disease virus", "rank": "Species"}, "204536": {"name": "Sulfurihydrogenibium azorense Az-Fu1", "rank": "Strain"}, "1100790": {"name": "Pseudomonas phage Bf7", "rank": "Species"}, "33746": {"name": "Hepatitis C virus genotype 5", "rank": "Strain"}, "33747": {"name": "Simian T-lymphotropic virus 1", "rank": "Strain"}, "33745": {"name": "Hepatitis C virus genotype 4", "rank": "Strain"}, "181007": {"name": "Listeria phage 2389", "rank": "Species"}, "1478132": {"name": "Sclerotinia sclerotiorum endornavirus 2", "rank": "Species"}, "1084230": {"name": "Yersinia pestis biovar Orientalis str. BA200901990", "rank": "Strain"}, "573569": {"name": "Francisella sp. TX077308", "rank": "Species"}, "44448": {"name": "Borrelia persica", "rank": "Species"}, "11646": {"name": "Lentivirus", "rank": "Genus"}, "1084234": {"name": "Yersinia pestis biovar Orientalis str. AS200901509", "rank": "Strain"}, "1084233": {"name": "Yersinia pestis biovar Orientalis str. AS200901434", "rank": "Strain"}, "207949": {"name": "Bermanella marisrubri", "rank": "Species"}, "1084231": {"name": "Yersinia pestis biovar Orientalis str. BA200902009", "rank": "Strain"}, "11640": {"name": "Spumavirus", "rank": "Genus"}, "1458831": {"name": "Mycobacterium phage Jolie2", "rank": "Species"}, "522492": {"name": "Pseudomonas sp. CB1", "rank": "Species"}, "2369": {"name": "Arhodomonas aquaeolei", "rank": "Species"}, "2368": {"name": "Arhodomonas", "rank": "Genus"}, "1204738": {"name": "Halomonas titanicae BH1", "rank": "Strain"}, "621372": {"name": "Paenibacillus sp. oral taxon 786 str. D14", "rank": "Strain"}, "417400": {"name": "Vibrio cholerae B33", "rank": "Strain"}, "44251": {"name": "Paenibacillus durus", "rank": "Species"}, "125316": {"name": "Beutenbergiaceae", "rank": "Family"}, "585524": {"name": "Lactobacillus amylolyticus DSM 11664", "rank": "Strain"}, "585520": {"name": "Lactobacillus helveticus DSM 20075 = CGMCC 1.1877", "rank": "Strain"}, "1136534": {"name": "Bacillus phage BCD7", "rank": "Species"}, "1136535": {"name": "Burkholderia phage DC1", "rank": "Species"}, "585529": {"name": "Corynebacterium genitalium ATCC 33030", "rank": "Strain"}, "585528": {"name": "Gardnerella vaginalis ATCC 14018 = JCM 11026", "rank": "Strain"}, "363832": {"name": "Solirubrobacter soli", "rank": "Species"}, "1114921": {"name": "Citrobacter werkmanii NBRC 105721", "rank": "Strain"}, "658763": {"name": "Saccharomyces cerevisiae Sigma1278b", "rank": "Strain"}, "823": {"name": "Parabacteroides distasonis", "rank": "Species"}, "1422140": {"name": "Staphylococcus aureus DAR3590", "rank": "Strain"}, "821": {"name": "Bacteroides vulgatus", "rank": "Species"}, "820": {"name": "Bacteroides uniformis", "rank": "Species"}, "827": {"name": "Campylobacter ureolyticus", "rank": "Species"}, "826": {"name": "Sebaldella termitidis", "rank": "Species"}, "1422147": {"name": "Staphylococcus aureus DAR3612", "rank": "Strain"}, "1422146": {"name": "Staphylococcus aureus DAR3609", "rank": "Strain"}, "1422149": {"name": "Staphylococcus aureus DAR3616", "rank": "Strain"}, "1422148": {"name": "Staphylococcus aureus DAR3613", "rank": "Strain"}, "39669": {"name": "Methanosalsum zhilinae", "rank": "Species"}, "356623": {"name": "Unclassified Inovirus", "rank": "No rank"}, "437063": {"name": "Ageratum yellow vein Hualian virus", "rank": "Species"}, "414970": {"name": "Enterobacteria phage cdtI", "rank": "Species"}, "67780": {"name": "Edwardsiella ictaluri", "rank": "Species"}, "1448833": {"name": "Mycobacterium tuberculosis H3367", "rank": "Strain"}, "420402": {"name": "Marinobacterium rhizophilum", "rank": "Species"}, "1009842": {"name": "Unclassified Hepeviridae", "rank": "No rank"}, "670904": {"name": "Escherichia coli OK1180", "rank": "Strain"}, "670905": {"name": "Escherichia coli OK1357", "rank": "Strain"}, "1009846": {"name": "Burkholderia cepacia GG4", "rank": "Strain"}, "553207": {"name": "Corynebacterium matruchotii ATCC 14266", "rank": "Strain"}, "553206": {"name": "Corynebacterium tuberculostearicum SK141", "rank": "Strain"}, "1439068": {"name": "Streptococcus pyogenes ABC020032057", "rank": "Strain"}, "553204": {"name": "Corynebacterium amycolatum SK46", "rank": "Strain"}, "324900": {"name": "Heterosigma akashiwo RNA virus", "rank": "Species"}, "324901": {"name": "Marnaviridae", "rank": "Family"}, "553201": {"name": "Rothia mucilaginosa ATCC 25296", "rank": "Strain"}, "198628": {"name": "Dickeya dadantii 3937", "rank": "Strain"}, "1439060": {"name": "Streptococcus pyogenes ABC020030063", "rank": "Strain"}, "1439066": {"name": "Streptococcus pyogenes ABC020031290", "rank": "Strain"}, "1439067": {"name": "Streptococcus pyogenes ABC020031898", "rank": "Strain"}, "553209": {"name": "Enterococcus faecalis TUSoD Ef11", "rank": "Strain"}, "36866": {"name": "Unclassified Enterobacteriaceae (miscellaneous)", "rank": "No rank"}, "36861": {"name": "Thiobacillus denitrificans", "rank": "Species"}, "1138906": {"name": "Enterococcus faecium EnGen0031", "rank": "Strain"}, "505321": {"name": "Staphylococcus aureus subsp. aureus str. CF-Marseille", "rank": "Strain"}, "36868": {"name": "Wigglesworthia glossinidia endosymbiont of Glossina morsitans", "rank": "Strain"}, "1292391": {"name": "Francisella tularensis subsp. tularensis 80700069", "rank": "Strain"}, "1292390": {"name": "Francisella tularensis subsp. tularensis 79201237", "rank": "Strain"}, "1292392": {"name": "Borrelia miyamotoi FR64b", "rank": "Strain"}, "32199": {"name": "Buchnera", "rank": "Genus"}, "253314": {"name": "Clostridium straminisolvens", "rank": "Species"}, "1151127": {"name": "Pseudomonas mandelii 36MFCvi1.1", "rank": "Strain"}, "471189": {"name": "Gordonibacter pamelaeae", "rank": "Species"}, "1055487": {"name": "Methylotenera versatilis", "rank": "Species"}, "1416031": {"name": "Escherichia phage bV_EcoS_AKS96", "rank": "Species"}, "191436": {"name": "Gremmeniella abietina RNA virus MS1", "rank": "Species"}, "1079800": {"name": "Rhizobium mesoamericanum", "rank": "Species"}, "754343": {"name": "Actinobacillus pleuropneumoniae serovar 4", "rank": "Strain"}, "148879": {"name": "Banana mild mosaic virus", "rank": "Species"}, "754347": {"name": "Actinobacillus pleuropneumoniae serovar 10", "rank": "Strain"}, "754346": {"name": "Actinobacillus pleuropneumoniae serovar 9", "rank": "Strain"}, "1588685": {"name": "Wenzhou virus", "rank": "Species"}, "754348": {"name": "Actinobacillus pleuropneumoniae serovar 11", "rank": "Strain"}, "1087454": {"name": "Corynebacterium pseudotuberculosis 1/06-A", "rank": "Strain"}, "1087452": {"name": "Corynebacterium pseudotuberculosis 3/99-5", "rank": "Strain"}, "1087453": {"name": "Corynebacterium pseudotuberculosis 42/02-A", "rank": "Strain"}, "1087451": {"name": "Corynebacterium pseudotuberculosis 31", "rank": "Strain"}, "81852": {"name": "Enterococcaceae", "rank": "Family"}, "1593364": {"name": "Candidatus Nitrosopelagicus", "rank": "Genus"}, "81850": {"name": "Leuconostocaceae", "rank": "Family"}, "298386": {"name": "Photobacterium profundum SS9", "rank": "Strain"}, "34353": {"name": "Dipodascaceae", "rank": "Family"}, "1048207": {"name": "Escherichia phage phiEB49", "rank": "Species"}, "67255": {"name": "Streptomyces achromogenes", "rank": "Species"}, "67257": {"name": "Streptomyces albus subsp. albus", "rank": "Subspecies"}, "67256": {"name": "Streptomyces achromogenes subsp. achromogenes", "rank": "Subspecies"}, "868210": {"name": "Escherichia coli DEC15E", "rank": "Strain"}, "1461743": {"name": "Vibrio phage PVA1", "rank": "Species"}, "58641": {"name": "Debaryomyces hansenii var. hansenii", "rank": "Varietas"}, "76728": {"name": "Streptomyces vitaminophilus", "rank": "Species"}, "857474": {"name": "Unclassified Spounavirinae", "rank": "No rank"}, "857473": {"name": "Spounavirinae", "rank": "Subfamily"}, "857479": {"name": "Peduovirinae", "rank": "Subfamily"}, "1211417": {"name": "Uncultured phage crAssphage", "rank": "Species"}, "47917": {"name": "Serratia fonticola", "rank": "Species"}, "1236548": {"name": "Bacillus subtilis subsp. inaquosorum KCTC 13429", "rank": "Strain"}, "672190": {"name": "Streptococcus suis 05HAS68", "rank": "Strain"}, "746032": {"name": "Mobilicoccus pelagius", "rank": "Species"}, "299567": {"name": "Adhaeribacter aquaticus", "rank": "Species"}, "299566": {"name": "Adhaeribacter", "rank": "Genus"}, "1310602": {"name": "Acinetobacter baumannii 96512", "rank": "Strain"}, "911120": {"name": "Methanobrevibacter smithii TS146C", "rank": "Strain"}, "911121": {"name": "Methanobrevibacter smithii TS146D", "rank": "Strain"}, "911122": {"name": "Methanobrevibacter smithii TS146E", "rank": "Strain"}, "911123": {"name": "Methanobrevibacter smithii TS147A", "rank": "Strain"}, "911124": {"name": "Methanobrevibacter smithii TS147B", "rank": "Strain"}, "911125": {"name": "Methanobrevibacter smithii TS147C", "rank": "Strain"}, "911126": {"name": "Methanobrevibacter smithii TS94A", "rank": "Strain"}, "911127": {"name": "Methanobrevibacter smithii TS94B", "rank": "Strain"}, "911128": {"name": "Methanobrevibacter smithii TS94C", "rank": "Strain"}, "911129": {"name": "Methanobrevibacter smithii TS95A", "rank": "Strain"}, "1238235": {"name": "Chlamydia psittaci 10_881_SC42", "rank": "Strain"}, "1238231": {"name": "Vibrio parahaemolyticus 10290", "rank": "Strain"}, "1217810": {"name": "Pectobacterium phage PP1", "rank": "Species"}, "1438668": {"name": "Escherichia coli BIDMC 58", "rank": "Strain"}, "311207": {"name": "Gaetbulibacter", "rank": "Genus"}, "311205": {"name": "Harpophora", "rank": "Genus"}, "444193": {"name": "Botrytis cinerea mitovirus 1", "rank": "Species"}, "311208": {"name": "Gaetbulibacter saemankumensis", "rank": "Species"}, "46228": {"name": "Ruminococcus lactaris", "rank": "Species"}, "1484157": {"name": "Pantoea sp. PSNIH2", "rank": "Species"}, "447600": {"name": "Mimosa yellow leaf curl virus satellite DNA beta", "rank": "Species"}, "447603": {"name": "Erectites yellow mosaic virus satellite DNA beta", "rank": "Species"}, "1484158": {"name": "Pantoea sp. PSNIH1", "rank": "Species"}, "447602": {"name": "Sida yellow vein Vietnam virus satellite DNA beta", "rank": "Species"}, "402584": {"name": "Bovine viral diarrhea virus 3 Th/04_KhonKaen", "rank": "Strain"}, "447605": {"name": "Lindernia anagallis yellow vein virus satellite DNA beta", "rank": "Species"}, "447606": {"name": "Alternanthera yellow vein betasatellite", "rank": "Species"}, "323848": {"name": "Nitrosospira multiformis ATCC 25196", "rank": "Strain"}, "444447": {"name": "Escherichia coli O157:H7 str. EC4206", "rank": "Strain"}, "537874": {"name": "Streptococcus phage PH15", "rank": "Species"}, "444448": {"name": "Escherichia coli O157:H7 str. EC4045", "rank": "Strain"}, "1325331": {"name": "Moorella thermoacetica Y72", "rank": "Strain"}, "682634": {"name": "Serratia plymuthica 4Rx13", "rank": "Strain"}, "682633": {"name": "Mesorhizobium ciceri ca181", "rank": "Strain"}, "368617": {"name": "Unclassified Luteovirus", "rank": "No rank"}, "1397999": {"name": "Staphylococcus aureus M1370", "rank": "Strain"}, "1397998": {"name": "Staphylococcus aureus M1369", "rank": "Strain"}, "184914": {"name": "Corallococcus coralloides", "rank": "Species"}, "1397997": {"name": "Staphylococcus aureus M1368", "rank": "Strain"}, "1397996": {"name": "Staphylococcus aureus M1366", "rank": "Strain"}, "1145192": {"name": "Neisseria meningitidis NM51", "rank": "Strain"}, "1145193": {"name": "Neisseria meningitidis NM80", "rank": "Strain"}, "1145190": {"name": "Neisseria meningitidis NM3164", "rank": "Strain"}, "1145191": {"name": "Neisseria meningitidis NM27", "rank": "Strain"}, "1403928": {"name": "Staphylococcus aureus M1555", "rank": "Strain"}, "1145195": {"name": "Neisseria meningitidis NM3223", "rank": "Strain"}, "1403926": {"name": "Staphylococcus aureus M1553", "rank": "Strain"}, "1403927": {"name": "Staphylococcus aureus M1554", "rank": "Strain"}, "1403924": {"name": "Staphylococcus aureus M1551", "rank": "Strain"}, "1403925": {"name": "Staphylococcus aureus M1552", "rank": "Strain"}, "1403922": {"name": "Staphylococcus aureus M1549", "rank": "Strain"}, "1403923": {"name": "Staphylococcus aureus M1550", "rank": "Strain"}, "1403920": {"name": "Staphylococcus aureus M1547", "rank": "Strain"}, "1403921": {"name": "Staphylococcus aureus M1548", "rank": "Strain"}, "1388452": {"name": "Staphylococcus aureus M0678", "rank": "Strain"}, "1388453": {"name": "Staphylococcus aureus M0679", "rank": "Strain"}, "1388450": {"name": "Staphylococcus aureus M0674", "rank": "Strain"}, "1388451": {"name": "Staphylococcus aureus M0677", "rank": "Strain"}, "1388456": {"name": "Staphylococcus aureus M0682", "rank": "Strain"}, "1388457": {"name": "Staphylococcus aureus M0683", "rank": "Strain"}, "1388454": {"name": "Staphylococcus aureus M0680", "rank": "Strain"}, "1388455": {"name": "Staphylococcus aureus M0681", "rank": "Strain"}, "1388458": {"name": "Staphylococcus aureus M0684", "rank": "Strain"}, "1388459": {"name": "Staphylococcus aureus M0685", "rank": "Strain"}, "1160175": {"name": "Brucella abortus NI639", "rank": "Strain"}, "1160174": {"name": "Brucella abortus NI633", "rank": "Strain"}, "1160177": {"name": "Brucella abortus 63/168", "rank": "Strain"}, "1160176": {"name": "Brucella abortus NI645", "rank": "Strain"}, "687917": {"name": "Fusarium graminearum dsRNA mycovirus-3", "rank": "Species"}, "687916": {"name": "Yersinia pestis KIM D27", "rank": "Strain"}, "687915": {"name": "Salmonella enterica subsp. enterica serovar Dublin str. SL1438", "rank": "Strain"}, "1160172": {"name": "Brucella abortus NI613", "rank": "Strain"}, "687918": {"name": "Fusarium graminearum dsRNA mycovirus-4", "rank": "Species"}, "1160179": {"name": "Brucella abortus 85/69", "rank": "Strain"}, "1160178": {"name": "Brucella abortus 88/19", "rank": "Strain"}, "1201288": {"name": "Bacteriovorax sp. Seq25_V", "rank": "Species"}, "1316583": {"name": "Streptococcus intermedius ATCC 27335", "rank": "Strain"}, "977880": {"name": "Cupriavidus taiwanensis LMG 19424", "rank": "Strain"}, "1316587": {"name": "Fusobacterium nucleatum CTI-6", "rank": "Strain"}, "1316586": {"name": "Fusobacterium nucleatum CTI-5", "rank": "Strain"}, "1316588": {"name": "Fusobacterium nucleatum CTI-7", "rank": "Strain"}, "237576": {"name": "Oribacterium sinus", "rank": "Species"}, "1168744": {"name": "Listeria phage vB_LmoM_AG20", "rank": "Species"}, "258230": {"name": "Frankia sp. CeD", "rank": "Species"}, "1223523": {"name": "Streptomyces mobaraensis NBRC 13819 = DSM 40847", "rank": "Strain"}, "100226": {"name": "Streptomyces coelicolor A3(2)", "rank": "Strain"}, "1068617": {"name": "Escherichia coli O104:H4 str. 11-4632 C1", "rank": "Strain"}, "1068616": {"name": "Escherichia coli O104:H4 str. 11-4623", "rank": "Strain"}, "1068615": {"name": "Escherichia coli O104:H4 str. 11-4522", "rank": "Strain"}, "1068614": {"name": "Escherichia coli O104:H4 str. 11-4404", "rank": "Strain"}, "1457194": {"name": "Pseudomonas aeruginosa CF_PA39", "rank": "Strain"}, "1457195": {"name": "Ralstonia solanacearum Rs-10-244", "rank": "Strain"}, "1457192": {"name": "Escherichia coli LR09", "rank": "Strain"}, "1457190": {"name": "Listeria ivanovii WSLC3009", "rank": "Strain"}, "546275": {"name": "Fusobacterium periodonticum ATCC 33693", "rank": "Strain"}, "361731": {"name": "Desmodium leaf distortion virus", "rank": "Species"}, "1502": {"name": "Clostridium perfringens", "rank": "Species"}, "1266729": {"name": "Bordetella holmesii F627", "rank": "Strain"}, "1501": {"name": "Clostridium pasteurianum", "rank": "Species"}, "1507": {"name": "Clostridium sp. ATCC 29733", "rank": "Species"}, "1505": {"name": "Clostridium sordellii", "rank": "Species"}, "10756": {"name": "Bacillus phage phi29", "rank": "Species"}, "10754": {"name": "Enterobacteria phage P22", "rank": "Species"}, "1509": {"name": "Clostridium sporogenes", "rank": "Species"}, "10752": {"name": "Escherichia phage N4", "rank": "Species"}, "101688": {"name": "Apple latent spherical virus", "rank": "Species"}, "101689": {"name": "Tetrasphaera elongata", "rank": "Species"}, "1005512": {"name": "Escherichia coli PA47", "rank": "Strain"}, "230667": {"name": "Chitinibacter tainanensis", "rank": "Species"}, "230666": {"name": "Chitinibacter", "rank": "Genus"}, "1422141": {"name": "Staphylococcus aureus DAR3591", "rank": "Strain"}, "938665": {"name": "Alpha proteobacterium SCGC AAA280-P20", "rank": "Species"}, "940286": {"name": "Komagataeibacter oboediens 174Bp2", "rank": "Strain"}, "938663": {"name": "Alpha proteobacterium SCGC AAA280-B11", "rank": "Species"}, "1434319": {"name": "Staphylococcus phage vB_SepS_SEP9", "rank": "Species"}, "1422142": {"name": "Staphylococcus aureus DAR3592", "rank": "Strain"}, "511437": {"name": "Lactobacillus buchneri NRRL B-30929", "rank": "Strain"}, "546414": {"name": "Deinococcus deserti VCD115", "rank": "Strain"}, "1422145": {"name": "Staphylococcus aureus DAR3608", "rank": "Strain"}, "1422144": {"name": "Staphylococcus aureus DAR3599", "rank": "Strain"}, "254408": {"name": "Solimonas variicoloris", "rank": "Species"}, "824": {"name": "Campylobacter gracilis", "rank": "Species"}, "1345023": {"name": "Exiguobacterium pavilionensis RW-2", "rank": "Strain"}, "887282": {"name": "Campylobacter coli 132-6", "rank": "Strain"}, "1158135": {"name": "Mycobacterium abscessus M94", "rank": "Strain"}, "357231": {"name": "Murine norovirus", "rank": "Species"}, "357233": {"name": "Cronobacter zurichensis", "rank": "Species"}, "99585": {"name": "Frangipani mosaic virus", "rank": "Species"}, "87097": {"name": "Yam mild mosaic virus", "rank": "Species"}, "1446768": {"name": "Escherichia coli O91:NM str. 2009C-3745", "rank": "Strain"}, "1446767": {"name": "Escherichia coli O91:NM", "rank": "Strain"}, "1446766": {"name": "Escherichia coli O91:H21 str. 2009C-4646", "rank": "Strain"}, "1446765": {"name": "Escherichia coli O91:H21 str. 2009C-3740", "rank": "Strain"}, "1446764": {"name": "Escherichia coli O91:H14 str. 2009C-3227", "rank": "Strain"}, "1446763": {"name": "Escherichia coli O91:H14 str. 06-3691", "rank": "Strain"}, "1446762": {"name": "Escherichia coli O86:H34 str. 99-3124", "rank": "Strain"}, "1446761": {"name": "Escherichia coli O81:NM str. 02-3012", "rank": "Strain"}, "1446760": {"name": "Escherichia coli O79:H7 str. 06-3501", "rank": "Strain"}, "171003": {"name": "Caloranaerobacter", "rank": "Genus"}, "1179226": {"name": "Staphylococcus lentus F1142", "rank": "Strain"}, "1179225": {"name": "Kocuria atrinae C3-8", "rank": "Strain"}, "1179224": {"name": "Lysinibacillus boronitolerans F1182", "rank": "Strain"}, "1537715": {"name": "Sphingopyxis sp. MWB1", "rank": "Species"}, "1209989": {"name": "Tepidanaerobacter acetatoxydans Re1", "rank": "Strain"}, "279010": {"name": "Bacillus licheniformis DSM 13 = ATCC 14580", "rank": "Strain"}, "1422126": {"name": "Staphylococcus aureus DAR3551", "rank": "Strain"}, "681518": {"name": "Tomato leaf deformation virus", "rank": "Species"}, "243560": {"name": "Calla lily latent virus", "rank": "Species"}, "627479": {"name": "Unclassified phiKMV-like phages", "rank": "No rank"}, "271098": {"name": "Shewanella halifaxensis", "rank": "Species"}, "486993": {"name": "Salmonella enterica subsp. enterica serovar Eastbourne", "rank": "Strain"}, "1162083": {"name": "Clitocybe odora virus", "rank": "Species"}, "342409": {"name": "White spot syndrome virus", "rank": "Species"}, "249184": {"name": "Tymoviridae", "rank": "Family"}, "486998": {"name": "Salmonella enterica subsp. enterica serovar Litchfield", "rank": "Strain"}, "486999": {"name": "Salmonella enterica subsp. enterica serovar Meleagridis", "rank": "Strain"}, "1392486": {"name": "Prevotella sp. HUN102", "rank": "Species"}, "1392487": {"name": "Eubacterium sp. AB3007", "rank": "Species"}, "185750": {"name": "Ageratum yellow vein betasatellite", "rank": "Species"}, "249185": {"name": "Maculavirus", "rank": "Genus"}, "1392488": {"name": "Leeuwenhoekiella sp. Hel_I_48", "rank": "Species"}, "1392489": {"name": "Leeuwenhoekiella sp. MAR_2009_132", "rank": "Species"}, "379900": {"name": "Niabella aurantiaca", "rank": "Species"}, "1168170": {"name": "Klebsiella sp. BRL6-2", "rank": "Species"}, "479437": {"name": "Eggerthella lenta DSM 2243", "rank": "Strain"}, "479436": {"name": "Veillonella parvula DSM 2008", "rank": "Strain"}, "479435": {"name": "Kribbella flavida DSM 17836", "rank": "Strain"}, "1283210": {"name": "Permutotetraviridae", "rank": "Family"}, "479434": {"name": "Sphaerobacter thermophilus DSM 20745", "rank": "Strain"}, "537007": {"name": "Blautia hansenii DSM 20583", "rank": "Strain"}, "537006": {"name": "Parabacteroides johnsonii DSM 18315", "rank": "Strain"}, "1118235": {"name": "Stenotrophomonas maltophilia PML168", "rank": "Strain"}, "479433": {"name": "Catenulispora acidiphila DSM 44928", "rank": "Strain"}, "537009": {"name": "Stygiolobus rod-shaped virus", "rank": "Species"}, "1412501": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. SA19940857", "rank": "Strain"}, "479432": {"name": "Streptosporangium roseum DSM 43021", "rank": "Strain"}, "1388102": {"name": "Staphylococcus aureus M0160", "rank": "Strain"}, "479430": {"name": "Actinospica robiniae DSM 44927", "rank": "Strain"}, "496064": {"name": "Salmonella enterica subsp. enterica serovar Typhi str. E98-3139", "rank": "Strain"}, "1120751": {"name": "Chocolate lily virus A", "rank": "Species"}, "1120752": {"name": "Nodosilinea", "rank": "Genus"}, "1436000": {"name": "Edwardsiella tarda ET080729", "rank": "Strain"}, "498301": {"name": "Flavobacterium rivuli", "rank": "Species"}, "541": {"name": "Zymomonas", "rank": "Genus"}, "542": {"name": "Zymomonas mobilis", "rank": "Species"}, "543": {"name": "Enterobacteriaceae", "rank": "Family"}, "544": {"name": "Citrobacter", "rank": "Genus"}, "1151209": {"name": "Enterococcus faecalis EnGen0067", "rank": "Strain"}, "546": {"name": "Citrobacter freundii", "rank": "Species"}, "547": {"name": "Enterobacter", "rank": "Genus"}, "548": {"name": "Enterobacter aerogenes", "rank": "Species"}, "5082": {"name": "Penicillium roqueforti", "rank": "Species"}, "337191": {"name": "Gordonia sp. KTR9", "rank": "Species"}, "1151208": {"name": "Enterococcus faecalis EnGen0072", "rank": "Strain"}, "1422387": {"name": "Staphylococcus aureus DAR116", "rank": "Strain"}, "1422386": {"name": "Staphylococcus aureus DAR104", "rank": "Strain"}, "1422385": {"name": "Staphylococcus aureus DAR26", "rank": "Strain"}, "1422384": {"name": "Staphylococcus aureus DAR5789", "rank": "Strain"}, "1422383": {"name": "Staphylococcus aureus DAR5790", "rank": "Strain"}, "1422382": {"name": "Staphylococcus aureus DAR5791", "rank": "Strain"}, "1422381": {"name": "Staphylococcus aureus DAR5792", "rank": "Strain"}, "1422380": {"name": "Staphylococcus aureus DAR5793", "rank": "Strain"}, "1422389": {"name": "Staphylococcus aureus DAR133", "rank": "Strain"}, "1422388": {"name": "Staphylococcus aureus DAR126", "rank": "Strain"}, "1397670": {"name": "Tomato leaf curl Karnataka betasatellite", "rank": "Species"}, "40538": {"name": "Human papillomavirus type 48", "rank": "Strain"}, "40537": {"name": "Epsilonpapillomavirus 1", "rank": "Species"}, "391896": {"name": "Rickettsia bellii OSU 85-389", "rank": "Strain"}, "130556": {"name": "Culex nigripalpus nucleopolyhedrovirus", "rank": "Species"}, "1124989": {"name": "Escherichia coli C157_11", "rank": "Strain"}, "1281185": {"name": "Escherichia coli UMEA 3117-1", "rank": "Strain"}, "1124980": {"name": "Salmonella enterica subsp. enterica serovar Give str. 564", "rank": "Strain"}, "1124982": {"name": "Treponema sp. JC4", "rank": "Species"}, "1124983": {"name": "Pseudomonas protegens CHA0", "rank": "Strain"}, "1124985": {"name": "Escherichia coli C1244_91", "rank": "Strain"}, "1124986": {"name": "Escherichia coli C12_92", "rank": "Strain"}, "1124987": {"name": "Escherichia coli C154_11", "rank": "Strain"}, "1423568": {"name": "Mycobacterium tuberculosis BTB12-449", "rank": "Strain"}, "1281186": {"name": "Escherichia coli UMEA 3121-1", "rank": "Strain"}, "887901": {"name": "Porphyromonas catoniae ATCC 51270", "rank": "Strain"}, "1423560": {"name": "Mycobacterium tuberculosis BTB12-294", "rank": "Strain"}, "1423561": {"name": "Mycobacterium tuberculosis BTB12-304", "rank": "Strain"}, "1423562": {"name": "Mycobacterium tuberculosis BTB12-305", "rank": "Strain"}, "1423563": {"name": "Mycobacterium tuberculosis BTB12-313", "rank": "Strain"}, "1423564": {"name": "Mycobacterium tuberculosis BTB12-314", "rank": "Strain"}, "1423565": {"name": "Mycobacterium tuberculosis BTB12-315", "rank": "Strain"}, "1423566": {"name": "Mycobacterium tuberculosis BTB12-384", "rank": "Strain"}, "1423567": {"name": "Mycobacterium tuberculosis BTB12-400", "rank": "Strain"}, "1123255": {"name": "Simplicispira psychrophila DSM 11588", "rank": "Strain"}, "679926": {"name": "Methanolacinia petrolearia DSM 11571", "rank": "Strain"}, "1123257": {"name": "Solimonas flava DSM 18980", "rank": "Strain"}, "1123256": {"name": "Solimonas variicoloris DSM 15731", "rank": "Strain"}, "1123251": {"name": "Serinicoccus marinus DSM 15273", "rank": "Strain"}, "1123250": {"name": "Selenomonas bovis DSM 23594", "rank": "Strain"}, "1123253": {"name": "Silanimonas lenta DSM 16282", "rank": "Strain"}, "1123252": {"name": "Shimazuella kribbensis DSM 45090", "rank": "Strain"}, "653358": {"name": "Ipomoea yellow vein virus", "rank": "Species"}, "1123258": {"name": "Smaragdicoccus niigatensis DSM 44881 = NBRC 103563", "rank": "Strain"}, "1231241": {"name": "Thermotoga sp. Mc24", "rank": "Species"}, "1165368": {"name": "Candida albicans Ca6", "rank": "Strain"}, "348449": {"name": "Raphanus sativus cryptic virus 1", "rank": "Species"}, "926844": {"name": "Tobacco curly shoot alphasatellite", "rank": "Species"}, "452652": {"name": "Kitasatospora setae KM-6054", "rank": "Strain"}, "1247024": {"name": "Arsenophonus endosymbiont str. Hangzhou of Nilaparvata lugens", "rank": "Strain"}, "1041156": {"name": "Sinorhizobium meliloti RRl128", "rank": "Strain"}, "452659": {"name": "Rickettsia rickettsii str. Iowa", "rank": "Strain"}, "1247023": {"name": "Arsenophonus endosymbiont of Nilaparvata lugens", "rank": "Species"}, "322095": {"name": "Porphyromonas somerae", "rank": "Species"}, "1499968": {"name": "Paenibacillus sp. TCA20", "rank": "Species"}, "1182701": {"name": "Escherichia coli KTE102", "rank": "Strain"}, "1204538": {"name": "Pseudomonas phage Phi-S1", "rank": "Species"}, "1204539": {"name": "Pectobacterium phage My1", "rank": "Species"}, "1204537": {"name": "Caulobacter phage phiCbK", "rank": "Species"}, "1204534": {"name": "Clostridium phage phiMMP02", "rank": "Species"}, "1204535": {"name": "Clostridium phage phiMMP04", "rank": "Species"}, "286780": {"name": "Salmonella enterica subsp. enterica serovar Miami", "rank": "Strain"}, "286783": {"name": "Salmonella enterica subsp. enterica serovar Indiana", "rank": "Strain"}, "286782": {"name": "Salmonella enterica subsp. enterica serovar Stanleyville", "rank": "Strain"}, "1330491": {"name": "Cosavirus A", "rank": "Species"}, "159290": {"name": "Desulfonatronum thiodismutans", "rank": "Species"}, "1409508": {"name": "Staphylococcus aureus WMCA6006", "rank": "Strain"}, "1409509": {"name": "Staphylococcus aureus WMCS6047", "rank": "Strain"}, "1409506": {"name": "Staphylococcus aureus HOAG6025", "rank": "Strain"}, "1409507": {"name": "Staphylococcus aureus GGMC6004", "rank": "Strain"}, "1409504": {"name": "Staphylococcus aureus SCOA6008", "rank": "Strain"}, "1409505": {"name": "Staphylococcus aureus SCOA6009", "rank": "Strain"}, "1409502": {"name": "Staphylococcus aureus KINW6002", "rank": "Strain"}, "1409503": {"name": "Staphylococcus aureus SCOA6006", "rank": "Strain"}, "1409500": {"name": "Staphylococcus aureus UCIM6009", "rank": "Strain"}, "1409501": {"name": "Staphylococcus aureus KINW6001", "rank": "Strain"}, "1034138": {"name": "Mycobacterium phage KLucky39", "rank": "Species"}, "1412599": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20100089", "rank": "Strain"}, "1412598": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20100088", "rank": "Strain"}, "1412591": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20130348", "rank": "Strain"}, "1412590": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20130347", "rank": "Strain"}, "1412593": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20121176", "rank": "Strain"}, "1412592": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20121175", "rank": "Strain"}, "1412595": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20121178", "rank": "Strain"}, "1412594": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20121177", "rank": "Strain"}, "1412597": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20121180", "rank": "Strain"}, "1412596": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20121179", "rank": "Strain"}, "1090926": {"name": "Escherichia coli W26", "rank": "Strain"}, "1090927": {"name": "Escherichia coli O104:H4 str. E92/11", "rank": "Strain"}, "1090928": {"name": "Escherichia coli O104:H4 str. E112/10", "rank": "Strain"}, "1090929": {"name": "Escherichia coli O127:H27 str. C43/90", "rank": "Strain"}, "253107": {"name": "Natronolimnobius innermongolicus", "rank": "Species"}, "61366": {"name": "Fusarium oxysporum f. cubense", "rank": "Forma"}, "527028": {"name": "Bacillus thuringiensis serovar pulsiensis BGSC 4CC1", "rank": "Strain"}, "1422378": {"name": "Staphylococcus aureus DAR5795", "rank": "Strain"}, "1133292": {"name": "Brucella phage Tb", "rank": "Species"}, "527029": {"name": "Bacillus thuringiensis serovar pondicheriensis BGSC 4BA1", "rank": "Strain"}, "1240677": {"name": "Mycobacterium tuberculosis UM 1072388579", "rank": "Strain"}, "640331": {"name": "Lactobacillus florum", "rank": "Species"}, "670903": {"name": "Escherichia coli TX1999", "rank": "Strain"}, "13335": {"name": "Anaerobiospirillum succiniciproducens", "rank": "Species"}, "13334": {"name": "Anaerobiospirillum", "rank": "Genus"}, "438744": {"name": "Halomonas caseinilytica", "rank": "Species"}, "1268883": {"name": "Staphylococcus aureus 880", "rank": "Strain"}, "158846": {"name": "Megamonas", "rank": "Genus"}, "158847": {"name": "Megamonas hypermegale", "rank": "Species"}, "1422370": {"name": "Staphylococcus aureus DAR5803", "rank": "Strain"}, "324902": {"name": "Marnavirus", "rank": "Genus"}, "1001263": {"name": "Cotton leaf curl virus associated DNA 1 isolate Lucknow", "rank": "Species"}, "1345549": {"name": "Helicobacter pylori SA302A", "rank": "Strain"}, "1345548": {"name": "Helicobacter pylori SA301C", "rank": "Strain"}, "1345543": {"name": "Helicobacter pylori SA47C", "rank": "Strain"}, "1345542": {"name": "Helicobacter pylori SA301A", "rank": "Strain"}, "1345541": {"name": "Helicobacter pylori SA300C", "rank": "Strain"}, "1345540": {"name": "Helicobacter pylori SA300A", "rank": "Strain"}, "1345547": {"name": "Helicobacter pylori SA146C", "rank": "Strain"}, "1345546": {"name": "Helicobacter pylori SA146A", "rank": "Strain"}, "1345545": {"name": "Helicobacter pylori SA144C", "rank": "Strain"}, "1345544": {"name": "Helicobacter pylori SA144A", "rank": "Strain"}, "147545": {"name": "Eurotiomycetes", "rank": "Class"}, "1500510": {"name": "Halovirus VNH-1", "rank": "Species"}, "1281188": {"name": "Escherichia coli UMEA 3124-1", "rank": "Strain"}, "285540": {"name": "Streptomyces thermolilacinus", "rank": "Species"}, "996311": {"name": "Tomato leaf curl Madagascar virus-Menabe Madagascar:Morondova:2001", "rank": "Strain"}, "1439064": {"name": "Streptococcus pyogenes ABC020030925", "rank": "Strain"}, "1287232": {"name": "Mesorhizobium sp. LNHC220B00", "rank": "Species"}, "1287233": {"name": "Mesorhizobium sp. LNHC221B00", "rank": "Species"}, "1281189": {"name": "Escherichia coli UMEA 3139-1", "rank": "Strain"}, "552466": {"name": "Filobasidiella/Cryptococcus neoformans species complex", "rank": "No rank"}, "552467": {"name": "Cryptococcus gattii", "rank": "Species"}, "294710": {"name": "Proteiniphilum acetatigenes", "rank": "Species"}, "147548": {"name": "Leotiomycetes", "rank": "Class"}, "1005564": {"name": "Escherichia coli TW00353", "rank": "Strain"}, "1005565": {"name": "Escherichia coli 3006", "rank": "Strain"}, "1005566": {"name": "Escherichia coli 07798", "rank": "Strain"}, "1005567": {"name": "Escherichia coli N1", "rank": "Strain"}, "1005560": {"name": "Escherichia coli EC96038", "rank": "Strain"}, "1005561": {"name": "Escherichia coli 5412", "rank": "Strain"}, "1005562": {"name": "Escherichia coli TW15901", "rank": "Strain"}, "1005563": {"name": "Escherichia coli ARS4.2123", "rank": "Strain"}, "96473": {"name": "Aeromonas salmonicida subsp. pectinolytica", "rank": "Subspecies"}, "325473": {"name": "Psychroserpens mesophilus", "rank": "Species"}, "889204": {"name": "Streptococcus infantis ATCC 700779", "rank": "Strain"}, "1410689": {"name": "Staphylococcus aureus W28469", "rank": "Strain"}, "1410688": {"name": "Staphylococcus aureus T45974", "rank": "Strain"}, "1410687": {"name": "Staphylococcus aureus M81493", "rank": "Strain"}, "1410686": {"name": "Staphylococcus aureus M81490", "rank": "Strain"}, "1410685": {"name": "Staphylococcus aureus M81424", "rank": "Strain"}, "1410684": {"name": "Staphylococcus aureus W25097", "rank": "Strain"}, "1410681": {"name": "Methyloglobulus morosus", "rank": "Species"}, "1410680": {"name": "Methyloglobulus", "rank": "Genus"}, "1226757": {"name": "Streptomyces rapamycinicus", "rank": "Species"}, "1226754": {"name": "Paenibacillus sp. FSL R5-192", "rank": "Species"}, "1226755": {"name": "Paenibacillus sp. FSL R7-269", "rank": "Species"}, "1223501": {"name": "Geobacillus thermoglucosidasius NBRC 107763", "rank": "Strain"}, "1128966": {"name": "Salmonella enterica subsp. enterica serovar Heidelberg str. 29169", "rank": "Strain"}, "1128967": {"name": "Salmonella enterica subsp. enterica serovar Heidelberg str. N18413", "rank": "Strain"}, "1128964": {"name": "Salmonella enterica subsp. enterica serovar Heidelberg str. N30678", "rank": "Strain"}, "1128965": {"name": "Salmonella enterica subsp. enterica serovar Heidelberg str. 32507", "rank": "Strain"}, "1128962": {"name": "Salmonella enterica subsp. enterica serovar Heidelberg str. N29341", "rank": "Strain"}, "1128963": {"name": "Salmonella enterica subsp. enterica serovar Heidelberg str. 41565", "rank": "Strain"}, "1128960": {"name": "Salmonella enterica subsp. enterica serovar Heidelberg str. 41576", "rank": "Strain"}, "1128961": {"name": "Salmonella enterica subsp. enterica serovar Heidelberg str. 41584", "rank": "Strain"}, "51656": {"name": "Kluyveromyces dobzhanskii", "rank": "Species"}, "1128968": {"name": "Salmonella enterica subsp. enterica serovar Heidelberg str. N18440", "rank": "Strain"}, "1128969": {"name": "Salmonella enterica subsp. enterica serovar Heidelberg str. N18453", "rank": "Strain"}, "1295394": {"name": "Campylobacter jejuni subsp. jejuni ICDCCJ07002", "rank": "Strain"}, "1295392": {"name": "Photobacterium gaetbulicola", "rank": "Species"}, "130499": {"name": "Bovine adenovirus D", "rank": "Species"}, "146785": {"name": "Thermosynechococcus", "rank": "Genus"}, "434346": {"name": "Cyanophage PP", "rank": "Species"}, "1438759": {"name": "Klebsiella pneumoniae CHS 53", "rank": "Strain"}, "4899": {"name": "Schizosaccharomyces octosporus", "rank": "Species"}, "1438758": {"name": "Klebsiella pneumoniae CHS 52", "rank": "Strain"}, "555779": {"name": "Desulfonatronospira thiodismutans ASO3-1", "rank": "Strain"}, "555778": {"name": "Halothiobacillus neapolitanus c2", "rank": "Strain"}, "4893": {"name": "Saccharomycetaceae", "rank": "Family"}, "4892": {"name": "Saccharomycetales", "rank": "Order"}, "4891": {"name": "Saccharomycetes", "rank": "Class"}, "4890": {"name": "Ascomycota", "rank": "Phylum"}, "4897": {"name": "Schizosaccharomyces japonicus", "rank": "Species"}, "4896": {"name": "Schizosaccharomyces pombe", "rank": "Species"}, "4895": {"name": "Schizosaccharomyces", "rank": "Genus"}, "4894": {"name": "Schizosaccharomycetaceae", "rank": "Family"}, "1413347": {"name": "Staphylococcus aureus 08-01728", "rank": "Strain"}, "1413346": {"name": "Staphylococcus aureus 08-01229", "rank": "Strain"}, "1413345": {"name": "Staphylococcus aureus 08-01062", "rank": "Strain"}, "1413344": {"name": "Staphylococcus aureus 08-01059", "rank": "Strain"}, "1413343": {"name": "Staphylococcus aureus 63-D10", "rank": "Strain"}, "1413342": {"name": "Staphylococcus aureus 23237", "rank": "Strain"}, "1413341": {"name": "Staphylococcus aureus 22846", "rank": "Strain"}, "1413340": {"name": "Staphylococcus aureus 22843", "rank": "Strain"}, "1422221": {"name": "Staphylococcus aureus DAR1161", "rank": "Strain"}, "1413349": {"name": "Staphylococcus aureus 09-00736", "rank": "Strain"}, "1413348": {"name": "Staphylococcus aureus 08-02906", "rank": "Strain"}, "1121349": {"name": "Comamonas composti DSM 21721", "rank": "Strain"}, "1121348": {"name": "Comamonas badia DSM 17552", "rank": "Strain"}, "760788": {"name": "Streptococcus pneumoniae GA17484", "rank": "Strain"}, "760786": {"name": "Streptococcus pneumoniae GA17371", "rank": "Strain"}, "1121344": {"name": "Clostridium viride DSM 6836", "rank": "Strain"}, "1121347": {"name": "Cohnella thermotolerans DSM 17683", "rank": "Strain"}, "760785": {"name": "Streptococcus pneumoniae GA17301", "rank": "Strain"}, "760782": {"name": "Streptococcus pneumoniae GA16833", "rank": "Strain"}, "760780": {"name": "Streptococcus pneumoniae GA16242", "rank": "Strain"}, "1121342": {"name": "Clostridium tyrobutyricum DSM 2637 = ATCC 25755 = JCM 11008", "rank": "Strain"}, "67826": {"name": "Citrobacter sedlakii", "rank": "Species"}, "67827": {"name": "Citrobacter werkmanii", "rank": "Species"}, "67824": {"name": "Citrobacter farmeri", "rank": "Species"}, "67825": {"name": "Citrobacter rodentium", "rank": "Species"}, "67820": {"name": "Microgenomates", "rank": "Phylum"}, "407837": {"name": "Tomato leaf curl Pune virus", "rank": "Species"}, "1423533": {"name": "Mycobacterium tuberculosis BTB11-001", "rank": "Strain"}, "365489": {"name": "Dyadobacter beijingensis", "rank": "Species"}, "538379": {"name": "Sphingobium quisquiliarum", "rank": "Species"}, "1233100": {"name": "Bacillus subtilis XF-1", "rank": "Strain"}, "68": {"name": "Lysobacter", "rank": "Genus"}, "64": {"name": "Herpetosiphon", "rank": "Genus"}, "65": {"name": "Herpetosiphon aurantiacus", "rank": "Species"}, "61": {"name": "Vitreoscilla stercoraria", "rank": "Species"}, "649": {"name": "Aeromonas eucrenophila", "rank": "Species"}, "32629": {"name": "Indian peanut clump virus", "rank": "Species"}, "1136218": {"name": "Escherichia coli O104:H4 str. ON2011", "rank": "Strain"}, "1136217": {"name": "Escherichia coli O104:H4 str. ON2010", "rank": "Strain"}, "642": {"name": "Aeromonas", "rank": "Genus"}, "641": {"name": "Vibrionaceae", "rank": "Family"}, "646": {"name": "Aeromonas sobria", "rank": "Species"}, "32624": {"name": "Lily mottle virus", "rank": "Species"}, "32625": {"name": "Mushroom bacilliform virus", "rank": "Species"}, "1423539": {"name": "Mycobacterium tuberculosis BTB11-160", "rank": "Strain"}, "204987": {"name": "Goose paramyxovirus SF02", "rank": "Species"}, "1423538": {"name": "Mycobacterium tuberculosis BTB11-139", "rank": "Strain"}, "1157375": {"name": "Enterococcus faecalis EnGen0116", "rank": "Strain"}, "1157374": {"name": "Enterococcus faecalis EnGen0105", "rank": "Strain"}, "1157377": {"name": "Enterococcus faecalis EnGen0118", "rank": "Strain"}, "1157376": {"name": "Enterococcus faecalis EnGen0117", "rank": "Strain"}, "1157371": {"name": "Enterococcus faecalis EnGen0102", "rank": "Strain"}, "1157370": {"name": "Enterococcus faecalis EnGen0101", "rank": "Strain"}, "1157373": {"name": "Enterococcus faecalis EnGen0104", "rank": "Strain"}, "1157372": {"name": "Enterococcus faecalis EnGen0103", "rank": "Strain"}, "193119": {"name": "Pea enation mosaic virus satellite RNA", "rank": "Species"}, "193118": {"name": "Lucerne transient streak virus satellite RNA", "rank": "Species"}, "1157379": {"name": "Enterococcus faecalis EnGen0195", "rank": "Strain"}, "1157378": {"name": "Enterococcus faecalis EnGen0194", "rank": "Strain"}, "2040": {"name": "Aeromicrobium", "rank": "Genus"}, "2047": {"name": "Rothia dentocariosa", "rank": "Species"}, "2044": {"name": "Pimelobacter", "rank": "Genus"}, "2045": {"name": "Pimelobacter simplex", "rank": "Species"}, "2049": {"name": "Actinomycetaceae", "rank": "Family"}, "1261555": {"name": "Wolbachia endosymbiont str. valsugana of Drosophila suzukii", "rank": "Strain"}, "1037410": {"name": "Mycoplasma columbinum SF7", "rank": "Strain"}, "1261557": {"name": "Enterococcus faecalis str. Symbioflor 1", "rank": "Strain"}, "1388610": {"name": "Staphylococcus aureus M0834", "rank": "Strain"}, "1388611": {"name": "Staphylococcus aureus M0836", "rank": "Strain"}, "1388612": {"name": "Staphylococcus aureus M0837", "rank": "Strain"}, "1388613": {"name": "Staphylococcus aureus M0838", "rank": "Strain"}, "1388614": {"name": "Staphylococcus aureus M0839", "rank": "Strain"}, "1388615": {"name": "Staphylococcus aureus M0840", "rank": "Strain"}, "1388616": {"name": "Staphylococcus aureus M0841", "rank": "Strain"}, "1388617": {"name": "Staphylococcus aureus M0842", "rank": "Strain"}, "1388618": {"name": "Staphylococcus aureus M0843", "rank": "Strain"}, "1388619": {"name": "Staphylococcus aureus M0845", "rank": "Strain"}, "1280982": {"name": "Escherichia coli HVH 31 (4-2602156)", "rank": "Strain"}, "158189": {"name": "Sphaerochaeta globosa str. Buddy", "rank": "Strain"}, "55510": {"name": "Staphylococcus phage Twort", "rank": "Species"}, "416169": {"name": "Rhodanobacter thiooxydans", "rank": "Species"}, "650150": {"name": "Erysipelothrix rhusiopathiae str. Fujisawa", "rank": "Strain"}, "1227355": {"name": "Bean chlorotic mosaic virus", "rank": "Species"}, "1227354": {"name": "Bean chlorosis virus", "rank": "Species"}, "1227357": {"name": "Datura leaf distortion virus", "rank": "Species"}, "1227356": {"name": "Dalechampia chlorotic mosaic virus", "rank": "Species"}, "1227351": {"name": "Paenibacillus sp. FSL H8-457", "rank": "Species"}, "1227350": {"name": "Paenibacillus sp. FSL H8-237", "rank": "Species"}, "1227352": {"name": "Paenibacillus sp. FSL R7-277", "rank": "Species"}, "1227359": {"name": "Bacillus weihenstephanensis FSL R5-860", "rank": "Strain"}, "1227358": {"name": "Bacillus weihenstephanensis FSL H7-687", "rank": "Strain"}, "251695": {"name": "Pseudomonas syringae group genomosp. 1", "rank": "Species subgroup"}, "862241": {"name": "Physalacriaceae", "rank": "Family"}, "470137": {"name": "Brucella suis ATCC 23445", "rank": "Strain"}, "1154888": {"name": "Streptococcus agalactiae str. Gottschalk 1003A", "rank": "Strain"}, "59926": {"name": "Prochlorococcus marinus str. SB", "rank": "Strain"}, "10693": {"name": "Enterobacteria phage RB51", "rank": "Species"}, "59924": {"name": "Prochlorococcus marinus str. PAC1", "rank": "Strain"}, "59925": {"name": "Prochlorococcus marinus str. GP2", "rank": "Strain"}, "225067": {"name": "Chlamydia phage 3", "rank": "Species"}, "59920": {"name": "Prochlorococcus marinus str. NATL2A", "rank": "Strain"}, "59921": {"name": "Prochlorococcus marinus str. MIT 9107", "rank": "Strain"}, "1198538": {"name": "Myxococcus xanthus DZF1", "rank": "Strain"}, "10690": {"name": "Haemophilus phage HP1", "rank": "Species"}, "1413489": {"name": "Staphylococcus aureus PA11", "rank": "Strain"}, "624134": {"name": "Enterobacteria phage SSL-2009a", "rank": "Species"}, "67854": {"name": "Actinobacillus succinogenes", "rank": "Species"}, "471881": {"name": "Proteus penneri ATCC 35198", "rank": "Strain"}, "9": {"name": "Buchnera aphidicola", "rank": "Species"}, "1305796": {"name": "Kingella kingae CC254", "rank": "Strain"}, "499202": {"name": "Lichtheimiaceae", "rank": "Family"}, "593105": {"name": "Pantoea sp. Sc1", "rank": "Species"}, "89924": {"name": "Kwoniella heveanensis", "rank": "Species"}, "1409613": {"name": "Staphylococcus aureus SJOS6145", "rank": "Strain"}, "1413480": {"name": "Staphylococcus aureus C5453", "rank": "Strain"}, "1413481": {"name": "Staphylococcus aureus C2549", "rank": "Strain"}, "991923": {"name": "Vibrio cholerae CP1032(5)", "rank": "Strain"}, "991924": {"name": "Vibrio cholerae CP1033(6)", "rank": "Strain"}, "1413482": {"name": "Staphylococcus aureus C2679", "rank": "Strain"}, "991926": {"name": "Vibrio cholerae CP1041(14)", "rank": "Strain"}, "991927": {"name": "Vibrio cholerae CP1042(15)", "rank": "Strain"}, "214856": {"name": "Alistipes finegoldii", "rank": "Species"}, "991929": {"name": "Vibrio cholerae CP1048(21)", "rank": "Strain"}, "214853": {"name": "Anaerofustis stercorihominis", "rank": "Species"}, "214851": {"name": "Subdoligranulum variabile", "rank": "Species"}, "1233524": {"name": "Vibrio cholerae CP1110", "rank": "Strain"}, "1233523": {"name": "Unclassified Gammabaculovirus", "rank": "No rank"}, "1154839": {"name": "Streptococcus agalactiae MRI Z1-202", "rank": "Strain"}, "1305794": {"name": "Kingella kingae D2363", "rank": "Strain"}, "1460371": {"name": "Amycolatopsis lurida NRRL 2430", "rank": "Strain"}, "1460373": {"name": "Chlamydia muridarum str. Nigg 2 MCR", "rank": "Strain"}, "1460374": {"name": "Ustilaginoidea virens RNA virus 3", "rank": "Species"}, "411684": {"name": "Hoeflea phototrophica DFL-43", "rank": "Strain"}, "1104692": {"name": "Unclassified Calescamantes", "rank": "No rank"}, "48543": {"name": "Whataroa virus", "rank": "Species"}, "1409611": {"name": "Staphylococcus aureus WMCA6015", "rank": "Strain"}, "48544": {"name": "Fort Morgan virus", "rank": "Species"}, "1154838": {"name": "Streptococcus agalactiae MRI Z1-201", "rank": "Strain"}, "219744": {"name": "Tomato yellow leaf curl Malaga virus", "rank": "Species"}, "290340": {"name": "Arthrobacter aurescens TC1", "rank": "Strain"}, "1305792": {"name": "Kingella kingae AA068", "rank": "Strain"}, "219748": {"name": "Clostridium tunisiense", "rank": "Species"}, "42092": {"name": "Ureaplasma canigenitalium", "rank": "Species"}, "362698": {"name": "Phaseolus vulgaris endornavirus", "rank": "Species"}, "41292": {"name": "Unclassified Rhizobiales (miscellaneous)", "rank": "No rank"}, "1154882": {"name": "Streptococcus agalactiae MRI Z1-219", "rank": "Strain"}, "943936": {"name": "Psychroserpens damuponensis", "rank": "Species"}, "1409617": {"name": "Staphylococcus aureus WMCA6025", "rank": "Strain"}, "404394": {"name": "Escherichia coli O26:NM", "rank": "Strain"}, "1221249": {"name": "Acinetobacter baumannii AB_1649-8", "rank": "Strain"}, "1221248": {"name": "Acinetobacter baumannii AB_1595-8", "rank": "Strain"}, "1154883": {"name": "Streptococcus agalactiae LDS 610", "rank": "Strain"}, "1221245": {"name": "Acinetobacter baumannii AB_1582-8", "rank": "Strain"}, "1221244": {"name": "Acinetobacter baumannii AB_1536-8", "rank": "Strain"}, "1221247": {"name": "Acinetobacter baumannii AB_1594-8", "rank": "Strain"}, "1221246": {"name": "Acinetobacter baumannii AB_1583-8", "rank": "Strain"}, "63330": {"name": "Hendra virus", "rank": "Species"}, "1225069": {"name": "Pouzolzia golden mosaic virus", "rank": "Species"}, "219299": {"name": "Tomato leaf curl Gujarat virus", "rank": "Species"}, "197913": {"name": "Influenzavirus C", "rank": "Genus"}, "197912": {"name": "Influenzavirus B", "rank": "Genus"}, "197911": {"name": "Influenzavirus A", "rank": "Genus"}, "164393": {"name": "Lactobacillus fuchuensis", "rank": "Species"}, "171279": {"name": "Mycoplasma anatis", "rank": "Species"}, "152263": {"name": "Xanthomonas translucens pv. cerealis", "rank": "Strain"}, "152260": {"name": "Chloroflexus aggregans", "rank": "Species"}, "274591": {"name": "Hoeflea", "rank": "Genus"}, "944564": {"name": "Veillonella sp. oral taxon 780 str. F0422", "rank": "Strain"}, "944565": {"name": "Parvimonas sp. oral taxon 393 str. F0440", "rank": "Strain"}, "944562": {"name": "Lactobacillus oris F0423", "rank": "Strain"}, "944560": {"name": "Actinomyces sp. oral taxon 175 str. F0384", "rank": "Strain"}, "1344046": {"name": "Mycobacterium tuberculosis PanR0207", "rank": "Strain"}, "72763": {"name": "Tessaracoccus", "rank": "Genus"}, "983594": {"name": "Burkholderia cepacia ATCC 25416", "rank": "Strain"}, "40041": {"name": "Streptococcus equi subsp. zooepidemicus", "rank": "Subspecies"}, "501571": {"name": "Butyricicoccus pullicaecorum", "rank": "Species"}, "675635": {"name": "Pseudonocardia dioxanivorans CB1190", "rank": "Strain"}, "408672": {"name": "Nocardioidaceae bacterium Broad-1", "rank": "Species"}, "1237364": {"name": "Enterobacteria phage HX01", "rank": "Species"}, "1158663": {"name": "Enterococcus faecalis EnGen0282", "rank": "Strain"}, "1394605": {"name": "Vibrio parahaemolyticus S062", "rank": "Strain"}, "1394603": {"name": "Vibrio parahaemolyticus S058", "rank": "Strain"}, "887298": {"name": "Campylobacter coli 1961", "rank": "Strain"}, "887299": {"name": "Campylobacter coli 202/04", "rank": "Strain"}, "887296": {"name": "Campylobacter coli 1948", "rank": "Strain"}, "887297": {"name": "Campylobacter coli 1957", "rank": "Strain"}, "331654": {"name": "Alkalibacillus", "rank": "Genus"}, "887295": {"name": "Campylobacter coli 1909", "rank": "Strain"}, "887292": {"name": "Campylobacter coli 1148", "rank": "Strain"}, "887293": {"name": "Campylobacter coli 1417", "rank": "Strain"}, "887290": {"name": "Campylobacter coli 1091", "rank": "Strain"}, "887291": {"name": "Campylobacter coli 1098", "rank": "Strain"}, "1236502": {"name": "Asaia prunellae JCM 25354", "rank": "Strain"}, "1236503": {"name": "Acetobacter persici JCM 25330", "rank": "Strain"}, "1236500": {"name": "Asaia astilbis JCM 15831", "rank": "Strain"}, "1236501": {"name": "Acetobacter okinawensis JCM 25146", "rank": "Strain"}, "182709": {"name": "Oceanobacillus", "rank": "Genus"}, "1236504": {"name": "Prevotella histicola JCM 15637 = DNF00424", "rank": "Strain"}, "1313171": {"name": "Ilumatobacter nonamiensis YM16-303", "rank": "Strain"}, "1236508": {"name": "Prevotella aurantiaca JCM 15754", "rank": "Strain"}, "1313172": {"name": "Ilumatobacter coccineus YM16-304", "rank": "Strain"}, "1169370": {"name": "Escherichia coli KTE97", "rank": "Strain"}, "1169371": {"name": "Escherichia coli KTE99", "rank": "Strain"}, "1169372": {"name": "Escherichia coli KTE104", "rank": "Strain"}, "1169373": {"name": "Escherichia coli KTE105", "rank": "Strain"}, "1169374": {"name": "Escherichia coli KTE106", "rank": "Strain"}, "1169375": {"name": "Escherichia coli KTE109", "rank": "Strain"}, "1169376": {"name": "Escherichia coli KTE112", "rank": "Strain"}, "1169377": {"name": "Escherichia coli KTE113", "rank": "Strain"}, "1169378": {"name": "Escherichia coli KTE117", "rank": "Strain"}, "1169379": {"name": "Escherichia coli KTE120", "rank": "Strain"}, "1408923": {"name": "Mycobacterium tuberculosis UT0040", "rank": "Strain"}, "1408922": {"name": "Mycobacterium tuberculosis UT0038", "rank": "Strain"}, "1408921": {"name": "Mycobacterium tuberculosis UT0037", "rank": "Strain"}, "1408920": {"name": "Mycobacterium tuberculosis UT0036", "rank": "Strain"}, "1408927": {"name": "Mycobacterium tuberculosis UT0046", "rank": "Strain"}, "1408926": {"name": "Mycobacterium tuberculosis UT0045", "rank": "Strain"}, "1408925": {"name": "Mycobacterium tuberculosis UT0044", "rank": "Strain"}, "1408924": {"name": "Mycobacterium tuberculosis UT0041", "rank": "Strain"}, "1310703": {"name": "Acinetobacter baumannii 1417041", "rank": "Strain"}, "479645": {"name": "Leptospira wolffii serovar Khorat", "rank": "Strain"}, "1408929": {"name": "Mycobacterium tuberculosis UT0050", "rank": "Strain"}, "1408928": {"name": "Mycobacterium tuberculosis UT0048", "rank": "Strain"}, "1310707": {"name": "Acinetobacter baumannii 318814", "rank": "Strain"}, "1310706": {"name": "Acinetobacter baumannii 1412924", "rank": "Strain"}, "1310705": {"name": "Acinetobacter baumannii 694762", "rank": "Strain"}, "1339339": {"name": "Bacteroides fragilis str. 1007-1-F #5", "rank": "Strain"}, "1339338": {"name": "Bacteroides fragilis str. 1007-1-F #4", "rank": "Strain"}, "1339337": {"name": "Bacteroides fragilis str. 1007-1-F #3", "rank": "Strain"}, "1339336": {"name": "Bacteroides fragilis str. 34-F-2 #13", "rank": "Strain"}, "1339335": {"name": "Bacteroides fragilis str. 3-F-2 #6", "rank": "Strain"}, "1339332": {"name": "Bacteroides fragilis str. S38L5", "rank": "Strain"}, "1339331": {"name": "Bacteroides fragilis str. S38L3", "rank": "Strain"}, "1339330": {"name": "Bacteroides fragilis str. S23L24", "rank": "Strain"}, "1398039": {"name": "Staphylococcus aureus M1422", "rank": "Strain"}, "1398038": {"name": "Staphylococcus aureus M1421", "rank": "Strain"}, "1398035": {"name": "Staphylococcus aureus M1417", "rank": "Strain"}, "1398034": {"name": "Staphylococcus aureus M1416", "rank": "Strain"}, "1398037": {"name": "Staphylococcus aureus M1420", "rank": "Strain"}, "1398036": {"name": "Staphylococcus aureus M1418", "rank": "Strain"}, "1398031": {"name": "Staphylococcus aureus M1413", "rank": "Strain"}, "1398030": {"name": "Staphylococcus aureus M1412", "rank": "Strain"}, "1398033": {"name": "Staphylococcus aureus M1415", "rank": "Strain"}, "1398032": {"name": "Staphylococcus aureus M1414", "rank": "Strain"}, "28292": {"name": "Sandfly fever Sicilian virus", "rank": "Species"}, "393125": {"name": "Listeria monocytogenes FSL R2-503", "rank": "Strain"}, "393126": {"name": "Listeria monocytogenes FSL R2-561", "rank": "Strain"}, "393127": {"name": "Listeria monocytogenes Finland 1998", "rank": "Strain"}, "393121": {"name": "Listeria monocytogenes FSL J2-071", "rank": "Strain"}, "436295": {"name": "Salmonella enterica subsp. enterica serovar Poona", "rank": "Strain"}, "393128": {"name": "Listeria monocytogenes F6900", "rank": "Strain"}, "546231": {"name": "Pseudomonas syringae pv. tomato T1", "rank": "Strain"}, "992048": {"name": "Helicobacter pylori Hp H-43", "rank": "Strain"}, "992049": {"name": "Helicobacter pylori Hp H-44", "rank": "Strain"}, "425386": {"name": "Pyrococcus abyssi virus 1", "rank": "Species"}, "992042": {"name": "Helicobacter pylori Hp H-29", "rank": "Strain"}, "992043": {"name": "Helicobacter pylori Hp H-30", "rank": "Strain"}, "992040": {"name": "Helicobacter pylori Hp H-27", "rank": "Strain"}, "992041": {"name": "Helicobacter pylori Hp H-28", "rank": "Strain"}, "992046": {"name": "Helicobacter pylori Hp H-41", "rank": "Strain"}, "992047": {"name": "Helicobacter pylori Hp H-42", "rank": "Strain"}, "992044": {"name": "Helicobacter pylori Hp H-36", "rank": "Strain"}, "505250": {"name": "Maribacter antarcticus", "rank": "Species"}, "405948": {"name": "Saccharopolyspora erythraea NRRL 2338", "rank": "Strain"}, "472175": {"name": "Nitratireductor basaltis", "rank": "Species"}, "1154889": {"name": "Streptococcus agalactiae str. Gottschalk 1005B", "rank": "Strain"}, "1154886": {"name": "Streptococcus agalactiae LDS 628", "rank": "Strain"}, "186677": {"name": "Hepevirus", "rank": "Genus"}, "1281123": {"name": "Escherichia coli HVH 196 (4-4530470)", "rank": "Strain"}, "1154884": {"name": "Streptococcus agalactiae LDS 617", "rank": "Strain"}, "685782": {"name": "Bartonella rochalimae ATCC BAA-1498", "rank": "Strain"}, "216945": {"name": "Spiroplasma syrphidicola", "rank": "Species"}, "1154885": {"name": "Streptococcus agalactiae LDS 623", "rank": "Strain"}, "1281126": {"name": "Escherichia coli HVH 199 (4-5670322)", "rank": "Strain"}, "1287106": {"name": "Mesorhizobium sp. L2C067A000", "rank": "Species"}, "1281127": {"name": "Escherichia coli HVH 200 (4-4449924)", "rank": "Strain"}, "1281124": {"name": "Escherichia coli HVH 197 (4-4466217)", "rank": "Strain"}, "28295": {"name": "Porcine epidemic diarrhea virus", "rank": "Species"}, "1154881": {"name": "Streptococcus agalactiae MRI Z1-218", "rank": "Strain"}, "1154782": {"name": "Streptococcus agalactiae FSL S3-105", "rank": "Strain"}, "1399146": {"name": "Enterobacter cloacae S611", "rank": "Strain"}, "1399147": {"name": "Holospora obtusa F1", "rank": "Strain"}, "1399144": {"name": "Brevibacillus laterosporus PE36", "rank": "Strain"}, "1399145": {"name": "Pseudomonas putida S610", "rank": "Strain"}, "1564182": {"name": "San Miguel sea lion virus 8", "rank": "Species"}, "1144328": {"name": "Pseudomonas sp. GM30", "rank": "Species"}, "76860": {"name": "Streptococcus constellatus", "rank": "Species"}, "1388249": {"name": "Staphylococcus aureus M0376", "rank": "Strain"}, "1388248": {"name": "Staphylococcus aureus M0373", "rank": "Strain"}, "946234": {"name": "Flavonifractor", "rank": "Genus"}, "946235": {"name": "Oceanobacillus massiliensis str. N'diop", "rank": "Strain"}, "314318": {"name": "Prolixibacter", "rank": "Genus"}, "314319": {"name": "Prolixibacter bellariivorans", "rank": "Species"}, "1388243": {"name": "Staphylococcus aureus M0366", "rank": "Strain"}, "76869": {"name": "Pseudomonas putida GB-1", "rank": "Strain"}, "1388241": {"name": "Staphylococcus aureus M0361", "rank": "Strain"}, "1388240": {"name": "Staphylococcus aureus M0360", "rank": "Strain"}, "1388247": {"name": "Staphylococcus aureus M0372", "rank": "Strain"}, "1388246": {"name": "Staphylococcus aureus M0370", "rank": "Strain"}, "1388245": {"name": "Staphylococcus aureus M0369", "rank": "Strain"}, "1388244": {"name": "Staphylococcus aureus M0368", "rank": "Strain"}, "670252": {"name": "Xylella phage Xfas53", "rank": "Species"}, "1390078": {"name": "Streptococcus pyogenes SP3-LAU", "rank": "Strain"}, "402626": {"name": "Ralstonia pickettii 12J", "rank": "Strain"}, "670251": {"name": "Leucas zeylanica yellow vein virus satellite DNA beta", "rank": "Species"}, "1244118": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20110360", "rank": "Strain"}, "1244119": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20110361", "rank": "Strain"}, "1390075": {"name": "Cronobacter turicensis z508", "rank": "Strain"}, "1390076": {"name": "Streptococcus pyogenes SP1-LAU", "rank": "Strain"}, "742765": {"name": "Dorea formicigenerans 4_6_53AFAA", "rank": "Strain"}, "742766": {"name": "Dysgonomonas gadei ATCC BAA-286", "rank": "Strain"}, "742767": {"name": "Dysgonomonas mossii DSM 22836", "rank": "Strain"}, "742768": {"name": "Eggerthella lenta 1_1_60AFAA", "rank": "Strain"}, "862909": {"name": "Trichodysplasia spinulosa-associated polyomavirus", "rank": "Species"}, "862908": {"name": "Bacteriovorax marinus SJ", "rank": "Strain"}, "10892": {"name": "Orbivirus", "rank": "Genus"}, "1391032": {"name": "Faecal-associated gemycircularvirus 3", "rank": "Species"}, "1391033": {"name": "Faecal-associated gemycircularvirus 4", "rank": "Species"}, "1403793": {"name": "Umbelopsidaceae", "rank": "Family"}, "1434211": {"name": "Burkholderia pseudomallei BDU 2", "rank": "Strain"}, "1391036": {"name": "Faecal-associated gemycircularvirus 7", "rank": "Species"}, "1391034": {"name": "Faecal-associated gemycircularvirus 5", "rank": "Species"}, "1391035": {"name": "Faecal-associated gemycircularvirus 6", "rank": "Species"}, "134047": {"name": "Salmonella enterica subsp. enterica serovar Bredeney", "rank": "Strain"}, "563124": {"name": "Mycobacterium phage Chah", "rank": "Species"}, "563121": {"name": "Mycobacterium phage Konstantine", "rank": "Species"}, "563123": {"name": "Mycobacterium phage Ramsey", "rank": "Species"}, "563122": {"name": "Mycobacterium phage Pacc40", "rank": "Species"}, "1402774": {"name": "Staphylococcus aureus M1288", "rank": "Strain"}, "1402775": {"name": "Staphylococcus aureus M1289", "rank": "Strain"}, "1402776": {"name": "Staphylococcus aureus M1290", "rank": "Strain"}, "1402777": {"name": "Staphylococcus aureus M1292", "rank": "Strain"}, "1402770": {"name": "Staphylococcus aureus M1282", "rank": "Strain"}, "1402771": {"name": "Staphylococcus aureus M1283", "rank": "Strain"}, "1402772": {"name": "Staphylococcus aureus M1285", "rank": "Strain"}, "1402773": {"name": "Staphylococcus aureus M1287", "rank": "Strain"}, "1402778": {"name": "Staphylococcus aureus M1293", "rank": "Strain"}, "1402779": {"name": "Staphylococcus aureus M1294", "rank": "Strain"}, "1446489": {"name": "Escherichia phage vB_EcoS_FFH1", "rank": "Species"}, "1175444": {"name": "Methanocella conradii", "rank": "Species"}, "1121035": {"name": "Azovibrio restrictus DSM 23866", "rank": "Strain"}, "1121034": {"name": "Niveispirillum irakense DSM 11586", "rank": "Strain"}, "1121033": {"name": "Azospirillum halopraeferens DSM 3675", "rank": "Strain"}, "1121032": {"name": "Azonexus hydrophilus DSM 23864", "rank": "Strain"}, "1121030": {"name": "Azohydromonas australica DSM 1124", "rank": "Strain"}, "1261617": {"name": "Duganella zoogloeoides ATCC 25935", "rank": "Strain"}, "171121": {"name": "Sulfurihydrogenibium subterraneum", "rank": "Species"}, "11138": {"name": "Murine hepatitis virus", "rank": "Strain"}, "649831": {"name": "Actinoplanes sp. N902-109", "rank": "Species"}, "1095699": {"name": "Neisseria meningitidis 98080", "rank": "Strain"}, "1095698": {"name": "Neisseria meningitidis 68094", "rank": "Strain"}, "1296119": {"name": "Kwoniella heveanensis CBS 569", "rank": "Strain"}, "1095693": {"name": "Neisseria meningitidis 2006087", "rank": "Strain"}, "1095692": {"name": "Neisseria meningitidis 2002038", "rank": "Strain"}, "1095691": {"name": "Neisseria meningitidis 97014", "rank": "Strain"}, "1095690": {"name": "Neisseria meningitidis M13255", "rank": "Strain"}, "1095697": {"name": "Neisseria meningitidis 97021", "rank": "Strain"}, "1095696": {"name": "Neisseria meningitidis 88050", "rank": "Strain"}, "1095695": {"name": "Neisseria meningitidis 70012", "rank": "Strain"}, "1095694": {"name": "Neisseria meningitidis 63041", "rank": "Strain"}, "1408440": {"name": "Gemella sanguinis ATCC 700632", "rank": "Strain"}, "1408441": {"name": "Helicobacter bilis ATCC 51630", "rank": "Strain"}, "1408442": {"name": "Helicobacter pametensis ATCC 51478", "rank": "Strain"}, "1408443": {"name": "Lactobacillus fermentum NB-22", "rank": "Strain"}, "1408444": {"name": "Legionella fairfieldensis ATCC 49588", "rank": "Strain"}, "1408445": {"name": "Legionella sainthelensi ATCC 35248", "rank": "Strain"}, "1408446": {"name": "Leptospira licerasiae ATCC BAA-1110", "rank": "Strain"}, "1408447": {"name": "Mesoplasma grammopterae ATCC 49580", "rank": "Strain"}, "1408448": {"name": "Mesoplasma photuris ATCC 49581", "rank": "Strain"}, "1408449": {"name": "Mesoplasma syrphidae ATCC 51578", "rank": "Strain"}, "279356": {"name": "Aquimarina muelleri", "rank": "Species"}, "1121961": {"name": "Hirschia maritima", "rank": "Species"}, "1121960": {"name": "Halomonas zhanjiangensis", "rank": "Species"}, "312182": {"name": "Unclassified Saccharomycetaceae", "rank": "No rank"}, "312185": {"name": "Equine rhinitis B virus", "rank": "Species"}, "486898": {"name": "Tomato leaf curl Bangalore virus-Ban5 satellite DNA beta", "rank": "Species"}, "1192688": {"name": "Salmonella enterica subsp. enterica serovar Dublin str. UC16", "rank": "Strain"}, "1192689": {"name": "Salmonella enterica subsp. enterica serovar Dublin str. DG22", "rank": "Strain"}, "1213733": {"name": "Staphylococcus aureus M0900", "rank": "Strain"}, "1328418": {"name": "Klebsiella pneumoniae BIDMC 23", "rank": "Strain"}, "1328419": {"name": "Klebsiella pneumoniae BIDMC 24", "rank": "Strain"}, "61673": {"name": "Porcine endogenous retrovirus", "rank": "Strain"}, "1470392": {"name": "Unclassified Solibacterales", "rank": "No rank"}, "1328410": {"name": "Klebsiella pneumoniae BIDMC 14", "rank": "Strain"}, "1328411": {"name": "Klebsiella pneumoniae BIDMC 16", "rank": "Strain"}, "1328412": {"name": "Klebsiella pneumoniae BIDMC 18A", "rank": "Strain"}, "1328413": {"name": "Klebsiella pneumoniae BIDMC 18B", "rank": "Strain"}, "1328414": {"name": "Klebsiella pneumoniae BIDMC 18C", "rank": "Strain"}, "1328415": {"name": "Klebsiella pneumoniae BIDMC 18D", "rank": "Strain"}, "1328416": {"name": "Klebsiella pneumoniae BIDMC 21", "rank": "Strain"}, "1328417": {"name": "Klebsiella pneumoniae BIDMC 22", "rank": "Strain"}, "313588": {"name": "Croceibacter atlanticus", "rank": "Species"}, "1422042": {"name": "Mycobacterium tuberculosis TB_RSA126", "rank": "Strain"}, "1334627": {"name": "Lactobacillus gasseri K7", "rank": "Strain"}, "165096": {"name": "Weissella koreensis", "rank": "Species"}, "252602": {"name": "Snake adeno-associated virus", "rank": "Strain"}, "346181": {"name": "Lysobacter daejeonensis", "rank": "Species"}, "36427": {"name": "Rotavirus C", "rank": "Species"}, "28304": {"name": "Murid herpesvirus 2", "rank": "Species"}, "28300": {"name": "Heron hepatitis B virus", "rank": "Species"}, "1471460": {"name": "Prochlorococcus sp. scB241_528P14", "rank": "Species"}, "1217627": {"name": "Acinetobacter baumannii NIPH 67", "rank": "Strain"}, "201174": {"name": "Actinobacteria", "rank": "Phylum"}, "443255": {"name": "Streptomyces clavuligerus ATCC 27064", "rank": "Strain"}, "1281179": {"name": "Escherichia coli UMEA 3065-1", "rank": "Strain"}, "1281178": {"name": "Escherichia coli UMEA 3053-1", "rank": "Strain"}, "713": {"name": "Actinobacillus", "rank": "Genus"}, "712": {"name": "Pasteurellaceae", "rank": "Family"}, "715": {"name": "Actinobacillus pleuropneumoniae", "rank": "Species"}, "1232658": {"name": "Aquaparamyxovirus", "rank": "Genus"}, "717": {"name": "Actinobacillus capsulatus", "rank": "Species"}, "716": {"name": "Actinobacillus suis", "rank": "Species"}, "1154855": {"name": "Streptococcus agalactiae STIR-CD-27", "rank": "Strain"}, "718": {"name": "Actinobacillus equuli", "rank": "Species"}, "1003195": {"name": "Streptomyces cattleya NRRL 8057 = DSM 46488", "rank": "Strain"}, "544405": {"name": "Helicobacter pylori 98-10", "rank": "Strain"}, "1281175": {"name": "Escherichia coli UMEA 3033-1", "rank": "Strain"}, "1003192": {"name": "Salmonella enterica subsp. enterica serovar Tennessee str. TXSC_TXSC08-21", "rank": "Strain"}, "1003191": {"name": "Salmonella enterica subsp. enterica serovar Tennessee str. TXSC_TXSC08-19", "rank": "Strain"}, "1580062": {"name": "Pseudoalteromonas sp. ECSMB14103", "rank": "Species"}, "1338033": {"name": "Vibrio parahaemolyticus O1:Kuk", "rank": "Strain"}, "1402810": {"name": "Staphylococcus aureus M1332", "rank": "Strain"}, "1402813": {"name": "Staphylococcus aureus M1336", "rank": "Strain"}, "1402812": {"name": "Staphylococcus aureus M1334", "rank": "Strain"}, "1158169": {"name": "Thioalkalivibrio sp. ALE9", "rank": "Species"}, "1402814": {"name": "Staphylococcus aureus M1337", "rank": "Strain"}, "1338035": {"name": "Campylobacter jejuni 32488", "rank": "Strain"}, "1338034": {"name": "Vibrio parahaemolyticus O1:Kuk str. FDA_R31", "rank": "Strain"}, "1158165": {"name": "Thioalkalivibrio sp. ALMg11", "rank": "Species"}, "1158167": {"name": "Thioalkalivibrio sp. ALMg13-2", "rank": "Species"}, "1471468": {"name": "Prochlorococcus sp. scB241_529O19", "rank": "Species"}, "1158163": {"name": "Thioalkalivibrio sp. ALMg3", "rank": "Species"}, "1158162": {"name": "Thioalkalivibrio sp. ALgr5", "rank": "Species"}, "40479": {"name": "Mycoplasma capricolum subsp. capricolum", "rank": "Subspecies"}, "1438679": {"name": "Escherichia coli BIDMC 75", "rank": "Strain"}, "40477": {"name": "Mycoplasma mycoides subsp. capri", "rank": "Subspecies"}, "509173": {"name": "Acinetobacter baumannii AYE", "rank": "Strain"}, "509170": {"name": "Acinetobacter baumannii SDF", "rank": "Strain"}, "1232188": {"name": "Clostridium botulinum CFSAN001628", "rank": "Strain"}, "744985": {"name": "Alpha proteobacterium HIMB59", "rank": "Species"}, "1284702": {"name": "Clostridiales genomosp. BVAB3 str. S7-24-11", "rank": "Strain"}, "744980": {"name": "Roseibium sp. TrichSKD4", "rank": "Species"}, "1158293": {"name": "Oxalobacteraceae bacterium AB_14", "rank": "Species"}, "1158292": {"name": "Thiomonas sp. FB-Cd", "rank": "Species"}, "1158291": {"name": "Thiomonas sp. FB-6", "rank": "Species"}, "1438672": {"name": "Escherichia coli BIDMC 64", "rank": "Strain"}, "1158294": {"name": "Prevotella sp. 10(H)", "rank": "Species"}, "1240086": {"name": "Dickeya solani RNS 08.23.3.1.A", "rank": "Strain"}, "174178": {"name": "Citrus yellow mosaic virus", "rank": "Species"}, "52438": {"name": "Colobus monkey papillomavirus", "rank": "Species"}, "340054": {"name": "Bacteriophage APSE-2", "rank": "Species"}, "634127": {"name": "Burkholderia heleia", "rank": "Species"}, "61459": {"name": "Coniosporium apollinis", "rank": "Species"}, "56730": {"name": "Rhizobium gallicum", "rank": "Species"}, "56731": {"name": "Rhizobium giardinii", "rank": "Species"}, "1231362": {"name": "Unclassified Bpp-1-like viruses", "rank": "No rank"}, "1231361": {"name": "Unclassified phiKZ-like viruses", "rank": "No rank"}, "1231360": {"name": "Unclassified Epsilon15likevirus", "rank": "No rank"}, "1415756": {"name": "Oceanicola sp. MCTG156(1a)", "rank": "Species"}, "220664": {"name": "Pseudomonas protegens Pf-5", "rank": "Strain"}, "593275": {"name": "Buchnera aphidicola str. LSR1 (Acyrthosiphon pisum)", "rank": "Strain"}, "220668": {"name": "Lactobacillus plantarum WCFS1", "rank": "Strain"}, "1458427": {"name": "Comamonadaceae bacterium H1", "rank": "Species"}, "1458426": {"name": "Comamonadaceae bacterium B1", "rank": "Species"}, "1458425": {"name": "Comamonadaceae bacterium A1", "rank": "Species"}, "568386": {"name": "Sinobacteraceae", "rank": "Family"}, "1123069": {"name": "Rubellimicrobium thermophilum DSM 16684", "rank": "Strain"}, "1123067": {"name": "Rubellimicrobium mesophilum", "rank": "Species"}, "1123065": {"name": "Ruania albidiflava DSM 18029", "rank": "Strain"}, "1123060": {"name": "Roseomonas aerilata DSM 19363", "rank": "Strain"}, "1422754": {"name": "Staphylococcus aureus VET0632S", "rank": "Strain"}, "1422755": {"name": "Staphylococcus aureus VET0645S", "rank": "Strain"}, "1422756": {"name": "Staphylococcus aureus VET0657S", "rank": "Strain"}, "1422757": {"name": "Staphylococcus aureus VET0678S", "rank": "Strain"}, "1422750": {"name": "Staphylococcus aureus VET1914R", "rank": "Strain"}, "1422751": {"name": "Staphylococcus aureus VET1915R", "rank": "Strain"}, "1422752": {"name": "Staphylococcus aureus VET0519S", "rank": "Strain"}, "1422753": {"name": "Staphylococcus aureus VET0612S", "rank": "Strain"}, "655183": {"name": "Lactobacillus casei group", "rank": "Species group"}, "1379687": {"name": "Klebsiella pneumoniae subsp. pneumoniae BJ1-GA", "rank": "Strain"}, "1422758": {"name": "Staphylococcus aureus VET0679S", "rank": "Strain"}, "1422759": {"name": "Staphylococcus aureus VET0765S", "rank": "Strain"}, "1427984": {"name": "Candidatus Hepatoplasma crinochetorum Av", "rank": "Strain"}, "1427985": {"name": "Bordetella bronchiseptica KM22", "rank": "Strain"}, "208177": {"name": "Tomato leaf curl Vietnam virus", "rank": "Species"}, "377315": {"name": "Mariprofundus", "rank": "Genus"}, "440079": {"name": "Aeromonas bivalvium", "rank": "Species"}, "53344": {"name": "Staphylococcus delphini", "rank": "Species"}, "53345": {"name": "Enterococcus durans", "rank": "Species"}, "53346": {"name": "Enterococcus mundtii", "rank": "Species"}, "1302646": {"name": "Enterococcus faecium LCT-EF301", "rank": "Strain"}, "469588": {"name": "Bacteroides sp. 2_1_22", "rank": "Species"}, "469589": {"name": "Bacteroides sp. 2_1_33B", "rank": "Species"}, "469586": {"name": "Bacteroides sp. 1_1_6", "rank": "Species"}, "469587": {"name": "Bacteroides sp. 2_1_16", "rank": "Species"}, "1425362": {"name": "Carrot betaflexivirus 2", "rank": "Species"}, "469585": {"name": "Bacteroides sp. 1_1_14", "rank": "Species"}, "1425364": {"name": "Carrot torradovirus 1", "rank": "Species"}, "1402570": {"name": "Pseudomonas aeruginosa M8A.4", "rank": "Strain"}, "1402571": {"name": "Pseudomonas aeruginosa M9A.1", "rank": "Strain"}, "1367493": {"name": "Pseudomonas aeruginosa PAO1-VE2", "rank": "Strain"}, "1500288": {"name": "Chryseobacterium sp. YR005", "rank": "Species"}, "1335746": {"name": "Spiribacter salinus", "rank": "Species"}, "394239": {"name": "Koala retrovirus", "rank": "Species"}, "1335745": {"name": "Spiribacter", "rank": "Genus"}, "1248823": {"name": "Escherichia coli O145:H28 str. RM12581", "rank": "Strain"}, "500577": {"name": "Nesiotobacter", "rank": "Genus"}, "1464011": {"name": "Kitasatospora papulosa", "rank": "Species"}, "223317": {"name": "Sida golden yellow vein virus", "rank": "Species"}, "223316": {"name": "Sida golden mosaic Honduras virus", "rank": "Species"}, "223314": {"name": "Sida golden mosaic Florida virus", "rank": "Species"}, "223313": {"name": "Sida golden mosaic Costa Rica virus", "rank": "Species"}, "1412722": {"name": "Staphylococcus aureus F43212", "rank": "Strain"}, "1412723": {"name": "Staphylococcus aureus F43221", "rank": "Strain"}, "1412720": {"name": "Staphylococcus aureus F36699", "rank": "Strain"}, "1412721": {"name": "Staphylococcus aureus F43199", "rank": "Strain"}, "1412726": {"name": "Staphylococcus aureus F46785", "rank": "Strain"}, "1412727": {"name": "Staphylococcus aureus F46798", "rank": "Strain"}, "1412724": {"name": "Staphylococcus aureus F43252", "rank": "Strain"}, "283675": {"name": "Clostera anachoreta granulovirus", "rank": "Species"}, "1273135": {"name": "Aeromonas hydrophila 145", "rank": "Strain"}, "1412728": {"name": "Staphylococcus aureus F50076", "rank": "Strain"}, "1412729": {"name": "Staphylococcus aureus F50093", "rank": "Strain"}, "1273132": {"name": "Liberibacter crescens", "rank": "Species"}, "1273133": {"name": "Lactobacillus salivarius cp400", "rank": "Strain"}, "1182173": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN000662", "rank": "Strain"}, "1422650": {"name": "Staphylococcus aureus VET0426R", "rank": "Strain"}, "1005424": {"name": "Escherichia coli 99.0713", "rank": "Strain"}, "640513": {"name": "Enterobacter asburiae LF7a", "rank": "Strain"}, "1331247": {"name": "Bordetella pertussis 2250905", "rank": "Strain"}, "1331245": {"name": "Bordetella bronchiseptica SO10328", "rank": "Strain"}, "1331244": {"name": "Bordetella bronchiseptica SBL-F6116", "rank": "Strain"}, "1331243": {"name": "Bordetella bronchiseptica RB630", "rank": "Strain"}, "1331242": {"name": "Bordetella bronchiseptica OSU553", "rank": "Strain"}, "1331241": {"name": "Bordetella bronchiseptica OSU095", "rank": "Strain"}, "1331240": {"name": "Bordetella bronchiseptica MO275", "rank": "Strain"}, "1331249": {"name": "Bordetella pertussis 2371640", "rank": "Strain"}, "1331248": {"name": "Bordetella pertussis 2356847", "rank": "Strain"}, "1268341": {"name": "Ralstonia sp. JGI 0001001-B07", "rank": "Species"}, "1268340": {"name": "Proteobacteria bacterium JGI 0001013-N05", "rank": "Species"}, "1268345": {"name": "Bradyrhizobium sp. JGI 0001019-J21", "rank": "Species"}, "1412643": {"name": "Staphylococcus aureus F81381", "rank": "Strain"}, "1268349": {"name": "Burkholderia sp. JGI 0001021-D09", "rank": "Species"}, "1268348": {"name": "Burkholderia sp. JGI 0001021-N16", "rank": "Species"}, "749489": {"name": "Enterococcus faecalis DAPTO 512", "rank": "Strain"}, "1310158": {"name": "Klebsiella pneumoniae Kb140", "rank": "Strain"}, "487174": {"name": "Barnesiella intestinihominis", "rank": "Species"}, "242527": {"name": "Burkholderia phage Bcep22", "rank": "Species"}, "591365": {"name": "Streptococcus intermedius JTH08", "rank": "Strain"}, "1074325": {"name": "Sclerotinia sclerotiorum hypovirus 1", "rank": "Species"}, "760570": {"name": "Streptococcus parasanguinis ATCC 15912", "rank": "Strain"}, "1125653": {"name": "Salmonella phage SPN1S", "rank": "Species"}, "1125652": {"name": "Escherichia coli 179100", "rank": "Strain"}, "1125651": {"name": "Escherichia coli P0304799.3", "rank": "Strain"}, "1125650": {"name": "Escherichia coli P0299483.3", "rank": "Strain"}, "1034943": {"name": "Legionella massiliensis", "rank": "Species"}, "205841": {"name": "Cryocola", "rank": "Genus"}, "205844": {"name": "Novosphingobium pentaromativorans", "rank": "Species"}, "521045": {"name": "Kosmotoga olearia TBF 19.5.1", "rank": "Strain"}, "1510391": {"name": "Geobacter sp. GSS01", "rank": "Species"}, "1412695": {"name": "Staphylococcus aureus T34036", "rank": "Strain"}, "561555": {"name": "Zhouia", "rank": "Genus"}, "1500281": {"name": "Chryseobacterium sp. CF284", "rank": "Species"}, "1272910": {"name": "Streptococcus anginosus subsp. whileyi", "rank": "Subspecies"}, "1500280": {"name": "Herbiconiux sp. YR403", "rank": "Species"}, "249584": {"name": "West Caucasian bat virus", "rank": "Species"}, "1123306": {"name": "Streptococcus marimammalium DSM 18627", "rank": "Strain"}, "151537": {"name": "Lactococcus phage bIL309", "rank": "Species"}, "151536": {"name": "Lactococcus phage bIL286", "rank": "Species"}, "151535": {"name": "Lactococcus phage bIL285", "rank": "Species"}, "151534": {"name": "Lactococcus phage bIL311", "rank": "Species"}, "151539": {"name": "Lactococcus phage bIL312", "rank": "Species"}, "151538": {"name": "Lactococcus phage bIL310", "rank": "Species"}, "1590063": {"name": "Lactobacillus sp. FMNP02", "rank": "Species"}, "435838": {"name": "Staphylococcus capitis C87", "rank": "Strain"}, "435832": {"name": "Neisseria mucosa C102", "rank": "Strain"}, "435830": {"name": "Actinomyces graevenitzii C83", "rank": "Strain"}, "435837": {"name": "Staphylococcus hominis subsp. hominis C80", "rank": "Strain"}, "194948": {"name": "Escherichia Stx1 converting phage", "rank": "Species"}, "57495": {"name": "Dermacoccus", "rank": "Genus"}, "1448602": {"name": "Mycobacterium tuberculosis TKK_04_0150", "rank": "Strain"}, "4751": {"name": "Fungi", "rank": "Kingdom"}, "4753": {"name": "Pneumocystis", "rank": "Genus"}, "423445": {"name": "KI polyomavirus", "rank": "Species"}, "1074094": {"name": "Streptococcus sobrinus TCI-2", "rank": "Strain"}, "1074095": {"name": "Streptococcus mutans TCI-11", "rank": "Strain"}, "1265845": {"name": "Listeria weihenstephanensis FSL R9-0317", "rank": "Strain"}, "1074090": {"name": "Streptococcus sobrinus TCI-396", "rank": "Strain"}, "1280967": {"name": "Escherichia coli HVH 16 (4-7649002)", "rank": "Strain"}, "1074092": {"name": "Streptococcus mutans TCI-399", "rank": "Strain"}, "1074093": {"name": "Streptococcus mutans TCI-400", "rank": "Strain"}, "1101192": {"name": "Methylobacterium sp. 77", "rank": "Species"}, "1101193": {"name": "Methylotenera versatilis 7", "rank": "Strain"}, "1101190": {"name": "Methylopila sp. M107", "rank": "Species"}, "1101191": {"name": "Methylobacterium sp. 10", "rank": "Species"}, "1101195": {"name": "Methylophilaceae bacterium 11", "rank": "Species"}, "1280963": {"name": "Escherichia coli HVH 9 (4-6942539)", "rank": "Strain"}, "148363": {"name": "Helicoverpa armigera nucleopolyhedrovirus G4", "rank": "Strain"}, "1400145": {"name": "Enterobacter aerogenes UCI 48", "rank": "Strain"}, "1400144": {"name": "Enterobacter aerogenes UCI 47", "rank": "Strain"}, "1400147": {"name": "Enterobacter cloacae UCI 24", "rank": "Strain"}, "1400146": {"name": "Enterobacter cloacae UCI 23", "rank": "Strain"}, "1400141": {"name": "Enterobacter aerogenes UCI 28", "rank": "Strain"}, "1400140": {"name": "Enterobacter aerogenes UCI 27", "rank": "Strain"}, "1400143": {"name": "Enterobacter aerogenes UCI 46", "rank": "Strain"}, "1400142": {"name": "Enterobacter aerogenes UCI 45", "rank": "Strain"}, "1400149": {"name": "Enterobacter cloacae UCI 30", "rank": "Strain"}, "1400148": {"name": "Enterobacter cloacae UCI 29", "rank": "Strain"}, "517436": {"name": "Anaplasma marginale str. Mississippi", "rank": "Strain"}, "1280969": {"name": "Escherichia coli HVH 18 (4-8589585)", "rank": "Strain"}, "1260769": {"name": "Ageratum enation alphasatellite", "rank": "Species"}, "38504": {"name": "Ureaplasma parvum serovar 3", "rank": "Strain"}, "1499107": {"name": "Smithella sp. SCADC", "rank": "Species"}, "178830": {"name": "Bornaviridae", "rank": "Family"}, "492476": {"name": "Ruminiclostridium thermocellum JW20", "rank": "Strain"}, "1036743": {"name": "Rhodospirillum rubrum F11", "rank": "Strain"}, "941189": {"name": "Salmonella enterica subsp. enterica serovar Paratyphi A str. ATCC 11511", "rank": "Strain"}, "941188": {"name": "Salmonella enterica subsp. enterica serovar Pomona str. ATCC 10729", "rank": "Strain"}, "941187": {"name": "Salmonella enterica subsp. enterica serovar Inverness str. ATCC 10720", "rank": "Strain"}, "1002367": {"name": "Prevotella stercorea DSM 18206", "rank": "Strain"}, "1002366": {"name": "Listeria innocua ATCC 33091", "rank": "Strain"}, "1002365": {"name": "Lactobacillus rhamnosus ATCC 21052", "rank": "Strain"}, "1002364": {"name": "Hafnia alvei ATCC 51873", "rank": "Strain"}, "1002369": {"name": "Peptoclostridium difficile 70-100-2010", "rank": "Strain"}, "1002368": {"name": "Yokenella regensburgei ATCC 43003", "rank": "Strain"}, "1418395": {"name": "Staphylococcus aureus H50387", "rank": "Strain"}, "1418394": {"name": "Staphylococcus aureus H32175", "rank": "Strain"}, "1418397": {"name": "Staphylococcus aureus H50411", "rank": "Strain"}, "1418396": {"name": "Staphylococcus aureus H50403", "rank": "Strain"}, "1418391": {"name": "Staphylococcus aureus H20315", "rank": "Strain"}, "1418390": {"name": "Staphylococcus aureus H12890", "rank": "Strain"}, "1418393": {"name": "Staphylococcus aureus H20322", "rank": "Strain"}, "1418392": {"name": "Staphylococcus aureus H20321", "rank": "Strain"}, "119219": {"name": "Cupriavidus metallidurans", "rank": "Species"}, "1418399": {"name": "Staphylococcus aureus H64570", "rank": "Strain"}, "1418398": {"name": "Staphylococcus aureus H59325", "rank": "Strain"}, "162481": {"name": "Microbotryomycetes", "rank": "Class"}, "437701": {"name": "Brucella sp. F5/99", "rank": "Species"}, "162484": {"name": "Pucciniomycetes", "rank": "Class"}, "361575": {"name": "Arthrobacter phenanthrenivorans", "rank": "Species"}, "1583098": {"name": "Fusobacterium hwasookii", "rank": "Species"}, "255238": {"name": "Fragaria chiloensis latent virus", "rank": "Species"}, "1439180": {"name": "Streptococcus pyogenes ABC020048395", "rank": "Strain"}, "1282444": {"name": "Cyanoramphus nest associated circular K DNA virus", "rank": "Species"}, "1282443": {"name": "Cyanoramphus nest associated circular X DNA virus", "rank": "Species"}, "1439182": {"name": "Streptococcus pyogenes ABC020048541", "rank": "Strain"}, "444449": {"name": "Escherichia coli O157:H7 str. EC4042", "rank": "Strain"}, "1183392": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN000969", "rank": "Strain"}, "1183393": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN000970", "rank": "Strain"}, "1183390": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN000967", "rank": "Strain"}, "1183391": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN000968", "rank": "Strain"}, "112437": {"name": "Oat necrotic mottle virus", "rank": "Species"}, "112436": {"name": "Celery mosaic virus", "rank": "Species"}, "327375": {"name": "Unclassified Carlavirus", "rank": "No rank"}, "153496": {"name": "Kozakia baliensis", "rank": "Species"}, "153497": {"name": "Kozakia", "rank": "Genus"}, "153493": {"name": "Conchiformibius steedae", "rank": "Species"}, "153491": {"name": "Alysiella crassa", "rank": "Species"}, "425303": {"name": "Tomato leaf curl Seychelles virus", "rank": "Species"}, "49338": {"name": "Desulfitobacterium hafniense", "rank": "Species"}, "59840": {"name": "Paenibacillus curdlanolyticus", "rank": "Species"}, "59842": {"name": "Paenibacillus chondroitinus", "rank": "Species"}, "580024": {"name": "Enterorhabdus", "rank": "Genus"}, "1419876": {"name": "Blastomonas sp. CACIA14H2", "rank": "Species"}, "171283": {"name": "Mycoplasma cricetuli", "rank": "Species"}, "540906": {"name": "Pedobacter glucosidilyticus DSM 23534", "rank": "Strain"}, "1346782": {"name": "Mycobacterium tuberculosis PanR0309", "rank": "Strain"}, "1346783": {"name": "Mycobacterium tuberculosis PanR0308", "rank": "Strain"}, "86004": {"name": "Pasteuria", "rank": "Genus"}, "1346784": {"name": "Mycobacterium tuberculosis PanR0307", "rank": "Strain"}, "1346785": {"name": "Mycobacterium tuberculosis PanR0306", "rank": "Strain"}, "1112202": {"name": "Papaya leaf curl alphasatellite", "rank": "Species"}, "1823": {"name": "Nocardia otitidiscaviarum", "rank": "Species"}, "1824": {"name": "Nocardia asteroides", "rank": "Species"}, "1827": {"name": "Rhodococcus", "rank": "Genus"}, "1829": {"name": "Rhodococcus rhodochrous", "rank": "Species"}, "1828": {"name": "Rhodococcus fascians", "rank": "Species"}, "1112208": {"name": "Mycobacterium avium subsp. paratuberculosis JQ6", "rank": "Strain"}, "1112209": {"name": "Psychrobacter sp. PAMC 21119", "rank": "Species"}, "1027271": {"name": "Candidatus Poribacteria sp. WGA-4C", "rank": "Species"}, "1027273": {"name": "Endozoicomonas montiporae", "rank": "Species"}, "218208": {"name": "Desulfatibacillum aliphaticivorans", "rank": "Species"}, "218207": {"name": "Desulfatibacillum", "rank": "Genus"}, "114378": {"name": "Thermofilaceae", "rank": "Family"}, "47466": {"name": "Borrelia miyamotoi", "rank": "Species"}, "990370": {"name": "Pseudogulbenkiania sp. MAI-1", "rank": "Species"}, "118655": {"name": "Oropouche virus", "rank": "Species"}, "48461": {"name": "Verrucomicrobiales", "rank": "Order"}, "344610": {"name": "Escherichia coli 53638", "rank": "Strain"}, "45285": {"name": "Eremothecium cymbalariae", "rank": "Species"}, "298650": {"name": "Ageratum leaf curl virus - G52", "rank": "Strain"}, "298653": {"name": "Frankia sp. EAN1pec", "rank": "Species"}, "298654": {"name": "Frankia sp. EuI1c", "rank": "Species"}, "298655": {"name": "Frankia sp. CN3", "rank": "Species"}, "298657": {"name": "Pseudoalteromonas spongiae", "rank": "Species"}, "453849": {"name": "Henriciella", "rank": "Genus"}, "369960": {"name": "Porcine type-C oncovirus", "rank": "Species"}, "194440": {"name": "Primate T-lymphotropic virus 1", "rank": "Species"}, "194441": {"name": "Primate T-lymphotropic virus 2", "rank": "Species"}, "290425": {"name": "Advenella", "rank": "Genus"}, "194443": {"name": "Primate T-lymphotropic virus 3", "rank": "Species"}, "194445": {"name": "Mirabilis mosaic virus", "rank": "Species"}, "1151434": {"name": "Peptoclostridium difficile P70", "rank": "Strain"}, "29518": {"name": "Borrelia afzelii", "rank": "Species"}, "29519": {"name": "Borrelia garinii", "rank": "Species"}, "1410809": {"name": "Staphylococcus aureus H27739", "rank": "Strain"}, "65958": {"name": "Komagataeibacter oboediens", "rank": "Species"}, "1432062": {"name": "Acidithiobacillus thiooxidans A01", "rank": "Strain"}, "1145194": {"name": "Neisseria meningitidis NM165", "rank": "Strain"}, "1403929": {"name": "Staphylococcus aureus M1557", "rank": "Strain"}, "284031": {"name": "Streptomyces flavovariabilis", "rank": "Species"}, "140409": {"name": "Spounalikevirus", "rank": "Genus"}, "1016854": {"name": "Banana streak UA virus", "rank": "Species"}, "1016855": {"name": "Banana streak UI virus", "rank": "Species"}, "1016856": {"name": "Banana streak UL virus", "rank": "Species"}, "1016857": {"name": "Banana streak UM virus", "rank": "Species"}, "1016852": {"name": "Banana streak CA virus", "rank": "Species"}, "1016853": {"name": "Banana streak IM virus", "rank": "Species"}, "190239": {"name": "Calicivirus strain NB", "rank": "Strain"}, "1094178": {"name": "Pseudomonas syringae pv. actinidiae PA459", "rank": "Strain"}, "84739": {"name": "European catfish virus", "rank": "Species"}, "138563": {"name": "Helicobacter cetorum", "rank": "Species"}, "572264": {"name": "Bacillus cereus 03BB102", "rank": "Strain"}, "572265": {"name": "Candidatus Hamiltonella defensa 5AT (Acyrthosiphon pisum)", "rank": "Strain"}, "99287": {"name": "Salmonella enterica subsp. enterica serovar Typhimurium str. LT2", "rank": "Strain"}, "99286": {"name": "Flavobacterium frigidarium", "rank": "Species"}, "1151435": {"name": "Peptoclostridium difficile P72", "rank": "Strain"}, "432096": {"name": "Kazachstania africana", "rank": "Species"}, "1400175": {"name": "Klebsiella pneumoniae UCI 22", "rank": "Strain"}, "1229671": {"name": "Mycobacterium avium subsp. hominissuis TH135", "rank": "Strain"}, "1137265": {"name": "Salinispora pacifica CNT854", "rank": "Strain"}, "754037": {"name": "Synechococcus phage S-CAM1", "rank": "Species"}, "754035": {"name": "Mesorhizobium australicum WSM2073", "rank": "Strain"}, "1160171": {"name": "Brucella abortus NI593", "rank": "Strain"}, "754039": {"name": "Synechococcus phage S-IOM18", "rank": "Species"}, "754038": {"name": "Synechococcus phage S-CAM8", "rank": "Species"}, "1417041": {"name": "Staphylococcus aureus F63687", "rank": "Strain"}, "1160170": {"name": "Brucella abortus NI495a", "rank": "Strain"}, "880161": {"name": "Micromonas sp. RCC1109 virus MpV1", "rank": "Species"}, "1160173": {"name": "Brucella abortus NI622", "rank": "Strain"}, "880162": {"name": "Ostreococcus lucimarinus virus OlV1", "rank": "Species"}, "1244095": {"name": "Streptococcus agalactiae SGBS010", "rank": "Strain"}, "1244094": {"name": "Streptococcus agalactiae SGBS007", "rank": "Strain"}, "172851": {"name": "Avian hepatitis E virus", "rank": "Species"}, "687914": {"name": "Salmonella enterica subsp. enterica serovar Rissen str. 150", "rank": "Strain"}, "1244091": {"name": "Streptococcus agalactiae SGBS004", "rank": "Strain"}, "1244090": {"name": "Streptococcus agalactiae SGBS003", "rank": "Strain"}, "1244093": {"name": "Streptococcus agalactiae SGBS006", "rank": "Strain"}, "1244092": {"name": "Streptococcus agalactiae SGBS005", "rank": "Strain"}, "215591": {"name": "Treponema caldaria", "rank": "Species"}, "1249615": {"name": "Mycobacterium tuberculosis K", "rank": "Strain"}, "232846": {"name": "Alcaligenes faecalis subsp. phenolicus", "rank": "Subspecies"}, "1249613": {"name": "Helicobacter pylori D33", "rank": "Strain"}, "189396": {"name": "Xanthomonas alfalfae subsp. citrumelonis", "rank": "Subspecies"}, "988644": {"name": "Unclassified ssRNA negative-strand viruses", "rank": "No rank"}, "1193146": {"name": "Pseudomonas putida LS46", "rank": "Strain"}, "1417043": {"name": "Staphylococcus aureus M28487", "rank": "Strain"}, "1151399": {"name": "Peptoclostridium difficile P8", "rank": "Strain"}, "998092": {"name": "Mycobacterium bovis BCG str. ATCC 35743", "rank": "Strain"}, "1339278": {"name": "Bacteroides fragilis str. DS-166", "rank": "Strain"}, "1339279": {"name": "Bacteroides fragilis str. 20793-3", "rank": "Strain"}, "1339272": {"name": "Bacteroides fragilis str. J38-1", "rank": "Strain"}, "1339273": {"name": "Bacteroides fragilis str. B1 (UDC16-1)", "rank": "Strain"}, "1339270": {"name": "Bacteroides fragilis str. I1345", "rank": "Strain"}, "1339271": {"name": "Bacteroides fragilis str. J-143-4", "rank": "Strain"}, "1339276": {"name": "Bacteroides fragilis str. DS-208", "rank": "Strain"}, "1151394": {"name": "Peptoclostridium difficile P2", "rank": "Strain"}, "1339274": {"name": "Bacteroides fragilis str. A7 (UDC12-2)", "rank": "Strain"}, "1151396": {"name": "Peptoclostridium difficile P5", "rank": "Strain"}, "486619": {"name": "Bacillus anthracis str. A0193", "rank": "Strain"}, "1154918": {"name": "Streptococcus agalactiae GB00548", "rank": "Strain"}, "1154919": {"name": "Streptococcus agalactiae GB00555", "rank": "Strain"}, "1417044": {"name": "Staphylococcus aureus M29068", "rank": "Strain"}, "1154914": {"name": "Streptococcus agalactiae GB00279", "rank": "Strain"}, "1154915": {"name": "Streptococcus agalactiae GB00300", "rank": "Strain"}, "1154916": {"name": "Streptococcus agalactiae GB00535", "rank": "Strain"}, "1154917": {"name": "Streptococcus agalactiae GB00543", "rank": "Strain"}, "1154910": {"name": "Streptococcus agalactiae GB00241", "rank": "Strain"}, "1154911": {"name": "Streptococcus agalactiae GB00245", "rank": "Strain"}, "1154912": {"name": "Streptococcus agalactiae GB00247", "rank": "Strain"}, "1154913": {"name": "Streptococcus agalactiae GB00264", "rank": "Strain"}, "1454777": {"name": "Candidatus Calescibacterium", "rank": "Genus"}, "1417045": {"name": "Staphylococcus aureus M28485", "rank": "Strain"}, "1413562": {"name": "Staphylococcus aureus 14(11MN_17-08-66-05)", "rank": "Strain"}, "1327976": {"name": "Cellulophaga phage phi12:1", "rank": "Species"}, "1327977": {"name": "Cellulophaga phage phi38:1", "rank": "Species"}, "1327974": {"name": "Cellulophaga phage phi46:1", "rank": "Species"}, "1327972": {"name": "Cellulophaga phage phi17:2", "rank": "Species"}, "1327970": {"name": "Cellulophaga phage phi19:1", "rank": "Species"}, "1327971": {"name": "Cellulophaga phage phi19:3", "rank": "Species"}, "1413566": {"name": "Staphylococcus aureus Tur-5", "rank": "Strain"}, "1198980": {"name": "Pbunalikevirus", "rank": "Genus"}, "1042127": {"name": "Aureobasidium subglaciale", "rank": "Species"}, "1042123": {"name": "Clostridium phage phiCP34O", "rank": "Species"}, "385492": {"name": "Pseudophaeobacter arcticus", "rank": "Species"}, "390641": {"name": "Wenxinia marina", "rank": "Species"}, "1435048": {"name": "Burkholderia pseudomallei MSHR7498", "rank": "Strain"}, "1435049": {"name": "Burkholderia pseudomallei MSHR7343", "rank": "Strain"}, "404196": {"name": "Blackberry yellow vein-associated virus", "rank": "Species"}, "1435044": {"name": "Pseudomonas monteilii SB3078", "rank": "Strain"}, "1435045": {"name": "Borrelia parkeri HR1", "rank": "Strain"}, "1435047": {"name": "Acinetobacter baumannii MDR_MMC4", "rank": "Strain"}, "690598": {"name": "Pseudomonas agarici NCPPB 2289", "rank": "Strain"}, "1182659": {"name": "Escherichia sp. KTE52", "rank": "Species"}, "904789": {"name": "Staphylococcus epidermidis IS-250", "rank": "Strain"}, "904786": {"name": "Staphylococcus aureus subsp. aureus IS-160", "rank": "Strain"}, "904787": {"name": "Staphylococcus aureus subsp. aureus IS-189", "rank": "Strain"}, "904784": {"name": "Staphylococcus aureus subsp. aureus IS-125", "rank": "Strain"}, "904785": {"name": "Staphylococcus aureus subsp. aureus IS-157", "rank": "Strain"}, "690597": {"name": "Pseudomonas fluorescens NZ007", "rank": "Strain"}, "904783": {"name": "Staphylococcus aureus subsp. aureus IS-122", "rank": "Strain"}, "904780": {"name": "Staphylococcus aureus subsp. aureus IS-99", "rank": "Strain"}, "1437447": {"name": "Streptococcus mutans UA159-FR", "rank": "Strain"}, "712531": {"name": "Selenomonas sp. oral taxon 137", "rank": "Species"}, "379": {"name": "Rhizobium", "rank": "Genus"}, "575200": {"name": "Corynebacterium maris", "rank": "Species"}, "712535": {"name": "Selenomonas sp. oral taxon 149", "rank": "Species"}, "234661": {"name": "Unclassified Geodermatophilaceae", "rank": "No rank"}, "373": {"name": "Agrobacterium vitis", "rank": "Species"}, "215221": {"name": "Komagataeibacter rhaeticus", "rank": "Species"}, "375": {"name": "Bradyrhizobium japonicum", "rank": "Species"}, "374": {"name": "Bradyrhizobium", "rank": "Genus"}, "1448456": {"name": "Mycobacterium tuberculosis TKK_03_0154", "rank": "Strain"}, "1448455": {"name": "Mycobacterium tuberculosis TKK_03_0153", "rank": "Strain"}, "1448454": {"name": "Mycobacterium tuberculosis TKK_03_0150", "rank": "Strain"}, "1448453": {"name": "Mycobacterium tuberculosis TKK_03_0149", "rank": "Strain"}, "1448452": {"name": "Mycobacterium tuberculosis TKK_03_0118", "rank": "Strain"}, "1448450": {"name": "Mycobacterium tuberculosis TKK_03_0116", "rank": "Strain"}, "1429878": {"name": "Staphylococcus aureus SA8-LAU", "rank": "Strain"}, "1429879": {"name": "Staphylococcus aureus SA9-LAU", "rank": "Strain"}, "1448459": {"name": "Mycobacterium tuberculosis TKK_03_0158", "rank": "Strain"}, "1448458": {"name": "Mycobacterium tuberculosis TKK_03_0156", "rank": "Strain"}, "688246": {"name": "Prevotella multisaccharivorax DSM 17128", "rank": "Strain"}, "1284240": {"name": "Amycolatopsis decaplanina DSM 44594", "rank": "Strain"}, "1208921": {"name": "Candidatus Kinetoplastibacterium galatii TCC219", "rank": "Strain"}, "1208920": {"name": "Candidatus Kinetoplastibacterium oncopeltii TCC290E", "rank": "Strain"}, "1208923": {"name": "Candidatus Kinetoplastibacterium blastocrithidii (ex Strigomonas culicis)", "rank": "Strain"}, "1208922": {"name": "Candidatus Kinetoplastibacterium blastocrithidii TCC012E", "rank": "Strain"}, "1149132": {"name": "Lactococcus lactis subsp. lactis YF11", "rank": "Strain"}, "1149133": {"name": "Pseudomonas pseudoalcaligenes KF707", "rank": "Strain"}, "1149134": {"name": "Mycobacterium abscessus M93", "rank": "Strain"}, "1149135": {"name": "Acinetobacter baumannii 107m", "rank": "Strain"}, "356851": {"name": "Micromonospora chokoriensis", "rank": "Species"}, "11229": {"name": "Morbillivirus", "rank": "Genus"}, "11228": {"name": "Simian virus 41", "rank": "Species"}, "29264": {"name": "Seaborne tick-borne virus group", "rank": "Subgenus"}, "29262": {"name": "Rio Bravo virus group", "rank": "Subgenus"}, "29263": {"name": "Tick-borne encephalitis virus group", "rank": "Subgenus"}, "29260": {"name": "Modoc virus group", "rank": "Subgenus"}, "29261": {"name": "Ntaya virus group", "rank": "Subgenus"}, "1229487": {"name": "Flavobacterium sp. WG21", "rank": "Species"}, "1229486": {"name": "Gamma proteobacterium L18", "rank": "Species"}, "1229485": {"name": "Gamma proteobacterium WG36", "rank": "Species"}, "1229484": {"name": "Alpha proteobacterium LLX12A", "rank": "Species"}, "1329640": {"name": "Spirochaeta sp. JC202", "rank": "Species"}, "889948": {"name": "Candidatus Nanosalina sp. J07AB43", "rank": "Species"}, "1229489": {"name": "Beta proteobacterium L13", "rank": "Species"}, "591160": {"name": "Bhendi yellow vein Bhubhaneswar virus", "rank": "Species"}, "591166": {"name": "Southern tomato virus", "rank": "Species"}, "591167": {"name": "Streptomyces pratensis ATCC 33331", "rank": "Strain"}, "1402631": {"name": "Staphylococcus aureus M1114", "rank": "Strain"}, "1402630": {"name": "Staphylococcus aureus M1113", "rank": "Strain"}, "1402633": {"name": "Staphylococcus aureus M1116", "rank": "Strain"}, "1402632": {"name": "Staphylococcus aureus M1115", "rank": "Strain"}, "1402635": {"name": "Staphylococcus aureus M1120", "rank": "Strain"}, "1402634": {"name": "Staphylococcus aureus M1117", "rank": "Strain"}, "1402637": {"name": "Staphylococcus aureus M1122", "rank": "Strain"}, "1402636": {"name": "Staphylococcus aureus M1121", "rank": "Strain"}, "1402639": {"name": "Staphylococcus aureus M1124", "rank": "Strain"}, "1402638": {"name": "Staphylococcus aureus M1123", "rank": "Strain"}, "1158707": {"name": "Staphylococcus aureus M1007", "rank": "Strain"}, "1158706": {"name": "Staphylococcus aureus M0999", "rank": "Strain"}, "1158701": {"name": "Staphylococcus aureus M0934", "rank": "Strain"}, "1158700": {"name": "Staphylococcus aureus M0844", "rank": "Strain"}, "1158703": {"name": "Staphylococcus aureus M0944", "rank": "Strain"}, "1158702": {"name": "Staphylococcus aureus M0943", "rank": "Strain"}, "858317": {"name": "Salmonella enterica subsp. enterica serovar Montevideo str. 609458-1", "rank": "Strain"}, "858316": {"name": "Salmonella enterica subsp. enterica serovar Montevideo str. 446600", "rank": "Strain"}, "858315": {"name": "Salmonella enterica subsp. enterica serovar Montevideo str. 413180", "rank": "Strain"}, "858314": {"name": "Salmonella enterica subsp. enterica serovar Montevideo str. 366867", "rank": "Strain"}, "858313": {"name": "Salmonella enterica subsp. enterica serovar Montevideo str. 414877", "rank": "Strain"}, "858312": {"name": "Salmonella enterica subsp. enterica serovar Newport str. CVM 19470", "rank": "Strain"}, "858311": {"name": "Salmonella enterica subsp. enterica serovar Newport str. CVM 19593", "rank": "Strain"}, "858310": {"name": "Salmonella enterica subsp. enterica serovar Newport str. CVM 37978", "rank": "Strain"}, "1500960": {"name": "Campylobacter sp. RM16704", "rank": "Species"}, "858318": {"name": "Salmonella enterica subsp. enterica serovar Montevideo str. 556150-1", "rank": "Strain"}, "202568": {"name": "Stachytarpheta leaf curl virus", "rank": "Species"}, "706122": {"name": "Ipomoea begomovirus satellite DNA beta", "rank": "Species"}, "29847": {"name": "Verticillium tricorpus", "rank": "Species"}, "202567": {"name": "Ageratum yellow vein China virus", "rank": "Species"}, "202566": {"name": "Cherry rasp leaf virus", "rank": "Species"}, "28131": {"name": "Prevotella intermedia", "rank": "Species"}, "28130": {"name": "Prevotella disiens", "rank": "Species"}, "28133": {"name": "Prevotella nigrescens", "rank": "Species"}, "28132": {"name": "Prevotella melaninogenica", "rank": "Species"}, "28135": {"name": "Prevotella oris", "rank": "Species"}, "1068619": {"name": "Escherichia coli O104:H4 str. 11-4632 C3", "rank": "Strain"}, "28137": {"name": "Prevotella veroralis", "rank": "Species"}, "28136": {"name": "Prevotella oulorum", "rank": "Species"}, "28139": {"name": "Rikenella microfusus", "rank": "Species"}, "28138": {"name": "Rikenella", "rank": "Genus"}, "1457191": {"name": "Lactobacillus rhamnosus E800", "rank": "Strain"}, "1438691": {"name": "Escherichia coli UCI 53", "rank": "Strain"}, "1438696": {"name": "Escherichia coli UCI 66", "rank": "Strain"}, "1415170": {"name": "Pseudomonas chlororaphis subsp. aurantiaca PB-St2", "rank": "Strain"}, "1438697": {"name": "Klebsiella pneumoniae BIDMC 54", "rank": "Strain"}, "1438694": {"name": "Escherichia coli UCI 58", "rank": "Strain"}, "1299044": {"name": "Salmonella enterica subsp. enterica serovar Heidelberg str. CFSAN002064", "rank": "Strain"}, "1438695": {"name": "Escherichia coli UCI 65", "rank": "Strain"}, "1195526": {"name": "Gryllotalpicola", "rank": "Genus"}, "106261": {"name": "Unclassified Thermotogales", "rank": "No rank"}, "308865": {"name": "Elizabethkingia", "rank": "Genus"}, "395085": {"name": "Lactobacillus ceti", "rank": "Species"}, "418756": {"name": "Salinicoccus albus", "rank": "Species"}, "238783": {"name": "Pseudorhodobacter", "rank": "Genus"}, "1385943": {"name": "Bifidobacterium breve 2L", "rank": "Strain"}, "1385942": {"name": "Bifidobacterium breve 689b", "rank": "Strain"}, "1385941": {"name": "Bifidobacterium breve NCFB 2258", "rank": "Strain"}, "1385940": {"name": "Bifidobacterium breve JCM 7019", "rank": "Strain"}, "1422655": {"name": "Staphylococcus aureus VET0433R", "rank": "Strain"}, "1422654": {"name": "Staphylococcus aureus VET0432R", "rank": "Strain"}, "1422657": {"name": "Staphylococcus aureus VET0435R", "rank": "Strain"}, "1422656": {"name": "Staphylococcus aureus VET0434R", "rank": "Strain"}, "1183154": {"name": "Stenotrophomonas maltophilia Ab55555", "rank": "Strain"}, "1183155": {"name": "Acinetobacter nosocomialis Ab22222", "rank": "Strain"}, "36772": {"name": "Subterranean clover stunt virus", "rank": "Species"}, "318279": {"name": "Human T-lymphotropic virus 4", "rank": "Species"}, "1183151": {"name": "Myroides injenensis", "rank": "Species"}, "32068": {"name": "Sebaldella", "rank": "Genus"}, "32069": {"name": "Aquificales", "rank": "Order"}, "32061": {"name": "Chloroflexia", "rank": "Class"}, "32064": {"name": "Chloroflexales", "rank": "Order"}, "32066": {"name": "Fusobacteria", "rank": "Phylum"}, "1141140": {"name": "Enterobacteria phage vB_EcoS_ACG-M12", "rank": "Species"}, "561576": {"name": "Cassava virus C", "rank": "Species"}, "498388": {"name": "Escherichia coli C", "rank": "Strain"}, "1408180": {"name": "Lactobacillus rhamnosus 51B", "rank": "Strain"}, "1408185": {"name": "Brucella abortus LMN2", "rank": "Strain"}, "1408184": {"name": "Brucella abortus LMN1", "rank": "Strain"}, "1408186": {"name": "Lactobacillus johnsonii N6.2", "rank": "Strain"}, "280702": {"name": "Mycoplasma phage phiMFV1", "rank": "Species"}, "280701": {"name": "Pseudomonas phage F116", "rank": "Species"}, "1124484": {"name": "Vibrio cholerae O1 str. 2010EL-2010N", "rank": "Strain"}, "2": {"name": "Bacteria", "rank": "Superkingdom"}, "1124487": {"name": "Vibrio cholerae O1 str. 3554-08", "rank": "Strain"}, "1294038": {"name": "Tropheryma whipplei str. DigMusc17", "rank": "Strain"}, "1268317": {"name": "Rhizobium sp. JGI 0001019-L19", "rank": "Species"}, "1124483": {"name": "Vibrio cholerae O1 str. 2011EL-1137", "rank": "Strain"}, "1268313": {"name": "Rhizobium sp. JGI 0001003-A11", "rank": "Species"}, "882855": {"name": "Streptococcus pneumoniae 06-01-003MEF", "rank": "Strain"}, "681847": {"name": "Labrenzia sp. DG1229", "rank": "Species"}, "11958": {"name": "Avian carcinoma virus", "rank": "Species"}, "12282": {"name": "Tobacco ringspot virus", "rank": "Species"}, "12283": {"name": "Nodaviridae", "rank": "Family"}, "12280": {"name": "Tomato ringspot virus", "rank": "Species"}, "263369": {"name": "Bacteriovoracaceae", "rank": "Family"}, "12286": {"name": "Boolarra virus", "rank": "Species"}, "12287": {"name": "Flock house virus", "rank": "Species"}, "12285": {"name": "Black beetle virus", "rank": "Species"}, "12288": {"name": "Nodamura virus", "rank": "Species"}, "12289": {"name": "Enamovirus", "rank": "Genus"}, "445984": {"name": "Borrelia burgdorferi Bol26", "rank": "Strain"}, "445985": {"name": "Borrelia burgdorferi ZS7", "rank": "Strain"}, "445986": {"name": "Borrelia afzelii ACA-1", "rank": "Strain"}, "445987": {"name": "Borrelia valaisiana VS116", "rank": "Strain"}, "1132836": {"name": "Rhizobium sp. CCGE 510", "rank": "Species"}, "1513298": {"name": "Unclassified Nyamiviridae", "rank": "No rank"}, "1513299": {"name": "Sprivivirus", "rank": "Genus"}, "1513296": {"name": "Unassigned Nyamiviridae", "rank": "No rank"}, "1513294": {"name": "Nyamiviridae", "rank": "Family"}, "1513295": {"name": "Nyavirus", "rank": "Genus"}, "208897": {"name": "New world arenaviruses", "rank": "No rank"}, "208896": {"name": "Old world arenaviruses", "rank": "No rank"}, "1281454": {"name": "Rodent hepacivirus", "rank": "Species"}, "208899": {"name": "Cupixi virus", "rank": "Species"}, "208898": {"name": "Unclassified Arenaviridae", "rank": "No rank"}, "1460639": {"name": "Bacillus sp. JCM 19045", "rank": "Species"}, "60478": {"name": "Shewanella amazonensis", "rank": "Species"}, "426418": {"name": "Pyrenophora tritici-repentis Pt-1C-BFP", "rank": "Strain"}, "1460635": {"name": "Geomicrobium sp. JCM 19038", "rank": "Species"}, "1460634": {"name": "Geomicrobium sp. JCM 19037", "rank": "Species"}, "1460636": {"name": "Geomicrobium sp. JCM 19039", "rank": "Species"}, "413816": {"name": "Halorubrum halophilum", "rank": "Species"}, "1200349": {"name": "Clostridium beijerinckii G117", "rank": "Strain"}, "1200348": {"name": "Mycobacterium tuberculosis NA-A0009", "rank": "Strain"}, "211044": {"name": "Influenza A virus (A/Puerto Rico/8/1934(H1N1))", "rank": "Strain"}, "413812": {"name": "Natronococcus jeotgali", "rank": "Species"}, "1200345": {"name": "Pseudomonas stutzeri XLDN-R", "rank": "Strain"}, "1200347": {"name": "Mycobacterium tuberculosis NA-A0008", "rank": "Strain"}, "1200346": {"name": "Alicyclobacillus hesperidum URH17-3-68", "rank": "Strain"}, "661513": {"name": "Vibrio cholerae CIRS101", "rank": "Strain"}, "1409586": {"name": "Staphylococcus aureus HSOU6002", "rank": "Strain"}, "1409587": {"name": "Staphylococcus aureus OCMM6065", "rank": "Strain"}, "553199": {"name": "Propionibacterium acnes SK137", "rank": "Strain"}, "553198": {"name": "Propionibacterium acidifaciens F0233", "rank": "Strain"}, "374840": {"name": "Enterobacteria phage phiX174 sensu lato", "rank": "Species"}, "1409583": {"name": "Staphylococcus aureus COAS6059", "rank": "Strain"}, "1409580": {"name": "Staphylococcus aureus COAS6055", "rank": "Strain"}, "1409581": {"name": "Staphylococcus aureus SMMC6085", "rank": "Strain"}, "553191": {"name": "Bifidobacterium dentium JCVIHMP022", "rank": "Strain"}, "553190": {"name": "Gardnerella vaginalis 409-05", "rank": "Strain"}, "617126": {"name": "Enterovibrio calviensis FF-85", "rank": "Strain"}, "1409588": {"name": "Staphylococcus aureus GGMC6049", "rank": "Strain"}, "1409589": {"name": "Staphylococcus aureus OCMM6067", "rank": "Strain"}, "1173947": {"name": "Salmonella enterica subsp. houtenae serovar 50:g,z51:-", "rank": "Strain"}, "1173940": {"name": "Salmonella enterica subsp. enterica serovar Worthington str. ATCC 9607", "rank": "Strain"}, "1173948": {"name": "Salmonella enterica subsp. houtenae serovar 50:g,z51:- str. 01-0133", "rank": "Strain"}, "1173949": {"name": "Salmonella enterica subsp. indica serovar 6,14,25:z10:1,(2),7", "rank": "Strain"}, "1421019": {"name": "Kurthia huakuii", "rank": "Species"}, "243550": {"name": "Calicivirus isolate TCG", "rank": "Species"}, "1421012": {"name": "Enterococcus faecalis Efa HS0914", "rank": "Strain"}, "1421013": {"name": "Rhodopseudomonas palustris JSC-3b", "rank": "Strain"}, "1421011": {"name": "Lactobacillus acidophilus CFH", "rank": "Strain"}, "1421016": {"name": "Thermoanaerobacterium aotearoense SCUT27", "rank": "Strain"}, "1421017": {"name": "Streptomyces rimosus R6-500", "rank": "Strain"}, "1412511": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. SA20093788", "rank": "Strain"}, "1412510": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. SA20093977", "rank": "Strain"}, "1412513": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. SA20090435", "rank": "Strain"}, "1412512": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. SA20093430", "rank": "Strain"}, "1412515": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. SA20094389", "rank": "Strain"}, "1412514": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. SA20093421", "rank": "Strain"}, "1412517": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. SA20090419", "rank": "Strain"}, "283824": {"name": "Faba bean necrotic stunt virus", "rank": "Species"}, "1412519": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. SA20093950", "rank": "Strain"}, "1412518": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. SA20094642", "rank": "Strain"}, "271087": {"name": "Geopsychrobacter", "rank": "Genus"}, "206672": {"name": "Bifidobacterium longum NCC2705", "rank": "Strain"}, "1438693": {"name": "Escherichia coli UCI 57", "rank": "Strain"}, "1286106": {"name": "Methylophaga lonarensis MPL", "rank": "Strain"}, "1417149": {"name": "Staphylococcus aureus F89062", "rank": "Strain"}, "1417148": {"name": "Staphylococcus aureus F89053", "rank": "Strain"}, "399726": {"name": "Thermoanaerobacter sp. X514", "rank": "Species"}, "1276647": {"name": "Streptococcus suis TL13", "rank": "Strain"}, "1276649": {"name": "Propionibacterium acnes FZ1/2/0", "rank": "Strain"}, "1417140": {"name": "Staphylococcus aureus F29450_091412", "rank": "Strain"}, "66948": {"name": "Meyerozyma caribbica", "rank": "Species"}, "1417142": {"name": "Staphylococcus aureus F85414", "rank": "Strain"}, "1417145": {"name": "Staphylococcus aureus F85691", "rank": "Strain"}, "1417144": {"name": "Staphylococcus aureus F85660", "rank": "Strain"}, "1417147": {"name": "Staphylococcus aureus F89046", "rank": "Strain"}, "1417146": {"name": "Staphylococcus aureus F85711", "rank": "Strain"}, "289397": {"name": "Mycoplasma bovis PG45", "rank": "Strain"}, "226665": {"name": "Rickettsia heilongjiangensis", "rank": "Species"}, "1412500": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. SA19930684", "rank": "Strain"}, "293227": {"name": "Cyphellophora europaea", "rank": "Species"}, "663917": {"name": "Geobacter sulfurreducens KN400", "rank": "Strain"}, "663918": {"name": "Mycoplasma genitalium M2321", "rank": "Strain"}, "1416760": {"name": "Myroides odoratimimus H1bi", "rank": "Strain"}, "1416761": {"name": "Serratia marcescens PH1a", "rank": "Strain"}, "1307798": {"name": "Negevirus", "rank": "Genus"}, "590849": {"name": "Nitritalea halalkaliphila", "rank": "Species"}, "112252": {"name": "Fungi incertae sedis", "rank": "No rank"}, "553384": {"name": "Alishewanella agri", "rank": "Species"}, "749527": {"name": "Escherichia coli MS 21-1", "rank": "Strain"}, "993615": {"name": "Vittaforma corneae ATCC 50505", "rank": "Strain"}, "749525": {"name": "Enterococcus faecium TX0133C", "rank": "Strain"}, "749524": {"name": "Enterococcus faecium TX0133B", "rank": "Strain"}, "749523": {"name": "Enterococcus faecium TX0133a04", "rank": "Strain"}, "749522": {"name": "Enterococcus faecium TX0133a01", "rank": "Strain"}, "749521": {"name": "Enterococcus faecium TX0133A", "rank": "Strain"}, "710687": {"name": "Mycobacterium tusciae JS617", "rank": "Strain"}, "1465751": {"name": "Anopheles minimus irodovirus", "rank": "Species"}, "348769": {"name": "Unclassified Chlamydiamicrovirus", "rank": "No rank"}, "1465754": {"name": "Alistipes timonensis", "rank": "Species"}, "1465757": {"name": "Peptoniphilus senegalensis", "rank": "Species"}, "1465756": {"name": "Peptoniphilus grossensis", "rank": "Species"}, "363265": {"name": "Prevotella stercorea", "rank": "Species"}, "1307428": {"name": "Fusobacterium nucleatum subsp. nucleatum ChDC F316", "rank": "Strain"}, "1307429": {"name": "Fusobacterium nucleatum subsp. animalis ChDC F324", "rank": "Strain"}, "1307427": {"name": "Fusobacterium nucleatum subsp. vincentii ChDC F8", "rank": "Strain"}, "1185664": {"name": "Xanthomonas axonopodis pv. manihotis str. UA323", "rank": "Strain"}, "1185665": {"name": "Xanthomonas axonopodis pv. manihotis str. UA324", "rank": "Strain"}, "1185666": {"name": "Xanthomonas axonopodis pv. manihotis str. UA536", "rank": "Strain"}, "1185667": {"name": "Xanthomonas axonopodis pv. manihotis str. UA556", "rank": "Strain"}, "667119": {"name": "Velvet bean severe mosaic virus", "rank": "Species"}, "1185661": {"name": "Xanthomonas axonopodis pv. manihotis str. UA226", "rank": "Strain"}, "1185662": {"name": "Xanthomonas axonopodis pv. manihotis str. UA303", "rank": "Strain"}, "1185663": {"name": "Xanthomonas axonopodis pv. manihotis str. UA306", "rank": "Strain"}, "1185668": {"name": "Xanthomonas axonopodis pv. manihotis str. UA560", "rank": "Strain"}, "1185669": {"name": "Xanthomonas axonopodis pv. manihotis str. UA686", "rank": "Strain"}, "120045": {"name": "Zymomonas mobilis subsp. mobilis", "rank": "Subspecies"}, "120044": {"name": "Zymomonas mobilis subsp. pomaceae", "rank": "Subspecies"}, "1409424": {"name": "Staphylococcus aureus SJUD6072", "rank": "Strain"}, "1122616": {"name": "Oceanospirillum beijerinckii DSM 7166", "rank": "Strain"}, "1122617": {"name": "Oceanospirillum maris DSM 6286", "rank": "Strain"}, "1122614": {"name": "Oceanicola nanhaiensis DSM 18065", "rank": "Strain"}, "1122615": {"name": "Oceanobacter kriegii DSM 6294", "rank": "Strain"}, "1122612": {"name": "Novosphingobium acidiphilum DSM 19966", "rank": "Strain"}, "1122613": {"name": "Oceanicaulis alexandrii DSM 11625", "rank": "Strain"}, "1122610": {"name": "Nocardioides insulae DSM 17944", "rank": "Strain"}, "1122611": {"name": "Nonomuraea coxensis DSM 45129", "rank": "Strain"}, "1122618": {"name": "Oenococcus oeni DSM 20252 = AWRIB129", "rank": "Strain"}, "1122619": {"name": "Oligella ureolytica DSM 18253", "rank": "Strain"}, "1295642": {"name": "Geobacillus stearothermophilus NUB3621", "rank": "Strain"}, "1072458": {"name": "Escherichia coli O7:K1", "rank": "Strain"}, "1072459": {"name": "Escherichia coli O7:K1 str. CE10", "rank": "Strain"}, "557601": {"name": "Acinetobacter baumannii AB900", "rank": "Strain"}, "557600": {"name": "Acinetobacter baumannii AB307-0294", "rank": "Strain"}, "1410607": {"name": "Bacteroides sp. Ga6A1", "rank": "Species"}, "1410606": {"name": "Candidatus Nitrosopelagicus brevis", "rank": "Species"}, "1410605": {"name": "Bifidobacterium pseudolongum subsp. globosum DSM 20092", "rank": "Strain"}, "658062": {"name": "Candidatus Koribacter versatilis", "rank": "Species"}, "658061": {"name": "Candidatus Koribacter", "rank": "Genus"}, "1410609": {"name": "Treponema sp. C6A8", "rank": "Species"}, "1410608": {"name": "Bacteroides sp. Ga6A2", "rank": "Species"}, "1144335": {"name": "Pseudomonas sp. GM67", "rank": "Species"}, "1144334": {"name": "Pseudomonas sp. GM60", "rank": "Species"}, "1144337": {"name": "Pseudomonas sp. GM78", "rank": "Species"}, "1144336": {"name": "Pseudomonas sp. GM74", "rank": "Species"}, "1144331": {"name": "Pseudomonas sp. GM49", "rank": "Species"}, "1144330": {"name": "Pseudomonas sp. GM48", "rank": "Species"}, "1144333": {"name": "Pseudomonas sp. GM55", "rank": "Species"}, "1144332": {"name": "Pseudomonas sp. GM50", "rank": "Species"}, "1182678": {"name": "Escherichia coli KTE71", "rank": "Strain"}, "1182679": {"name": "Escherichia coli KTE72", "rank": "Strain"}, "1144339": {"name": "Pseudomonas sp. GM80", "rank": "Species"}, "1144338": {"name": "Pseudomonas sp. GM79", "rank": "Species"}, "111782": {"name": "Tolypothrix", "rank": "Genus"}, "908337": {"name": "Eremococcus coleocola ACS-139-V-Col8", "rank": "Strain"}, "526980": {"name": "Bacillus cereus ATCC 10876", "rank": "Strain"}, "526981": {"name": "Bacillus cereus Rock1-3", "rank": "Strain"}, "526982": {"name": "Bacillus cereus Rock1-15", "rank": "Strain"}, "526983": {"name": "Bacillus cereus Rock3-28", "rank": "Strain"}, "526984": {"name": "Bacillus cereus Rock3-29", "rank": "Strain"}, "526985": {"name": "Bacillus cereus Rock3-42", "rank": "Strain"}, "526986": {"name": "Bacillus cereus Rock3-44", "rank": "Strain"}, "526987": {"name": "Bacillus cereus Rock4-2", "rank": "Strain"}, "526988": {"name": "Bacillus cereus Rock4-18", "rank": "Strain"}, "526989": {"name": "Bacillus cereus F65185", "rank": "Strain"}, "1348237": {"name": "Kingella kingae KK238", "rank": "Strain"}, "84136": {"name": "Gemella bergeri", "rank": "Species"}, "84135": {"name": "Gemella sanguinis", "rank": "Species"}, "1348239": {"name": "Kingella kingae KK97", "rank": "Strain"}, "121719": {"name": "Pannonibacter phragmitetus", "rank": "Species"}, "908338": {"name": "Peptoniphilus harei ACS-146-V-Sch2b", "rank": "Strain"}, "1357732": {"name": "Anabaena phage A-4L", "rank": "Species"}, "1074119": {"name": "Streptococcus mutans TCI-123", "rank": "Strain"}, "1074118": {"name": "Streptococcus mutans TCI-120", "rank": "Strain"}, "373862": {"name": "Siniperca chuatsi rhabdovirus", "rank": "Species"}, "1074111": {"name": "Streptococcus mutans TCI-96", "rank": "Strain"}, "1074113": {"name": "Streptococcus mutans TCI-101", "rank": "Strain"}, "1074112": {"name": "Streptococcus mutans TCI-99", "rank": "Strain"}, "1074115": {"name": "Streptococcus mutans TCI-110", "rank": "Strain"}, "1074114": {"name": "Streptococcus mutans TCI-109", "rank": "Strain"}, "1074117": {"name": "Streptococcus sobrinus TCI-118", "rank": "Strain"}, "1074116": {"name": "Streptococcus mutans TCI-116", "rank": "Strain"}, "365150": {"name": "Lolium latent virus", "rank": "Species"}, "1201034": {"name": "Bartonella birtlesii E7", "rank": "Strain"}, "1250232": {"name": "Muricauda sp. MAR_2010_75", "rank": "Species"}, "1201035": {"name": "Bartonella birtlesii E11", "rank": "Strain"}, "1009711": {"name": "Gamma proteobacterium SCGC AAA536-N21", "rank": "Species"}, "565575": {"name": "Ureaplasma urealyticum serovar 10 str. ATCC 33699", "rank": "Strain"}, "146907": {"name": "Desulfitobacterium sp. PCE1", "rank": "Species"}, "1201033": {"name": "Bartonella birtlesii H12", "rank": "Strain"}, "1147684": {"name": "Achromobacter arsenitoxydans", "rank": "Species"}, "1448614": {"name": "Mycobacterium tuberculosis M1004", "rank": "Strain"}, "1448617": {"name": "Mycobacterium tuberculosis M1007", "rank": "Strain"}, "1448616": {"name": "Mycobacterium tuberculosis M995", "rank": "Strain"}, "1185325": {"name": "Lactobacillus coryniformis subsp. coryniformis CECT 5711", "rank": "Strain"}, "1185324": {"name": "Lactobacillus gasseri CECT 5714", "rank": "Strain"}, "1185327": {"name": "Xanthomonas axonopodis pv. manihotis str. Xam668", "rank": "Strain"}, "1448612": {"name": "Mycobacterium tuberculosis M990", "rank": "Strain"}, "1448619": {"name": "Mycobacterium tuberculosis M1009", "rank": "Strain"}, "1448618": {"name": "Mycobacterium tuberculosis M1008", "rank": "Strain"}, "1297646": {"name": "Corchorus yellow vein mosaic betasatellite", "rank": "Species"}, "351425": {"name": "Unclassified Foveavirus", "rank": "No rank"}, "133": {"name": "Methylocystis", "rank": "Genus"}, "1410833": {"name": "Staphylococcus aureus H30737", "rank": "Strain"}, "134": {"name": "Methylocystis parvus", "rank": "Species"}, "137": {"name": "Spirochaetaceae", "rank": "Family"}, "136": {"name": "Spirochaetales", "rank": "Order"}, "139": {"name": "Borrelia burgdorferi", "rank": "Species"}, "138": {"name": "Borrelia", "rank": "Genus"}, "866915": {"name": "Salmonella enterica subsp. enterica serovar 4,5,12:i:- str. 08-1739", "rank": "Strain"}, "1427360": {"name": "Escherichia coli O91:H14", "rank": "Strain"}, "1427366": {"name": "Dickeya zeae EC1", "rank": "Strain"}, "1427365": {"name": "Pandoraea sp. E26", "rank": "Species"}, "1427368": {"name": "Chlamydia pecorum IPTaLE", "rank": "Strain"}, "1520006": {"name": "Duck adenovirus 2", "rank": "Species"}, "456492": {"name": "Saccharibacillus", "rank": "Genus"}, "1511906": {"name": "Carnivore protoparvovirus 1", "rank": "Species"}, "1388038": {"name": "Staphylococcus aureus M0073", "rank": "Strain"}, "1388039": {"name": "Staphylococcus aureus M0074", "rank": "Strain"}, "866919": {"name": "Salmonella enterica subsp. enterica serovar Kentucky str. 29439", "rank": "Strain"}, "1388034": {"name": "Staphylococcus aureus M0068", "rank": "Strain"}, "1388035": {"name": "Staphylococcus aureus M0069", "rank": "Strain"}, "1388036": {"name": "Staphylococcus aureus M0070", "rank": "Strain"}, "1388037": {"name": "Staphylococcus aureus M0071", "rank": "Strain"}, "1388030": {"name": "Staphylococcus aureus M0063", "rank": "Strain"}, "1388031": {"name": "Staphylococcus aureus M0064", "rank": "Strain"}, "1388032": {"name": "Staphylococcus aureus M0065", "rank": "Strain"}, "1388033": {"name": "Staphylococcus aureus M0067", "rank": "Strain"}, "456491": {"name": "Unclassified Inoviridae", "rank": "No rank"}, "153135": {"name": "Gammaretrovirus", "rank": "Genus"}, "153137": {"name": "Epsilonretrovirus", "rank": "Genus"}, "153136": {"name": "Deltaretrovirus", "rank": "Genus"}, "12165": {"name": "Chrysanthemum virus B", "rank": "Species"}, "353799": {"name": "Halostagnicola", "rank": "Genus"}, "142461": {"name": "Vibrio ichthyoenteri", "rank": "Species"}, "1217713": {"name": "Acinetobacter sp. NIPH 809", "rank": "Species"}, "1217710": {"name": "Acinetobacter sp. NIPH 899", "rank": "Species"}, "1217711": {"name": "Acinetobacter sp. NIPH 236", "rank": "Species"}, "1217716": {"name": "Acinetobacter ursingii NIPH 706", "rank": "Strain"}, "1217714": {"name": "Acinetobacter sp. ANC 3789", "rank": "Species"}, "1217715": {"name": "Acinetobacter bohemicus ANC 3994", "rank": "Strain"}, "1310970": {"name": "Acinetobacter baumannii 25750_6", "rank": "Strain"}, "1384066": {"name": "Ruminococcus flavefaciens AE3010", "rank": "Strain"}, "1310972": {"name": "Acinetobacter baumannii 25750_8", "rank": "Strain"}, "1384064": {"name": "Lactobacillus brevis AG48", "rank": "Strain"}, "1384063": {"name": "Ruminococcus gnavus AGR2154", "rank": "Strain"}, "1320309": {"name": "Salmonella enterica subsp. enterica serovar Bovismorbificans str. 3114", "rank": "Strain"}, "1310976": {"name": "Acinetobacter baumannii 44467_2", "rank": "Strain"}, "1310977": {"name": "Acinetobacter baumannii 44467_3", "rank": "Strain"}, "1310978": {"name": "Acinetobacter baumannii 44467_4", "rank": "Strain"}, "1310979": {"name": "Acinetobacter baumannii 44467_5", "rank": "Strain"}, "1282363": {"name": "Asticcacaulis sp. YBE204", "rank": "Species"}, "1282362": {"name": "Asticcacaulis sp. AC466", "rank": "Species"}, "1289594": {"name": "Pectobacterium atrosepticum CFBP 6276", "rank": "Strain"}, "556266": {"name": "Escherichia coli D9", "rank": "Strain"}, "1156391": {"name": "Paenibacillus sp. WLY78", "rank": "Species"}, "556264": {"name": "Fusobacterium nucleatum subsp. animalis D11", "rank": "Strain"}, "1227464": {"name": "Haloferax sp. ATCC BAA-646", "rank": "Species"}, "556262": {"name": "Coprobacillus sp. D6", "rank": "Species"}, "556263": {"name": "Fusobacterium necrophorum D12", "rank": "Strain"}, "556260": {"name": "Bacteroides dorei 5_1_36/D4", "rank": "Strain"}, "556261": {"name": "Clostridium sp. D5", "rank": "Species"}, "1137651": {"name": "Xanthomonas citri subsp. citri Aw12879", "rank": "Strain"}, "556268": {"name": "Oxalobacter formigenes HOxBLS", "rank": "Strain"}, "556269": {"name": "Oxalobacter formigenes OXCC13", "rank": "Strain"}, "53418": {"name": "Treponema lecithinolyticum", "rank": "Species"}, "53419": {"name": "Treponema socranskii", "rank": "Species"}, "1388698": {"name": "Staphylococcus aureus M0930", "rank": "Strain"}, "1388699": {"name": "Staphylococcus aureus M0931", "rank": "Strain"}, "1162": {"name": "Nostocaceae", "rank": "Family"}, "1163": {"name": "Anabaena", "rank": "Genus"}, "1164": {"name": "Trichormus azollae", "rank": "Species"}, "1165": {"name": "Anabaena cylindrica", "rank": "Species"}, "1350001": {"name": "Duck megrivirus", "rank": "Species"}, "1388690": {"name": "Staphylococcus aureus M0919", "rank": "Strain"}, "1388691": {"name": "Staphylococcus aureus M0920", "rank": "Strain"}, "1388692": {"name": "Staphylococcus aureus M0921", "rank": "Strain"}, "1388693": {"name": "Staphylococcus aureus M0922", "rank": "Strain"}, "1388694": {"name": "Staphylococcus aureus M0923", "rank": "Strain"}, "1388695": {"name": "Staphylococcus aureus M0924", "rank": "Strain"}, "1388696": {"name": "Staphylococcus aureus M0928", "rank": "Strain"}, "1123405": {"name": "Tuberibacillus calidus DSM 17572", "rank": "Strain"}, "470866": {"name": "Salinimicrobium terrae", "rank": "Species"}, "470865": {"name": "Staphylococcus phage SAP-2", "rank": "Species"}, "470864": {"name": "Gracilibacillus halophilus", "rank": "Species"}, "82373": {"name": "Anaerovibrio", "rank": "Genus"}, "82376": {"name": "Anaeroarcus burkinensis", "rank": "Species"}, "82374": {"name": "Anaerovibrio lipolyticus", "rank": "Species"}, "49279": {"name": "Gelidibacter", "rank": "Genus"}, "49278": {"name": "Psychroserpens burtonensis", "rank": "Species"}, "49277": {"name": "Psychroserpens", "rank": "Genus"}, "1379401": {"name": "Marinimicrobia bacterium JGI OTU-1", "rank": "Species"}, "1305791": {"name": "Kingella kingae AA417", "rank": "Strain"}, "1291550": {"name": "Yersinia pestis G1670A", "rank": "Strain"}, "1379406": {"name": "Marinimicrobia bacterium JGI OTU-2", "rank": "Species"}, "224914": {"name": "Brucella melitensis bv. 1 str. 16M", "rank": "Strain"}, "224915": {"name": "Buchnera aphidicola str. Bp (Baizongia pistaciae)", "rank": "Strain"}, "224911": {"name": "Bradyrhizobium diazoefficiens USDA 110", "rank": "Strain"}, "1439259": {"name": "Streptococcus pyogenes ABC020056020", "rank": "Strain"}, "1439258": {"name": "Streptococcus pyogenes ABC020055897", "rank": "Strain"}, "1323659": {"name": "Staphylococcus aureus HST-066", "rank": "Strain"}, "39780": {"name": "Unclassified dsRNA viruses", "rank": "No rank"}, "1191699": {"name": "Bacillus sp. ZYK", "rank": "Species"}, "39782": {"name": "Blattabacteriaceae", "rank": "Family"}, "671228": {"name": "Veillonella sp. oral taxon 158", "rank": "Species"}, "671229": {"name": "Veillonella sp. oral taxon 780", "rank": "Species"}, "671222": {"name": "Propionibacterium sp. oral taxon 192", "rank": "Species"}, "1004836": {"name": "Gluconacetobacter sp. SXCC-1", "rank": "Species"}, "671224": {"name": "Selenomonas artemidis", "rank": "Species"}, "1116138": {"name": "Escherichia coli MP021566.1", "rank": "Strain"}, "1116139": {"name": "Escherichia coli MP020980.2", "rank": "Strain"}, "1116134": {"name": "Escherichia coli MP021552.11", "rank": "Strain"}, "1116135": {"name": "Escherichia coli MP021552.12", "rank": "Strain"}, "1116136": {"name": "Escherichia coli MP021561.2", "rank": "Strain"}, "1116137": {"name": "Escherichia coli MP021561.3", "rank": "Strain"}, "1508595": {"name": "Roseiflexineae", "rank": "Suborder"}, "1116131": {"name": "Escherichia coli P02997067.6", "rank": "Strain"}, "1116132": {"name": "Escherichia coli MP021552.7", "rank": "Strain"}, "1116133": {"name": "Escherichia coli MP021552.8", "rank": "Strain"}, "643561": {"name": "Acidovorax avenae subsp. avenae ATCC 19860", "rank": "Strain"}, "189836": {"name": "Propionibacterium phage B5", "rank": "Species"}, "707546": {"name": "Porcine parvovirus 4", "rank": "Strain"}, "1230480": {"name": "Escherichia coli EC302/04", "rank": "Strain"}, "476270": {"name": "Pediococcus lolii", "rank": "Species"}, "768724": {"name": "Peptoniphilus sp. oral taxon 836 str. F0141", "rank": "Strain"}, "476272": {"name": "Blautia hydrogenotrophica DSM 10507", "rank": "Strain"}, "456493": {"name": "Saccharibacillus sacchari", "rank": "Species"}, "1504288": {"name": "Bovine herpesvirus 6", "rank": "Species"}, "215813": {"name": "Dinoroseobacter shibae", "rank": "Species"}, "1388357": {"name": "Staphylococcus aureus M0542", "rank": "Strain"}, "101564": {"name": "Pseudomonas alcaliphila", "rank": "Species"}, "323850": {"name": "Shewanella loihica PV-4", "rank": "Strain"}, "1391998": {"name": "Mycobacterium avium subsp. paratuberculosis 08-8281", "rank": "Strain"}, "1199191": {"name": "Legionella pneumophila subsp. pneumophila str. Thunder Bay", "rank": "Strain"}, "698769": {"name": "Virgibacillus alimentarius", "rank": "Species"}, "481448": {"name": "Methylacidiphilum infernorum V4", "rank": "Strain"}, "1343073": {"name": "Acinetobacter baumannii CI78", "rank": "Strain"}, "353496": {"name": "Lactobacillus delbrueckii subsp. bulgaricus 2038", "rank": "Strain"}, "309181": {"name": "Acidianus rod-shaped virus 1", "rank": "Species"}, "1441379": {"name": "Mycoplasma pneumoniae M29", "rank": "Strain"}, "859350": {"name": "Candidatus Nitrosopumilus salaria BD31", "rank": "Strain"}, "471728": {"name": "Seal picornavirus type 1", "rank": "Strain"}, "282786": {"name": "Penaeid shrimp infectious myonecrosis virus", "rank": "Species"}, "1169384": {"name": "Escherichia coli KTE129", "rank": "Strain"}, "1156995": {"name": "Staphylococcus aureus HI010", "rank": "Strain"}, "221988": {"name": "Mannheimia succiniciproducens MBEL55E", "rank": "Strain"}, "889738": {"name": "Acinetobacter baumannii MDR-TJ", "rank": "Strain"}, "1048834": {"name": "Alicyclobacillus acidocaldarius subsp. acidocaldarius Tc-4-1", "rank": "Strain"}, "487849": {"name": "Xanthomonas campestris pv. arecae", "rank": "Strain"}, "741759": {"name": "Tomitella", "rank": "Genus"}, "1091039": {"name": "Lactococcus garvieae LG9", "rank": "Strain"}, "221670": {"name": "Cucurbitariaceae", "rank": "Family"}, "1455308": {"name": "Mycobacterium tuberculosis NRITLD34", "rank": "Strain"}, "1455305": {"name": "Mycobacterium tuberculosis NRITLD31", "rank": "Strain"}, "1455307": {"name": "Mycobacterium tuberculosis NRITLD33", "rank": "Strain"}, "264462": {"name": "Bdellovibrio bacteriovorus HD100", "rank": "Strain"}, "1455302": {"name": "Mycobacterium tuberculosis NRITLD28", "rank": "Strain"}, "1053692": {"name": "Methanococcus maripaludis X1", "rank": "Strain"}, "75684": {"name": "Balneatrix alpica", "rank": "Species"}, "75687": {"name": "Neptunomonas", "rank": "Genus"}, "75683": {"name": "Balneatrix", "rank": "Genus"}, "75682": {"name": "Oxalobacteraceae", "rank": "Family"}, "1428420": {"name": "Oenococcus oeni IOEB_9805", "rank": "Strain"}, "61593": {"name": "Thiorhodovibrio", "rank": "Genus"}, "1428421": {"name": "Oenococcus oeni IOEB_B10", "rank": "Strain"}, "1428422": {"name": "Oenococcus oeni IOEB_B16", "rank": "Strain"}, "1111074": {"name": "Campylobacter jejuni subsp. jejuni 6399", "rank": "Strain"}, "222984": {"name": "Natrinema altunense", "rank": "Species"}, "1111076": {"name": "Campylobacter jejuni subsp. jejuni 04199", "rank": "Strain"}, "1428423": {"name": "Oenococcus oeni IOEB_C23", "rank": "Strain"}, "1111072": {"name": "Campylobacter jejuni subsp. jejuni xy259", "rank": "Strain"}, "1111073": {"name": "Campylobacter jejuni subsp. jejuni RB922", "rank": "Strain"}, "1111078": {"name": "Comamonas testosteroni NBRC 100989", "rank": "Strain"}, "1315956": {"name": "Shigella phage pSf-1", "rank": "Species"}, "184923": {"name": "Methylocapsa", "rank": "Genus"}, "184925": {"name": "Chlorogloeopsis fritschii PCC 9212", "rank": "Strain"}, "935473": {"name": "Rhynchosia yellow mosaic India virus", "rank": "Species"}, "1298971": {"name": "Viunalikevirus", "rank": "Genus"}, "1005057": {"name": "Buchnera aphidicola str. Ua (Uroleucon ambrosiae)", "rank": "Strain"}, "1176488": {"name": "Salmonella enterica subsp. enterica serovar Typhi str. CR0044", "rank": "Strain"}, "1176489": {"name": "Enterococcus faecium C309", "rank": "Strain"}, "1176487": {"name": "Salmonella enterica subsp. enterica serovar Typhi str. ST0208", "rank": "Strain"}, "1176482": {"name": "Sulfurimonas gotlandica", "rank": "Species"}, "1163708": {"name": "Rupicapra rupicapra papillomavirus 1", "rank": "Species"}, "1439228": {"name": "Streptococcus pyogenes ABC020053240", "rank": "Strain"}, "938293": {"name": "Anaerococcus sp. 9402080", "rank": "Species"}, "447455": {"name": "Candidate division TM7 single-cell isolate TM7b", "rank": "Species"}, "447456": {"name": "Candidate division TM7 single-cell isolate TM7c", "rank": "Species"}, "938294": {"name": "Anaerococcus pacaensis 9403502", "rank": "Strain"}, "1572752": {"name": "Kirrobacter", "rank": "Genus"}, "1572751": {"name": "Kirrobacter mercurialis", "rank": "Species"}, "1281034": {"name": "Escherichia coli HVH 98 (4-5799287)", "rank": "Strain"}, "1439229": {"name": "Streptococcus pyogenes ABC020053250", "rank": "Strain"}, "1080800": {"name": "Salmonella phage SFP10", "rank": "Species"}, "574560": {"name": "Photorhabdus temperata", "rank": "Species"}, "1422727": {"name": "Staphylococcus aureus VET1877R", "rank": "Strain"}, "690417": {"name": "Paracoccus sphaerophysae", "rank": "Species"}, "1283211": {"name": "Alphapermutotetravirus", "rank": "Genus"}, "473422": {"name": "Xanthomonas citri pv. malvacearum", "rank": "Strain"}, "914149": {"name": "Vibrio cholerae O1 str. 2010EL-1786", "rank": "Strain"}, "1121721": {"name": "Gordonia kroppenstedtii", "rank": "Species"}, "914148": {"name": "Streptococcus pneumoniae 2090008", "rank": "Strain"}, "1281036": {"name": "Escherichia coli HVH 100 (4-2850729)", "rank": "Strain"}, "1094956": {"name": "Comamonadaceae bacterium JGI 0001003-E14", "rank": "Species"}, "1504823": {"name": "Bacterium LF-3", "rank": "Species"}, "493803": {"name": "Merkel cell polyomavirus", "rank": "Species"}, "1169663": {"name": "Escherichia coli NCCP15647", "rank": "Strain"}, "1169660": {"name": "Salmonella enterica subsp. enterica serovar Typhi str. UJ308A", "rank": "Strain"}, "1169661": {"name": "Salmonella enterica subsp. enterica serovar Typhi str. UJ816A", "rank": "Strain"}, "1169666": {"name": "Enterococcus sp. GMD2E", "rank": "Species"}, "1169667": {"name": "Enterococcus sp. GMD3E", "rank": "Species"}, "1169664": {"name": "Escherichia coli AD30", "rank": "Strain"}, "1169665": {"name": "Enterococcus sp. GMD1E", "rank": "Species"}, "1161415": {"name": "Streptococcus sp. BS29a", "rank": "Species"}, "1161414": {"name": "Streptococcus sp. BS21", "rank": "Species"}, "1161417": {"name": "Streptococcus sp. SR4", "rank": "Species"}, "1161416": {"name": "Streptococcus sp. SR1", "rank": "Species"}, "1161413": {"name": "Streptococcus sp. ACC21", "rank": "Species"}, "1161412": {"name": "Prevotella sp. ICM33", "rank": "Species"}, "1118236": {"name": "Shigella boydii 08-0009", "rank": "Strain"}, "1422729": {"name": "Staphylococcus aureus VET1884R", "rank": "Strain"}, "914141": {"name": "Streptococcus pneumoniae 2070335", "rank": "Strain"}, "914140": {"name": "Streptococcus pneumoniae 2070108", "rank": "Strain"}, "1341673": {"name": "Brucella abortus 89-2646-1238", "rank": "Strain"}, "1438861": {"name": "Mycobacterium tuberculosis 2231BH", "rank": "Strain"}, "914142": {"name": "Streptococcus pneumoniae 2070531", "rank": "Strain"}, "1438860": {"name": "Mycobacterium tuberculosis 2230BH", "rank": "Strain"}, "1353277": {"name": "Rhizobium freirei", "rank": "Species"}, "668820": {"name": "Burkholderia sp. JPY366", "rank": "Species"}, "1446536": {"name": "Escherichia coli O111:NM str. K6890", "rank": "Strain"}, "1446537": {"name": "Escherichia coli O111:NM str. K6895", "rank": "Strain"}, "1446534": {"name": "Escherichia coli O111:NM str. K6723", "rank": "Strain"}, "1446535": {"name": "Escherichia coli O111:NM str. K6728", "rank": "Strain"}, "1446532": {"name": "Escherichia coli O111:NM str. 2011C-3679", "rank": "Strain"}, "1446533": {"name": "Escherichia coli O111:NM str. K6722", "rank": "Strain"}, "1446530": {"name": "Escherichia coli O111:NM str. 2011C-3573", "rank": "Strain"}, "886728": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. CDC_2010K_1791", "rank": "Strain"}, "1438869": {"name": "Mycobacterium tuberculosis 2542MS", "rank": "Strain"}, "272942": {"name": "Rhodobacter capsulatus SB 1003", "rank": "Strain"}, "272943": {"name": "Rhodobacter sphaeroides 2.4.1", "rank": "Strain"}, "272944": {"name": "Rickettsia conorii str. Malish 7", "rank": "Strain"}, "1446538": {"name": "Escherichia coli O111:NM str. K6897", "rank": "Strain"}, "1446539": {"name": "Escherichia coli O111:NM str. K6898", "rank": "Strain"}, "1412451": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20110223", "rank": "Strain"}, "929833": {"name": "Rhizobium phage RR1-A", "rank": "Species"}, "929832": {"name": "Cyanophage P-RSM6", "rank": "Species"}, "1412454": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20090698", "rank": "Strain"}, "929834": {"name": "Rhizobium phage RR1-B", "rank": "Species"}, "1412456": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20110222", "rank": "Strain"}, "1412457": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20100101", "rank": "Strain"}, "1412458": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20100103", "rank": "Strain"}, "1412459": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20090193", "rank": "Strain"}, "1281032": {"name": "Escherichia coli HVH 96 (4-5934869)", "rank": "Strain"}, "13724": {"name": "Thiocystis", "rank": "Genus"}, "570266": {"name": "Methanocella", "rank": "Genus"}, "570267": {"name": "Methanocella paludicola", "rank": "Species"}, "570264": {"name": "Methanocellales", "rank": "Order"}, "570265": {"name": "Methanocellaceae", "rank": "Family"}, "570268": {"name": "Nocardiopsis potens DSM 45234", "rank": "Strain"}, "330214": {"name": "Candidatus Nitrospira defluvii", "rank": "Species"}, "1120966": {"name": "Algoriphagus marincola DSM 16067", "rank": "Strain"}, "939745": {"name": "Oceanospirillales bacterium SCGC AAA298-N10", "rank": "Species"}, "4929": {"name": "Meyerozyma guilliermondii", "rank": "Species"}, "1122989": {"name": "Prevotella oris DSM 18711 = JCM 12252", "rank": "Strain"}, "10385": {"name": "Bovine herpesvirus 4", "rank": "Species"}, "1122987": {"name": "Prevotella micans DSM 21469 = JCM 16134", "rank": "Strain"}, "1122984": {"name": "Prevotella intermedia ATCC 25611 = DSM 20706", "rank": "Strain"}, "4924": {"name": "Scheffersomyces stipitis", "rank": "Species"}, "10381": {"name": "Saimiriine herpesvirus 2", "rank": "Species"}, "4922": {"name": "Komagataella pastoris", "rank": "Species"}, "1122980": {"name": "Prevotella baroniae DSM 16972 = JCM 13447", "rank": "Strain"}, "4920": {"name": "Millerozyma farinosa", "rank": "Species"}, "498737": {"name": "Borrelia burgdorferi WI91-23", "rank": "Strain"}, "1120965": {"name": "Algoriphagus mannitolivorans DSM 15301", "rank": "Strain"}, "241555": {"name": "Helcococcus sueciensis", "rank": "Species"}, "1120962": {"name": "Alcaligenes faecalis subsp. phenolicus DSM 16503", "rank": "Strain"}, "323118": {"name": "Blackberry virus Y", "rank": "Species"}, "498739": {"name": "Borrelia burgdorferi CA-11.2A", "rank": "Strain"}, "498738": {"name": "Borrelia burgdorferi 29805", "rank": "Strain"}, "1120963": {"name": "Algicola sagamiensis DSM 14643", "rank": "Strain"}, "35252": {"name": "Alcelaphine herpesvirus 1", "rank": "Species"}, "35250": {"name": "Gallid herpesvirus 3", "rank": "Species"}, "1151253": {"name": "Peptoclostridium difficile CD8", "rank": "Strain"}, "886727": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. CDC_2010K_1745", "rank": "Strain"}, "35254": {"name": "Cryptophlebia leucotreta granulovirus", "rank": "Species"}, "589873": {"name": "Alteromonas australica", "rank": "Species"}, "1072593": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 400095 14", "rank": "Strain"}, "35258": {"name": "Lambdapapillomavirus 2", "rank": "Species"}, "12524": {"name": "Junonia coenia densovirus", "rank": "Strain"}, "423349": {"name": "Mucilaginibacter", "rank": "Genus"}, "1151256": {"name": "Peptoclostridium difficile CD17", "rank": "Strain"}, "1151257": {"name": "Peptoclostridium difficile CD18", "rank": "Strain"}, "1151258": {"name": "Peptoclostridium difficile CD21", "rank": "Strain"}, "380160": {"name": "Obodhiang virus", "rank": "Species"}, "226899": {"name": "Grosmannia clavigera", "rank": "Species"}, "1479651": {"name": "Microbacterium sp. CH12i", "rank": "Species"}, "1159049": {"name": "Helicobacter pylori GAM265BSii", "rank": "Strain"}, "1159048": {"name": "Helicobacter pylori GAM264Ai", "rank": "Strain"}, "33959": {"name": "Lactobacillus johnsonii", "rank": "Species"}, "33958": {"name": "Lactobacillaceae", "rank": "Family"}, "1159041": {"name": "Helicobacter pylori GAM252Bi", "rank": "Strain"}, "33952": {"name": "Acetobacterium woodii", "rank": "Species"}, "33951": {"name": "Acetobacterium", "rank": "Genus"}, "1159042": {"name": "Helicobacter pylori GAM252T", "rank": "Strain"}, "1159045": {"name": "Helicobacter pylori GAM260Bi", "rank": "Strain"}, "1159044": {"name": "Helicobacter pylori GAM260ASi", "rank": "Strain"}, "1159047": {"name": "Helicobacter pylori GAM263BFi", "rank": "Strain"}, "1159046": {"name": "Helicobacter pylori GAM260BSi", "rank": "Strain"}, "1047024": {"name": "Aminicenantes bacterium SCGC AAA252-J15", "rank": "Species"}, "10271": {"name": "Rabbit fibroma virus", "rank": "Species"}, "1047022": {"name": "Aminicenantes bacterium SCGC AAA252-I14", "rank": "Species"}, "29491": {"name": "Aeromonas salmonicida subsp. salmonicida", "rank": "Subspecies"}, "29495": {"name": "Vibrio navarrensis", "rank": "Species"}, "29494": {"name": "Vibrio furnissii", "rank": "Species"}, "29497": {"name": "Vibrio splendidus", "rank": "Species"}, "1229517": {"name": "Lactococcus garvieae I113", "rank": "Strain"}, "29498": {"name": "Vibrio tubiashii", "rank": "Species"}, "307595": {"name": "Gloeobacterales", "rank": "Order"}, "307596": {"name": "Gloeobacteria", "rank": "Class"}, "582744": {"name": "Methylovorus glucosetrophus SIP3-4", "rank": "Strain"}, "348018": {"name": "Unclassified Orthobunyavirus", "rank": "No rank"}, "349945": {"name": "Unclassified Closterovirus", "rank": "No rank"}, "37329": {"name": "Nocardia farcinica", "rank": "Species"}, "168810": {"name": "Corynebacterium crenatum", "rank": "Species"}, "37325": {"name": "Muscovy duck parvovirus", "rank": "Strain"}, "37326": {"name": "Nocardia brasiliensis", "rank": "Species"}, "1209372": {"name": "Bacillus sp. WBUNB009", "rank": "Species"}, "35788": {"name": "Rickettsia africae", "rank": "Species"}, "35789": {"name": "Rickettsia helvetica", "rank": "Species"}, "696485": {"name": "Vibrio owensii", "rank": "Species"}, "94290": {"name": "Sugarcane yellow leaf virus", "rank": "Species"}, "35786": {"name": "Coprothermobacter proteolyticus", "rank": "Species"}, "545": {"name": "Citrobacter koseri", "rank": "Species"}, "1422264": {"name": "Staphylococcus aureus DAR1956", "rank": "Strain"}, "1422265": {"name": "Staphylococcus aureus DAR1961", "rank": "Strain"}, "1422266": {"name": "Staphylococcus aureus DAR1980", "rank": "Strain"}, "1422267": {"name": "Staphylococcus aureus DAR1995", "rank": "Strain"}, "1422260": {"name": "Staphylococcus aureus DAR1941", "rank": "Strain"}, "1422261": {"name": "Staphylococcus aureus DAR1942", "rank": "Strain"}, "1422262": {"name": "Staphylococcus aureus DAR1954", "rank": "Strain"}, "1422263": {"name": "Staphylococcus aureus DAR1955", "rank": "Strain"}, "54248": {"name": "Hyperthermus butylicus", "rank": "Species"}, "1422268": {"name": "Staphylococcus aureus DAR2000", "rank": "Strain"}, "1422269": {"name": "Staphylococcus aureus DAR2002", "rank": "Strain"}, "927691": {"name": "Leuconostoc gelidum subsp. gelidum KCTC 3527", "rank": "Strain"}, "549": {"name": "Pantoea agglomerans", "rank": "Species"}, "641524": {"name": "Cyclobacterium qasimii M12-11B", "rank": "Strain"}, "641526": {"name": "Winogradskyella psychrotolerans RS-3", "rank": "Strain"}, "244698": {"name": "Gillisia", "rank": "Genus"}, "743026": {"name": "Okra yellow crinkle Cameroon alphasatellite CM:Lys1sp2:09", "rank": "Strain"}, "1345662": {"name": "Nilaparvata lugens honeydew virus-3", "rank": "Species"}, "743023": {"name": "Okra yellow crinkle Cameroon alphasatellite", "rank": "Species"}, "1280947": {"name": "Hyphomonas chukchiensis", "rank": "Species"}, "1497391": {"name": "New Jersey polyomavirus-2013", "rank": "Species"}, "1095900": {"name": "Bartonella birtlesii IBS 325", "rank": "Strain"}, "574750": {"name": "Cupriavidus sp. SK-4", "rank": "Species"}, "52603": {"name": "Sagittula stellata", "rank": "Species"}, "260378": {"name": "Pepper yellow vein Mali virus", "rank": "Species"}, "260379": {"name": "Tomato leaf curl Mali virus", "rank": "Species"}, "260372": {"name": "Vibrio phage VP2", "rank": "Species"}, "260373": {"name": "Burkholderia phage Bcep43", "rank": "Species"}, "354259": {"name": "Lactococcus phage 936 sensu lato", "rank": "Species"}, "1321938": {"name": "Helicobacter pylori UM299", "rank": "Strain"}, "177972": {"name": "Shuttleworthia satelles", "rank": "Species"}, "177971": {"name": "Shuttleworthia", "rank": "Genus"}, "1071753": {"name": "Chlamydia trachomatis A/363", "rank": "Strain"}, "1071754": {"name": "Chlamydia trachomatis A/5291", "rank": "Strain"}, "336476": {"name": "Unclassified Iflavirus", "rank": "No rank"}, "1071756": {"name": "Chlamydia trachomatis D/SotonD1", "rank": "Strain"}, "396595": {"name": "Thioalkalivibrio sp. K90mix", "rank": "Species"}, "1071758": {"name": "Chlamydia trachomatis D/SotonD6", "rank": "Strain"}, "1071759": {"name": "Chlamydia trachomatis E/SW3", "rank": "Strain"}, "396598": {"name": "Burkholderia graminis C4D1M", "rank": "Strain"}, "1235755": {"name": "Salinicoccus carnicancri Crm", "rank": "Strain"}, "349307": {"name": "Methanosaeta thermophila PT", "rank": "Strain"}, "1339298": {"name": "Bacteroides fragilis str. 3725 D9(v)", "rank": "Strain"}, "1339299": {"name": "Bacteroides fragilis str. 3397 T14", "rank": "Strain"}, "223283": {"name": "Pseudomonas syringae pv. tomato str. DC3000", "rank": "Strain"}, "223282": {"name": "Macroptilium mosaic Puerto Rico virus", "rank": "Species"}, "223284": {"name": "Macroptilium yellow mosaic Florida virus", "rank": "Species"}, "223287": {"name": "Mungbean yellow mosaic India virus", "rank": "Species"}, "1339291": {"name": "Bacteroides fragilis str. S23 R14", "rank": "Strain"}, "1339292": {"name": "Bacteroides fragilis str. 1007-1-F #7", "rank": "Strain"}, "1339293": {"name": "Bacteroides fragilis str. 1007-1-F #8", "rank": "Strain"}, "1339294": {"name": "Bacteroides fragilis str. 1007-1-F #9", "rank": "Strain"}, "1339295": {"name": "Bacteroides fragilis str. 1007-1-F #10", "rank": "Strain"}, "1339296": {"name": "Bacteroides fragilis str. 1009-4-F #7", "rank": "Strain"}, "1339297": {"name": "Bacteroides fragilis str. 1009-4-F #10", "rank": "Strain"}, "1359195": {"name": "Rickettsia felis str. LSU", "rank": "Strain"}, "376806": {"name": "Bacteroides gallinarum", "rank": "Species"}, "1412632": {"name": "Staphylococcus aureus F26873", "rank": "Strain"}, "376805": {"name": "Bacteroides salanitronis", "rank": "Species"}, "1421843": {"name": "Staphylococcus aureus F64897", "rank": "Strain"}, "1032866": {"name": "Pasteurella multocida subsp. gallicida str. Anand1_poultry", "rank": "Strain"}, "370978": {"name": "Runella limosa", "rank": "Species"}, "1397859": {"name": "Mycobacterium tuberculosis TKK_02_0014", "rank": "Strain"}, "52607": {"name": "Xenococcus", "rank": "Genus"}, "269275": {"name": "Squash leaf curl China virus - B", "rank": "Strain"}, "370974": {"name": "Flavobacterium filum", "rank": "Species"}, "370977": {"name": "Brevundimonas aveniformis", "rank": "Species"}, "696837": {"name": "Unclassified Betapapillomavirus", "rank": "No rank"}, "40539": {"name": "Human papillomavirus type 50", "rank": "Strain"}, "760154": {"name": "Sulfurospirillum barnesii SES-3", "rank": "Strain"}, "1333514": {"name": "Pseudoalteromonas haloplanktis TAE80", "rank": "Strain"}, "1278311": {"name": "Acholeplasma axanthum ATCC 25176", "rank": "Strain"}, "1397853": {"name": "Mycobacterium tuberculosis TKK_02_0001", "rank": "Strain"}, "379360": {"name": "Oenococcus oeni ATCC BAA-1163", "rank": "Strain"}, "1278312": {"name": "Psychromonas aquimarina ATCC BAA-1526", "rank": "Strain"}, "1607807": {"name": "Candidatus Methanoplasma", "rank": "Genus"}, "1047167": {"name": "Zymoseptoria", "rank": "Genus"}, "1121422": {"name": "Desulfotomaculum alcoholivorax DSM 16058", "rank": "Strain"}, "1121423": {"name": "Desulfotomaculum alkaliphilum DSM 12257", "rank": "Strain"}, "579405": {"name": "Dickeya dadantii Ech703", "rank": "Strain"}, "1121428": {"name": "Desulfotomaculum hydrothermale Lam5 = DSM 18033", "rank": "Strain"}, "266835": {"name": "Mesorhizobium loti MAFF303099", "rank": "Strain"}, "266834": {"name": "Sinorhizobium meliloti 1021", "rank": "Strain"}, "904728": {"name": "Staphylococcus aureus subsp. aureus 21195", "rank": "Strain"}, "904729": {"name": "Staphylococcus aureus subsp. aureus 21196", "rank": "Strain"}, "1510206": {"name": "Salinivibrio socompensis", "rank": "Species"}, "904724": {"name": "Staphylococcus aureus subsp. aureus 21178", "rank": "Strain"}, "904725": {"name": "Staphylococcus aureus subsp. aureus 21189", "rank": "Strain"}, "904726": {"name": "Staphylococcus aureus subsp. aureus 21193", "rank": "Strain"}, "904727": {"name": "Staphylococcus aureus subsp. aureus 21194", "rank": "Strain"}, "904723": {"name": "Staphylococcus aureus subsp. aureus 21172", "rank": "Strain"}, "450821": {"name": "Rhodococcus sp. P14", "rank": "Species"}, "376488": {"name": "Halotalea", "rank": "Genus"}, "376489": {"name": "Halotalea alkalilenta", "rank": "Species"}, "29574": {"name": "Taylorella", "rank": "Genus"}, "29575": {"name": "Taylorella equigenitalis", "rank": "Species"}, "1181758": {"name": "Escherichia coli KTE212", "rank": "Strain"}, "1181759": {"name": "Escherichia coli KTE213", "rank": "Strain"}, "329290": {"name": "Malvastrum leaf curl virus", "rank": "Species"}, "1181754": {"name": "Escherichia coli KTE208", "rank": "Strain"}, "1181755": {"name": "Escherichia coli KTE209", "rank": "Strain"}, "1181756": {"name": "Escherichia coli KTE210", "rank": "Strain"}, "1181757": {"name": "Escherichia coli KTE211", "rank": "Strain"}, "1181750": {"name": "Escherichia coli KTE204", "rank": "Strain"}, "1181751": {"name": "Escherichia coli KTE205", "rank": "Strain"}, "1181752": {"name": "Escherichia coli KTE206", "rank": "Strain"}, "1181753": {"name": "Escherichia coli KTE207", "rank": "Strain"}, "235572": {"name": "Candidatus Portiera", "rank": "Genus"}, "413503": {"name": "Cronobacter malonaticus", "rank": "Species"}, "413502": {"name": "Cronobacter turicensis", "rank": "Species"}, "413501": {"name": "Cronobacter muytjensii", "rank": "Species"}, "413500": {"name": "Cronobacter dublinensis subsp. lausannensis", "rank": "Subspecies"}, "1389424": {"name": "Escherichia coli LAU-EC3", "rank": "Strain"}, "1274431": {"name": "Mycobacterium tuberculosis SP21", "rank": "Strain"}, "1389425": {"name": "Escherichia coli LAU-EC4", "rank": "Strain"}, "948741": {"name": "Drosophila obscura sigmavirus", "rank": "Species"}, "151414": {"name": "Afipia birgiae", "rank": "Species"}, "43668": {"name": "Brachybacterium", "rank": "Genus"}, "1238674": {"name": "Weissella ceti NC36", "rank": "Strain"}, "536474": {"name": "Cyanophage Syn30", "rank": "Species"}, "1218082": {"name": "Burkholderia mimosarum NBRC 106338", "rank": "Strain"}, "11287": {"name": "Viral hemorrhagic septicemia virus", "rank": "Species"}, "11286": {"name": "Lyssavirus", "rank": "Genus"}, "1002725": {"name": "Shigella phage Shfl2", "rank": "Species"}, "1002724": {"name": "Shigella phage Shfl1", "rank": "Species"}, "43669": {"name": "Brachybacterium faecium", "rank": "Species"}, "11280": {"name": "Vesicular stomatitis New Jersey virus", "rank": "Species"}, "390333": {"name": "Lactobacillus delbrueckii subsp. bulgaricus ATCC 11842 = JCM 1002", "rank": "Strain"}, "384616": {"name": "Pyrobaculum islandicum DSM 4184", "rank": "Strain"}, "229149": {"name": "Johnsongrass chlorotic stripe mosaic virus", "rank": "Species"}, "1423827": {"name": "Lactobacillus kefiranofaciens subsp. kefiranofaciens DSM 5016 = JCM 6985", "rank": "Strain"}, "1423823": {"name": "Lactobacillus delbrueckii subsp. delbrueckii DSM 20074 = JCM 1012", "rank": "Strain"}, "1423822": {"name": "Lactobacillus coryniformis subsp. torquens DSM 20004 = KCTC 3535", "rank": "Strain"}, "10482": {"name": "Polydnaviridae", "rank": "Family"}, "10483": {"name": "Ichnovirus", "rank": "Genus"}, "325776": {"name": "Xanthomonas vasicola pv. vasculorum", "rank": "Strain"}, "325777": {"name": "Xanthomonas axonopodis pv. vasculorum", "rank": "Strain"}, "10486": {"name": "Iridoviridae", "rank": "Family"}, "10487": {"name": "Iridovirus", "rank": "Genus"}, "10484": {"name": "Campoletis sonorensis ichnovirus", "rank": "Species"}, "10485": {"name": "Bracovirus", "rank": "Genus"}, "1042417": {"name": "Brachyspira pilosicoli P43/6/78", "rank": "Strain"}, "577310": {"name": "Parasutterella", "rank": "Genus"}, "93218": {"name": "Pandoraea apista", "rank": "Species"}, "521377": {"name": "Bacillus marmarensis", "rank": "Species"}, "12224": {"name": "Sugarcane mosaic virus", "rank": "Species"}, "204799": {"name": "Nitratireductor aquibiodomus", "rank": "Species"}, "12227": {"name": "Tobacco etch virus", "rank": "Species"}, "12222": {"name": "Soybean mosaic virus", "rank": "Species"}, "12228": {"name": "Tobacco vein mottling virus", "rank": "Species"}, "489779": {"name": "Enterobacteria phage Min27", "rank": "Species"}, "936005": {"name": "Bromus catharticus striate mosaic virus", "rank": "Species"}, "1170562": {"name": "Calothrix sp. PCC 6303", "rank": "Strain"}, "1422059": {"name": "Mycobacterium tuberculosis TB_RSA143", "rank": "Strain"}, "1422058": {"name": "Mycobacterium tuberculosis TB_RSA142", "rank": "Strain"}, "54076": {"name": "Thermococcus zilligii", "rank": "Species"}, "1422053": {"name": "Mycobacterium tuberculosis TB_RSA137", "rank": "Strain"}, "1422052": {"name": "Mycobacterium tuberculosis TB_RSA136", "rank": "Strain"}, "1422051": {"name": "Mycobacterium tuberculosis TB_RSA135", "rank": "Strain"}, "1422050": {"name": "Mycobacterium tuberculosis TB_RSA134", "rank": "Strain"}, "66270": {"name": "Pantoea stewartii subsp. indologenes", "rank": "Subspecies"}, "66271": {"name": "Pantoea stewartii subsp. stewartii", "rank": "Subspecies"}, "106179": {"name": "Phagocytophilum group", "rank": "Species group"}, "106178": {"name": "Canis group", "rank": "Species group"}, "1202540": {"name": "Candidatus Carsonella ruddii PC isolate NHV", "rank": "Strain"}, "28197": {"name": "Arcobacter butzleri", "rank": "Species"}, "150333": {"name": "Thermobrachium", "rank": "Genus"}, "28194": {"name": "Thermonema", "rank": "Genus"}, "28199": {"name": "Arcobacter nitrofigilis", "rank": "Species"}, "1444101": {"name": "Escherichia coli 5-172-05_S1_C3", "rank": "Strain"}, "1444100": {"name": "Escherichia coli 2-460-02_S1_C3", "rank": "Strain"}, "1444103": {"name": "Escherichia coli 7-233-03_S1_C3", "rank": "Strain"}, "1444102": {"name": "Escherichia coli 5-366-08_S1_C3", "rank": "Strain"}, "1444105": {"name": "Escherichia coli 1-176-05_S1_C3", "rank": "Strain"}, "1444104": {"name": "Escherichia coli 1-110-08_S1_C3", "rank": "Strain"}, "1444107": {"name": "Escherichia coli 1-250-04_S1_C3", "rank": "Strain"}, "1444106": {"name": "Escherichia coli 1-182-04_S1_C3", "rank": "Strain"}, "1444108": {"name": "Escherichia coli 3-020-07_S1_C3", "rank": "Strain"}, "1080230": {"name": "Synechocystis sp. PCC 6803 substr. PCC-P", "rank": "Strain"}, "1080237": {"name": "Pseudomonas phage phiPto-bp6g", "rank": "Species"}, "761193": {"name": "Runella slithyformis DSM 19594", "rank": "Strain"}, "1001989": {"name": "Escherichia coli PCN033", "rank": "Strain"}, "1001986": {"name": "Leptospira interrogans serovar Copenhageni str. 2006007831", "rank": "Strain"}, "1001987": {"name": "Leptospira interrogans serovar Copenhageni str. 2001025091", "rank": "Strain"}, "1300227": {"name": "Bifidobacterium longum subsp. longum GT15", "rank": "Strain"}, "766499": {"name": "Citreicella sp. 357", "rank": "Species"}, "52022": {"name": "Meiothermus silvanus", "rank": "Species"}, "52023": {"name": "Meiothermus chliarophilus", "rank": "Species"}, "1422489": {"name": "Staphylococcus aureus VET0189R", "rank": "Strain"}, "1460385": {"name": "Pediococcus pentosaceus CGMCC 7049", "rank": "Strain"}, "553178": {"name": "Capnocytophaga gingivalis ATCC 33624", "rank": "Strain"}, "1460381": {"name": "Bordetella pertussis H934", "rank": "Strain"}, "553171": {"name": "Prevotella bivia JCVIHMP010", "rank": "Strain"}, "10856": {"name": "Bdellomicrovirus", "rank": "Genus"}, "553175": {"name": "Porphyromonas endodontalis ATCC 35406", "rank": "Strain"}, "553174": {"name": "Prevotella melaninogenica ATCC 25845", "rank": "Strain"}, "553177": {"name": "Capnocytophaga sputigena ATCC 33612", "rank": "Strain"}, "1400893": {"name": "Mycobacterium tuberculosis KT-0039", "rank": "Strain"}, "1138822": {"name": "Lactobacillus curieae", "rank": "Species"}, "1411991": {"name": "Banana streak VN virus", "rank": "Species"}, "168935": {"name": "Thalassospira lucentensis", "rank": "Species"}, "168934": {"name": "Thalassospira", "rank": "Genus"}, "168933": {"name": "Legionella drancourtii", "rank": "Species"}, "756285": {"name": "Tetraselmis viridis virus S1", "rank": "Species"}, "756282": {"name": "Cellulophaga phage phiST", "rank": "Species"}, "1455272": {"name": "Mycobacterium tuberculosis NRITLD53", "rank": "Strain"}, "756280": {"name": "Cellulophaga phage phiSM", "rank": "Species"}, "1109710": {"name": "Gordonia phage GRU1", "rank": "Species"}, "1109711": {"name": "Nocardia phage NBR1", "rank": "Species"}, "1109712": {"name": "Rhodococcus phage REQ1", "rank": "Species"}, "1109713": {"name": "Rhodococcus phage REQ2", "rank": "Species"}, "1109714": {"name": "Rhodococcus phage REQ3", "rank": "Species"}, "1109715": {"name": "Rhodococcus phage RER2", "rank": "Species"}, "1109716": {"name": "Rhodococcus phage RGL3", "rank": "Species"}, "1109717": {"name": "Rhodococcus phage RRH1", "rank": "Species"}, "1297584": {"name": "Citrobacter freundii GTC 09629", "rank": "Strain"}, "1297582": {"name": "Candidatus Portiera aleyrodidarum TV", "rank": "Strain"}, "1297581": {"name": "Anoxybacillus flavithermus AK1", "rank": "Strain"}, "1250339": {"name": "Burkholderia thailandensis MSMB59", "rank": "Strain"}, "1381133": {"name": "Candidatus Profftella", "rank": "Genus"}, "157228": {"name": "Jeotgalicoccus psychrophilus", "rank": "Species"}, "106633": {"name": "Thioalkalivibrio", "rank": "Genus"}, "189518": {"name": "Leptospira interrogans serovar Lai str. 56601", "rank": "Strain"}, "157226": {"name": "Jeotgalibacillus", "rank": "Genus"}, "877422": {"name": "Butyrivibrio hungatei NK4A153", "rank": "Strain"}, "877420": {"name": "Lachnospiraceae bacterium NK4A136", "rank": "Species"}, "877421": {"name": "Lachnospiraceae bacterium NK4A144", "rank": "Species"}, "877424": {"name": "Lachnospiraceae bacterium NK4A179", "rank": "Species"}, "1448701": {"name": "Mycobacterium tuberculosis M1533", "rank": "Strain"}, "160661": {"name": "Desulfobulbus mediterraneus", "rank": "Species"}, "160660": {"name": "Thiobacillus prosperus", "rank": "Species"}, "1221520": {"name": "Photorhabdus temperata subsp. temperata M1021", "rank": "Strain"}, "1380376": {"name": "Pseudomonas sp. URHB0015", "rank": "Species"}, "1221522": {"name": "Pseudomonas fluorescens NCIMB 11764", "rank": "Strain"}, "1380374": {"name": "Staphylococcus sp. URHA0057", "rank": "Species"}, "1380373": {"name": "Pseudoalteromonas sp. 23_GOM-1509m", "rank": "Species"}, "1380372": {"name": "Paenibacillus sp. URHA0014", "rank": "Species"}, "1380371": {"name": "Bacillus sp. UNC125MFCrub1.1", "rank": "Species"}, "1380370": {"name": "Intrasporangiaceae bacterium URHB0013", "rank": "Species"}, "1513272": {"name": "Lambdapapillomavirus 5", "rank": "Species"}, "1513274": {"name": "Taupapillomavirus 2", "rank": "Species"}, "1513276": {"name": "Chipapillomavirus 3", "rank": "Species"}, "1513277": {"name": "Higrevirus", "rank": "Genus"}, "1582493": {"name": "Pseudomonas sp. PH1(2014b)", "rank": "Species"}, "1455276": {"name": "Mycobacterium tuberculosis NRITLD57", "rank": "Strain"}, "871701": {"name": "Oscivirus A2", "rank": "Strain"}, "871700": {"name": "Oscivirus A1", "rank": "Strain"}, "1422480": {"name": "Staphylococcus aureus VET0177R", "rank": "Strain"}, "309868": {"name": "Candidatus Liberibacter americanus", "rank": "Species"}, "494419": {"name": "Arthrobacter sp. TB 23", "rank": "Species"}, "1463873": {"name": "Streptomyces sp. NRRL F-5917", "rank": "Species"}, "1463870": {"name": "Streptomyces sp. NRRL F-5702", "rank": "Species"}, "1463871": {"name": "Streptomyces sp. NRRL F-5727", "rank": "Species"}, "1463876": {"name": "Streptomyces sp. NRRL F-6628", "rank": "Species"}, "1463877": {"name": "Streptomyces sp. NRRL F-6674", "rank": "Species"}, "1463874": {"name": "Streptomyces sp. NRRL F-6131", "rank": "Species"}, "1463875": {"name": "Streptomyces sp. NRRL F-6133", "rank": "Species"}, "1757": {"name": "Thermoanaerobacter ethanolicus", "rank": "Species"}, "1463878": {"name": "Streptomyces sp. NRRL F-6676", "rank": "Species"}, "1754": {"name": "Thermoanaerobacter", "rank": "Genus"}, "1752": {"name": "Propionibacterium freudenreichii subsp. shermanii", "rank": "Subspecies"}, "1751": {"name": "Propionibacterium thoenii", "rank": "Species"}, "1750": {"name": "Propionibacterium propionicum", "rank": "Species"}, "82508": {"name": "Trichosporon asahii", "rank": "Species"}, "693998": {"name": "Rhinolophus bat coronavirus HKU2", "rank": "Species"}, "721785": {"name": "Acidovorax ebreus", "rank": "Species"}, "290339": {"name": "Cronobacter sakazakii ATCC BAA-894", "rank": "Strain"}, "1291348": {"name": "Leptospira interrogans serovar Copenhageni str. Fiocruz LV4234", "rank": "Strain"}, "1291347": {"name": "Leptospira interrogans serovar Copenhageni str. Fiocruz LV4211", "rank": "Strain"}, "1291346": {"name": "Leptospira interrogans serovar Copenhageni str. Fiocruz LV4034", "rank": "Strain"}, "1291345": {"name": "Leptospira interrogans serovar Copenhageni str. Fiocruz LV3409", "rank": "Strain"}, "1291344": {"name": "Leptospira interrogans serovar Copenhageni str. Fiocruz LV4188", "rank": "Strain"}, "1291343": {"name": "Leptospira interrogans serovar Copenhageni str. Fiocruz LV4174", "rank": "Strain"}, "1291342": {"name": "Leptospira interrogans serovar Copenhageni str. Fiocruz LV4217", "rank": "Strain"}, "1291341": {"name": "Leptospira interrogans serovar Copenhageni str. Wijnberg", "rank": "Strain"}, "1291340": {"name": "Leptospira interrogans serovar Copenhageni str. Fiocruz LV4212", "rank": "Strain"}, "1104620": {"name": "Hydrogenedentes bacterium JGI 0000077-O16", "rank": "Species"}, "1199278": {"name": "Vervet monkey polyomavirus", "rank": "Species"}, "213462": {"name": "Syntrophobacterales", "rank": "Order"}, "249408": {"name": "Deinococcus marmoris", "rank": "Species"}, "37914": {"name": "Dietzia", "rank": "Genus"}, "37919": {"name": "Rhodococcus opacus", "rank": "Species"}, "39047": {"name": "Mycoplasma sturni", "rank": "Species"}, "39046": {"name": "Cassava common mosaic virus", "rank": "Species"}, "33024": {"name": "Phascolarctobacterium", "rank": "Genus"}, "33029": {"name": "Anaerococcus hydrogenalis", "rank": "Species"}, "363754": {"name": "Rhizobium freirei PRF 81", "rank": "Strain"}, "81056": {"name": "Wolfiporia cocos", "rank": "Species"}, "81055": {"name": "Wolfiporia", "rank": "Genus"}, "85578": {"name": "Mitosporic Ustilaginaceae", "rank": "No rank"}, "1073384": {"name": "Aeromonas veronii AER397", "rank": "Strain"}, "1073387": {"name": "Bacteroides fragilis HMW 615", "rank": "Strain"}, "1073386": {"name": "Bacteroides fragilis HMW 610", "rank": "Strain"}, "1073383": {"name": "Aeromonas veronii AMC34", "rank": "Strain"}, "1073382": {"name": "Aeromonas veronii AER39", "rank": "Strain"}, "195709": {"name": "Xanthomonas arboricola pv. juglandis", "rank": "Strain"}, "364409": {"name": "Granulibacter", "rank": "Genus"}, "1048752": {"name": "Candidatus Caldiarchaeum", "rank": "Genus"}, "983507": {"name": "Ponticoccus", "rank": "Genus"}, "84480": {"name": "Amycolatopsis thermoflava", "rank": "Species"}, "1048758": {"name": "Candidatus Moranella endobia", "rank": "Species"}, "1268285": {"name": "Burkholderia kururiensis M130", "rank": "Strain"}, "85688": {"name": "Nocardia cerradoensis", "rank": "Species"}, "63560": {"name": "Desulfovibrio oxyclinae", "rank": "Species"}, "85683": {"name": "Bacillus selenitireducens", "rank": "Species"}, "367830": {"name": "Staphylococcus aureus subsp. aureus USA300", "rank": "Strain"}, "1165950": {"name": "Escherichia coli O26:H11 str. CVM10021", "rank": "Strain"}, "1165951": {"name": "Escherichia coli O26:H11 str. CVM10026", "rank": "Strain"}, "1165952": {"name": "Escherichia coli O26:H11 str. CVM10030", "rank": "Strain"}, "1165953": {"name": "Escherichia coli O26:H11 str. CVM10224", "rank": "Strain"}, "1388092": {"name": "Staphylococcus aureus M0146", "rank": "Strain"}, "1388093": {"name": "Staphylococcus aureus M0147", "rank": "Strain"}, "1388090": {"name": "Staphylococcus aureus M0143", "rank": "Strain"}, "1388091": {"name": "Staphylococcus aureus M0145", "rank": "Strain"}, "1388096": {"name": "Staphylococcus aureus M0153", "rank": "Strain"}, "1388097": {"name": "Staphylococcus aureus M0155", "rank": "Strain"}, "1388094": {"name": "Staphylococcus aureus M0148", "rank": "Strain"}, "1388095": {"name": "Staphylococcus aureus M0149", "rank": "Strain"}, "994484": {"name": "Pseudomonas brassicacearum subsp. brassicacearum NFM421", "rank": "Strain"}, "1388098": {"name": "Staphylococcus aureus M0156", "rank": "Strain"}, "1388099": {"name": "Staphylococcus aureus M0157", "rank": "Strain"}, "1418264": {"name": "Staphylococcus aureus F12749", "rank": "Strain"}, "1274814": {"name": "Escherichia coli APEC O78", "rank": "Strain"}, "1215113": {"name": "Pseudomonas oryzihabitans NBRC 102199", "rank": "Strain"}, "1215110": {"name": "Pseudomonas monteilii NBRC 103158 = DSM 14164", "rank": "Strain"}, "68570": {"name": "Streptomyces albulus", "rank": "Species"}, "351195": {"name": "Salimicrobium", "rank": "Genus"}, "1204533": {"name": "Bacillus phage phiAGATE", "rank": "Species"}, "1398507": {"name": "Felis catus papillomavirus 4", "rank": "Species"}, "1499966": {"name": "Bacterium UASB14", "rank": "Species"}, "1150990": {"name": "Enterobacter phage Enc34", "rank": "Species"}, "1150991": {"name": "Sphingomonas phage PAU", "rank": "Species"}, "1150992": {"name": "Ralstonia phage RSS0", "rank": "Species"}, "1150997": {"name": "Marinobacter manganoxydans", "rank": "Species"}, "1310790": {"name": "Acinetobacter baumannii 1179249", "rank": "Strain"}, "1310791": {"name": "Acinetobacter baumannii 742879", "rank": "Strain"}, "1310792": {"name": "Acinetobacter baumannii 981176", "rank": "Strain"}, "1310793": {"name": "Acinetobacter baumannii 98826", "rank": "Strain"}, "1310794": {"name": "Acinetobacter baumannii 303002", "rank": "Strain"}, "1310795": {"name": "Acinetobacter baumannii 1281984", "rank": "Strain"}, "1310796": {"name": "Acinetobacter baumannii 1406182", "rank": "Strain"}, "1310797": {"name": "Acinetobacter baumannii 1428368", "rank": "Strain"}, "1310798": {"name": "Acinetobacter baumannii 14216", "rank": "Strain"}, "1310799": {"name": "Acinetobacter baumannii 1494580", "rank": "Strain"}, "199361": {"name": "Pea stem necrosis virus", "rank": "Species"}, "1234428": {"name": "Unclassified AHJD-like viruses", "rank": "No rank"}, "119603": {"name": "Streptococcus dysgalactiae group", "rank": "Species group"}, "940190": {"name": "Melissococcus plutonius ATCC 35311", "rank": "Strain"}, "80811": {"name": "Cystobacterineae", "rank": "Suborder"}, "80812": {"name": "Sorangiineae", "rank": "Suborder"}, "80816": {"name": "Haliangium ochraceum", "rank": "Species"}, "1158698": {"name": "Staphylococcus aureus M0799", "rank": "Strain"}, "1158697": {"name": "Staphylococcus aureus M0780", "rank": "Strain"}, "1158696": {"name": "Staphylococcus aureus M0770", "rank": "Strain"}, "1158695": {"name": "Staphylococcus aureus M0769", "rank": "Strain"}, "1158694": {"name": "Staphylococcus aureus M0719", "rank": "Strain"}, "1158693": {"name": "Staphylococcus aureus M0692", "rank": "Strain"}, "1158692": {"name": "Staphylococcus aureus M0687", "rank": "Strain"}, "1158691": {"name": "Staphylococcus aureus M0676", "rank": "Strain"}, "1158690": {"name": "Staphylococcus aureus M0622", "rank": "Strain"}, "1441629": {"name": "Pseudomonas cichorii JBC1", "rank": "Strain"}, "880478": {"name": "Thermoanaerobacter siderophilus SR4", "rank": "Strain"}, "1194415": {"name": "Pseudomonas syringae pv. actinidiae ICMP 19103", "rank": "Strain"}, "1194417": {"name": "Pseudomonas syringae pv. actinidiae ICMP 9855", "rank": "Strain"}, "1194416": {"name": "Pseudomonas syringae pv. actinidiae ICMP 19102", "rank": "Strain"}, "1194418": {"name": "Pseudomonas syringae pv. actinidiae ICMP 9617", "rank": "Strain"}, "1214242": {"name": "Streptomyces collinus Tu 365", "rank": "Strain"}, "1388130": {"name": "Staphylococcus aureus M0198", "rank": "Strain"}, "909943": {"name": "SAR116 cluster alpha proteobacterium HIMB100", "rank": "Species"}, "1388545": {"name": "Staphylococcus aureus M0152", "rank": "Strain"}, "1388546": {"name": "Staphylococcus aureus M0167", "rank": "Strain"}, "1388547": {"name": "Staphylococcus aureus M0176", "rank": "Strain"}, "909947": {"name": "Salmonella enterica subsp. enterica serovar Gallinarum str. SG9", "rank": "Strain"}, "909946": {"name": "Salmonella enterica subsp. enterica serovar Typhimurium str. ST4/74", "rank": "Strain"}, "909945": {"name": "Salmonella enterica subsp. enterica serovar Dublin str. SD3246", "rank": "Strain"}, "1388543": {"name": "Staphylococcus aureus M0130", "rank": "Strain"}, "1388548": {"name": "Staphylococcus aureus M0190", "rank": "Strain"}, "1422136": {"name": "Staphylococcus aureus DAR3583", "rank": "Strain"}, "687800": {"name": "Synechococcus phage S-RIM2", "rank": "Species"}, "393119": {"name": "Listeria monocytogenes FSL J1-208", "rank": "Strain"}, "393118": {"name": "Listeria monocytogenes FSL J1-175", "rank": "Strain"}, "1422132": {"name": "Staphylococcus aureus DAR3575", "rank": "Strain"}, "607711": {"name": "Neisseria wadsworthii", "rank": "Species"}, "1422133": {"name": "Staphylococcus aureus DAR3576", "rank": "Strain"}, "393115": {"name": "Francisella tularensis subsp. tularensis FSC198", "rank": "Strain"}, "1407608": {"name": "Erwinia phage FE44", "rank": "Species"}, "883876": {"name": "Luna virus", "rank": "Species"}, "1028989": {"name": "Pseudomonas sp. StFLB209", "rank": "Species"}, "992039": {"name": "Helicobacter pylori Hp H-24", "rank": "Strain"}, "255066": {"name": "Pepper veinal mottle virus", "rank": "Species"}, "745277": {"name": "Rahnella aquatilis CIP 78.65 = ATCC 33071", "rank": "Strain"}, "1422139": {"name": "Staphylococcus aureus DAR3587", "rank": "Strain"}, "883120": {"name": "Klebsiella oxytoca 10-5245", "rank": "Strain"}, "883121": {"name": "Klebsiella oxytoca 10-5246", "rank": "Strain"}, "883123": {"name": "Klebsiella oxytoca 10-5248", "rank": "Strain"}, "1283300": {"name": "Methylohalobius crimeensis 10Ki", "rank": "Strain"}, "883125": {"name": "Klebsiella oxytoca 10-5250", "rank": "Strain"}, "883126": {"name": "Massilia timonae CCUG 45783", "rank": "Strain"}, "1283308": {"name": "Ferlavirus", "rank": "Genus"}, "86416": {"name": "Clostridium pasteurianum BC1", "rank": "Strain"}, "1151336": {"name": "Peptoclostridium difficile DA00174", "rank": "Strain"}, "443149": {"name": "Mycobacterium tuberculosis CCDC5079", "rank": "Strain"}, "443144": {"name": "Geobacter sp. M21", "rank": "Species"}, "443143": {"name": "Geobacter sp. M18", "rank": "Species"}, "1418": {"name": "Bacillus mannanilyticus", "rank": "Species"}, "1212568": {"name": "Shigella flexneri S6678", "rank": "Strain"}, "1212569": {"name": "Shigella flexneri S6764", "rank": "Strain"}, "1212566": {"name": "Shigella flexneri S6585", "rank": "Strain"}, "1411": {"name": "Bacillus akibai", "rank": "Species"}, "1212564": {"name": "Shigella sonnei S6513", "rank": "Strain"}, "1413": {"name": "Bacillus cellulosilyticus", "rank": "Species"}, "1212562": {"name": "Shigella flexneri S5717", "rank": "Strain"}, "1212561": {"name": "Salmonella enterica subsp. enterica serovar Mississippi str. 2010K-1406", "rank": "Strain"}, "1168290": {"name": "Bifidobacterium animalis subsp. lactis B420", "rank": "Strain"}, "1126411": {"name": "Silurus glanis circovirus", "rank": "Species"}, "1195162": {"name": "Unclassified Anulavirus", "rank": "No rank"}, "223958": {"name": "Exiguobacterium oxidotolerans", "rank": "Species"}, "1353016": {"name": "Sclerotinia sclerotiorum endornavirus-1", "rank": "Species"}, "543349": {"name": "Symbiobacteriaceae", "rank": "Family"}, "235888": {"name": "Salinibacterium", "rank": "Genus"}, "1284796": {"name": "Klebsiella pneumoniae DMC0526", "rank": "Strain"}, "1284797": {"name": "Klebsiella pneumoniae DMC0799", "rank": "Strain"}, "1284794": {"name": "Klebsiella pneumoniae UHKPC77", "rank": "Strain"}, "1284795": {"name": "Klebsiella pneumoniae UHKPC96", "rank": "Strain"}, "1284792": {"name": "Klebsiella pneumoniae UHKPC67", "rank": "Strain"}, "1284793": {"name": "Klebsiella pneumoniae UHKPC69", "rank": "Strain"}, "1284790": {"name": "Klebsiella pneumoniae UHKPC05", "rank": "Strain"}, "1284791": {"name": "Klebsiella pneumoniae UHKPC47", "rank": "Strain"}, "1232410": {"name": "Desulfuromonas sp. TF", "rank": "Species"}, "1050843": {"name": "Propionibacterium humerusii", "rank": "Species"}, "1541197": {"name": "Planococcus sp. CAU13", "rank": "Species"}, "1437442": {"name": "Bacillus anthracis str. 95014", "rank": "Strain"}, "1437443": {"name": "Methylibium sp. T29-B", "rank": "Species"}, "221036": {"name": "Malvastrum yellow vein betasatellite", "rank": "Species"}, "72539": {"name": "Physalis mottle virus", "rank": "Species"}, "1316929": {"name": "Bacillus subtilis SPZ1", "rank": "Strain"}, "1316928": {"name": "Gordonia terrae C-6", "rank": "Strain"}, "768485": {"name": "Neisseria meningitidis K1207", "rank": "Strain"}, "768484": {"name": "Neisseria meningitidis S0108", "rank": "Strain"}, "1316927": {"name": "Pseudomonas corrugata CFBP 5454", "rank": "Strain"}, "768486": {"name": "Enterococcus hirae ATCC 9790", "rank": "Strain"}, "1316923": {"name": "Campylobacter jejuni g113", "rank": "Strain"}, "28038": {"name": "Lactobacillus curvatus", "rank": "Species"}, "70822": {"name": "Okra mosaic virus", "rank": "Species"}, "997879": {"name": "Bacteroides fragilis CL03T12C07", "rank": "Strain"}, "65502": {"name": "Cryptosporangium", "rank": "Genus"}, "1445613": {"name": "Sciscionella sp. SE31", "rank": "Species"}, "1445611": {"name": "Mycobacterium smegmatis MC2 51", "rank": "Strain"}, "53413": {"name": "Xanthomonas axonopodis", "rank": "Species"}, "367190": {"name": "Yersinia similis", "rank": "Species"}, "1321941": {"name": "Helicobacter pylori UM298", "rank": "Strain"}, "1321940": {"name": "Helicobacter pylori UM066", "rank": "Strain"}, "1116190": {"name": "Escherichia coli P0304816.14", "rank": "Strain"}, "1116191": {"name": "Escherichia coli P0304816.15", "rank": "Strain"}, "1321945": {"name": "Coxiella burnetii str. Namibia", "rank": "Strain"}, "1217655": {"name": "Acinetobacter guillouiae CIP 63.46", "rank": "Strain"}, "1116194": {"name": "Escherichia coli P0305260.5", "rank": "Strain"}, "1038869": {"name": "Burkholderia mimosarum LMG 23256", "rank": "Strain"}, "1038861": {"name": "Bradyrhizobium japonicum USDA 122", "rank": "Strain"}, "1038860": {"name": "Bradyrhizobium elkanii WSM2783", "rank": "Strain"}, "2214": {"name": "Methanosarcina acetivorans", "rank": "Species"}, "1038864": {"name": "Bradyrhizobium japonicum USDA 4", "rank": "Strain"}, "1038867": {"name": "Bradyrhizobium sp. WSM3983", "rank": "Species"}, "1038866": {"name": "Bradyrhizobium sp. WSM2793", "rank": "Species"}, "1444260": {"name": "Escherichia coli 2-052-05_S4_C3", "rank": "Strain"}, "1444261": {"name": "Escherichia coli 2-156-04_S4_C3", "rank": "Strain"}, "1444262": {"name": "Escherichia coli 2-177-06_S4_C3", "rank": "Strain"}, "1444263": {"name": "Escherichia coli 2-210-07_S4_C3", "rank": "Strain"}, "1444264": {"name": "Escherichia coli 2-222-05_S4_C3", "rank": "Strain"}, "1444265": {"name": "Escherichia coli 2-316-03_S4_C3", "rank": "Strain"}, "1444266": {"name": "Escherichia coli 2-427-07_S4_C3", "rank": "Strain"}, "1444267": {"name": "Escherichia coli 2-460-02_S4_C3", "rank": "Strain"}, "1409678": {"name": "Staphylococcus aureus KINW6040", "rank": "Strain"}, "1444269": {"name": "Escherichia coli 5-172-05_S4_C3", "rank": "Strain"}, "1281010": {"name": "Escherichia coli HVH 69 (4-2837072)", "rank": "Strain"}, "1281011": {"name": "Escherichia coli HVH 70 (4-2963531)", "rank": "Strain"}, "1249508": {"name": "Unclassified Hepacivirus", "rank": "No rank"}, "1281017": {"name": "Escherichia coli HVH 79 (4-2512823)", "rank": "Strain"}, "1281014": {"name": "Escherichia coli HVH 76 (4-2538717)", "rank": "Strain"}, "1281015": {"name": "Escherichia coli HVH 77 (4-2605759)", "rank": "Strain"}, "1422523": {"name": "Staphylococcus aureus VET0232R", "rank": "Strain"}, "1422522": {"name": "Staphylococcus aureus VET0230R", "rank": "Strain"}, "1422521": {"name": "Staphylococcus aureus VET0229R", "rank": "Strain"}, "1422520": {"name": "Staphylococcus aureus VET0228R", "rank": "Strain"}, "629773": {"name": "Sphingomonas sp. Mn802worker", "rank": "Species"}, "1422526": {"name": "Staphylococcus aureus VET0237R", "rank": "Strain"}, "1422525": {"name": "Staphylococcus aureus VET0236R", "rank": "Strain"}, "1422524": {"name": "Staphylococcus aureus VET0235R", "rank": "Strain"}, "1422529": {"name": "Staphylococcus aureus VET0244R", "rank": "Strain"}, "1422528": {"name": "Staphylococcus aureus VET0243R", "rank": "Strain"}, "137475": {"name": "Cucumber vein yellowing virus", "rank": "Species"}, "332102": {"name": "Fluviicola", "rank": "Genus"}, "332101": {"name": "Clostridium drakei", "rank": "Species"}, "498213": {"name": "Clostridium botulinum B1 str. Okra", "rank": "Strain"}, "498211": {"name": "Cellvibrio japonicus Ueda107", "rank": "Strain"}, "498216": {"name": "Lactobacillus casei str. Zhang", "rank": "Strain"}, "498217": {"name": "Edwardsiella tarda EIB202", "rank": "Strain"}, "498214": {"name": "Clostridium botulinum A3 str. Loch Maree", "rank": "Strain"}, "186807": {"name": "Peptococcaceae", "rank": "Family"}, "764562": {"name": "Brochothrix phage BL3", "rank": "Species"}, "545259": {"name": "Melandrium yellow fleck virus", "rank": "Species"}, "186804": {"name": "Peptostreptococcaceae", "rank": "Family"}, "186803": {"name": "Lachnospiraceae", "rank": "Family"}, "186802": {"name": "Clostridiales", "rank": "Order"}, "186801": {"name": "Clostridia", "rank": "Class"}, "905067": {"name": "Streptococcus parasanguinis F0405", "rank": "Strain"}, "12151": {"name": "Eggplant mosaic virus", "rank": "Species"}, "280477": {"name": "Bacillus anthracis str. Australia 94", "rank": "Strain"}, "45670": {"name": "Salinicoccus roseus", "rank": "Species"}, "1155777": {"name": "Bacillus amyloliquefaciens subsp. plantarum YAU B9601-Y2", "rank": "Strain"}, "1155776": {"name": "Treponema pallidum subsp. endemicum str. Bosnia A", "rank": "Strain"}, "1155775": {"name": "Treponema pallidum str. Fribourg-Blanc", "rank": "Strain"}, "260908": {"name": "Tomato mosaic leaf curl virus", "rank": "Species"}, "192987": {"name": "Allofustis", "rank": "Genus"}, "223524": {"name": "Vibrio phage VGJphi", "rank": "Species"}, "223527": {"name": "Halomonas boliviensis", "rank": "Species"}, "1451263": {"name": "Klebsiella pneumoniae JT4", "rank": "Strain"}, "1149865": {"name": "Pedobacter agri PB92", "rank": "Strain"}, "370438": {"name": "Pelotomaculum thermopropionicum SI", "rank": "Strain"}, "1133293": {"name": "Brucella phage Pr", "rank": "Species"}, "765414": {"name": "Burkholderia bannensis", "rank": "Species"}, "441157": {"name": "Burkholderia thailandensis MSMB43", "rank": "Strain"}, "565034": {"name": "Brachyspira hyodysenteriae WA1", "rank": "Strain"}, "209052": {"name": "Burkholderia phage Bcep781", "rank": "Species"}, "565033": {"name": "Geoglobus acetivorans", "rank": "Species"}, "1240676": {"name": "Pseudomonas sp. PAMC 26793", "rank": "Species"}, "959": {"name": "Bdellovibrio bacteriovorus", "rank": "Species"}, "958": {"name": "Bdellovibrio", "rank": "Genus"}, "955": {"name": "Wolbachia pipientis", "rank": "Species"}, "953": {"name": "Wolbachia", "rank": "Genus"}, "952": {"name": "Wolbachieae", "rank": "Tribe"}, "951": {"name": "Neorickettsia sennetsu", "rank": "Species"}, "950": {"name": "Neorickettsia risticii", "rank": "Species"}, "935948": {"name": "Caldanaerobius polysaccharolyticus DSM 13641", "rank": "Strain"}, "192989": {"name": "Nanoarchaeota", "rank": "Phylum"}, "419005": {"name": "Prevotella amnii", "rank": "Species"}, "935942": {"name": "Desulfonatronum lacustre DSM 10312", "rank": "Strain"}, "54308": {"name": "Pleurocapsa minor", "rank": "Species"}, "228600": {"name": "Nocardia araoensis", "rank": "Species"}, "228601": {"name": "Nocardia pneumoniae", "rank": "Species"}, "228603": {"name": "Prevotella shahii", "rank": "Species"}, "228604": {"name": "Prevotella salivae", "rank": "Species"}, "454164": {"name": "Salmonella enterica subsp. enterica serovar Heidelberg str. SL486", "rank": "Strain"}, "54304": {"name": "Planktothrix", "rank": "Genus"}, "454166": {"name": "Salmonella enterica subsp. enterica serovar Agona str. SL483", "rank": "Strain"}, "53245": {"name": "Desulfonatronovibrio hydrogenovorans", "rank": "Species"}, "53244": {"name": "Desulfonatronovibrio", "rank": "Genus"}, "53246": {"name": "Pseudoalteromonas", "rank": "Genus"}, "320849": {"name": "Staphylococcus phage 92", "rank": "Strain"}, "320848": {"name": "Staphylococcus phage 88", "rank": "Strain"}, "320845": {"name": "Staphylococcus phage 55", "rank": "Species"}, "320844": {"name": "Staphylococcus phage 71", "rank": "Strain"}, "320847": {"name": "Staphylococcus phage 52A", "rank": "Strain"}, "320846": {"name": "Staphylococcus phage 29", "rank": "Strain"}, "320841": {"name": "Staphylococcus phage EW", "rank": "Species"}, "320840": {"name": "Staphylococcus phage 37", "rank": "Species"}, "320843": {"name": "Staphylococcus phage ROSA", "rank": "Species"}, "320842": {"name": "Staphylococcus phage 96", "rank": "Strain"}, "552536": {"name": "Listeria monocytogenes HCC23", "rank": "Strain"}, "454162": {"name": "Kiloniella laminariae", "rank": "Species"}, "552531": {"name": "Bifidobacterium animalis subsp. lactis BB-12", "rank": "Strain"}, "1004301": {"name": "Flavihumibacter", "rank": "Genus"}, "1335640": {"name": "Clostridium saccharoperbutylacetonicum N1-4", "rank": "Strain"}, "1230730": {"name": "Clostridiales bacterium S5-A11", "rank": "Species"}, "1230734": {"name": "Clostridiales bacterium S5-A14a", "rank": "Species"}, "272131": {"name": "Nostoc punctiforme", "rank": "Species"}, "561180": {"name": "Bifidobacterium gallicum DSM 20093 = LMG 11596", "rank": "Strain"}, "1333520": {"name": "Pseudoalteromonas sp. S8-8", "rank": "Species"}, "1333523": {"name": "Salinarchaeum sp. Harcht-Bsk1", "rank": "Species"}, "1333525": {"name": "Pseudoalteromonas atlantica TB41", "rank": "Strain"}, "1333529": {"name": "Campylobacter fetus subsp. venerealis bv. intermedius str. 99541", "rank": "Strain"}, "34003": {"name": "Paracoccus aminophilus", "rank": "Species"}, "34007": {"name": "Paracoccus versutus", "rank": "Species"}, "1286093": {"name": "Pandoraea sp. SD6-2", "rank": "Species"}, "189478": {"name": "Orbiliomycetes", "rank": "Class"}, "289201": {"name": "Pontibacillus", "rank": "Genus"}, "52598": {"name": "Sulfitobacter sp. EE-36", "rank": "Species"}, "1085548": {"name": "Leptospira interrogans serovar Manilae str. M001_Tn_Mutant_Parent", "rank": "Strain"}, "1085549": {"name": "Leptospira santarosai serovar Arenal str. 11", "rank": "Strain"}, "1085540": {"name": "Leptospira noguchii serovar Autumnalis str. ZUN142", "rank": "Strain"}, "88916": {"name": "Borrelia spielmanii", "rank": "Species"}, "1085546": {"name": "Leptospira interrogans serovar Manilae str. M874_LA0615_mutant", "rank": "Strain"}, "1085547": {"name": "Leptospira interrogans serovar Manilae str. M933_lip32_mutant", "rank": "Strain"}, "1085544": {"name": "Leptospira interrogans serovar Manilae str. M1352_LPS_mutant", "rank": "Strain"}, "1085545": {"name": "Leptospira interrogans serovar Manilae str. M776_fur_mutant", "rank": "Strain"}, "129337": {"name": "Geobacillus", "rank": "Genus"}, "425944": {"name": "Sulfolobus islandicus L.D.8.5", "rank": "Strain"}, "586420": {"name": "Human cosavirus B", "rank": "Species"}, "425941": {"name": "Prevotella nanceiensis", "rank": "Species"}, "10326": {"name": "Equid herpesvirus 1", "rank": "Species"}, "10325": {"name": "Macacine herpesvirus 1", "rank": "Species"}, "1301098": {"name": "Pseudomonas knackmussii B13", "rank": "Strain"}, "129338": {"name": "Geobacillus subterraneus", "rank": "Species"}, "10320": {"name": "Bovine herpesvirus 1", "rank": "Species"}, "1121254": {"name": "Hamadaea", "rank": "Genus"}, "1121253": {"name": "Catelliglobosispora", "rank": "Genus"}, "1121252": {"name": "Cucumibacter marinus", "rank": "Species"}, "1121251": {"name": "Cucumibacter", "rank": "Genus"}, "1121259": {"name": "Caldicellulosiruptor acetigenus DSM 7040", "rank": "Strain"}, "938278": {"name": "Clostridiales bacterium 9400853", "rank": "Species"}, "586423": {"name": "Human cosavirus E", "rank": "Species"}, "42302": {"name": "Lasiosphaeriaceae", "rank": "Family"}, "938276": {"name": "Tomato leaf curl Ranchi virus", "rank": "Species"}, "480224": {"name": "Chloroflexus sp. Y-400-fl", "rank": "Species"}, "242710": {"name": "Tree shrew adenovirus A", "rank": "Species"}, "1501391": {"name": "Alistipes sp. 627", "rank": "Species"}, "282402": {"name": "Prevotella multiformis", "rank": "Species"}, "155863": {"name": "Methanothermococcus okinawensis", "rank": "Species"}, "155862": {"name": "Methanothermococcus", "rank": "Genus"}, "155864": {"name": "Escherichia coli O157:H7 str. EDL933", "rank": "Strain"}, "561275": {"name": "Mycobacterium bovis BCG str. Tokyo 172", "rank": "Strain"}, "439219": {"name": "Streptococcus henryi", "rank": "Species"}, "208013": {"name": "Agrotis ipsilon multiple nucleopolyhedrovirus", "rank": "Species"}, "12877": {"name": "Satellites", "rank": "No rank"}, "1073414": {"name": "Porticoccus hydrocarbonoclasticus", "rank": "Species"}, "29432": {"name": "Psychrobacter phenylpyruvicus", "rank": "Species"}, "590739": {"name": "Salmonella phage g341c", "rank": "Species"}, "205323": {"name": "Tobacco leaf curl betasatellite", "rank": "Species"}, "29438": {"name": "Pseudomonas savastanoi", "rank": "Species"}, "338079": {"name": "African green monkey simian foamy virus", "rank": "Species"}, "1185766": {"name": "Thioclava dalianensis", "rank": "Species"}, "1354109": {"name": "Mycobacterium tuberculosis MAL020199", "rank": "Strain"}, "1227486": {"name": "Halorubrum terrestre JCM 10247", "rank": "Strain"}, "50294": {"name": "Psittacid herpesvirus 1", "rank": "Species"}, "50292": {"name": "Cercopithecine herpesvirus 5", "rank": "Species"}, "50290": {"name": "Aotine herpesvirus 1", "rank": "Species"}, "168697": {"name": "Salinispora arenicola", "rank": "Species"}, "1421898": {"name": "Staphylococcus aureus W12583", "rank": "Strain"}, "1421899": {"name": "Staphylococcus aureus W12586", "rank": "Strain"}, "1421892": {"name": "Staphylococcus aureus T55959", "rank": "Strain"}, "1421893": {"name": "Staphylococcus aureus T55960", "rank": "Strain"}, "1421890": {"name": "Staphylococcus aureus T39102", "rank": "Strain"}, "1421891": {"name": "Staphylococcus aureus T39105", "rank": "Strain"}, "1421896": {"name": "Staphylococcus aureus T86792", "rank": "Strain"}, "1421897": {"name": "Staphylococcus aureus W12582", "rank": "Strain"}, "1421894": {"name": "Staphylococcus aureus T62976", "rank": "Strain"}, "1000935": {"name": "Anaplasma marginale str. Florida Relapse", "rank": "Strain"}, "1000936": {"name": "Anaplasma marginale str. Okeechobee", "rank": "Strain"}, "1000937": {"name": "Anaplasma marginale str. Washington Okanogan", "rank": "Strain"}, "134262": {"name": "Streptococcus mitis bv. 2", "rank": "Strain"}, "1365176": {"name": "Thermofilum sp. 1910b", "rank": "Species"}, "1429903": {"name": "Mycobacterium phage Bernardo", "rank": "Species"}, "1000938": {"name": "Anaplasma marginale str. Oklahoma", "rank": "Strain"}, "1000939": {"name": "Anaplasma marginale str. South Idaho", "rank": "Strain"}, "1388708": {"name": "Staphylococcus aureus M0942", "rank": "Strain"}, "1388709": {"name": "Staphylococcus aureus M0945", "rank": "Strain"}, "1388702": {"name": "Staphylococcus aureus M0936", "rank": "Strain"}, "1388703": {"name": "Staphylococcus aureus M0937", "rank": "Strain"}, "1388700": {"name": "Staphylococcus aureus M0932", "rank": "Strain"}, "1388701": {"name": "Staphylococcus aureus M0935", "rank": "Strain"}, "1388706": {"name": "Staphylococcus aureus M0940", "rank": "Strain"}, "69973": {"name": "Closteroviridae", "rank": "Family"}, "1388704": {"name": "Staphylococcus aureus M0938", "rank": "Strain"}, "1388705": {"name": "Staphylococcus aureus M0939", "rank": "Strain"}, "1411549": {"name": "Staphylococcus aureus M24487", "rank": "Strain"}, "1411548": {"name": "Staphylococcus aureus M16438", "rank": "Strain"}, "1411547": {"name": "Staphylococcus aureus H77102", "rank": "Strain"}, "1411546": {"name": "Staphylococcus aureus H77098", "rank": "Strain"}, "1411545": {"name": "Staphylococcus aureus H77094", "rank": "Strain"}, "1411544": {"name": "Staphylococcus aureus H74056", "rank": "Strain"}, "1411543": {"name": "Staphylococcus aureus H70834", "rank": "Strain"}, "1340713": {"name": "Mycobacterium phage Wanda", "rank": "Species"}, "1411541": {"name": "Staphylococcus aureus H70821", "rank": "Strain"}, "1411540": {"name": "Staphylococcus aureus H67656", "rank": "Strain"}, "204457": {"name": "Sphingomonadales", "rank": "Order"}, "204456": {"name": "Gemmobacter", "rank": "Genus"}, "204455": {"name": "Rhodobacterales", "rank": "Order"}, "204454": {"name": "Unclassified Holosporaceae", "rank": "No rank"}, "1499684": {"name": "Clostridium sp. CL-2", "rank": "Species"}, "1499685": {"name": "Bacillus sp. KW-12", "rank": "Species"}, "1499686": {"name": "Pseudomonas sp. 20_BN", "rank": "Species"}, "1499687": {"name": "Planomicrobium sp. ES2", "rank": "Species"}, "1499689": {"name": "Clostridium sp. LF2", "rank": "Species"}, "204458": {"name": "Caulobacterales", "rank": "Order"}, "749930": {"name": "Salmonella enterica subsp. enterica serovar Tennessee str. 4535", "rank": "Strain"}, "570508": {"name": "Helicobacter pylori P12", "rank": "Strain"}, "59195": {"name": "Rickettsiella", "rank": "Genus"}, "857154": {"name": "Streptococcus mutans 1ID3", "rank": "Strain"}, "765869": {"name": "Bdellovibrio bacteriovorus W", "rank": "Strain"}, "865937": {"name": "Gillisia limnaea DSM 15749", "rank": "Strain"}, "475080": {"name": "Torrubiella", "rank": "Genus"}, "865938": {"name": "Weeksella virosa DSM 16922", "rank": "Strain"}, "1659": {"name": "Actinomyces israelii", "rank": "Species"}, "437687": {"name": "Brucella sp. F8/99", "rank": "Species"}, "437684": {"name": "Brucella sp. UK40/99", "rank": "Species"}, "437685": {"name": "Brucella sp. UK5/01", "rank": "Species"}, "1652": {"name": "Alloiococcus otitis", "rank": "Species"}, "1653": {"name": "Corynebacteriaceae", "rank": "Family"}, "1651": {"name": "Alloiococcus", "rank": "Genus"}, "1656": {"name": "Actinomyces viscosus", "rank": "Species"}, "1654": {"name": "Actinomyces", "rank": "Genus"}, "1655": {"name": "Actinomyces naeslundii", "rank": "Species"}, "991878": {"name": "Helicoverpa armigera SNPV", "rank": "Species"}, "553184": {"name": "Atopobium rimae ATCC 49626", "rank": "Strain"}, "320432": {"name": "Chrysodeixis chalcites nucleopolyhedrovirus", "rank": "Species"}, "756499": {"name": "Desulfitobacterium dehalogenans ATCC 51507", "rank": "Strain"}, "128818": {"name": "Chinese yam necrotic mosaic virus", "rank": "Species"}, "421072": {"name": "Epilithonimonas lactis", "rank": "Species"}, "304371": {"name": "Methanocella paludicola SANAE", "rank": "Strain"}, "196079": {"name": "Oceanobacter", "rank": "Genus"}, "1157409": {"name": "Enterococcus faecalis EnGen0223", "rank": "Strain"}, "1157408": {"name": "Enterococcus faecalis EnGen0222", "rank": "Strain"}, "1157407": {"name": "Enterococcus faecalis EnGen0221", "rank": "Strain"}, "1157406": {"name": "Enterococcus faecalis EnGen0220", "rank": "Strain"}, "1157405": {"name": "Enterococcus faecalis EnGen0219", "rank": "Strain"}, "1157404": {"name": "Enterococcus faecalis EnGen0218", "rank": "Strain"}, "1157403": {"name": "Enterococcus faecalis EnGen0217", "rank": "Strain"}, "1157402": {"name": "Enterococcus faecalis EnGen0216", "rank": "Strain"}, "1157401": {"name": "Enterococcus faecalis EnGen0215", "rank": "Strain"}, "1220551": {"name": "Staphylococcus chromogenes MU 970", "rank": "Strain"}, "2158": {"name": "Methanobacteriales", "rank": "Order"}, "2159": {"name": "Methanobacteriaceae", "rank": "Family"}, "2150": {"name": "Acholeplasma modicum", "rank": "Species"}, "2151": {"name": "Mesoplasma florum", "rank": "Species"}, "317045": {"name": "Kuraishia", "rank": "Genus"}, "2157": {"name": "Archaea", "rank": "Superkingdom"}, "1133849": {"name": "Nocardia brasiliensis ATCC 700358", "rank": "Strain"}, "157897": {"name": "Rudiviridae", "rank": "Family"}, "1169329": {"name": "Escherichia coli KTE9", "rank": "Strain"}, "1169328": {"name": "Escherichia coli KTE8", "rank": "Strain"}, "157898": {"name": "Sulfolobus islandicus rod-shaped virus 1", "rank": "Species"}, "157899": {"name": "Sulfolobus islandicus rod-shaped virus 2", "rank": "Species"}, "35768": {"name": "Mycoplasma felifaucium", "rank": "Species"}, "35760": {"name": "Bifidobacterium choerinum", "rank": "Species"}, "1169325": {"name": "Escherichia coli KTE4", "rank": "Strain"}, "1169324": {"name": "Escherichia coli KTE2", "rank": "Strain"}, "1194088": {"name": "Halorubrum sp. T3", "rank": "Species"}, "1324278": {"name": "Mycobacterium tuberculosis TKK-01-0068", "rank": "Strain"}, "1324279": {"name": "Mycobacterium tuberculosis TKK-01-0070", "rank": "Strain"}, "1324274": {"name": "Mycobacterium tuberculosis TKK-01-0064", "rank": "Strain"}, "1324275": {"name": "Mycobacterium tuberculosis TKK-01-0065", "rank": "Strain"}, "1324276": {"name": "Mycobacterium tuberculosis TKK-01-0066", "rank": "Strain"}, "1324277": {"name": "Mycobacterium tuberculosis TKK-01-0067", "rank": "Strain"}, "1324270": {"name": "Mycobacterium tuberculosis TKK-01-0060", "rank": "Strain"}, "1324271": {"name": "Mycobacterium tuberculosis TKK-01-0061", "rank": "Strain"}, "1324272": {"name": "Mycobacterium tuberculosis TKK-01-0062", "rank": "Strain"}, "1324273": {"name": "Mycobacterium tuberculosis TKK-01-0063", "rank": "Strain"}, "1346614": {"name": "Serratia liquefaciens ATCC 27592", "rank": "Strain"}, "256466": {"name": "Pseudomonas japonica", "rank": "Species"}, "1461577": {"name": "Weeksella sp. FF8", "rank": "Species"}, "1461579": {"name": "Haemophilus sp. FF7", "rank": "Species"}, "327833": {"name": "Unclassified Atadenovirus", "rank": "No rank"}, "1523858": {"name": "Phomopsis longicolla hypovirus", "rank": "Species"}, "1439123": {"name": "Streptococcus pyogenes ABC020043540", "rank": "Strain"}, "1439122": {"name": "Streptococcus pyogenes ABC020041424", "rank": "Strain"}, "1439120": {"name": "Streptococcus pyogenes ABC020041397", "rank": "Strain"}, "1439127": {"name": "Streptococcus pyogenes ABC020044010", "rank": "Strain"}, "218387": {"name": "Kalanchoe top-spotting virus", "rank": "Species"}, "1437873": {"name": "Pseudomonas aeruginosa PA99", "rank": "Strain"}, "114259": {"name": "Nocardia paucivorans", "rank": "Species"}, "1437872": {"name": "Vibrio vulnificus BAA87", "rank": "Strain"}, "1116037": {"name": "Escherichia coli BCE001_MS16", "rank": "Strain"}, "1223261": {"name": "Pseudomonas phage JBD5", "rank": "Species"}, "1223260": {"name": "Pseudomonas phage JBD30", "rank": "Species"}, "1223262": {"name": "Pseudomonas phage JBD88a", "rank": "Species"}, "398577": {"name": "Burkholderia ambifaria MC40-6", "rank": "Strain"}, "70771": {"name": "Pyrobaculum neutrophilum", "rank": "Species"}, "70775": {"name": "Pseudomonas plecoglossicida", "rank": "Species"}, "398578": {"name": "Delftia acidovorans SPH-1", "rank": "Strain"}, "398579": {"name": "Shewanella pealeana ATCC 700345", "rank": "Strain"}, "253239": {"name": "Ethanoligenens harbinense", "rank": "Species"}, "253238": {"name": "Ethanoligenens", "rank": "Genus"}, "395331": {"name": "Methanoregula", "rank": "Genus"}, "1455294": {"name": "Mycobacterium tuberculosis NRITLD20", "rank": "Strain"}, "1455293": {"name": "Mycobacterium tuberculosis NRITLD19", "rank": "Strain"}, "1455292": {"name": "Mycobacterium tuberculosis NRITLD18", "rank": "Strain"}, "1455291": {"name": "Mycobacterium tuberculosis NRITLD17", "rank": "Strain"}, "1455290": {"name": "Mycobacterium tuberculosis NRITLD16", "rank": "Strain"}, "62977": {"name": "Acinetobacter sp. ADP1", "rank": "Species"}, "908028": {"name": "Bhendi yellow vein India virus India:Dharwad OYDWR2:2006", "rank": "Strain"}, "1407063": {"name": "Erwinia amylovora LA636", "rank": "Strain"}, "1407062": {"name": "Erwinia amylovora LA635", "rank": "Strain"}, "1407067": {"name": "Escherichia coli TTSH84137", "rank": "Strain"}, "1407064": {"name": "Erwinia amylovora LA637", "rank": "Strain"}, "213121": {"name": "Desulfobulbaceae", "rank": "Family"}, "1487711": {"name": "Streptomyces sp. NTK 937", "rank": "Species"}, "264027": {"name": "Algoriphagus marincola", "rank": "Species"}, "1256869": {"name": "Perch rhabdovirus", "rank": "Species"}, "264029": {"name": "Eubacterium yurii subsp. margaretiae", "rank": "Subspecies"}, "1392060": {"name": "Staphylococcus aureus M1054", "rank": "Strain"}, "1392061": {"name": "Staphylococcus aureus M1055", "rank": "Strain"}, "1392062": {"name": "Staphylococcus aureus M1056", "rank": "Strain"}, "1392063": {"name": "Staphylococcus aureus M1057", "rank": "Strain"}, "1392064": {"name": "Staphylococcus aureus M1058", "rank": "Strain"}, "1392065": {"name": "Staphylococcus aureus M1059", "rank": "Strain"}, "1392066": {"name": "Staphylococcus aureus M1065", "rank": "Strain"}, "1392067": {"name": "Staphylococcus aureus M1066", "rank": "Strain"}, "67332": {"name": "Streptomyces mutabilis", "rank": "Species"}, "1392069": {"name": "Staphylococcus aureus M1069", "rank": "Strain"}, "76020": {"name": "Amycolatopsis alba", "rank": "Species"}, "76023": {"name": "Halothece", "rank": "Genus"}, "355249": {"name": "Streptomyces sp. Tu6071", "rank": "Species"}, "355246": {"name": "Enterobacteria phage RTP", "rank": "Species"}, "355245": {"name": "Unclassified Tunalikevirus", "rank": "No rank"}, "1169855": {"name": "Rhodobacteraceae bacterium PD-2", "rank": "Species"}, "406425": {"name": "Burkholderia cenocepacia MC0-3", "rank": "Strain"}, "360293": {"name": "Leeuwenhoekiella blandensis", "rank": "Species"}, "92824": {"name": "Xanthomonas campestris pv. cannabis", "rank": "Strain"}, "1051632": {"name": "Sulfobacillus acidophilus TPY", "rank": "Strain"}, "262071": {"name": "Clostridium phage phiC2", "rank": "Species"}, "1054037": {"name": "Sphingobium sp. KK22", "rank": "Species"}, "77048": {"name": "Methanobacterium phage psiM2", "rank": "Species"}, "1446613": {"name": "Escherichia coli O157:H7 str. 08-3037", "rank": "Strain"}, "1287064": {"name": "Helicobacter pylori UM034", "rank": "Strain"}, "190047": {"name": "Prochlorococcus marinus str. EQPAC1", "rank": "Strain"}, "1287066": {"name": "Enterococcus faecalis DENG1", "rank": "Strain"}, "72638": {"name": "Streptococcus phage Sfi19", "rank": "Species"}, "1287061": {"name": "Helicobacter pylori UM018", "rank": "Strain"}, "62680": {"name": "Marinimicrobia", "rank": "Phylum"}, "1287063": {"name": "Helicobacter pylori UM007", "rank": "Strain"}, "1287062": {"name": "Helicobacter pylori UM054", "rank": "Strain"}, "78541": {"name": "Streptococcus phage Sfi11", "rank": "Species"}, "81467": {"name": "Aminobacterium mobile", "rank": "Species"}, "81464": {"name": "Anaeromusa acidaminophila", "rank": "Species"}, "81462": {"name": "Thermanaerovibrio acidaminovorans", "rank": "Species"}, "81463": {"name": "Anaeromusa", "rank": "Genus"}, "81461": {"name": "Thermanaerovibrio", "rank": "Genus"}, "373403": {"name": "Mycobacterium phage 244", "rank": "Species"}, "81468": {"name": "Aminobacterium colombiense", "rank": "Species"}, "1236516": {"name": "Prevotella saccharolytica JCM 17484", "rank": "Strain"}, "1156417": {"name": "Caloranaerobacter azorensis H53214", "rank": "Strain"}, "373405": {"name": "Mycobacterium phage Che12", "rank": "Species"}, "984242": {"name": "Salmonella enterica subsp. enterica serovar Montevideo str. CT_02035320", "rank": "Strain"}, "984241": {"name": "Salmonella enterica subsp. enterica serovar Montevideo str. CT_02035318", "rank": "Strain"}, "984240": {"name": "Salmonella enterica subsp. enterica serovar Montevideo str. CT_02035278", "rank": "Strain"}, "1193047": {"name": "Leptospira kirschneri str. 200802841", "rank": "Strain"}, "1193046": {"name": "Leptospira kirschneri str. 200801925", "rank": "Strain"}, "1193045": {"name": "Leptospira kirschneri str. 200801774", "rank": "Strain"}, "1193044": {"name": "Leptospira interrogans serovar Valbuzzi str. Valbuzzi", "rank": "Strain"}, "1193043": {"name": "Leptospira interrogans serovar Valbuzzi", "rank": "Strain"}, "1193042": {"name": "Leptospira interrogans str. Kito", "rank": "Strain"}, "1193041": {"name": "Leptospira interrogans str. HAI1536", "rank": "Strain"}, "1193040": {"name": "Leptospira interrogans str. FPW1039", "rank": "Strain"}, "1325472": {"name": "Halophilic archaeon J07HX5", "rank": "Species"}, "1325475": {"name": "Yersinia pestis G1670E", "rank": "Strain"}, "577650": {"name": "Desulfobulbus propionicus DSM 2032", "rank": "Strain"}, "1169194": {"name": "Salinispora pacifica CNS863", "rank": "Strain"}, "1169195": {"name": "Salinispora tropica CNS416", "rank": "Strain"}, "1169196": {"name": "Salinispora tropica CNT250", "rank": "Strain"}, "1169197": {"name": "Salinispora tropica CNY012", "rank": "Strain"}, "1169190": {"name": "Salinispora pacifica CNT045", "rank": "Strain"}, "1169191": {"name": "Salinispora pacifica CNT584", "rank": "Strain"}, "1169192": {"name": "Salinispora pacifica CNY330", "rank": "Strain"}, "1169193": {"name": "Salinispora pacifica CNQ768", "rank": "Strain"}, "351016": {"name": "Roseobacter sp. AzwK-3b", "rank": "Species"}, "1215095": {"name": "Pseudomonas chlororaphis subsp. aureofaciens NBRC 3521", "rank": "Strain"}, "1215092": {"name": "Pseudomonas alcaligenes NBRC 14159", "rank": "Strain"}, "1215098": {"name": "Pseudomonas cremoricolorata NBRC 16634", "rank": "Strain"}, "1394578": {"name": "Vibrio parahaemolyticus S031", "rank": "Strain"}, "1394571": {"name": "Vibrio parahaemolyticus S024", "rank": "Strain"}, "1394572": {"name": "Vibrio parahaemolyticus S025", "rank": "Strain"}, "1394573": {"name": "Vibrio parahaemolyticus S026", "rank": "Strain"}, "1394574": {"name": "Vibrio parahaemolyticus S027", "rank": "Strain"}, "1394575": {"name": "Vibrio parahaemolyticus S028", "rank": "Strain"}, "119434": {"name": "Halorubrum tebenquichense", "rank": "Species"}, "1394577": {"name": "Vibrio parahaemolyticus S030", "rank": "Strain"}, "368736": {"name": "Maracuja mosaic virus", "rank": "Species"}, "368735": {"name": "Bell pepper mottle virus", "rank": "Species"}, "59241": {"name": "Streptococcus phage Dp-1", "rank": "Species"}, "340099": {"name": "Thermoanaerobacter pseudethanolicus ATCC 33223", "rank": "Strain"}, "1439940": {"name": "Pseudomonas sp. BAY1663", "rank": "Species"}, "360528": {"name": "Pelagibaca", "rank": "Genus"}, "1169229": {"name": "Brucella melitensis UK31/99", "rank": "Strain"}, "1169222": {"name": "Brucella canis 79/122", "rank": "Strain"}, "1169223": {"name": "Brucella melitensis BG2 (S27)", "rank": "Strain"}, "1169220": {"name": "Brucella abortus F10/06-3", "rank": "Strain"}, "1169221": {"name": "Brucella abortus R42-08", "rank": "Strain"}, "1169226": {"name": "Brucella melitensis F9/05", "rank": "Strain"}, "1169227": {"name": "Brucella melitensis UK29/05", "rank": "Strain"}, "1169224": {"name": "Brucella melitensis F10/06-16", "rank": "Strain"}, "1169225": {"name": "Brucella melitensis F6/05-6", "rank": "Strain"}, "1408875": {"name": "Borrelia burgdorferi IPT87", "rank": "Strain"}, "1408877": {"name": "Borrelia burgdorferi IPT93", "rank": "Strain"}, "1408876": {"name": "Borrelia burgdorferi IPT92", "rank": "Strain"}, "1310619": {"name": "Acinetobacter baumannii 1419130", "rank": "Strain"}, "1408870": {"name": "Borrelia burgdorferi IPT61", "rank": "Strain"}, "1406857": {"name": "Geobacillus thermoleovorans B23", "rank": "Strain"}, "1408872": {"name": "Borrelia burgdorferi IPT70", "rank": "Strain"}, "1406859": {"name": "Nocardia brasiliensis IFM 10847", "rank": "Strain"}, "1406858": {"name": "Nocardia otitidiscaviarum IFM 11049", "rank": "Strain"}, "1310617": {"name": "Acinetobacter baumannii 1406750", "rank": "Strain"}, "1310616": {"name": "Acinetobacter baumannii 400834", "rank": "Strain"}, "1408879": {"name": "Borrelia burgdorferi IPT125", "rank": "Strain"}, "1310610": {"name": "Acinetobacter baumannii 647609", "rank": "Strain"}, "1310613": {"name": "Acinetobacter baumannii 1295743", "rank": "Strain"}, "647227": {"name": "Chlamydia muridarum str. Weiss", "rank": "Strain"}, "691816": {"name": "Bacteroides rodentium", "rank": "Species"}, "509635": {"name": "Pedobacter sp. V48", "rank": "Species"}, "171101": {"name": "Streptococcus pneumoniae R6", "rank": "Strain"}, "330380": {"name": "Unclassified Carmovirus", "rank": "No rank"}, "879628": {"name": "Aeromonas phage phiAS4", "rank": "Species"}, "402399": {"name": "Brugmansia mild mottle virus", "rank": "Species"}, "407148": {"name": "Campylobacter jejuni subsp. jejuni 81116", "rank": "Strain"}, "440512": {"name": "Pseudomonas sp. Chol1", "rank": "Species"}, "340956": {"name": "Desulfovibrio frigidus", "rank": "Species"}, "440518": {"name": "Sphingobium lucknowense", "rank": "Species"}, "683305": {"name": "Frankia sp. BMG5.23", "rank": "Species"}, "1200984": {"name": "Streptomyces lividans 1326", "rank": "Strain"}, "1388261": {"name": "Staphylococcus aureus M0394", "rank": "Strain"}, "1388260": {"name": "Staphylococcus aureus M0390", "rank": "Strain"}, "1388263": {"name": "Staphylococcus aureus M0398", "rank": "Strain"}, "1388262": {"name": "Staphylococcus aureus M0397", "rank": "Strain"}, "314330": {"name": "Enterobacter sp. DC1", "rank": "Species"}, "1388264": {"name": "Staphylococcus aureus M0399", "rank": "Strain"}, "1388267": {"name": "Staphylococcus aureus M0403", "rank": "Strain"}, "1388266": {"name": "Staphylococcus aureus M0402", "rank": "Strain"}, "1388269": {"name": "Staphylococcus aureus M0406", "rank": "Strain"}, "1388268": {"name": "Staphylococcus aureus M0405", "rank": "Strain"}, "981334": {"name": "Acinetobacter radioresistens DSM 6976 = NBRC 102413 = CIP 103788", "rank": "Strain"}, "1388399": {"name": "Staphylococcus aureus M0603", "rank": "Strain"}, "981335": {"name": "Tetrasphaera phage TJE1", "rank": "Species"}, "76802": {"name": "Xanthomonas fuscans subsp. aurantifolii", "rank": "Subspecies"}, "76803": {"name": "Arteriviridae", "rank": "Family"}, "402649": {"name": "Actinomycetospora", "rank": "Genus"}, "981336": {"name": "Acinetobacter ursingii DSM 16037 = CIP 107286", "rank": "Strain"}, "76804": {"name": "Nidovirales", "rank": "Order"}, "939301": {"name": "Alpha proteobacterium SCGC AAA015-O19", "rank": "Species"}, "1570339": {"name": "Peptoniphilaceae", "rank": "Family"}, "1005418": {"name": "Escherichia coli 97.1742", "rank": "Strain"}, "1005415": {"name": "Escherichia coli 96.0107", "rank": "Strain"}, "1005416": {"name": "Escherichia coli 97.0003", "rank": "Strain"}, "1005410": {"name": "Escherichia coli 96.0428", "rank": "Strain"}, "1005411": {"name": "Escherichia coli 96.0427", "rank": "Strain"}, "1005412": {"name": "Escherichia coli 96.0939", "rank": "Strain"}, "1005413": {"name": "Escherichia coli 96.0932", "rank": "Strain"}, "879088": {"name": "Listeria monocytogenes SLCC2378", "rank": "Strain"}, "862962": {"name": "Bacteroides fragilis 638R", "rank": "Strain"}, "862965": {"name": "Haemophilus parainfluenzae T3T1", "rank": "Strain"}, "862964": {"name": "Haemophilus influenzae 10810", "rank": "Strain"}, "862967": {"name": "Streptococcus intermedius B196", "rank": "Strain"}, "862966": {"name": "Streptococcus intermedius C270", "rank": "Strain"}, "862969": {"name": "Streptococcus constellatus subsp. pharyngis C1050", "rank": "Strain"}, "936548": {"name": "Actinomyces sp. ICM47", "rank": "Species"}, "981333": {"name": "Acinetobacter parvus DSM 16617 = CIP 108168", "rank": "Strain"}, "1239881": {"name": "Candidatus Portiera aleyrodidarum BT-QVLC", "rank": "Strain"}, "1176156": {"name": "Tomato leaf curl Yemen betasatellite", "rank": "Species"}, "1176150": {"name": "Upsilonpapillomavirus 1", "rank": "Species"}, "1176153": {"name": "Tomato necrotic stunt virus", "rank": "Species"}, "225453": {"name": "Yaniella halotolerans", "rank": "Species"}, "569881": {"name": "Wolbachia endosymbiont of Culex quinquefasciatus JHB", "rank": "Strain"}, "47246": {"name": "Clostridium viride", "rank": "Species"}, "483045": {"name": "Unclassified Old world arenaviruses", "rank": "No rank"}, "259901": {"name": "Staphylococcus phage 77", "rank": "Species"}, "743965": {"name": "Mycoplasma putrefaciens KS1", "rank": "Strain"}, "743966": {"name": "Mycoplasma bovoculi M165/69", "rank": "Strain"}, "306025": {"name": "Cotton leaf curl Multan betasatellite", "rank": "Species"}, "1234701": {"name": "Pseudomonas phage vB_PaeP_p2-10_Or1", "rank": "Strain"}, "1402752": {"name": "Staphylococcus aureus M1261", "rank": "Strain"}, "1402753": {"name": "Staphylococcus aureus M1262", "rank": "Strain"}, "1402750": {"name": "Staphylococcus aureus M1259", "rank": "Strain"}, "1402751": {"name": "Staphylococcus aureus M1260", "rank": "Strain"}, "1402756": {"name": "Staphylococcus aureus M1265", "rank": "Strain"}, "1402757": {"name": "Staphylococcus aureus M1267", "rank": "Strain"}, "1402754": {"name": "Staphylococcus aureus M1263", "rank": "Strain"}, "1402755": {"name": "Staphylococcus aureus M1264", "rank": "Strain"}, "1158486": {"name": "Staphylococcus aureus M1320", "rank": "Strain"}, "1158487": {"name": "Staphylococcus aureus M1321", "rank": "Strain"}, "1402758": {"name": "Staphylococcus aureus M1268", "rank": "Strain"}, "1402759": {"name": "Staphylococcus aureus M1269", "rank": "Strain"}, "1158482": {"name": "Staphylococcus aureus M1257", "rank": "Strain"}, "1158483": {"name": "Staphylococcus aureus M1277", "rank": "Strain"}, "1158480": {"name": "Staphylococcus aureus M1253", "rank": "Strain"}, "1158481": {"name": "Staphylococcus aureus M1255", "rank": "Strain"}, "1121015": {"name": "Arenimonas oryziterrae DSM 21050 = YC6267", "rank": "Strain"}, "1121014": {"name": "Arenimonas donghaensis DSM 18148 = HO3-R19", "rank": "Strain"}, "1121017": {"name": "Arsenicicoccus bolidensis DSM 15745", "rank": "Strain"}, "1121016": {"name": "Arhodomonas aquaeolei DSM 8974", "rank": "Strain"}, "1121011": {"name": "Arenibacter certesii DSM 19833", "rank": "Strain"}, "1190574": {"name": "Neisseria meningitidis NM151", "rank": "Strain"}, "1121013": {"name": "Arenimonas composti TR7-09 = DSM 18010", "rank": "Strain"}, "1121012": {"name": "Arenibacter latericius DSM 15913", "rank": "Strain"}, "1238427": {"name": "Halonotius sp. J07HN6", "rank": "Species"}, "1238426": {"name": "Haloquadratum sp. J07HQX50", "rank": "Species"}, "1476876": {"name": "Streptomyces sp. NRRL B-24720", "rank": "Species"}, "1476877": {"name": "Streptomyces sp. NRRL B-1347", "rank": "Species"}, "1121019": {"name": "Arthrobacter castelli DSM 16402", "rank": "Strain"}, "1121018": {"name": "Arsenophonus nasoniae DSM 15247", "rank": "Strain"}, "1579379": {"name": "Archaeon GW2011_AR21", "rank": "Species"}, "43356": {"name": "Kutzneria", "rank": "Genus"}, "1579371": {"name": "Archaeon GW2011_AR11", "rank": "Species"}, "1579372": {"name": "Archaeon GW2011_AR13", "rank": "Species"}, "1579375": {"name": "Archaeon GW2011_AR17", "rank": "Species"}, "1579374": {"name": "Archaeon GW2011_AR16", "rank": "Species"}, "1579377": {"name": "Archaeon GW2011_AR19", "rank": "Species"}, "1579376": {"name": "Archaeon GW2011_AR18", "rank": "Species"}, "147537": {"name": "Saccharomycotina", "rank": "Subphylum"}, "133704": {"name": "Porcine circovirus-1", "rank": "Species"}, "687367": {"name": "Torque teno virus 28", "rank": "Species"}, "927701": {"name": "Mycoplasma capricolum subsp. capripneumoniae M1601", "rank": "Strain"}, "1121909": {"name": "Gaetbulibacter saemankumensis DSM 17032", "rank": "Strain"}, "927704": {"name": "Selenomonas ruminantium subsp. lactilytica TAM6421", "rank": "Strain"}, "43674": {"name": "Jonesia denitrificans", "rank": "Species"}, "1121903": {"name": "Flexibacter roseolus DSM 9546", "rank": "Strain"}, "1275977": {"name": "Salmonella enterica subsp. enterica serovar Newport str. Shandong_3", "rank": "Strain"}, "1275974": {"name": "Salmonella enterica subsp. enterica serovar Newport str. SH111077", "rank": "Strain"}, "1275975": {"name": "Salmonella enterica subsp. enterica serovar Newport str. Henan_3", "rank": "Strain"}, "1275972": {"name": "Haemophilus parasuis 174", "rank": "Strain"}, "1275973": {"name": "Haemophilus parasuis SW140", "rank": "Strain"}, "1275970": {"name": "Haemophilus parasuis H465", "rank": "Strain"}, "1121904": {"name": "Flexithrix dorotheae DSM 6795", "rank": "Strain"}, "95661": {"name": "Ureaplasma urealyticum serovar 7", "rank": "Strain"}, "95660": {"name": "Ureaplasma parvum serovar 6", "rank": "Strain"}, "95663": {"name": "Ureaplasma urealyticum serovar 9", "rank": "Strain"}, "95662": {"name": "Ureaplasma urealyticum serovar 8", "rank": "Strain"}, "95665": {"name": "Ureaplasma urealyticum serovar 11", "rank": "Strain"}, "95664": {"name": "Ureaplasma urealyticum serovar 10", "rank": "Strain"}, "95667": {"name": "Ureaplasma urealyticum serovar 13", "rank": "Strain"}, "95666": {"name": "Ureaplasma urealyticum serovar 12", "rank": "Strain"}, "1408466": {"name": "Mycoplasma opalescens ATCC 27921", "rank": "Strain"}, "1408467": {"name": "Mycoplasma pirum ATCC 25960", "rank": "Strain"}, "1408464": {"name": "Mycoplasma iners ATCC 19705", "rank": "Strain"}, "1408465": {"name": "Mycoplasma lipofaciens ATCC 35015", "rank": "Strain"}, "1408462": {"name": "Mycoplasma felis ATCC 23391", "rank": "Strain"}, "1408463": {"name": "Mycoplasma glycophilum ATCC 35277", "rank": "Strain"}, "1408461": {"name": "Mycoplasma felifaucium ATCC 43428", "rank": "Strain"}, "934027": {"name": "Campylobacter phage NCTC12673", "rank": "Species"}, "12475": {"name": "Hepatitis delta virus", "rank": "Species"}, "12474": {"name": "Coconut foliar decay virus", "rank": "Species"}, "28095": {"name": "Burkholderia gladioli", "rank": "Species"}, "28092": {"name": "Burkholderia andropogonis", "rank": "Species"}, "12470": {"name": "Lucerne transient streak virus", "rank": "Species"}, "12473": {"name": "Velvet tobacco mottle virus", "rank": "Species"}, "12472": {"name": "Subterranean clover mottle virus", "rank": "Species"}, "1328436": {"name": "Escherichia coli BIDMC 2B", "rank": "Strain"}, "1328437": {"name": "Escherichia coli BIDMC 3", "rank": "Strain"}, "1328434": {"name": "Escherichia coli BWH 40", "rank": "Strain"}, "1328435": {"name": "Escherichia coli BWH 24", "rank": "Strain"}, "1328432": {"name": "Escherichia coli BWH 32", "rank": "Strain"}, "1328433": {"name": "Escherichia coli BWH 34", "rank": "Strain"}, "1328430": {"name": "Klebsiella oxytoca MGH 41", "rank": "Strain"}, "1328431": {"name": "Klebsiella oxytoca MGH 42", "rank": "Strain"}, "1328438": {"name": "Escherichia coli BIDMC 6", "rank": "Strain"}, "1328439": {"name": "Escherichia coli BIDMC 9", "rank": "Strain"}, "226900": {"name": "Bacillus cereus ATCC 14579", "rank": "Strain"}, "1195465": {"name": "Mycobacterium bovis BCG str. Glaxo", "rank": "Strain"}, "1195464": {"name": "Bacillus thuringiensis MC28", "rank": "Strain"}, "1472719": {"name": "Paenibacillus sp. P1XP2", "rank": "Species"}, "28321": {"name": "Amsacta moorei entomopoxvirus 'L'", "rank": "Species"}, "1472717": {"name": "Enhydra lutris papillomavirus 1", "rank": "Species"}, "1472716": {"name": "Burkholderia sp. K24", "rank": "Species"}, "176090": {"name": "Streptococcus sinensis", "rank": "Species"}, "638849": {"name": "Pyramidobacter piscolens", "rank": "Species"}, "1002804": {"name": "Helicobacter bizzozeronii CIII-1", "rank": "Strain"}, "1002805": {"name": "Helicobacter bizzozeronii CCUG 35545", "rank": "Strain"}, "1002809": {"name": "Solibacillus silvestris StLB046", "rank": "Strain"}, "1121087": {"name": "Bacillus chagannorensis DSM 18086", "rank": "Strain"}, "777": {"name": "Coxiella burnetii", "rank": "Species"}, "776": {"name": "Coxiella", "rank": "Genus"}, "775": {"name": "Rickettsiaceae", "rank": "Family"}, "774": {"name": "Bartonella bacilliformis", "rank": "Species"}, "773": {"name": "Bartonella", "rank": "Genus"}, "772": {"name": "Bartonellaceae", "rank": "Family"}, "1281191": {"name": "Escherichia coli UMEA 3144-1", "rank": "Strain"}, "770": {"name": "Anaplasma marginale", "rank": "Species"}, "1154833": {"name": "Streptococcus agalactiae BSU108", "rank": "Strain"}, "1154832": {"name": "Streptococcus agalactiae BSU92", "rank": "Strain"}, "1154831": {"name": "Streptococcus agalactiae BSU165", "rank": "Strain"}, "1154830": {"name": "Streptococcus agalactiae BSU96", "rank": "Strain"}, "1154837": {"name": "Streptococcus agalactiae MRI Z1-200", "rank": "Strain"}, "1154836": {"name": "Streptococcus agalactiae MRI Z1-199", "rank": "Strain"}, "1154835": {"name": "Streptococcus agalactiae MRI Z1-198", "rank": "Strain"}, "1246458": {"name": "Nocardiopsis potens", "rank": "Species"}, "381046": {"name": "Lachancea thermotolerans", "rank": "Species"}, "198541": {"name": "Streptococcus pyogenes phage 315.4", "rank": "Species"}, "198540": {"name": "Streptococcus pyogenes phage 315.3", "rank": "Species"}, "198543": {"name": "Streptococcus pyogenes phage 315.6", "rank": "Species"}, "35756": {"name": "Corynebacterium pilosum", "rank": "Species"}, "1422488": {"name": "Staphylococcus aureus VET0188R", "rank": "Strain"}, "90142": {"name": "Ferroplasmaceae", "rank": "Family"}, "106588": {"name": "Pseudoflavonifractor capillosus", "rank": "Species"}, "106589": {"name": "Cupriavidus", "rank": "Genus"}, "1338011": {"name": "Elizabethkingia anophelis NUHP1", "rank": "Strain"}, "1422481": {"name": "Staphylococcus aureus VET0178R", "rank": "Strain"}, "1338013": {"name": "Elizabethkingia anophelis NUHP3", "rank": "Strain"}, "1338012": {"name": "Elizabethkingia anophelis NUHP2", "rank": "Strain"}, "1422484": {"name": "Staphylococcus aureus VET0183R", "rank": "Strain"}, "1338014": {"name": "Elizabethkingia anophelis NUH1", "rank": "Strain"}, "1338017": {"name": "Elizabethkingia anophelis NUH11", "rank": "Strain"}, "1338016": {"name": "Elizabethkingia anophelis NUH6", "rank": "Strain"}, "1051059": {"name": "Brucella abortus bv. 1 str. NI010", "rank": "Strain"}, "190977": {"name": "Methanobrevibacter wolinii", "rank": "Species"}, "1051058": {"name": "Brucella abortus bv. 1 str. NI488", "rank": "Strain"}, "1095658": {"name": "Vibrio cholerae O1 str. NHCC-010F", "rank": "Strain"}, "1095657": {"name": "Vibrio cholerae O1 str. NHCC-008D", "rank": "Strain"}, "1051057": {"name": "Brucella abortus bv. 1 str. NI486", "rank": "Strain"}, "1332080": {"name": "Sphingobium baderi", "rank": "Species"}, "1095654": {"name": "Vibrio cholerae O1 str. EC-0051", "rank": "Strain"}, "1182188": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN000958", "rank": "Strain"}, "1182189": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN000959", "rank": "Strain"}, "1423427": {"name": "Mycobacterium tuberculosis BTB04-120", "rank": "Strain"}, "1423426": {"name": "Mycobacterium tuberculosis BTB03-108", "rank": "Strain"}, "1182184": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN000955", "rank": "Strain"}, "1182185": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN000956", "rank": "Strain"}, "1182186": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN000755", "rank": "Strain"}, "1182187": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN000957", "rank": "Strain"}, "1182180": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN000951", "rank": "Strain"}, "1182181": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN000952", "rank": "Strain"}, "1182182": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN000953", "rank": "Strain"}, "1331262": {"name": "Bordetella hinzii OH87 BAL007II", "rank": "Strain"}, "639313": {"name": "Amycolicicoccus subflavus", "rank": "Species"}, "1247726": {"name": "Advenella mimigardefordensis DPN7", "rank": "Strain"}, "1247727": {"name": "Campylobacter coli BIGS0001", "rank": "Strain"}, "1247725": {"name": "Rhodobacter sp. AKP1", "rank": "Species"}, "228410": {"name": "Nitrosomonas europaea ATCC 19718", "rank": "Strain"}, "1247728": {"name": "Campylobacter coli BIGS0002", "rank": "Strain"}, "1247729": {"name": "Campylobacter coli BIGS0003", "rank": "Strain"}, "2420": {"name": "Thermosipho", "rank": "Genus"}, "2421": {"name": "Thermosipho africanus", "rank": "Species"}, "1331199": {"name": "Bordetella bronchiseptica 00-P-2796", "rank": "Strain"}, "1331198": {"name": "Bordetella bronchiseptica 00-P-2730", "rank": "Strain"}, "2424": {"name": "Fervidobacterium nodosum", "rank": "Species"}, "2425": {"name": "Teredinibacter", "rank": "Genus"}, "2426": {"name": "Teredinibacter turnerae", "rank": "Species"}, "1331196": {"name": "Kwoniella mangroviensis CBS 10435", "rank": "Strain"}, "760787": {"name": "Streptococcus pneumoniae GA17457", "rank": "Strain"}, "626930": {"name": "Bacteroides fluxus", "rank": "Species"}, "760784": {"name": "Streptococcus pneumoniae GA17227", "rank": "Strain"}, "1409407": {"name": "Staphylococcus aureus UCIM6015", "rank": "Strain"}, "1409406": {"name": "Staphylococcus aureus UCIM6014", "rank": "Strain"}, "1409405": {"name": "Staphylococcus aureus MISS6007", "rank": "Strain"}, "1409404": {"name": "Staphylococcus aureus HOAG6059", "rank": "Strain"}, "1409403": {"name": "Staphylococcus aureus AMMC6068", "rank": "Strain"}, "1409402": {"name": "Staphylococcus aureus WMCA6040", "rank": "Strain"}, "1409401": {"name": "Staphylococcus aureus WAMC6013", "rank": "Strain"}, "1420885": {"name": "Vibrio cholerae MS6", "rank": "Strain"}, "626933": {"name": "Odoribacter laneus", "rank": "Species"}, "1409409": {"name": "Staphylococcus aureus UCIM6019", "rank": "Strain"}, "1409408": {"name": "Staphylococcus aureus UCIM6018", "rank": "Strain"}, "1422772": {"name": "Staphylococcus aureus VET1035S", "rank": "Strain"}, "1422773": {"name": "Staphylococcus aureus VET1048S", "rank": "Strain"}, "1422770": {"name": "Staphylococcus aureus VET1025S", "rank": "Strain"}, "1422771": {"name": "Staphylococcus aureus VET1026S", "rank": "Strain"}, "1422777": {"name": "Staphylococcus aureus VET1068S", "rank": "Strain"}, "1422774": {"name": "Staphylococcus aureus VET1052S", "rank": "Strain"}, "1422775": {"name": "Staphylococcus aureus VET1054S", "rank": "Strain"}, "1422778": {"name": "Staphylococcus aureus VET1088S", "rank": "Strain"}, "760781": {"name": "Streptococcus pneumoniae GA16531", "rank": "Strain"}, "108980": {"name": "Acinetobacter ursingii", "rank": "Species"}, "108981": {"name": "Acinetobacter schindleri", "rank": "Species"}, "1128179": {"name": "Bradyrhizobium sp. CCBAU 15615", "rank": "Species"}, "1034015": {"name": "Nitrososphaera viennensis", "rank": "Species"}, "513550": {"name": "Bacillus phage AP50", "rank": "Species"}, "626939": {"name": "Phascolarctobacterium succinatutens YIT 12067", "rank": "Strain"}, "1302623": {"name": "Listeria monocytogenes SHL002", "rank": "Strain"}, "1302622": {"name": "Listeria monocytogenes SHL001", "rank": "Strain"}, "1302620": {"name": "Cellulomonas sp. URHD0024", "rank": "Species"}, "1346779": {"name": "Mycobacterium tuberculosis PanR0314", "rank": "Strain"}, "157619": {"name": "Avian paramyxovirus 6", "rank": "Species"}, "1425340": {"name": "Listeria monocytogenes Lm_1889", "rank": "Strain"}, "1302624": {"name": "Listeria monocytogenes SHL004", "rank": "Strain"}, "1346775": {"name": "Mycobacterium tuberculosis PanR0401", "rank": "Strain"}, "1346774": {"name": "Mycobacterium tuberculosis PanR0402", "rank": "Strain"}, "1346777": {"name": "Mycobacterium tuberculosis PanR0316", "rank": "Strain"}, "1346776": {"name": "Mycobacterium tuberculosis PanR0317", "rank": "Strain"}, "1346771": {"name": "Mycobacterium tuberculosis PanR0405", "rank": "Strain"}, "911240": {"name": "Pseudomonas sp. CF150", "rank": "Species"}, "1346773": {"name": "Mycobacterium tuberculosis PanR0403", "rank": "Strain"}, "1346772": {"name": "Mycobacterium tuberculosis PanR0404", "rank": "Strain"}, "43776": {"name": "Haloarcula argentinensis", "rank": "Species"}, "1464078": {"name": "Microbispora rosea subsp. nonnitritogenes", "rank": "Subspecies"}, "43770": {"name": "Corynebacterium striatum", "rank": "Species"}, "43771": {"name": "Corynebacterium urealyticum", "rank": "Species"}, "767029": {"name": "Propionibacterium propionicum F0230a", "rank": "Strain"}, "656437": {"name": "Escherichia coli TA143", "rank": "Strain"}, "656435": {"name": "Escherichia coli TA124", "rank": "Strain"}, "1464077": {"name": "Streptomyces purpeochromogenes", "rank": "Species"}, "1412748": {"name": "Staphylococcus aureus H81885", "rank": "Strain"}, "1412749": {"name": "Staphylococcus aureus H84973", "rank": "Strain"}, "578361": {"name": "Soybean yellow mottle mosaic virus", "rank": "Species"}, "1412740": {"name": "Staphylococcus aureus H12893", "rank": "Strain"}, "1412741": {"name": "Staphylococcus aureus H12930", "rank": "Strain"}, "1412742": {"name": "Staphylococcus aureus H16097", "rank": "Strain"}, "1412743": {"name": "Staphylococcus aureus H19476", "rank": "Strain"}, "1412744": {"name": "Staphylococcus aureus H25869", "rank": "Strain"}, "1412745": {"name": "Staphylococcus aureus H25872", "rank": "Strain"}, "1412746": {"name": "Staphylococcus aureus H81800", "rank": "Strain"}, "1412747": {"name": "Staphylococcus aureus H81809", "rank": "Strain"}, "1134579": {"name": "Lunk virus NKS-1", "rank": "Species"}, "242507": {"name": "Magnaporthe oryzae 70-15", "rank": "Strain"}, "1481451": {"name": "Mosavirus", "rank": "Genus"}, "379072": {"name": "Sediminibacter", "rank": "Genus"}, "363569": {"name": "Salmonella enterica subsp. enterica serovar Javiana", "rank": "Strain"}, "1417865": {"name": "Unclassified Luz24likevirus", "rank": "No rank"}, "155616": {"name": "Tremellomycetes", "rank": "Class"}, "155617": {"name": "Enterococcus moraviensis", "rank": "Species"}, "155615": {"name": "Fusobacterium nucleatum subsp. vincentii", "rank": "Subspecies"}, "247156": {"name": "Nocardia farcinica IFM 10152", "rank": "Strain"}, "155618": {"name": "Enterococcus haemoperoxidus", "rank": "Species"}, "155619": {"name": "Agaricomycetes", "rank": "Class"}, "1227076": {"name": "Paenibacillus sp. FSL R5-808", "rank": "Species"}, "89471": {"name": "Melon yellow spot virus", "rank": "Species"}, "1400930": {"name": "Mycobacterium tuberculosis KT-0094", "rank": "Strain"}, "1936": {"name": "Streptomyces violaceus", "rank": "Species"}, "1935": {"name": "Streptomyces violaceoruber", "rank": "Species"}, "420915": {"name": "Pseudoalteromonas sp. BSi20439", "rank": "Species"}, "945543": {"name": "Vibrio brasiliensis LMG 20546", "rank": "Strain"}, "945541": {"name": "Salmonella enterica subsp. enterica serovar Javiana str. PRS_2010_0720", "rank": "Strain"}, "1427518": {"name": "Xenorhabdus szentirmaii DSM 16338", "rank": "Strain"}, "1511776": {"name": "Gallivirus A", "rank": "Species"}, "1511775": {"name": "Gallivirus", "rank": "Genus"}, "706526": {"name": "Phocoena phocoena papillomavirus 2", "rank": "Species"}, "83558": {"name": "Chlamydia pneumoniae", "rank": "Species"}, "1427517": {"name": "Xenorhabdus cabanillasii JM26", "rank": "Strain"}, "1427516": {"name": "Mycobacterium tuberculosis 49-02", "rank": "Strain"}, "364039": {"name": "Azohydromonas australica", "rank": "Species"}, "557436": {"name": "Lactobacillus reuteri DSM 20016", "rank": "Strain"}, "1052808": {"name": "Fervidibacteria bacterium SCGC AAA471-D06", "rank": "Species"}, "542959": {"name": "Bppunalikevirus", "rank": "Genus"}, "326489": {"name": "Sida yellow vein virus satellite DNA beta", "rank": "Species"}, "557433": {"name": "Lactobacillus reuteri JCM 1112", "rank": "Strain"}, "706527": {"name": "Phocoena phocoena papillomavirus 4", "rank": "Strain"}, "246280": {"name": "Liao ning virus", "rank": "Species"}, "1052803": {"name": "Crenarchaeota archaeon SCGC AAA471-C03", "rank": "Species"}, "644337": {"name": "Brucella melitensis bv. 1", "rank": "Strain"}, "1211776": {"name": "Campylobacter jejuni subsp. jejuni NCTC 11168-BN148", "rank": "Strain"}, "1211777": {"name": "Rhizobium mesoamericanum STM3625", "rank": "Strain"}, "666147": {"name": "Euphorbia mosaic virus associated DNA 1", "rank": "Species"}, "666146": {"name": "Cleome leaf crumple virus associated DNA 1", "rank": "Species"}, "42004": {"name": "Leek yellow stripe virus", "rank": "Species"}, "1265861": {"name": "Brochothrix campestris FSL F6-1037", "rank": "Strain"}, "644332": {"name": "Brucella abortus bv. 2", "rank": "Strain"}, "1265868": {"name": "Streptomyces rimosus subsp. rimosus ATCC 10970", "rank": "Strain"}, "1421917": {"name": "Mycobacterium tuberculosis TB_RSA01", "rank": "Strain"}, "1421916": {"name": "Staphylococcus aureus W85810", "rank": "Strain"}, "1421915": {"name": "Staphylococcus aureus W85807", "rank": "Strain"}, "904730": {"name": "Staphylococcus aureus subsp. aureus 21200", "rank": "Strain"}, "1421913": {"name": "Staphylococcus aureus W82238", "rank": "Strain"}, "1421912": {"name": "Staphylococcus aureus W45758", "rank": "Strain"}, "1421911": {"name": "Staphylococcus aureus W45757", "rank": "Strain"}, "1421910": {"name": "Staphylococcus aureus W42304", "rank": "Strain"}, "1121451": {"name": "Desulfovibrio hydrothermalis AM13 = DSM 14728", "rank": "Strain"}, "1421919": {"name": "Mycobacterium tuberculosis TB_RSA03", "rank": "Strain"}, "1421918": {"name": "Mycobacterium tuberculosis TB_RSA02", "rank": "Strain"}, "1121453": {"name": "Desulfovibrio inopinatus DSM 10711", "rank": "Strain"}, "378833": {"name": "Sowbane mosaic virus", "rank": "Species"}, "148303": {"name": "Magnaporthe", "rank": "Genus"}, "211882": {"name": "Leptospira interrogans serovar Australis", "rank": "Strain"}, "211880": {"name": "Leptospira interrogans serovar Canicola", "rank": "Strain"}, "211881": {"name": "Leptospira interrogans serovar Hebdomadis", "rank": "Strain"}, "1522179": {"name": "Asterionellopsis glacialis RNA virus", "rank": "Species"}, "1522178": {"name": "Unclassified Bacillarnavirus", "rank": "No rank"}, "1114880": {"name": "Aeromonas australiensis", "rank": "Species"}, "1353537": {"name": "Thioclava pacifica DSM 10166", "rank": "Strain"}, "1353531": {"name": "Ensifer sp. TW10", "rank": "Species"}, "1353533": {"name": "Pseudoalteromonas luteoviolacea 2ta16", "rank": "Strain"}, "1353532": {"name": "Thalassospira permensis NBRC 106175", "rank": "Strain"}, "359391": {"name": "Brucella abortus 2308", "rank": "Strain"}, "67962": {"name": "Carrot red leaf luteovirus associated RNA", "rank": "Species"}, "298333": {"name": "Turkey siadenovirus A", "rank": "Species"}, "298331": {"name": "Frog siadenovirus A", "rank": "Species"}, "51288": {"name": "Kluyvera ascorbata", "rank": "Species"}, "1511889": {"name": "Ungulate copiparvovirus 1", "rank": "Species"}, "1511888": {"name": "Copiparvovirus", "rank": "Genus"}, "1295747": {"name": "Mycobacterium tuberculosis TKK_02_0031", "rank": "Strain"}, "27337": {"name": "Verticillium dahliae", "rank": "Species"}, "27334": {"name": "Penicillium expansum", "rank": "Species"}, "1290996": {"name": "Klebsiella pneumoniae KP3-S", "rank": "Strain"}, "1295742": {"name": "Mycobacterium tuberculosis TKK_02_0026", "rank": "Strain"}, "1295740": {"name": "Mycobacterium tuberculosis TKK_02_0024", "rank": "Strain"}, "298334": {"name": "Simian mastadenovirus A", "rank": "Species"}, "1002340": {"name": "Leisingera sp. ANG1", "rank": "Species"}, "593117": {"name": "Thermococcus gammatolerans EJ3", "rank": "Strain"}, "76113": {"name": "Thauera terpenica", "rank": "Species"}, "1074059": {"name": "Streptococcus sobrinus TCI-56", "rank": "Strain"}, "267970": {"name": "Bean yellow disorder virus", "rank": "Species"}, "991937": {"name": "Vibrio cholerae HC-1A2", "rank": "Strain"}, "991936": {"name": "Vibrio cholerae HC-81A1", "rank": "Strain"}, "991935": {"name": "Vibrio cholerae HC-49A2", "rank": "Strain"}, "991934": {"name": "Vibrio cholerae HC-36A1", "rank": "Strain"}, "991933": {"name": "Vibrio cholerae HC-23A1", "rank": "Strain"}, "991932": {"name": "Vibrio cholerae HC-20A2", "rank": "Strain"}, "991931": {"name": "Vibrio cholerae HC-7A1", "rank": "Strain"}, "991930": {"name": "Vibrio cholerae HCUF01", "rank": "Strain"}, "991939": {"name": "Vibrio cholerae HC-43B1", "rank": "Strain"}, "991938": {"name": "Vibrio cholerae HC-43A1", "rank": "Strain"}, "756759": {"name": "Okra leaf curl betasatellite", "rank": "Species"}, "99807": {"name": "Corynebacterium auriscanis", "rank": "Species"}, "1157368": {"name": "Enterococcus faecalis EnGen0086", "rank": "Strain"}, "1157369": {"name": "Enterococcus faecalis EnGen0115", "rank": "Strain"}, "193122": {"name": "Peanut stunt virus satellite RNA", "rank": "Species"}, "193120": {"name": "Pea enation mosaic virus-2", "rank": "Species"}, "193121": {"name": "Pea enation mosaic virus-1", "rank": "Species"}, "1157362": {"name": "Enterococcus faecalis EnGen0113", "rank": "Strain"}, "1157363": {"name": "Enterococcus faecalis EnGen0114", "rank": "Strain"}, "1157360": {"name": "Enterococcus faecalis EnGen0098", "rank": "Strain"}, "1157361": {"name": "Enterococcus faecalis EnGen0099", "rank": "Strain"}, "1157366": {"name": "Enterococcus faecalis EnGen0087", "rank": "Strain"}, "1157367": {"name": "Enterococcus faecalis EnGen0108", "rank": "Strain"}, "1157364": {"name": "Enterococcus faecalis EnGen0100", "rank": "Strain"}, "1157365": {"name": "Enterococcus faecalis EnGen0107", "rank": "Strain"}, "2055": {"name": "Gordonia terrae", "rank": "Species"}, "2054": {"name": "Gordonia bronchialis", "rank": "Species"}, "2057": {"name": "Sphaerobacter thermophilus", "rank": "Species"}, "2056": {"name": "Sphaerobacter", "rank": "Genus"}, "2051": {"name": "Mobiluncus curtisii", "rank": "Species"}, "2050": {"name": "Mobiluncus", "rank": "Genus"}, "2053": {"name": "Gordonia", "rank": "Genus"}, "2052": {"name": "Mobiluncus mulieris", "rank": "Species"}, "1147094": {"name": "Enterobacteria phage vB_KleM-RaK2", "rank": "Species"}, "1155716": {"name": "Streptomyces sp. LaPpAH-202", "rank": "Species"}, "1401328": {"name": "Candidatus Endolissoclinum faulkneri L5", "rank": "Strain"}, "1401326": {"name": "Ornithobacterium rhinotracheale H06-030791", "rank": "Strain"}, "1037409": {"name": "Bradyrhizobium japonicum USDA 6", "rank": "Strain"}, "1261545": {"name": "Halarchaeum acidiphilum MH1-52-1", "rank": "Strain"}, "1221252": {"name": "Acinetobacter baumannii AB_2007-09-110-01-7", "rank": "Strain"}, "1306950": {"name": "Klebsiella pneumoniae subsp. pneumoniae 12-3578", "rank": "Strain"}, "1221250": {"name": "Acinetobacter baumannii AB_1650-8", "rank": "Strain"}, "1221251": {"name": "Acinetobacter baumannii AB_1766_8", "rank": "Strain"}, "1221256": {"name": "Acinetobacter baumannii AB_2008-15-45", "rank": "Strain"}, "151895": {"name": "Pedobacter saltans", "rank": "Species"}, "1221254": {"name": "Acinetobacter baumannii AB_2007-16-27-01", "rank": "Strain"}, "674952": {"name": "Trichomonasvirus", "rank": "Genus"}, "516700": {"name": "Jeotgalicoccus marinus", "rank": "Species"}, "516703": {"name": "Pontibacillus litoralis", "rank": "Species"}, "404386": {"name": "Nonomuraea coxensis", "rank": "Species"}, "404380": {"name": "Geobacter bemidjiensis Bem", "rank": "Strain"}, "31631": {"name": "Human coronavirus OC43", "rank": "Strain"}, "31632": {"name": "Rat coronavirus", "rank": "Strain"}, "645": {"name": "Aeromonas salmonicida", "rank": "Species"}, "1188812": {"name": "Peristrophe mosaic virus", "rank": "Species"}, "77856": {"name": "Beak and feather disease virus", "rank": "Species"}, "644": {"name": "Aeromonas hydrophila", "rank": "Species"}, "1188819": {"name": "Cuban alphasatellite 1", "rank": "Species"}, "83677": {"name": "Thermobifida", "rank": "Genus"}, "83676": {"name": "Nocardiopsaceae", "rank": "Family"}, "1310564": {"name": "Acinetobacter baumannii 1043794", "rank": "Strain"}, "1268975": {"name": "Escherichia coli 110957", "rank": "Strain"}, "1268976": {"name": "Escherichia coli 113290", "rank": "Strain"}, "1268977": {"name": "Escherichia coli 113302", "rank": "Strain"}, "1268978": {"name": "Escherichia coli 113303", "rank": "Strain"}, "1268979": {"name": "Escherichia coli 907357", "rank": "Strain"}, "1455264": {"name": "Mycobacterium tuberculosis NRITLD45", "rank": "Strain"}, "477689": {"name": "Aliiglaciecola lipolytica", "rank": "Species"}, "1398991": {"name": "Acinetobacter baumannii UH9907", "rank": "Strain"}, "1217107": {"name": "Anaplasma phagocytophilum str. HGE1", "rank": "Strain"}, "1310561": {"name": "Acinetobacter baumannii 942133", "rank": "Strain"}, "169133": {"name": "Citricoccus", "rank": "Genus"}, "1310560": {"name": "Acinetobacter baumannii 564012", "rank": "Strain"}, "255587": {"name": "Pelargonium necrotic spot virus", "rank": "Species"}, "225058": {"name": "Acidithiobacillaceae", "rank": "Family"}, "225059": {"name": "Thermithiobacillaceae", "rank": "Family"}, "225057": {"name": "Acidithiobacillales", "rank": "Order"}, "212667": {"name": "Vibrio fortis", "rank": "Species"}, "1297662": {"name": "Thrush coronavirus HKU12", "rank": "Species"}, "212663": {"name": "Vibrio tasmaniensis", "rank": "Species"}, "1032845": {"name": "Rickettsia heilongjiangensis 054", "rank": "Strain"}, "269258": {"name": "Nitratiruptor", "rank": "Genus"}, "71451": {"name": "Enterococcus malodoratus", "rank": "Species"}, "71452": {"name": "Enterococcus raffinosus", "rank": "Species"}, "1455269": {"name": "Mycobacterium tuberculosis NRITLD50", "rank": "Strain"}, "1216362": {"name": "Fusobacterium hwasookii ChDC F128", "rank": "Strain"}, "136609": {"name": "Leuconostoc kimchii", "rank": "Species"}, "1311142": {"name": "Acinetobacter baumannii 45052_2", "rank": "Strain"}, "1311143": {"name": "Acinetobacter baumannii 45052_3", "rank": "Strain"}, "1311141": {"name": "Acinetobacter baumannii 45052_1", "rank": "Strain"}, "1311144": {"name": "Acinetobacter baumannii 45052_4", "rank": "Strain"}, "1311145": {"name": "Acinetobacter baumannii 45052_5", "rank": "Strain"}, "1124959": {"name": "Salmonella enterica subsp. enterica serovar Muenster str. 420", "rank": "Strain"}, "1304892": {"name": "Xanthomonas axonopodis Xac29-1", "rank": "Strain"}, "1288293": {"name": "Listeria monocytogenes QOC1", "rank": "Strain"}, "1288291": {"name": "Anncaliia algerae PRA339", "rank": "Strain"}, "1288296": {"name": "Listeria monocytogenes 4423", "rank": "Strain"}, "1288295": {"name": "Listeria monocytogenes 6179", "rank": "Strain"}, "1288294": {"name": "Listeria monocytogenes QOC2", "rank": "Strain"}, "1288298": {"name": "Roseovarius mucosus DSM 17069", "rank": "Strain"}, "1402967": {"name": "Mycobacterium avium subsp. hominissuis 101", "rank": "Strain"}, "1402966": {"name": "Mycobacterium avium subsp. hominissuis 100", "rank": "Strain"}, "1071061": {"name": "Bacillus sp. MSP13", "rank": "Species"}, "1055770": {"name": "Arthrobacter sp. CAL618", "rank": "Species"}, "224326": {"name": "Borrelia burgdorferi B31", "rank": "Strain"}, "398743": {"name": "Zunongwangia profunda", "rank": "Species"}, "224324": {"name": "Aquifex aeolicus VF5", "rank": "Strain"}, "391589": {"name": "Roseobacter sp. GAI101", "rank": "Species"}, "257985": {"name": "Bacillus thuringiensis serovar andalousiensis", "rank": "Strain"}, "65842": {"name": "Fibrobacteres", "rank": "Phylum"}, "391586": {"name": "Vibrio sp. 16", "rank": "Species"}, "265948": {"name": "Anoxybacillus tepidamans", "rank": "Species"}, "1398023": {"name": "Staphylococcus aureus M1403", "rank": "Strain"}, "1398020": {"name": "Staphylococcus aureus M1400", "rank": "Strain"}, "1398021": {"name": "Staphylococcus aureus M1401", "rank": "Strain"}, "1339328": {"name": "Bacteroides fragilis str. S36L12", "rank": "Strain"}, "1339329": {"name": "Bacteroides fragilis str. S23L17", "rank": "Strain"}, "1398024": {"name": "Staphylococcus aureus M1404", "rank": "Strain"}, "1398025": {"name": "Staphylococcus aureus M1406", "rank": "Strain"}, "1339324": {"name": "Bacteroides fragilis str. S24L26", "rank": "Strain"}, "1339325": {"name": "Bacteroides fragilis str. S24L34", "rank": "Strain"}, "1048208": {"name": "Geobacillus sp. FW23", "rank": "Species"}, "1339327": {"name": "Bacteroides fragilis str. S36L11", "rank": "Strain"}, "1339320": {"name": "Bacteroides fragilis str. S6R5", "rank": "Strain"}, "1339321": {"name": "Bacteroides fragilis str. S6R6", "rank": "Strain"}, "1339322": {"name": "Bacteroides fragilis str. S6R8", "rank": "Strain"}, "1339323": {"name": "Bacteroides fragilis str. S24L15", "rank": "Strain"}, "92945": {"name": "Ketogulonicigenium vulgare", "rank": "Species"}, "92944": {"name": "Ketogulonicigenium", "rank": "Genus"}, "393131": {"name": "Listeria monocytogenes J2818", "rank": "Strain"}, "393130": {"name": "Listeria monocytogenes J0161", "rank": "Strain"}, "1196237": {"name": "Digitaria ciliaris striate mosaic virus", "rank": "Species"}, "222891": {"name": "Neorickettsia sennetsu str. Miyayama", "rank": "Strain"}, "992059": {"name": "Helicobacter pylori Hp H-3", "rank": "Strain"}, "992058": {"name": "Helicobacter pylori Hp H-1", "rank": "Strain"}, "992050": {"name": "Helicobacter pylori Hp H-45", "rank": "Strain"}, "992053": {"name": "Helicobacter pylori Hp A-8", "rank": "Strain"}, "992052": {"name": "Helicobacter pylori Hp A-6", "rank": "Strain"}, "992055": {"name": "Helicobacter pylori Hp A-16", "rank": "Strain"}, "992054": {"name": "Helicobacter pylori Hp A-14", "rank": "Strain"}, "992057": {"name": "Helicobacter pylori Hp A-27", "rank": "Strain"}, "992056": {"name": "Helicobacter pylori Hp A-26", "rank": "Strain"}, "47886": {"name": "Pseudomonas luteola", "rank": "Species"}, "435488": {"name": "Honeysuckle yellow vein Japan betasatellite", "rank": "Species"}, "405558": {"name": "Arracacha mottle virus", "rank": "Species"}, "47883": {"name": "Pseudomonas synxantha", "rank": "Species"}, "676032": {"name": "Francisella cf. tularensis subsp. novicida 3523", "rank": "Strain"}, "84406": {"name": "Virgibacillus", "rank": "Genus"}, "84405": {"name": "Hippea maritima", "rank": "Species"}, "84404": {"name": "Hippea", "rank": "Genus"}, "435486": {"name": "Honeysuckle yellow vein beta-Japan:Fukui:2001", "rank": "Strain"}, "405554": {"name": "White bream virus", "rank": "Species"}, "169865": {"name": "Macroptilium yellow mosaic virus", "rank": "Species"}, "40059": {"name": "Palyam virus", "rank": "Species"}, "40050": {"name": "African horse sickness virus", "rank": "Species"}, "40051": {"name": "Bluetongue virus", "rank": "Species"}, "40052": {"name": "Changuinola virus", "rank": "Species"}, "40054": {"name": "Epizootic hemorrhagic disease virus", "rank": "Species"}, "138948": {"name": "Enterovirus A", "rank": "Species"}, "1316414": {"name": "Enterococcus sp. HSIEG1", "rank": "Species"}, "904316": {"name": "Staphylococcus epidermidis VCU014", "rank": "Strain"}, "1316411": {"name": "Streptococcus sp. HSISS2", "rank": "Species"}, "1316410": {"name": "Streptococcus sp. HSISS1", "rank": "Species"}, "1316413": {"name": "Streptococcus sp. HSISS4", "rank": "Species"}, "1316412": {"name": "Streptococcus sp. HSISS3", "rank": "Species"}, "354090": {"name": "UR2 sarcoma virus", "rank": "Species"}, "1054959": {"name": "Salmonella enterica subsp. enterica serovar Heidelberg str. N1536", "rank": "Strain"}, "1054958": {"name": "Salmonella enterica subsp. enterica serovar Heidelberg str. N1514", "rank": "Strain"}, "1286354": {"name": "Escherichia coli TOP2662-4", "rank": "Strain"}, "1054952": {"name": "Salmonella enterica subsp. enterica serovar Heidelberg str. RI-11-013988", "rank": "Strain"}, "1054950": {"name": "Salmonella enterica subsp. enterica serovar Heidelberg str. SARA 39", "rank": "Strain"}, "1286350": {"name": "Escherichia coli TOP2652", "rank": "Strain"}, "1286351": {"name": "Escherichia coli TOP2662-1", "rank": "Strain"}, "1286352": {"name": "Escherichia coli TOP2662-2", "rank": "Strain"}, "1286353": {"name": "Escherichia coli TOP2662-3", "rank": "Strain"}, "335543": {"name": "Syntrophobacter fumaroxidans MPOB", "rank": "Strain"}, "335541": {"name": "Syntrophomonas wolfei subsp. wolfei str. Goettingen G311", "rank": "Strain"}, "397290": {"name": "Lachnospiraceae bacterium A2", "rank": "Species"}, "397291": {"name": "Lachnospiraceae bacterium A4", "rank": "Species"}, "182710": {"name": "Oceanobacillus iheyensis", "rank": "Species"}, "887289": {"name": "Campylobacter coli 86119", "rank": "Strain"}, "887288": {"name": "Campylobacter coli 80352", "rank": "Strain"}, "419697": {"name": "Melaka orthoreovirus", "rank": "Species"}, "887285": {"name": "Campylobacter coli 151-9", "rank": "Strain"}, "1394632": {"name": "Vibrio parahaemolyticus S093", "rank": "Strain"}, "1394631": {"name": "Vibrio parahaemolyticus S092", "rank": "Strain"}, "887286": {"name": "Campylobacter coli 90-3", "rank": "Strain"}, "887281": {"name": "Campylobacter coli 7--1", "rank": "Strain"}, "887280": {"name": "Campylobacter coli 111-3", "rank": "Strain"}, "887283": {"name": "Campylobacter coli 59-2", "rank": "Strain"}, "331642": {"name": "Newbury agent 1", "rank": "Strain"}, "1236535": {"name": "Legionella pneumophila subsp. pneumophila JCM 7571", "rank": "Strain"}, "57488": {"name": "Thiorhodococcus", "rank": "Genus"}, "1236532": {"name": "Acinetobacter baumannii JCM 6841", "rank": "Strain"}, "1236531": {"name": "Klebsiella pneumoniae subsp. pneumoniae JCM 1662", "rank": "Strain"}, "1236539": {"name": "Campylobacter jejuni subsp. jejuni JCM 2013", "rank": "Strain"}, "1169305": {"name": "Enterococcus faecalis EnGen0370", "rank": "Strain"}, "1169304": {"name": "Enterococcus faecalis EnGen0358", "rank": "Strain"}, "1169307": {"name": "Enterococcus faecalis EnGen0359", "rank": "Strain"}, "1169306": {"name": "Enterococcus faecalis EnGen0368", "rank": "Strain"}, "1169301": {"name": "Enterococcus faecalis EnGen0369", "rank": "Strain"}, "1169300": {"name": "Enterococcus faecalis EnGen0355", "rank": "Strain"}, "1169303": {"name": "Enterococcus faecalis EnGen0357", "rank": "Strain"}, "1169302": {"name": "Enterococcus faecalis EnGen0356", "rank": "Strain"}, "73422": {"name": "Streptococcus phage TP-J34", "rank": "Species"}, "1169309": {"name": "Enterococcus faecalis EnGen0340", "rank": "Strain"}, "1169308": {"name": "Enterococcus faecalis EnGen0360", "rank": "Strain"}, "1408930": {"name": "Mycobacterium tuberculosis UT0051", "rank": "Strain"}, "1408931": {"name": "Mycobacterium tuberculosis UT0052", "rank": "Strain"}, "1408932": {"name": "Mycobacterium tuberculosis UT0053", "rank": "Strain"}, "1408933": {"name": "Mycobacterium tuberculosis UT0055", "rank": "Strain"}, "1408934": {"name": "Mycobacterium tuberculosis UT0056", "rank": "Strain"}, "1408935": {"name": "Mycobacterium tuberculosis UT0057", "rank": "Strain"}, "1408936": {"name": "Mycobacterium tuberculosis UT0058", "rank": "Strain"}, "1408937": {"name": "Mycobacterium tuberculosis UT0059", "rank": "Strain"}, "1408938": {"name": "Mycobacterium tuberculosis UT0060", "rank": "Strain"}, "1408939": {"name": "Mycobacterium tuberculosis UT0067", "rank": "Strain"}, "1310712": {"name": "Acinetobacter baumannii 655555", "rank": "Strain"}, "1310713": {"name": "Acinetobacter baumannii 1471012", "rank": "Strain"}, "1310716": {"name": "Acinetobacter baumannii 1482820", "rank": "Strain"}, "1310717": {"name": "Acinetobacter baumannii 1457504", "rank": "Strain"}, "400673": {"name": "Legionella pneumophila str. Corby", "rank": "Strain"}, "1310569": {"name": "Acinetobacter baumannii 1043903", "rank": "Strain"}, "1157640": {"name": "Streptomyces sp. FxanaC1", "rank": "Species"}, "1158614": {"name": "Enterococcus gilvus ATCC BAA-350", "rank": "Strain"}, "1158612": {"name": "Enterococcus caccae ATCC BAA-1240", "rank": "Strain"}, "1158610": {"name": "Enterococcus phoeniculicola ATCC BAA-412", "rank": "Strain"}, "1158619": {"name": "Enterococcus faecalis EnGen0238", "rank": "Strain"}, "1158618": {"name": "Enterococcus faecalis EnGen0237", "rank": "Strain"}, "366394": {"name": "Sinorhizobium medicae WSM419", "rank": "Strain"}, "1446639": {"name": "Escherichia coli O157:H7 str. 2011EL-2108", "rank": "Strain"}, "1446638": {"name": "Escherichia coli O157:H7 str. 2011EL-2107", "rank": "Strain"}, "596777": {"name": "Chlamydia trachomatis E/Bour", "rank": "Strain"}, "674529": {"name": "Bacteroides faecis", "rank": "Species"}, "392917": {"name": "Paenibacillus larvae subsp. larvae BRL-230010", "rank": "Strain"}, "1446631": {"name": "Escherichia coli O157:H7 str. 2011EL-2098", "rank": "Strain"}, "1446630": {"name": "Escherichia coli O157:H7 str. 2011EL-2097", "rank": "Strain"}, "1446633": {"name": "Escherichia coli O157:H7 str. 2011EL-2101", "rank": "Strain"}, "1446632": {"name": "Escherichia coli O157:H7 str. 2011EL-2099", "rank": "Strain"}, "1446635": {"name": "Escherichia coli O157:H7 str. 2011EL-2104", "rank": "Strain"}, "1446634": {"name": "Escherichia coli O157:H7 str. 2011EL-2103", "rank": "Strain"}, "1446637": {"name": "Escherichia coli O157:H7 str. 2011EL-2106", "rank": "Strain"}, "1446636": {"name": "Escherichia coli O157:H7 str. 2011EL-2105", "rank": "Strain"}, "1449058": {"name": "Microbacterium sp. UNCCL10", "rank": "Species"}, "1449059": {"name": "Mycobacterium sp. UNC410CL29Cvi84", "rank": "Species"}, "234440": {"name": "Unclassified Intrasporangiaceae", "rank": "No rank"}, "234447": {"name": "Unclassified Paenibacillaceae", "rank": "No rank"}, "1384040": {"name": "Vibrio coralliilyticus OCN008", "rank": "Strain"}, "1449050": {"name": "Clostridium sp. KNHs205", "rank": "Species"}, "1449051": {"name": "Curtobacterium sp. UNCCL17", "rank": "Species"}, "1449057": {"name": "Methylobacterium sp. UNCCL110", "rank": "Species"}, "314271": {"name": "Maritimibacter alkaliphilus HTCC2654", "rank": "Strain"}, "314270": {"name": "Rhodobacteraceae bacterium HTCC2083", "rank": "Species"}, "981350": {"name": "Komagataella pastoris CBS 7435", "rank": "Strain"}, "314275": {"name": "Alteromonas macleodii str. 'Deep ecotype'", "rank": "Strain"}, "314277": {"name": "Marinomonas sp. MED121", "rank": "Species"}, "314276": {"name": "Idiomarina baltica OS145", "rank": "Strain"}, "314278": {"name": "Nitrococcus mobilis Nb-231", "rank": "Strain"}, "1293597": {"name": "Lactobacillus equicursoris DSM 19284 = JCM 14600 = CIP 110162", "rank": "Strain"}, "1112856": {"name": "Mycoplasma pneumoniae 309", "rank": "Strain"}, "319522": {"name": "Gordonia phage GTE5", "rank": "Species"}, "1421849": {"name": "Staphylococcus aureus H31086", "rank": "Strain"}, "68288": {"name": "Cyclobacterium", "rank": "Genus"}, "931276": {"name": "Clostridium saccharoperbutylacetonicum N1-4(HMT)", "rank": "Strain"}, "931277": {"name": "Halococcus morrhuae DSM 1307", "rank": "Strain"}, "68280": {"name": "Streptomyces violaceusniger", "rank": "Species"}, "68287": {"name": "Mesorhizobium", "rank": "Genus"}, "1495331": {"name": "Pseudomonas sp. WCS374", "rank": "Species"}, "1495334": {"name": "Cellulophaga sp. E6(2014)", "rank": "Species"}, "1495336": {"name": "Methanobacterium sp. SMA-27", "rank": "Species"}, "170179": {"name": "Ophiostoma novo-ulmi subsp. novo-ulmi", "rank": "Subspecies"}, "926571": {"name": "Nitrososphaera viennensis EN76", "rank": "Strain"}, "926570": {"name": "Acidiphilium multivorum AIU301", "rank": "Strain"}, "418642": {"name": "Shewanella haliotis", "rank": "Species"}, "183939": {"name": "Methanococci", "rank": "Class"}, "388452": {"name": "Lactococcus phage KSY1", "rank": "Species"}, "1434139": {"name": "Shigella flexneri Shi06HN250", "rank": "Strain"}, "1434138": {"name": "Shigella flexneri Shi06HN016", "rank": "Strain"}, "1511862": {"name": "Carnivore amdoparvovirus 1", "rank": "Species"}, "1434133": {"name": "Shigella flexneri Shi06HN118", "rank": "Strain"}, "1434132": {"name": "Shigella flexneri Shi06GS48", "rank": "Strain"}, "334727": {"name": "Bacillus atrophaeus C89", "rank": "Strain"}, "1434130": {"name": "Shigella flexneri Shi06AH116", "rank": "Strain"}, "1434137": {"name": "Shigella flexneri Shi06HN378", "rank": "Strain"}, "1434136": {"name": "Shigella flexneri Shi06AH135", "rank": "Strain"}, "1434135": {"name": "Shigella flexneri 2005AH264", "rank": "Strain"}, "1434134": {"name": "Shigella flexneri Shi06HN023", "rank": "Strain"}, "203522": {"name": "Longispora", "rank": "Genus"}, "203523": {"name": "Longispora albida", "rank": "Species"}, "1234661": {"name": "Yersinia pestis subsp. pestis bv. Orientalis", "rank": "Strain"}, "1234660": {"name": "Yersinia pestis subsp. pestis bv. Antiqua", "rank": "Strain"}, "1234662": {"name": "Yersinia pestis subsp. pestis bv. Medievalis", "rank": "Strain"}, "1235278": {"name": "Staphylococcus aureus PPUKM-775-2009", "rank": "Strain"}, "43994": {"name": "Johnsonella", "rank": "Genus"}, "43995": {"name": "Johnsonella ignava", "rank": "Species"}, "43996": {"name": "Catonella", "rank": "Genus"}, "43997": {"name": "Catonella morbi", "rank": "Species"}, "10649": {"name": "Figwort mosaic virus", "rank": "Species"}, "10640": {"name": "Carnation etched ring virus", "rank": "Species"}, "10641": {"name": "Cauliflower mosaic virus", "rank": "Species"}, "1121110": {"name": "Bifidobacterium subtile DSM 20096", "rank": "Strain"}, "1121111": {"name": "Bifidobacterium thermacidophilum subsp. thermacidophilum DSM 15837", "rank": "Strain"}, "1446581": {"name": "Escherichia coli O128:H2 str. 2011C-3317", "rank": "Strain"}, "1446580": {"name": "Escherichia coli O123:H11 str. 2009C-3307", "rank": "Strain"}, "1446587": {"name": "Escherichia coli O145:NM str. 2010C-3507", "rank": "Strain"}, "1446586": {"name": "Escherichia coli O145:NM str. 08-4270", "rank": "Strain"}, "1446585": {"name": "Escherichia coli O145:NM str. 06-3484", "rank": "Strain"}, "1446584": {"name": "Escherichia coli O145:H28 str. 2009C-3292", "rank": "Strain"}, "1121118": {"name": "Brackiella oedipodis DSM 13743", "rank": "Strain"}, "1446589": {"name": "Escherichia coli O145:NM str. 2010C-3509", "rank": "Strain"}, "1446588": {"name": "Escherichia coli O145:NM str. 2010C-3508", "rank": "Strain"}, "366649": {"name": "Xanthomonas fuscans subsp. fuscans", "rank": "Subspecies"}, "366648": {"name": "Xanthomonas fuscans", "rank": "Species"}, "1392056": {"name": "Staphylococcus aureus M1049", "rank": "Strain"}, "47055": {"name": "Dethiosulfovibrio peptidovorans", "rank": "Species"}, "47054": {"name": "Dethiosulfovibrio", "rank": "Genus"}, "1418357": {"name": "Staphylococcus aureus W19225", "rank": "Strain"}, "1418356": {"name": "Staphylococcus aureus W19220", "rank": "Strain"}, "557724": {"name": "Burkholderia pseudomallei 576", "rank": "Strain"}, "1151417": {"name": "Peptoclostridium difficile P41", "rank": "Strain"}, "1202785": {"name": "Methylacidiphilum kamchatkense Kam1", "rank": "Strain"}, "1336600": {"name": "Felis catus papillomavirus 3", "rank": "Species"}, "72201": {"name": "Armadillidium vulgare iridescent virus", "rank": "Strain"}, "882944": {"name": "Listonella anguillarum M3", "rank": "Strain"}, "1248232": {"name": "Photobacterium leiognathi lrivu.4.1", "rank": "Strain"}, "251698": {"name": "Pseudomonas syringae group genomosp. 2", "rank": "Species subgroup"}, "1151410": {"name": "Peptoclostridium difficile P28", "rank": "Strain"}, "1203258": {"name": "Lactobacillus rhamnosus LRHMDP2", "rank": "Strain"}, "1203259": {"name": "Lactobacillus rhamnosus LRHMDP3", "rank": "Strain"}, "1203257": {"name": "Streptomyces sp. AA1529", "rank": "Species"}, "1151411": {"name": "Peptoclostridium difficile P29", "rank": "Strain"}, "261684": {"name": "Thermosinus", "rank": "Genus"}, "1409692": {"name": "Staphylococcus aureus MISS6078", "rank": "Strain"}, "1161930": {"name": "Leuconostoc phage Lmd1", "rank": "Species"}, "1161931": {"name": "Agrobacterium phage 7-7-1", "rank": "Species"}, "1548712": {"name": "Circoviridae SFBeef", "rank": "Species"}, "1161939": {"name": "Enterococcus phage vB_Efae230P-4", "rank": "Species"}, "1409690": {"name": "Staphylococcus aureus OCMM6117", "rank": "Strain"}, "1327774": {"name": "Mycobacterium phage Phrux", "rank": "Species"}, "1327775": {"name": "Mycobacterium phage SDcharge11", "rank": "Species"}, "1327776": {"name": "Mycobacterium phage Severus", "rank": "Species"}, "864568": {"name": "Streptococcus pyogenes ATCC 10782", "rank": "Strain"}, "1327770": {"name": "Mycobacterium phage HINdeR", "rank": "Species"}, "1327771": {"name": "Mycobacterium phage Job42", "rank": "Species"}, "1327772": {"name": "Mycobacterium phage Jobu08", "rank": "Species"}, "1327773": {"name": "Mycobacterium phage PattyP", "rank": "Species"}, "864563": {"name": "Selenomonas sp. oral taxon 149 str. 67H29BP", "rank": "Strain"}, "1469956": {"name": "Danaus plexippus plexippus iteravirus", "rank": "Species"}, "864567": {"name": "Streptococcus mitis ATCC 6249", "rank": "Strain"}, "864566": {"name": "Campylobacter coli JV20", "rank": "Strain"}, "864565": {"name": "Eubacterium yurii subsp. margaretiae ATCC 43715", "rank": "Strain"}, "1469950": {"name": "Robinsoniella sp. KNHs210", "rank": "Species"}, "1504317": {"name": "Actinobacterium acMicro-4", "rank": "Species"}, "1221308": {"name": "Acinetobacter nosocomialis TG21145", "rank": "Strain"}, "1157440": {"name": "Enterococcus faecium EnGen0145", "rank": "Strain"}, "11599": {"name": "Hantaan virus", "rank": "Species"}, "1221309": {"name": "Acinetobacter pittii TG6411", "rank": "Strain"}, "904337": {"name": "Staphylococcus epidermidis VCU120", "rank": "Strain"}, "904336": {"name": "Staphylococcus epidermidis VCU118", "rank": "Strain"}, "11595": {"name": "Dugbe virus", "rank": "Species"}, "904334": {"name": "Staphylococcus capitis VCU116", "rank": "Strain"}, "11593": {"name": "Crimean-Congo hemorrhagic fever virus", "rank": "Species"}, "11592": {"name": "Nairovirus", "rank": "Genus"}, "904331": {"name": "Staphylococcus epidermidis VCU111", "rank": "Strain"}, "904330": {"name": "Staphylococcus epidermidis VCU109", "rank": "Strain"}, "1471493": {"name": "Prochlorococcus sp. scB243_498I20", "rank": "Species"}, "12643": {"name": "Ectromelia virus", "rank": "Species"}, "1471491": {"name": "Prochlorococcus sp. scB243_498F21", "rank": "Species"}, "1471490": {"name": "Prochlorococcus sp. scB243_498C16", "rank": "Species"}, "1471497": {"name": "Prochlorococcus sp. scB243_498N4", "rank": "Species"}, "1471496": {"name": "Prochlorococcus sp. scB243_498M14", "rank": "Species"}, "1471495": {"name": "Prochlorococcus sp. scB243_498L10", "rank": "Species"}, "1471494": {"name": "Prochlorococcus sp. scB243_498J20", "rank": "Species"}, "195061": {"name": "Solanum nodiflorum mottle virus satellite RNA", "rank": "Species"}, "1471499": {"name": "Prochlorococcus sp. scB243_498P15", "rank": "Species"}, "1471498": {"name": "Prochlorococcus sp. scB243_498N8", "rank": "Species"}, "1409698": {"name": "Staphylococcus aureus OCMM6121", "rank": "Strain"}, "28209": {"name": "Chelatococcus", "rank": "Genus"}, "195060": {"name": "Potato yellow dwarf virus", "rank": "Species"}, "648885": {"name": "Methylobacterium sp. MB200", "rank": "Species"}, "1444289": {"name": "Clostridium novyi A str. 4552", "rank": "Strain"}, "195063": {"name": "Subterranean clover mottle virus satellite RNA", "rank": "Species"}, "195062": {"name": "Strawberry latent ringspot virus satellite RNA", "rank": "Species"}, "2296": {"name": "Desulfobacterium autotrophicum", "rank": "Species"}, "2295": {"name": "Desulfobacterium", "rank": "Genus"}, "2293": {"name": "Desulfobacter postgatei", "rank": "Species"}, "2290": {"name": "Desulfobacter curvatus", "rank": "Species"}, "2299": {"name": "Desulfosarcina", "rank": "Genus"}, "1281092": {"name": "Escherichia coli HVH 159 (4-5818141)", "rank": "Strain"}, "1281093": {"name": "Escherichia coli HVH 160 (4-5695937)", "rank": "Strain"}, "1281090": {"name": "Escherichia coli HVH 157 (4-3406229)", "rank": "Strain"}, "1281091": {"name": "Escherichia coli HVH 158 (4-3224287)", "rank": "Strain"}, "1281096": {"name": "Escherichia coli HVH 163 (4-4697553)", "rank": "Strain"}, "1281097": {"name": "Escherichia coli HVH 164 (4-5953081)", "rank": "Strain"}, "1281094": {"name": "Escherichia coli HVH 161 (4-3119890)", "rank": "Strain"}, "1281095": {"name": "Escherichia coli HVH 162 (4-5627982)", "rank": "Strain"}, "1082705": {"name": "Lonsdalea quercina subsp. quercina", "rank": "Subspecies"}, "273133": {"name": "Pseudomonas phage EL", "rank": "Species"}, "1281098": {"name": "Escherichia coli HVH 167 (4-6073565)", "rank": "Strain"}, "1281099": {"name": "Escherichia coli HVH 169 (4-1075578)", "rank": "Strain"}, "1274985": {"name": "Staphylococcus aureus subsp. aureus SK1585", "rank": "Strain"}, "1082702": {"name": "Lonsdalea", "rank": "Genus"}, "553088": {"name": "Chitiniphilus shinanonensis", "rank": "Species"}, "198466": {"name": "Streptococcus pyogenes MGAS315", "rank": "Strain"}, "198467": {"name": "Anoxybacillus gonensis", "rank": "Species"}, "1502784": {"name": "Pseudomonas sp. AAC", "rank": "Species"}, "1221307": {"name": "Acinetobacter lwoffii TG19636", "rank": "Strain"}, "655338": {"name": "Fervidicella metallireducens", "rank": "Species"}, "173480": {"name": "Gemmatimonas aurantiaca", "rank": "Species"}, "332186": {"name": "Shewanella xiamenensis", "rank": "Species"}, "36629": {"name": "Neosartorya", "rank": "Genus"}, "59922": {"name": "Prochlorococcus marinus str. MIT 9303", "rank": "Strain"}, "1155084": {"name": "Staphylococcus aureus subsp. aureus 71193", "rank": "Strain"}, "69279": {"name": "Aquamicrobium defluvii", "rank": "Species"}, "5217": {"name": "Tremella mesenterica", "rank": "Species"}, "1294271": {"name": "Staphylococcus epidermidis 41tr", "rank": "Strain"}, "1157444": {"name": "Enterococcus faecium EnGen0149", "rank": "Strain"}, "1294272": {"name": "Staphylococcus epidermidis 528m", "rank": "Strain"}, "1294273": {"name": "Roseibacterium elongatum DSM 19469", "rank": "Strain"}, "1294275": {"name": "Vibrio cholerae CP1116", "rank": "Strain"}, "1462430": {"name": "Nanohaloarchaeota", "rank": "Phylum"}, "1276756": {"name": "Acidovorax sp. JHL-9", "rank": "Species"}, "1276755": {"name": "Acidovorax sp. JHL-3", "rank": "Species"}, "5215": {"name": "Tremellaceae", "rank": "Family"}, "33196": {"name": "Botrytis", "rank": "Genus"}, "33194": {"name": "Bipolaris", "rank": "Genus"}, "44560": {"name": "Ageratum yellow vein virus", "rank": "Species"}, "44561": {"name": "Murine type C retrovirus", "rank": "Strain"}, "44562": {"name": "Pothos latent virus", "rank": "Species"}, "1438834": {"name": "Mycobacterium tuberculosis UT0074", "rank": "Strain"}, "56459": {"name": "Xanthomonas vasicola", "rank": "Species"}, "56458": {"name": "Xanthomonas sacchari", "rank": "Species"}, "123735": {"name": "Tomato yellow leaf curl Sardinia virus", "rank": "Species"}, "56454": {"name": "Xanthomonas hortorum", "rank": "Species"}, "56450": {"name": "Xanthomonas cassavae", "rank": "Species"}, "211668": {"name": "Colwellia piezophila", "rank": "Species"}, "211669": {"name": "Psychromonas hadalis", "rank": "Species"}, "1458724": {"name": "Mycobacterium phage Alsfro", "rank": "Species"}, "1458725": {"name": "Mycobacterium phage Soto", "rank": "Species"}, "1458726": {"name": "Mycobacterium phage 20ES", "rank": "Species"}, "689831": {"name": "Spinareovirinae", "rank": "Subfamily"}, "1413530": {"name": "Staphylococcus aureus GD2010-112", "rank": "Strain"}, "1413531": {"name": "Staphylococcus aureus GD2010-131", "rank": "Strain"}, "1413532": {"name": "Staphylococcus aureus GD2010-147", "rank": "Strain"}, "301865": {"name": "Mint virus X", "rank": "Species"}, "766762": {"name": "Salmonella enterica subsp. enterica serovar Montevideo str. 81038-01", "rank": "Strain"}, "887899": {"name": "Mobiluncus curtisii subsp. holmesii ATCC 35242", "rank": "Strain"}, "766760": {"name": "Bacillus licheniformis 9945A", "rank": "Strain"}, "766761": {"name": "Salmonella enterica subsp. enterica serovar Montevideo str. 4441 H", "rank": "Strain"}, "1413538": {"name": "Staphylococcus aureus Rd.3", "rank": "Strain"}, "1413539": {"name": "Staphylococcus aureus Rd.9", "rank": "Strain"}, "766764": {"name": "Debaryomycetaceae", "rank": "Family"}, "766765": {"name": "Yamadazyma", "rank": "Genus"}, "1409362": {"name": "Staphylococcus aureus SJOS6052", "rank": "Strain"}, "1409363": {"name": "Staphylococcus aureus LAMC0024", "rank": "Strain"}, "1409360": {"name": "Staphylococcus aureus SJOS6050", "rank": "Strain"}, "1409361": {"name": "Staphylococcus aureus SJOS6051", "rank": "Strain"}, "1409366": {"name": "Staphylococcus aureus SJOS6061", "rank": "Strain"}, "1409367": {"name": "Staphylococcus aureus AMMC6040", "rank": "Strain"}, "1409364": {"name": "Staphylococcus aureus GGMC6008", "rank": "Strain"}, "1409365": {"name": "Staphylococcus aureus SJOS6053", "rank": "Strain"}, "1409368": {"name": "Staphylococcus aureus SJOS6071", "rank": "Strain"}, "1409369": {"name": "Staphylococcus aureus AMMC6050", "rank": "Strain"}, "393277": {"name": "Donghicola", "rank": "Genus"}, "1219382": {"name": "Acinetobacter nectaris", "rank": "Species"}, "1267973": {"name": "Arthrobacter sp. H5", "rank": "Species"}, "284503": {"name": "Bombyx mori cypovirus 1 satellite RNA", "rank": "Species"}, "284502": {"name": "Aphanizomenon flos-aquae NIES-81", "rank": "Strain"}, "1305778": {"name": "Kingella kingae KK128", "rank": "Strain"}, "1305779": {"name": "Kingella kingae KK190", "rank": "Strain"}, "1348584": {"name": "Cellulophaga baltica 18", "rank": "Strain"}, "1305775": {"name": "Kingella kingae KK60", "rank": "Strain"}, "1305776": {"name": "Kingella kingae KK199", "rank": "Strain"}, "1305777": {"name": "Kingella kingae KK411", "rank": "Strain"}, "1305771": {"name": "Kingella kingae KK56", "rank": "Strain"}, "1348582": {"name": "Cellulophaga baltica 4", "rank": "Strain"}, "1348583": {"name": "Cellulophaga baltica 13", "rank": "Strain"}, "1461322": {"name": "Vibrio sp. DCR 1-4-2", "rank": "Species"}, "1461323": {"name": "Vibrio sp. DCR 1-4-12", "rank": "Species"}, "857099": {"name": "Streptococcus mutans OMZ175", "rank": "Strain"}, "34084": {"name": "Riemerella", "rank": "Genus"}, "34085": {"name": "Riemerella anatipestifer", "rank": "Species"}, "34086": {"name": "Sphingobacterium antarcticum", "rank": "Species"}, "281361": {"name": "Flavobacterium denitrificans", "rank": "Species"}, "1412669": {"name": "Staphylococcus aureus M46070", "rank": "Strain"}, "1412668": {"name": "Staphylococcus aureus M46066", "rank": "Strain"}, "1412663": {"name": "Staphylococcus aureus H68256", "rank": "Strain"}, "1412662": {"name": "Staphylococcus aureus H68252", "rank": "Strain"}, "1412661": {"name": "Staphylococcus aureus H68244", "rank": "Strain"}, "1412660": {"name": "Staphylococcus aureus H64967", "rank": "Strain"}, "1412667": {"name": "Staphylococcus aureus M46058", "rank": "Strain"}, "1412666": {"name": "Staphylococcus aureus H75143", "rank": "Strain"}, "1412665": {"name": "Staphylococcus aureus H71553", "rank": "Strain"}, "1412664": {"name": "Staphylococcus aureus H71538", "rank": "Strain"}, "1417053": {"name": "Staphylococcus aureus F63730", "rank": "Strain"}, "1417052": {"name": "Staphylococcus aureus W56912", "rank": "Strain"}, "1417051": {"name": "Staphylococcus aureus T74141", "rank": "Strain"}, "1417057": {"name": "Staphylococcus aureus H32181", "rank": "Strain"}, "1417056": {"name": "Staphylococcus aureus H32126", "rank": "Strain"}, "1417055": {"name": "Staphylococcus aureus H32166", "rank": "Strain"}, "1417054": {"name": "Staphylococcus aureus H32135", "rank": "Strain"}, "449673": {"name": "Bacteroides stercoris ATCC 43183", "rank": "Strain"}, "1417059": {"name": "Staphylococcus aureus F66778", "rank": "Strain"}, "1417058": {"name": "Staphylococcus aureus F63786", "rank": "Strain"}, "84642": {"name": "Aeromonadaceae", "rank": "Family"}, "84647": {"name": "Candidatus Odyssella thessalonicensis", "rank": "Species"}, "84646": {"name": "Candidatus Odyssella", "rank": "Genus"}, "292443": {"name": "Vibrio phage KSF-1phi", "rank": "Species"}, "1382345": {"name": "Flammeovirga sp. OC4", "rank": "Species"}, "1184609": {"name": "Kineosphaera limosa NBRC 100340", "rank": "Strain"}, "1340175": {"name": "Acinetobacter baumannii MRY10-0558", "rank": "Strain"}, "1340174": {"name": "Acinetobacter baumannii MRY09-0642", "rank": "Strain"}, "1184607": {"name": "Austwickia chelonae NBRC 105200", "rank": "Strain"}, "1340176": {"name": "Acinetobacter baumannii MRY12-0277", "rank": "Strain"}, "1413253": {"name": "Klebsiella pneumoniae subsp. pneumoniae KPB-2", "rank": "Strain"}, "1413252": {"name": "Klebsiella pneumoniae subsp. pneumoniae KPB-1", "rank": "Strain"}, "1444116": {"name": "Escherichia coli 6-537-08_S1_C3", "rank": "Strain"}, "1416011": {"name": "Klebsiella phage F19", "rank": "Species"}, "1416012": {"name": "Enterococcus phage IME_EF3", "rank": "Species"}, "1444117": {"name": "Escherichia coli 2-005-03_S3_C1", "rank": "Strain"}, "1294027": {"name": "Tropheryma whipplei str. Slow2", "rank": "Strain"}, "1387333": {"name": "Salmonella enterica subsp. enterica serovar Typhimurium str. 98346", "rank": "Strain"}, "1387330": {"name": "Salmonella enterica subsp. enterica serovar 9,12:l,v:- str. 94293", "rank": "Strain"}, "1387331": {"name": "Salmonella enterica subsp. enterica serovar Typhimurium str. 95799", "rank": "Strain"}, "324617": {"name": "Aeromonas tecta", "rank": "Species"}, "1387339": {"name": "Salmonella enterica subsp. enterica serovar Typhimurium str. 104772", "rank": "Strain"}, "328515": {"name": "Nonlabens dokdonensis", "rank": "Species"}, "285450": {"name": "Streptomyces roseochromogenus", "rank": "Species"}, "627141": {"name": "Pseudomonas nitroreducens/multiresinivorans group", "rank": "Species subgroup"}, "44260": {"name": "Moorella", "rank": "Genus"}, "1398558": {"name": "Piscirickettsia salmonis AUSTRAL-005", "rank": "Strain"}, "1187065": {"name": "Mycobacterium sp. 012931", "rank": "Species"}, "1394033": {"name": "Butcherbird polyomavirus", "rank": "Species"}, "1211388": {"name": "Apple green crinkle associated virus", "rank": "Species"}, "991928": {"name": "Vibrio cholerae CP1046(19)", "rank": "Strain"}, "411566": {"name": "Candidatus Midichloria", "rank": "Genus"}, "717774": {"name": "Marinomonas mediterranea MMB-1", "rank": "Strain"}, "1451189": {"name": "Corynebacterium falsenii DSM 44353", "rank": "Strain"}, "1451188": {"name": "Stenotrophomonas maltophilia M30", "rank": "Strain"}, "717773": {"name": "Thioalkalimicrobium cyclicum ALM1", "rank": "Strain"}, "717772": {"name": "Thioalkalimicrobium aerophilum AL3", "rank": "Strain"}, "941338": {"name": "Bhargavaea", "rank": "Genus"}, "254945": {"name": "Ehrlichia ruminantium str. Welgevonden", "rank": "Strain"}, "1492922": {"name": "Gammaproteobacteria bacterium MFB021", "rank": "Species"}, "429": {"name": "Methylobacter", "rank": "Genus"}, "426": {"name": "Methylosinus trichosporium", "rank": "Species"}, "425": {"name": "Methylosinus", "rank": "Genus"}, "37705": {"name": "Sin Nombre virus", "rank": "Species"}, "673198": {"name": "Pseudomonas syringae pv. tomato Max13", "rank": "Strain"}, "421": {"name": "Methylomonas methanica", "rank": "Species"}, "1130798": {"name": "Lactobacillus mucosae LM1", "rank": "Strain"}, "190650": {"name": "Caulobacter crescentus CB15", "rank": "Strain"}, "1410719": {"name": "Staphylococcus aureus W41914", "rank": "Strain"}, "1410718": {"name": "Staphylococcus aureus T59609", "rank": "Strain"}, "1131267": {"name": "Marine Group I thaumarchaeote SCGC AB-629-A13", "rank": "Species"}, "1131266": {"name": "Marine Group I thaumarchaeote SCGC AB-629-I23", "rank": "Species"}, "999141": {"name": "Halomonas sp. TD01", "rank": "Species"}, "1410711": {"name": "Staphylococcus aureus W35325", "rank": "Strain"}, "1410710": {"name": "Staphylococcus aureus M92086", "rank": "Strain"}, "1131269": {"name": "Nitrospina sp. AB-629-B18", "rank": "Species"}, "1131268": {"name": "Marine Group II euryarchaeote SCGC AB-629-J06", "rank": "Species"}, "1211035": {"name": "Lysinibacillus massiliensis 4400831 = CIP 108448 = CCUG 49529", "rank": "Strain"}, "1410714": {"name": "Staphylococcus aureus M13316", "rank": "Strain"}, "1410717": {"name": "Staphylococcus aureus T59607", "rank": "Strain"}, "1211036": {"name": "Mangrovimonas", "rank": "Genus"}, "1182724": {"name": "Escherichia coli KTE144", "rank": "Strain"}, "1182725": {"name": "Escherichia coli KTE146", "rank": "Strain"}, "1182726": {"name": "Escherichia coli KTE147", "rank": "Strain"}, "1182720": {"name": "Escherichia coli KTE140", "rank": "Strain"}, "1182721": {"name": "Escherichia coli KTE141", "rank": "Strain"}, "1182722": {"name": "Escherichia coli KTE142", "rank": "Strain"}, "1182723": {"name": "Escherichia coli KTE143", "rank": "Strain"}, "1451233": {"name": "Acinetobacter soli TCM341", "rank": "Strain"}, "1504981": {"name": "Halomonas sp. KO116", "rank": "Species"}, "1182728": {"name": "Escherichia coli KTE154", "rank": "Strain"}, "1182729": {"name": "Escherichia coli KTE155", "rank": "Strain"}, "439703": {"name": "Prevotella maculosa", "rank": "Species"}, "179997": {"name": "Salmonella enterica subsp. enterica serovar Havana", "rank": "Strain"}, "329641": {"name": "Human bocavirus", "rank": "Species"}, "329647": {"name": "Wolbachia endosymbiont of Culex molestus", "rank": "Species"}, "1293540": {"name": "Adoxophyes honmai entomopoxvirus 'L'", "rank": "Species"}, "145458": {"name": "Rathayibacter toxicus", "rank": "Species"}, "1488328": {"name": "Pseudomonas sp. Ant30-3", "rank": "Species"}, "796334": {"name": "Erwinia oleae", "rank": "Species"}, "1034": {"name": "Afipia clevelandensis", "rank": "Species"}, "1035": {"name": "Afipia felis", "rank": "Species"}, "1438739": {"name": "Klebsiella pneumoniae CHS 33", "rank": "Strain"}, "1033": {"name": "Afipia", "rank": "Genus"}, "1030": {"name": "Thiothrix", "rank": "Genus"}, "1031": {"name": "Thiothrix nivea", "rank": "Species"}, "1438735": {"name": "Klebsiella pneumoniae CHS 29", "rank": "Strain"}, "1438734": {"name": "Klebsiella pneumoniae CHS 28", "rank": "Strain"}, "1438737": {"name": "Klebsiella pneumoniae CHS 31", "rank": "Strain"}, "1438736": {"name": "Klebsiella pneumoniae CHS 30", "rank": "Strain"}, "1438731": {"name": "Klebsiella pneumoniae CHS 25", "rank": "Strain"}, "1438730": {"name": "Klebsiella pneumoniae CHS 24", "rank": "Strain"}, "1438733": {"name": "Klebsiella pneumoniae CHS 27", "rank": "Strain"}, "1438732": {"name": "Klebsiella pneumoniae CHS 26", "rank": "Strain"}, "1215603": {"name": "Fusarium fujikuroi B14", "rank": "Strain"}, "1568973": {"name": "Botrytis cinerea RNA virus 1", "rank": "Species"}, "1568974": {"name": "Chickpea yellow dwarf virus", "rank": "Species"}, "68042": {"name": "Streptomyces hygroscopicus subsp. hygroscopicus", "rank": "Subspecies"}, "1007127": {"name": "Staphylococcus phage Sb-1", "rank": "Species"}, "1007124": {"name": "Marinimicrobia bacterium SCGC AAA076-M08", "rank": "Species"}, "251701": {"name": "Pseudomonas syringae group genomosp. 3", "rank": "Species"}, "1007123": {"name": "Marinimicrobia bacterium SCGC AAA160-I06", "rank": "Species"}, "1007120": {"name": "Gamma proteobacterium SCGC AAA160-D02", "rank": "Species"}, "1007121": {"name": "Marinimicrobia bacterium SCGC AAA160-B08", "rank": "Species"}, "182082": {"name": "Chlamydophila pneumoniae TW-183", "rank": "Strain"}, "1324794": {"name": "Simian adenovirus C", "rank": "Species"}, "1074919": {"name": "Staphylococcus aureus subsp. aureus ST228", "rank": "Strain"}, "1400797": {"name": "Vibrio mimicus CAIM 1882", "rank": "Strain"}, "979781": {"name": "Tomato mottle leaf curl Zulia virus", "rank": "Species"}, "1400798": {"name": "Vibrio mimicus CAIM 1883", "rank": "Strain"}, "1400799": {"name": "Enterococcus faecalis FL2", "rank": "Strain"}, "1412618": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20120929", "rank": "Strain"}, "154046": {"name": "Clostridium hathewayi", "rank": "Species"}, "940846": {"name": "Sweet potato leaf curl Uganda virus-Uganda:Kampala:2008", "rank": "Strain"}, "1231185": {"name": "Nitratireductor aquibiodomus NL21 = JCM 21793", "rank": "Strain"}, "1437824": {"name": "Castellaniella defragrans 65Phen", "rank": "Strain"}, "1437826": {"name": "Xenorhabdus nematophila str. Websteri", "rank": "Strain"}, "298701": {"name": "Desulfovibrio sp. A2", "rank": "Species"}, "1400180": {"name": "Klebsiella pneumoniae UCI 37", "rank": "Strain"}, "883094": {"name": "Lactobacillus crispatus FB049-03", "rank": "Strain"}, "1032475": {"name": "Marine group II euryarchaeote SCGC AAA288-C18", "rank": "Species"}, "883096": {"name": "Bergeyella zoohelcum ATCC 43767", "rank": "Strain"}, "269666": {"name": "Streptococcus marimammalium", "rank": "Species"}, "1115650": {"name": "Candidatus Pelagibacter ubique HTCC1016", "rank": "Strain"}, "102608": {"name": "Helicobacter pylori F32", "rank": "Strain"}, "883092": {"name": "Lactobacillus crispatus FB077-07", "rank": "Strain"}, "883098": {"name": "Bergeyella zoohelcum CCUG 30536", "rank": "Strain"}, "1486469": {"name": "Mycobacterium phage Damien", "rank": "Species"}, "1157487": {"name": "Enterococcus faecium EnGen0192", "rank": "Strain"}, "65551": {"name": "Meiothermus", "rank": "Genus"}, "65552": {"name": "Meiothermus cerbereus", "rank": "Species"}, "65553": {"name": "Sulfurospirillum deleyianum", "rank": "Species"}, "1157483": {"name": "Enterococcus faecium EnGen0188", "rank": "Strain"}, "1157482": {"name": "Enterococcus faecium EnGen0187", "rank": "Strain"}, "1157481": {"name": "Enterococcus faecium EnGen0186", "rank": "Strain"}, "1157480": {"name": "Enterococcus faecium EnGen0185", "rank": "Strain"}, "1157488": {"name": "Enterococcus faecium EnGen0193", "rank": "Strain"}, "1388": {"name": "Alicyclobacillus acidocaldarius subsp. acidocaldarius", "rank": "Subspecies"}, "115561": {"name": "Halomonas hydrothermalis", "rank": "Species"}, "61646": {"name": "Lelliottia amnigena", "rank": "Species"}, "61647": {"name": "Pluralibacter gergoviae", "rank": "Species"}, "1385": {"name": "Bacillales", "rank": "Order"}, "1386": {"name": "Bacillus", "rank": "Genus"}, "1435461": {"name": "Escherichia coli KLY", "rank": "Strain"}, "1380": {"name": "Atopobium", "rank": "Genus"}, "1381": {"name": "Atopobium minutum", "rank": "Species"}, "1382": {"name": "Atopobium parvulum", "rank": "Species"}, "1383": {"name": "Atopobium rimae", "rank": "Species"}, "1310828": {"name": "Acinetobacter baumannii 472237-120", "rank": "Strain"}, "1310829": {"name": "Acinetobacter baumannii 1276470-132", "rank": "Strain"}, "1310820": {"name": "Acinetobacter baumannii 323408", "rank": "Strain"}, "1310826": {"name": "Acinetobacter baumannii 1195185_80", "rank": "Strain"}, "1310827": {"name": "Acinetobacter baumannii 1262761-105", "rank": "Strain"}, "1310824": {"name": "Acinetobacter baumannii 1264765", "rank": "Strain"}, "1310825": {"name": "Acinetobacter baumannii 1064293_46", "rank": "Strain"}, "1402558": {"name": "Pseudomonas aeruginosa BL17", "rank": "Strain"}, "1402559": {"name": "Pseudomonas aeruginosa BL18", "rank": "Strain"}, "1402554": {"name": "Pseudomonas aeruginosa BL13", "rank": "Strain"}, "1402555": {"name": "Pseudomonas aeruginosa BL14", "rank": "Strain"}, "1402556": {"name": "Pseudomonas aeruginosa BL15", "rank": "Strain"}, "1402557": {"name": "Pseudomonas aeruginosa BL16", "rank": "Strain"}, "1402550": {"name": "Pseudomonas aeruginosa BL09", "rank": "Strain"}, "1402551": {"name": "Pseudomonas aeruginosa BL10", "rank": "Strain"}, "1402552": {"name": "Pseudomonas aeruginosa BL11", "rank": "Strain"}, "1402553": {"name": "Pseudomonas aeruginosa BL12", "rank": "Strain"}, "1188990": {"name": "Vallota speciosa virus", "rank": "Species"}, "1436289": {"name": "Candidatus Symbiobacter", "rank": "Genus"}, "487155": {"name": "Brugmansia suaveolens mottle virus", "rank": "Species"}, "63265": {"name": "Sporisorium", "rank": "Genus"}, "487152": {"name": "Staphylococcus phage phiMR25", "rank": "Species"}, "1284663": {"name": "Lactobacillus plantarum ZJ316", "rank": "Strain"}, "545630": {"name": "Planktothrix mougeotii NIVA-CYA 405", "rank": "Strain"}, "1284664": {"name": "Streptomyces gancidicus BKS 13-15", "rank": "Strain"}, "152335": {"name": "Lactobacillus suebicus", "rank": "Species"}, "1968": {"name": "Streptomyces cellulosae", "rank": "Species"}, "1969": {"name": "Streptomyces chartreusis", "rank": "Species"}, "1280949": {"name": "Hyphomonas adhaerens MHS-3", "rank": "Strain"}, "1280948": {"name": "Hyphomonas atlantica", "rank": "Species"}, "1535421": {"name": "Pseudoalteromonas sp. ND6B", "rank": "Species"}, "1280946": {"name": "Hyphomonas beringensis", "rank": "Species"}, "1535422": {"name": "Thalassotalea sp. ND16A", "rank": "Species"}, "1280941": {"name": "Hyphomonas sp. T16B2", "rank": "Species"}, "64602": {"name": "Natrialba asiatica", "rank": "Species"}, "85874": {"name": "Thermacetogenium phaeum", "rank": "Species"}, "1352345": {"name": "Helicobacter pylori UM111", "rank": "Strain"}, "180837": {"name": "Wolbachia endosymbiont of Nasonia vitripennis", "rank": "Species"}, "442694": {"name": "Xanthomonas perforans", "rank": "Species"}, "1203603": {"name": "Capnocytophaga sp. oral taxon 336 str. F0502", "rank": "Strain"}, "1435992": {"name": "Burkholderia pseudomallei MSHR1357", "rank": "Strain"}, "1435993": {"name": "Burkholderia pseudomallei MSHR2138", "rank": "Strain"}, "1435990": {"name": "Burkholderia pseudomallei MSHR543", "rank": "Strain"}, "1435991": {"name": "Burkholderia pseudomallei MSHR1029", "rank": "Strain"}, "1118154": {"name": "Brevibacillus laterosporus GI-9", "rank": "Strain"}, "1435997": {"name": "Burkholderia pseudomallei MSHR3016", "rank": "Strain"}, "1435994": {"name": "Burkholderia pseudomallei MSHR2243", "rank": "Strain"}, "1435995": {"name": "Burkholderia pseudomallei MSHR2451", "rank": "Strain"}, "1118158": {"name": "Candidatus Pelagibacter ubique HTCC1040", "rank": "Strain"}, "1118159": {"name": "Pseudomonas aeruginosa NCAIM B.001380", "rank": "Strain"}, "1435998": {"name": "Burkholderia pseudomallei MSHR456", "rank": "Strain"}, "1435999": {"name": "Burkholderia pseudomallei MSHR684", "rank": "Strain"}, "1398963": {"name": "Acinetobacter baumannii UH19908", "rank": "Strain"}, "1398962": {"name": "Acinetobacter baumannii UH19608", "rank": "Strain"}, "1398961": {"name": "Acinetobacter baumannii UH18608", "rank": "Strain"}, "1398960": {"name": "Acinetobacter baumannii UH16208", "rank": "Strain"}, "1398967": {"name": "Acinetobacter baumannii UH2307", "rank": "Strain"}, "1398966": {"name": "Acinetobacter baumannii UH22908", "rank": "Strain"}, "1398965": {"name": "Acinetobacter baumannii UH2107", "rank": "Strain"}, "1398964": {"name": "Acinetobacter baumannii UH20108", "rank": "Strain"}, "1398969": {"name": "Acinetobacter baumannii UH2907", "rank": "Strain"}, "1398968": {"name": "Acinetobacter baumannii UH2707", "rank": "Strain"}, "1079986": {"name": "Streptomyces chartreusis NRRL 12338", "rank": "Strain"}, "1079988": {"name": "Corynebacterium glutamicum ATCC 14067", "rank": "Strain"}, "299200": {"name": "Thunberg fritillary virus", "rank": "Species"}, "511745": {"name": "Methylacidiphilum", "rank": "Genus"}, "511746": {"name": "Methylacidiphilum infernorum", "rank": "Species"}, "669502": {"name": "Candidatus Profftella armatura", "rank": "Species"}, "239365": {"name": "Enzootic nasal tumour virus of goats", "rank": "Species"}, "1194641": {"name": "Bacillus phage BtCS33", "rank": "Species"}, "342023": {"name": "Streptococcus pyogenes serotype M12", "rank": "Strain"}, "342021": {"name": "Streptococcus pyogenes serotype M44", "rank": "Strain"}, "1508657": {"name": "Ruminiclostridium", "rank": "Genus"}, "1325963": {"name": "Salmonella phage L13", "rank": "Species"}, "184870": {"name": "Varibaculum cambriense", "rank": "Species"}, "754344": {"name": "Actinobacillus pleuropneumoniae serovar 6", "rank": "Strain"}, "99182": {"name": "Murine leukemia-related retroviruses", "rank": "Species"}, "1388332": {"name": "Staphylococcus aureus M0502", "rank": "Strain"}, "188141": {"name": "Spring beauty latent virus", "rank": "Species"}, "188143": {"name": "Enterovibrio", "rank": "Genus"}, "188144": {"name": "Enterovibrio norvegicus", "rank": "Species"}, "1388331": {"name": "Staphylococcus aureus M0501", "rank": "Strain"}, "1388330": {"name": "Staphylococcus aureus M0499", "rank": "Strain"}, "1388337": {"name": "Staphylococcus aureus M0509", "rank": "Strain"}, "1427204": {"name": "Mycobacterium tuberculosis XTB13-112", "rank": "Strain"}, "1427207": {"name": "Mycobacterium tuberculosis XTB13-115", "rank": "Strain"}, "1169252": {"name": "Enterococcus faecalis EnGen0335", "rank": "Strain"}, "1388334": {"name": "Staphylococcus aureus M0505", "rank": "Strain"}, "944435": {"name": "Burkholderia sp. WSM2230", "rank": "Species"}, "944436": {"name": "Burkholderia sp. WSM2232", "rank": "Species"}, "58116": {"name": "Glycomyces tenuis", "rank": "Species"}, "1169254": {"name": "Enterococcus faecalis EnGen0330", "rank": "Strain"}, "58113": {"name": "Glycomyces", "rank": "Genus"}, "133193": {"name": "Alkalilimnicola", "rank": "Genus"}, "754349": {"name": "Actinobacillus pleuropneumoniae serovar 12", "rank": "Strain"}, "1118964": {"name": "Mycoplasma hyorhinis SK76", "rank": "Strain"}, "1448538": {"name": "Mycobacterium tuberculosis TKK_05SA_0025", "rank": "Strain"}, "1448539": {"name": "Mycobacterium tuberculosis TKK_05SA_0026", "rank": "Strain"}, "1005496": {"name": "Escherichia coli PA15", "rank": "Strain"}, "1005497": {"name": "Escherichia coli PA22", "rank": "Strain"}, "1005491": {"name": "Escherichia coli PA7", "rank": "Strain"}, "1005492": {"name": "Escherichia coli PA8", "rank": "Strain"}, "1005493": {"name": "Escherichia coli PA9", "rank": "Strain"}, "1448530": {"name": "Mycobacterium tuberculosis TKK_05SA_0016", "rank": "Strain"}, "1448531": {"name": "Mycobacterium tuberculosis TKK_05SA_0017", "rank": "Strain"}, "1448532": {"name": "Mycobacterium tuberculosis TKK_05SA_0018", "rank": "Strain"}, "1448533": {"name": "Mycobacterium tuberculosis TKK_05SA_0019", "rank": "Strain"}, "1005498": {"name": "Escherichia coli PA23", "rank": "Strain"}, "1448535": {"name": "Mycobacterium tuberculosis TKK_05SA_0021", "rank": "Strain"}, "1448536": {"name": "Mycobacterium tuberculosis TKK_05SA_0023", "rank": "Strain"}, "1448537": {"name": "Mycobacterium tuberculosis TKK_05SA_0024", "rank": "Strain"}, "1310644": {"name": "Acinetobacter baumannii 1159076", "rank": "Strain"}, "1169117": {"name": "Holospora undulata", "rank": "Species"}, "1124470": {"name": "Vibrio cholerae O1 str. 2009V-1096", "rank": "Strain"}, "1046627": {"name": "Bizionia argentinensis JUB59", "rank": "Strain"}, "1089548": {"name": "Thermicanus aegyptius DSM 12793", "rank": "Strain"}, "1089549": {"name": "Haloglycomyces albus DSM 45210", "rank": "Strain"}, "1089546": {"name": "Actinopolyspora halophila DSM 43834", "rank": "Strain"}, "1089547": {"name": "Rudanella lutea DSM 19387", "rank": "Strain"}, "1089544": {"name": "Amycolatopsis benzoatilytica AK 16/65", "rank": "Strain"}, "1089545": {"name": "Amycolatopsis balhimycina FH 1894", "rank": "Strain"}, "1447520": {"name": "Mycobacterium tuberculosis MD14720", "rank": "Strain"}, "1447521": {"name": "Mycobacterium tuberculosis MD15212", "rank": "Strain"}, "1447526": {"name": "Mycobacterium tuberculosis MD15765", "rank": "Strain"}, "273036": {"name": "Staphylococcus aureus RF122", "rank": "Strain"}, "886715": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. CDC_2010K_0968", "rank": "Strain"}, "128403": {"name": "Scytonema hofmanni PCC 7110", "rank": "Strain"}, "886716": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. CDC_2010K_1444", "rank": "Strain"}, "886717": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. CDC_2010K_1445", "rank": "Strain"}, "935650": {"name": "Psipapillomavirus", "rank": "Genus"}, "1049564": {"name": "Endosymbiont of Tevnia jerichonana (vent Tica)", "rank": "Strain"}, "630749": {"name": "Spongiibacter", "rank": "Genus"}, "403191": {"name": "Haloferax elongans", "rank": "Species"}, "886719": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. CDC_2010K_1565", "rank": "Strain"}, "1428442": {"name": "Oenococcus oeni S22", "rank": "Strain"}, "1051502": {"name": "Bacillus vallismortis DV1-F-3", "rank": "Strain"}, "1051501": {"name": "Bacillus mojavensis RO-H-1 = KCTC 3706", "rank": "Strain"}, "1428441": {"name": "Oenococcus oeni S19", "rank": "Strain"}, "1428444": {"name": "Oenococcus oeni S25", "rank": "Strain"}, "1428445": {"name": "Oenococcus oeni S28", "rank": "Strain"}, "1121099": {"name": "Bacteroides propionicifaciens DSM 19291 = JCM 14649", "rank": "Strain"}, "1121098": {"name": "Bacteroides massiliensis B84634 = Timone 84634 = DSM 17679 = JCM 13223", "rank": "Strain"}, "1121094": {"name": "Bacteroides barnesiae DSM 18169 = JCM 13652", "rank": "Strain"}, "1121097": {"name": "Bacteroides graminisolvens DSM 19988 = JCM 15093", "rank": "Strain"}, "1121096": {"name": "Bacteroides gallinarum DSM 18171 = JCM 13658", "rank": "Strain"}, "1121091": {"name": "Bacillus gelatini DSM 15865", "rank": "Strain"}, "1121090": {"name": "Bacillus fordii DSM 16014 = CIP 108821", "rank": "Strain"}, "1121093": {"name": "Bacillus panaciterrae DSM 19096", "rank": "Strain"}, "1446467": {"name": "Hymenobacter swuensis", "rank": "Species"}, "1120941": {"name": "Actinomyces dentalis DSM 19115", "rank": "Strain"}, "1120942": {"name": "Actinomyces georgiae DSM 6843", "rank": "Strain"}, "1120943": {"name": "Actinomyces gerencseriae DSM 6844", "rank": "Strain"}, "1120944": {"name": "Actinomyces israelii DSM 43320", "rank": "Strain"}, "1120945": {"name": "Actinomyces neuii subsp. neuii DSM 8576", "rank": "Strain"}, "1120946": {"name": "Actinomyces suimastitidis DSM 15538", "rank": "Strain"}, "1120947": {"name": "Actinomyces vaccimaxillae DSM 15804", "rank": "Strain"}, "1120948": {"name": "Actinomycetospora chiangmaiensis DSM 45062", "rank": "Strain"}, "1120949": {"name": "Actinoplanes globisporus DSM 43857", "rank": "Strain"}, "1496722": {"name": "Butyrivibrio sp. AE2005", "rank": "Species"}, "1496721": {"name": "Butyrivibrio sp. AE3003", "rank": "Species"}, "2107": {"name": "Mycoplasma pulmonis", "rank": "Species"}, "1283289": {"name": "Pseudomonas sp. URMO17WK12:I3", "rank": "Species"}, "1390361": {"name": "Ochrobactrum sp. EGD-AQ16", "rank": "Species"}, "1390360": {"name": "Lactococcus lactis subsp. lactis Dephy 1", "rank": "Strain"}, "1047073": {"name": "Cloacimonetes bacterium JGI 0000039-I17", "rank": "Species"}, "1435146": {"name": "Morganella sp. EGD-HP17", "rank": "Species"}, "702443": {"name": "Bacteroides ovatus SD CMC 3f", "rank": "Strain"}, "907268": {"name": "Chlamydia trachomatis RC-L2(s)/3", "rank": "Strain"}, "907269": {"name": "Chlamydia trachomatis RC-F(s)/342", "rank": "Strain"}, "907264": {"name": "Chlamydia trachomatis RC-L2(s)/46", "rank": "Strain"}, "907265": {"name": "Chlamydia trachomatis RC-F(s)/852", "rank": "Strain"}, "907266": {"name": "Chlamydia trachomatis RC-J/943", "rank": "Strain"}, "907267": {"name": "Chlamydia trachomatis RC-J/953", "rank": "Strain"}, "907262": {"name": "Gardnerella vaginalis 41V", "rank": "Strain"}, "907263": {"name": "Chlamydia trachomatis RC-F/69", "rank": "Strain"}, "1047079": {"name": "Cloacimonetes bacterium JGI 0000059-L07", "rank": "Species"}, "412447": {"name": "Criblamydiaceae", "rank": "Family"}, "1433844": {"name": "Prevotella sp. HJM029", "rank": "Species"}, "566972": {"name": "Helicoverpa armigera NPV NNg1", "rank": "Strain"}, "1159488": {"name": "Staphylococcus equorum subsp. equorum Mu2", "rank": "Strain"}, "885272": {"name": "Jonquetella anthropi DSM 22815", "rank": "Strain"}, "1572646": {"name": "Coprobacter sp. 177", "rank": "Species"}, "1276221": {"name": "Spiroplasma diminutum CUAS-1", "rank": "Strain"}, "1276220": {"name": "Spiroplasma taiwanense CT-1", "rank": "Strain"}, "1276227": {"name": "Spiroplasma chrysopicola DF-1", "rank": "Strain"}, "939383": {"name": "Alpha proteobacterium SCGC AAA300-B11", "rank": "Species"}, "1276229": {"name": "Spiroplasma syrphidicola EA-1", "rank": "Strain"}, "1337958": {"name": "Amycolatopsis orientalis DSM 46075", "rank": "Strain"}, "1388359": {"name": "Staphylococcus aureus M0544", "rank": "Strain"}, "1208622": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN001118", "rank": "Strain"}, "1208623": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN001140", "rank": "Strain"}, "1208627": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN001108", "rank": "Strain"}, "1208624": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN001099", "rank": "Strain"}, "1208625": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN001102", "rank": "Strain"}, "1208628": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN001109", "rank": "Strain"}, "1208629": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN001112", "rank": "Strain"}, "10839": {"name": "Bean golden mosaic virus", "rank": "Species"}, "10838": {"name": "Bean dwarf mosaic virus", "rank": "Species"}, "10837": {"name": "Digitaria streak virus", "rank": "Species"}, "10836": {"name": "Sugarcane streak virus", "rank": "Species"}, "10835": {"name": "Tomato mottle virus", "rank": "Species"}, "10834": {"name": "Wheat dwarf virus", "rank": "Species"}, "997825": {"name": "Escherichia coli O157:H7 str. 1125", "rank": "Strain"}, "10831": {"name": "Tomato golden mosaic virus", "rank": "Species"}, "10830": {"name": "Tobacco yellow dwarf virus", "rank": "Species"}, "317577": {"name": "Deinococcus ficus", "rank": "Species"}, "11120": {"name": "Infectious bronchitis virus", "rank": "Strain"}, "11128": {"name": "Bovine coronavirus", "rank": "Strain"}, "649724": {"name": "Clostridium sp. ATCC BAA-442", "rank": "Species"}, "997821": {"name": "Rose rosette virus", "rank": "Species"}, "563180": {"name": "Jatropha yellow mosaic India virus", "rank": "Species"}, "930778": {"name": "Salmonella enterica subsp. enterica serovar Newport str. Levine 1", "rank": "Strain"}, "930779": {"name": "Salmonella enterica subsp. enterica serovar Newport str. Levine 15", "rank": "Strain"}, "1213730": {"name": "Staphylococcus aureus M0877", "rank": "Strain"}, "543539": {"name": "Staphylococcus aureus subsp. aureus CGS01", "rank": "Strain"}, "930776": {"name": "Salmonella enterica subsp. enterica serovar Paratyphi B str. ATCC 51962", "rank": "Strain"}, "930777": {"name": "Salmonella enterica subsp. enterica serovar Paratyphi B str. ATCC 8759", "rank": "Strain"}, "930770": {"name": "Salmonella enterica subsp. enterica serovar Muenchen str. ATCC 8388", "rank": "Strain"}, "930771": {"name": "Salmonella enterica subsp. enterica serovar Braenderup str. ATCC BAA-664", "rank": "Strain"}, "930772": {"name": "Salmonella enterica subsp. enterica serovar Senftenberg str. ATCC 43845", "rank": "Strain"}, "930773": {"name": "Salmonella enterica subsp. enterica serovar Senftenberg str. ATCC 8400", "rank": "Strain"}, "748003": {"name": "Vibrio vulnificus VVyb1(BT3)", "rank": "Strain"}, "203488": {"name": "Dictyoglomaceae", "rank": "Family"}, "680649": {"name": "Staphylococcus aureus subsp. aureus MR1", "rank": "Strain"}, "1242866": {"name": "Thermoplasmatales archaeon SCGC AB-540-F20", "rank": "Species"}, "1242864": {"name": "Cystobacter fuscus DSM 2262", "rank": "Strain"}, "1242865": {"name": "Campylobacter coli CVM N29716", "rank": "Strain"}, "1217415": {"name": "Lysinimicrobium", "rank": "Genus"}, "680646": {"name": "Rothia mucilaginosa DY-18", "rank": "Strain"}, "203487": {"name": "Dictyoglomales", "rank": "Order"}, "203486": {"name": "Dictyoglomia", "rank": "Class"}, "183585": {"name": "Peach mosaic virus", "rank": "Species"}, "997829": {"name": "Porphyromonas sp. KLE 1280", "rank": "Species"}, "1159210": {"name": "Streptococcus pneumoniae SPAR48", "rank": "Strain"}, "997828": {"name": "Peptoclostridium difficile 050-P50-2011", "rank": "Strain"}, "225985": {"name": "Fictibacillus gelatini", "rank": "Species"}, "1232428": {"name": "Megasphaera sp. NP3", "rank": "Species"}, "727977": {"name": "Bat adenovirus TJM", "rank": "Strain"}, "1095675": {"name": "Neisseria meningitidis 65014", "rank": "Strain"}, "1173023": {"name": "Fischerella sp. PCC 9431", "rank": "Species"}, "1173022": {"name": "Crinalium epipsammum PCC 9333", "rank": "Strain"}, "1173021": {"name": "Cyanobacterium PCC 7702", "rank": "Species"}, "1173020": {"name": "Chamaesiphon minutus PCC 6605", "rank": "Strain"}, "1173027": {"name": "Microcoleus sp. PCC 7113", "rank": "Species"}, "1173026": {"name": "Gloeocapsa sp. PCC 7428", "rank": "Species"}, "1173025": {"name": "Geitlerinema sp. PCC 7407", "rank": "Species"}, "1173024": {"name": "Fischerella sp. PCC 9605", "rank": "Species"}, "1173029": {"name": "Spirulina subsalsa PCC 9445", "rank": "Strain"}, "1173028": {"name": "Oscillatoria sp. PCC 10802", "rank": "Species"}, "1232426": {"name": "Collinsella sp. GD3", "rank": "Species"}, "1422049": {"name": "Mycobacterium tuberculosis TB_RSA133", "rank": "Strain"}, "246410": {"name": "Coccidioides immitis RS", "rank": "Strain"}, "375928": {"name": "Natranaerobius", "rank": "Genus"}, "375929": {"name": "Natranaerobius thermophilus", "rank": "Species"}, "658401": {"name": "Cyanophage PSS2", "rank": "Species"}, "323620": {"name": "Shinella", "rank": "Genus"}, "991973": {"name": "Vibrio cholerae HC-56A1", "rank": "Strain"}, "655837": {"name": "Yellow oat-grass mosaic virus", "rank": "Species"}, "1422041": {"name": "Mycobacterium tuberculosis TB_RSA125", "rank": "Strain"}, "589924": {"name": "Ferroglobus placidus DSM 10642", "rank": "Strain"}, "762984": {"name": "Bacteroides clarus YIT 12056", "rank": "Strain"}, "451457": {"name": "Lactococcus chungangensis", "rank": "Species"}, "1403449": {"name": "Streptococcus equi subsp. zooepidemicus CY", "rank": "Strain"}, "765952": {"name": "Parachlamydia acanthamoebae UV-7", "rank": "Strain"}, "762982": {"name": "Paraprevotella xylaniphila YIT 11841", "rank": "Strain"}, "1219077": {"name": "Vibrio azureus NBRC 104587", "rank": "Strain"}, "1219076": {"name": "Vibrio alginolyticus NBRC 15630 = ATCC 17749", "rank": "Strain"}, "1219071": {"name": "Vibrio harveyi NBRC 15634 = ATCC 14126", "rank": "Strain"}, "403978": {"name": "Unclassified Flavobacteriales (miscellaneous)", "rank": "No rank"}, "487213": {"name": "Streptococcus pneumoniae Taiwan19F-14", "rank": "Strain"}, "479834": {"name": "Peptoclostridium difficile QCD-37x79", "rank": "Strain"}, "487214": {"name": "Streptococcus pneumoniae Hungary19A-6", "rank": "Strain"}, "487215": {"name": "Streptococcus pyogenes Alab49", "rank": "Strain"}, "1330536": {"name": "Yersinia pestis S3", "rank": "Strain"}, "1330537": {"name": "Yersinia pestis 24H", "rank": "Strain"}, "1330534": {"name": "Clostridium papyrosolvens C7", "rank": "Strain"}, "1330535": {"name": "Yersinia pestis 113", "rank": "Strain"}, "528348": {"name": "Neisseria gonorrhoeae DGI2", "rank": "Strain"}, "1330531": {"name": "Pseudomonas plecoglossicida NB2011", "rank": "Strain"}, "528345": {"name": "Neisseria gonorrhoeae 1291", "rank": "Strain"}, "991971": {"name": "Vibrio cholerae HC-55B2", "rank": "Strain"}, "528347": {"name": "Neisseria gonorrhoeae DGI18", "rank": "Strain"}, "430710": {"name": "Blueberry latent virus", "rank": "Species"}, "856793": {"name": "Micavibrio aeruginosavorus ARL-13", "rank": "Strain"}, "760829": {"name": "Streptococcus pneumoniae GA47179", "rank": "Strain"}, "760828": {"name": "Streptococcus pneumoniae GA47033", "rank": "Strain"}, "991970": {"name": "Vibrio cholerae HC-55A1", "rank": "Strain"}, "760826": {"name": "Streptococcus pneumoniae GA44500", "rank": "Strain"}, "760825": {"name": "Streptococcus pneumoniae GA44452", "rank": "Strain"}, "760824": {"name": "Streptococcus pneumoniae GA44386", "rank": "Strain"}, "760823": {"name": "Streptococcus pneumoniae GA44378", "rank": "Strain"}, "760822": {"name": "Streptococcus pneumoniae GA44288", "rank": "Strain"}, "760821": {"name": "Streptococcus pneumoniae GA44194", "rank": "Strain"}, "760820": {"name": "Streptococcus pneumoniae GA44128", "rank": "Strain"}, "644609": {"name": "Midway nyavirus", "rank": "Species"}, "1227739": {"name": "Hymenobacter swuensis DY53", "rank": "Strain"}, "458639": {"name": "Bacillus phage 0305phi8-36", "rank": "Species"}, "526413": {"name": "Equine papillomavirus 2", "rank": "Species"}, "360910": {"name": "Bordetella avium 197N", "rank": "Strain"}, "1333846": {"name": "Paenibacillus sp. 1-18", "rank": "Species"}, "1086729": {"name": "Tolypocladium inflatum NRRL8044", "rank": "Strain"}, "1333849": {"name": "Enterobacter cloacae ECR091", "rank": "Strain"}, "1333848": {"name": "Citrobacter freundii CFNIH1", "rank": "Strain"}, "1412606": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20120597", "rank": "Strain"}, "1347420": {"name": "Aeromonas veronii Hm21", "rank": "Strain"}, "244320": {"name": "Escherichia coli O55:H7", "rank": "Strain"}, "200918": {"name": "Thermotogae", "rank": "Phylum"}, "1417035": {"name": "Staphylococcus aureus F60360", "rank": "Strain"}, "1123376": {"name": "Thermodesulfovibrio thiophilus DSM 17215", "rank": "Strain"}, "1123377": {"name": "Thermomonas fusca DSM 15424", "rank": "Strain"}, "1123375": {"name": "Thermodesulfovibrio islandicus DSM 12570", "rank": "Strain"}, "1123372": {"name": "Thermodesulfobacterium hveragerdense DSM 12571", "rank": "Strain"}, "1123373": {"name": "Thermodesulfobacterium thermophilum DSM 1276", "rank": "Strain"}, "1410928": {"name": "Salmonella enterica subsp. enterica serovar Cerro str. CFSAN001690", "rank": "Strain"}, "1123371": {"name": "Thermodesulfatator atlanticus DSM 21156", "rank": "Strain"}, "1410926": {"name": "Salmonella enterica subsp. enterica serovar Cerro str. CFSAN001680", "rank": "Strain"}, "1410927": {"name": "Salmonella enterica subsp. enterica serovar Cerro str. CFSAN001681", "rank": "Strain"}, "1410924": {"name": "Salmonella enterica subsp. enterica serovar Cerro str. CFSAN001673", "rank": "Strain"}, "1410925": {"name": "Salmonella enterica subsp. enterica serovar Cerro str. CFSAN001679", "rank": "Strain"}, "1410922": {"name": "Salmonella enterica subsp. enterica serovar Cerro str. CFSAN001670", "rank": "Strain"}, "1410923": {"name": "Salmonella enterica subsp. enterica serovar Cerro str. CFSAN001671", "rank": "Strain"}, "1410920": {"name": "Salmonella enterica subsp. enterica serovar Cerro str. CFSAN001590", "rank": "Strain"}, "1410921": {"name": "Salmonella enterica subsp. enterica serovar Cerro str. CFSAN001669", "rank": "Strain"}, "76832": {"name": "Myroides odoratimimus", "rank": "Species"}, "1417032": {"name": "Staphylococcus aureus F60349", "rank": "Strain"}, "1413471": {"name": "Staphylococcus aureus C4155", "rank": "Strain"}, "1413470": {"name": "Staphylococcus aureus C1673", "rank": "Strain"}, "1413473": {"name": "Staphylococcus aureus C3452", "rank": "Strain"}, "1413472": {"name": "Staphylococcus aureus C2930", "rank": "Strain"}, "1413475": {"name": "Staphylococcus aureus C2942", "rank": "Strain"}, "1413474": {"name": "Staphylococcus aureus C2928", "rank": "Strain"}, "1413477": {"name": "Staphylococcus aureus C4151", "rank": "Strain"}, "1413476": {"name": "Staphylococcus aureus C3672", "rank": "Strain"}, "1281261": {"name": "Escherichia coli UMEA 3682-1", "rank": "Strain"}, "1281260": {"name": "Escherichia coli UMEA 3671-1", "rank": "Strain"}, "1281263": {"name": "Escherichia coli UMEA 3693-1", "rank": "Strain"}, "1281262": {"name": "Escherichia coli UMEA 3687-1", "rank": "Strain"}, "153265": {"name": "Aequorivita", "rank": "Genus"}, "1281264": {"name": "Escherichia coli UMEA 3694-1", "rank": "Strain"}, "1281267": {"name": "Escherichia coli UMEA 3705-1", "rank": "Strain"}, "1281266": {"name": "Escherichia coli UMEA 3703-1", "rank": "Strain"}, "286604": {"name": "Streptococcus suis 89/1591", "rank": "Strain"}, "1281268": {"name": "Escherichia coli UMEA 3707-1", "rank": "Strain"}, "1137271": {"name": "Saccharomonospora sp. CNQ490", "rank": "Species"}, "291270": {"name": "Sida yellow mosaic virus-China-associated DNA beta", "rank": "Species"}, "291272": {"name": "Candidatus Blochmannia pennsylvanicus str. BPEN", "rank": "Strain"}, "64561": {"name": "Umbelopsis", "rank": "Genus"}, "161879": {"name": "Corynebacterium kroppenstedtii", "rank": "Species"}, "1421338": {"name": "Enterobacter asburiae L1", "rank": "Strain"}, "1215332": {"name": "Trichophyton rubrum CBS 735.88", "rank": "Strain"}, "1510440": {"name": "Bacillus phage Waukesha92", "rank": "Species"}, "991983": {"name": "Vibrio cholerae HC-68A1", "rank": "Strain"}, "991980": {"name": "Vibrio cholerae HC-64A1", "rank": "Strain"}, "1034096": {"name": "Fig badnavirus 1", "rank": "Species"}, "861530": {"name": "Staphylococcus sp. AL1", "rank": "Species"}, "1134510": {"name": "Bartonella koehlerae C-29", "rank": "Strain"}, "991981": {"name": "Vibrio cholerae HC-65A1", "rank": "Strain"}, "1282876": {"name": "Alpha proteobacterium Mf 1.05b.01", "rank": "Species"}, "991984": {"name": "Vibrio cholerae HC-70A1", "rank": "Strain"}, "991985": {"name": "Vibrio cholerae HC-71A1", "rank": "Strain"}, "66849": {"name": "Desulfonatronum lacustre", "rank": "Species"}, "66848": {"name": "Desulfonatronum", "rank": "Genus"}, "1050202": {"name": "Actinopolyspora mortivallis DSM 44261", "rank": "Strain"}, "1453359": {"name": "Candidatus Atelocyanobacterium", "rank": "Genus"}, "420233": {"name": "Sphingobium chinhatense", "rank": "Species"}, "996811": {"name": "Leptospira interrogans serovar Copenhageni str. Fiocruz LV192", "rank": "Strain"}, "996813": {"name": "Leptospira interrogans serovar Copenhageni str. Fiocruz LV204", "rank": "Strain"}, "996812": {"name": "Leptospira interrogans serovar Copenhageni str. Fiocruz LV199", "rank": "Strain"}, "996815": {"name": "Leptospira interrogans serovar Copenhageni str. Fiocruz LV224", "rank": "Strain"}, "996814": {"name": "Leptospira interrogans serovar Copenhageni str. Fiocruz LV212", "rank": "Strain"}, "996817": {"name": "Leptospira interrogans serovar Copenhageni str. Fiocruz LV251", "rank": "Strain"}, "996816": {"name": "Leptospira interrogans serovar Copenhageni str. Fiocruz LV239", "rank": "Strain"}, "996819": {"name": "Leptospira interrogans serovar Copenhageni str. Fiocruz LV2755", "rank": "Strain"}, "996818": {"name": "Leptospira interrogans serovar Copenhageni str. Fiocruz LV130", "rank": "Strain"}, "1158546": {"name": "Enterococcus faecalis EnGen0233", "rank": "Strain"}, "1397900": {"name": "Mycobacterium tuberculosis TKK_03_0034", "rank": "Strain"}, "1397901": {"name": "Mycobacterium tuberculosis TKK_03_0036", "rank": "Strain"}, "1397902": {"name": "Mycobacterium tuberculosis TKK_03_0043", "rank": "Strain"}, "1397903": {"name": "Mycobacterium tuberculosis TKK_03_0045", "rank": "Strain"}, "1397904": {"name": "Mycobacterium tuberculosis TKK_03_0078", "rank": "Strain"}, "1397905": {"name": "Mycobacterium tuberculosis TKK_03_0081", "rank": "Strain"}, "1397906": {"name": "Mycobacterium tuberculosis TKK_03_0082", "rank": "Strain"}, "1397907": {"name": "Mycobacterium tuberculosis TKK_04_0001", "rank": "Strain"}, "1397908": {"name": "Mycobacterium tuberculosis TKK_04_0002", "rank": "Strain"}, "1397909": {"name": "Mycobacterium tuberculosis TKK_04_0003", "rank": "Strain"}, "1158548": {"name": "Enterococcus faecium EnGen0259", "rank": "Strain"}, "1145129": {"name": "Neisseria meningitidis 63023", "rank": "Strain"}, "1145128": {"name": "Neisseria meningitidis 97018", "rank": "Strain"}, "1145127": {"name": "Neisseria meningitidis 69100", "rank": "Strain"}, "1145126": {"name": "Neisseria meningitidis 75689", "rank": "Strain"}, "1145125": {"name": "Neisseria meningitidis 75643", "rank": "Strain"}, "1145124": {"name": "Neisseria meningitidis 94018", "rank": "Strain"}, "1145123": {"name": "Neisseria meningitidis 96060", "rank": "Strain"}, "1145122": {"name": "Neisseria meningitidis 2000080", "rank": "Strain"}, "1145121": {"name": "Neisseria meningitidis 70021", "rank": "Strain"}, "1145120": {"name": "Neisseria meningitidis 69176", "rank": "Strain"}, "1211480": {"name": "Persimmon virus A", "rank": "Species"}, "1211481": {"name": "Persimmon latent virus", "rank": "Species"}, "360104": {"name": "Campylobacter concisus 13826", "rank": "Strain"}, "360105": {"name": "Campylobacter curvus 525.92", "rank": "Strain"}, "360106": {"name": "Campylobacter fetus subsp. fetus 82-40", "rank": "Strain"}, "360107": {"name": "Campylobacter hominis ATCC BAA-381", "rank": "Strain"}, "360102": {"name": "Yersinia pestis Antiqua", "rank": "Strain"}, "1354141": {"name": "Mycobacterium africanum MAL020136", "rank": "Strain"}, "1354140": {"name": "Mycobacterium tuberculosis MAL020132", "rank": "Strain"}, "1354143": {"name": "Mycobacterium tuberculosis MAL010078", "rank": "Strain"}, "1354142": {"name": "Mycobacterium tuberculosis MAL020174", "rank": "Strain"}, "360108": {"name": "Campylobacter jejuni subsp. jejuni 260.94", "rank": "Strain"}, "360109": {"name": "Campylobacter jejuni subsp. doylei 269.97", "rank": "Strain"}, "1354147": {"name": "Mycobacterium tuberculosis MAL010088", "rank": "Strain"}, "1196083": {"name": "Snodgrassella alvi", "rank": "Species"}, "68336": {"name": "Bacteroidetes/Chlorobi group", "rank": "Superphylum"}, "713636": {"name": "Gallionellales", "rank": "Order"}, "1000565": {"name": "Methyloversatilis universalis FAM5", "rank": "Strain"}, "1000562": {"name": "Streptococcus phocae C-4", "rank": "Strain"}, "271431": {"name": "Arthrobacter castelli", "rank": "Species"}, "269797": {"name": "Methanosarcina barkeri str. Fusaro", "rank": "Strain"}, "1000569": {"name": "Megasphaera sp. UPII 135-E", "rank": "Species"}, "1000568": {"name": "Megasphaera sp. UPII 199-6", "rank": "Species"}, "1151430": {"name": "Peptoclostridium difficile P78", "rank": "Strain"}, "1151431": {"name": "Peptoclostridium difficile P64", "rank": "Strain"}, "1151432": {"name": "Peptoclostridium difficile P68", "rank": "Strain"}, "1151433": {"name": "Peptoclostridium difficile P69", "rank": "Strain"}, "1511809": {"name": "Betapartitivirus", "rank": "Genus"}, "1511808": {"name": "Alphapartitivirus", "rank": "Genus"}, "1151436": {"name": "Peptoclostridium difficile P71", "rank": "Strain"}, "1151437": {"name": "Peptoclostridium difficile P73", "rank": "Strain"}, "1511805": {"name": "Rosavirus A", "rank": "Species"}, "1511804": {"name": "Rosavirus", "rank": "Genus"}, "1511807": {"name": "Rosavirus A2", "rank": "Subspecies"}, "1511803": {"name": "Passerivirus A", "rank": "Species"}, "1511802": {"name": "Passerivirus", "rank": "Genus"}, "1531959": {"name": "Desulfotomaculum sp. BICA1-6", "rank": "Species"}, "1531958": {"name": "Desulfosporosinus sp. BICA1-9", "rank": "Species"}, "1418379": {"name": "Staphylococcus aureus F34824", "rank": "Strain"}, "1418378": {"name": "Staphylococcus aureus F31078", "rank": "Strain"}, "1418373": {"name": "Staphylococcus aureus W62354", "rank": "Strain"}, "1418372": {"name": "Staphylococcus aureus W62344", "rank": "Strain"}, "1418371": {"name": "Staphylococcus aureus W55536", "rank": "Strain"}, "1418370": {"name": "Staphylococcus aureus W52298", "rank": "Strain"}, "1418377": {"name": "Staphylococcus aureus F29214", "rank": "Strain"}, "1418376": {"name": "Staphylococcus aureus F27233", "rank": "Strain"}, "1418375": {"name": "Staphylococcus aureus F23585", "rank": "Strain"}, "1418374": {"name": "Staphylococcus aureus F16533", "rank": "Strain"}, "1394600": {"name": "Vibrio parahaemolyticus S055", "rank": "Strain"}, "1529605": {"name": "Cladosporium cladosporioides virus 1", "rank": "Species"}, "712037": {"name": "Japanese eel endothelial cells-infecting virus", "rank": "Species"}, "7": {"name": "Azorhizobium caulinodans", "rank": "Species"}, "1144253": {"name": "Pontibacter sp. BAB1700", "rank": "Species"}, "69219": {"name": "Enterobacter cloacae subsp. dissolvens", "rank": "Subspecies"}, "69218": {"name": "Enterobacter cancerogenus", "rank": "Species"}, "1260129": {"name": "Streptococcus iniae KCTC 11634BP", "rank": "Strain"}, "991778": {"name": "Rhodopirellula baltica WH47", "rank": "Strain"}, "1050617": {"name": "Escherichia coli UMNF18", "rank": "Strain"}, "116598": {"name": "Wolbachia endosymbiont of Diaphorina citri", "rank": "Species"}, "756954": {"name": "VHML-like phages", "rank": "No rank"}, "559561": {"name": "Aureobasidium namibiae", "rank": "Species"}, "1354496": {"name": "Ralstonia phage RSS20", "rank": "Species"}, "1304275": {"name": "Salinisphaera hydrothermalis C41B8", "rank": "Strain"}, "1304279": {"name": "Mycobacterium tuberculosis str. Haarlem/NITR202", "rank": "Strain"}, "931627": {"name": "Mycobacterium rhodesiae JS60", "rank": "Strain"}, "931626": {"name": "Acetobacterium woodii DSM 1030", "rank": "Strain"}, "1227276": {"name": "Prevotella sp. F0091", "rank": "Species"}, "1227272": {"name": "Porphyromonas sp. oral taxon 278 str. W7784", "rank": "Strain"}, "1227271": {"name": "Porphyromonas gingivalis F0570", "rank": "Strain"}, "1324587": {"name": "Yersinia pseudotuberculosis B-7195", "rank": "Strain"}, "1292035": {"name": "Clostridium sordellii VPI 9048", "rank": "Strain"}, "105850": {"name": "Acidilobus", "rank": "Genus"}, "251535": {"name": "Candidatus Blochmannia vafer", "rank": "Species"}, "1236509": {"name": "Prevotella dentasini JCM 15908", "rank": "Strain"}, "1214168": {"name": "Streptococcus suis 88-1861", "rank": "Strain"}, "1214169": {"name": "Streptococcus suis 89-2479", "rank": "Strain"}, "1214164": {"name": "Streptococcus suis 42A", "rank": "Strain"}, "1214165": {"name": "Streptococcus suis R735", "rank": "Strain"}, "1214166": {"name": "Streptococcus suis 86-5192", "rank": "Strain"}, "1214167": {"name": "Streptococcus suis 14A", "rank": "Strain"}, "1214160": {"name": "Streptococcus suis NCTC 10446", "rank": "Strain"}, "1214161": {"name": "Streptococcus suis 2726", "rank": "Strain"}, "1214162": {"name": "Streptococcus suis 93A", "rank": "Strain"}, "1214163": {"name": "Streptococcus suis NT77", "rank": "Strain"}, "1297742": {"name": "Myxococcus sp. (contaminant ex DSM 436)", "rank": "Species"}, "216851": {"name": "Faecalibacterium", "rank": "Genus"}, "979199": {"name": "Staphylococcus epidermidis NIHLM095", "rank": "Strain"}, "473772": {"name": "Unclassified Oscillospiraceae", "rank": "No rank"}, "1448738": {"name": "Mycobacterium tuberculosis M1976", "rank": "Strain"}, "1448739": {"name": "Mycobacterium tuberculosis M1978", "rank": "Strain"}, "1448736": {"name": "Mycobacterium tuberculosis M1967", "rank": "Strain"}, "1448737": {"name": "Mycobacterium tuberculosis M1973", "rank": "Strain"}, "1448734": {"name": "Mycobacterium tuberculosis M1959", "rank": "Strain"}, "1448735": {"name": "Mycobacterium tuberculosis M1961", "rank": "Strain"}, "1448732": {"name": "Mycobacterium tuberculosis M1955", "rank": "Strain"}, "1448733": {"name": "Mycobacterium tuberculosis M1956", "rank": "Strain"}, "1448730": {"name": "Mycobacterium tuberculosis M1932", "rank": "Strain"}, "1448731": {"name": "Mycobacterium tuberculosis M1948", "rank": "Strain"}, "477641": {"name": "Modestobacter marinus", "rank": "Species"}, "83839": {"name": "Pepper leaf curl virus", "rank": "Species"}, "1093790": {"name": "Vibrio cholerae H1", "rank": "Strain"}, "1388355": {"name": "Staphylococcus aureus M0540", "rank": "Strain"}, "548682": {"name": "Alloherpesviridae", "rank": "Family"}, "548681": {"name": "Herpesvirales", "rank": "Order"}, "1388356": {"name": "Staphylococcus aureus M0541", "rank": "Strain"}, "1388351": {"name": "Staphylococcus aureus M0533", "rank": "Strain"}, "548686": {"name": "Ostreavirus", "rank": "Genus"}, "1388353": {"name": "Staphylococcus aureus M0535", "rank": "Strain"}, "1388352": {"name": "Staphylococcus aureus M0534", "rank": "Strain"}, "1427223": {"name": "Mycobacterium tuberculosis XTB13-133", "rank": "Strain"}, "1427222": {"name": "Mycobacterium tuberculosis XTB13-132", "rank": "Strain"}, "548689": {"name": "Proboscivirus", "rank": "Genus"}, "548688": {"name": "Percavirus", "rank": "Genus"}, "291590": {"name": "Erethizon dorsatum papillomavirus 1", "rank": "Strain"}, "1388358": {"name": "Staphylococcus aureus M0543", "rank": "Strain"}, "1427225": {"name": "Mycobacterium tuberculosis XTB13-135", "rank": "Strain"}, "1427224": {"name": "Mycobacterium tuberculosis XTB13-134", "rank": "Strain"}, "1449976": {"name": "Kutzneria albida DSM 43870", "rank": "Strain"}, "100716": {"name": "Chloroherpeton thalassium", "rank": "Species"}, "421628": {"name": "Ectothiorhodospira haloalkaliphila", "rank": "Species"}, "1367477": {"name": "Bacillus infantis NRRL B-14911", "rank": "Strain"}, "484508": {"name": "Ornithinibacillus", "rank": "Genus"}, "1367479": {"name": "Streptococcus pneumoniae ICE59", "rank": "Strain"}, "1367478": {"name": "Streptococcus pneumoniae ICE44", "rank": "Strain"}, "162426": {"name": "Microbacterium hominis", "rank": "Species"}, "162425": {"name": "Aspergillus nidulans", "rank": "Species"}, "112904": {"name": "Enterococcus villorum", "rank": "Species"}, "1599": {"name": "Lactobacillus sakei", "rank": "Species"}, "1598": {"name": "Lactobacillus reuteri", "rank": "Species"}, "1051985": {"name": "Neisseria weaveri LMG 5135", "rank": "Strain"}, "1596": {"name": "Lactobacillus gasseri", "rank": "Species"}, "1590": {"name": "Lactobacillus plantarum", "rank": "Species"}, "1190620": {"name": "Atopobium sp. ICM42b", "rank": "Species"}, "1190621": {"name": "Olsenella uli MSTE5", "rank": "Strain"}, "1206743": {"name": "Nocardia veterana NBRC 100344", "rank": "Strain"}, "1206742": {"name": "Nocardia vinacea NBRC 16497", "rank": "Strain"}, "1206741": {"name": "Nocardia concava NBRC 100430", "rank": "Strain"}, "1206740": {"name": "Nocardia thailandica NBRC 100428", "rank": "Strain"}, "1137135": {"name": "Escherichia coli O157:H43 str. T22", "rank": "Strain"}, "1137134": {"name": "Lactococcus lactis subsp. lactis A12", "rank": "Strain"}, "1206745": {"name": "Helicobacter cinaedi ATCC BAA-847", "rank": "Strain"}, "1206744": {"name": "Nocardia transvalensis NBRC 15921", "rank": "Strain"}, "1137138": {"name": "Pleurotus ostreatus PC15", "rank": "Strain"}, "675806": {"name": "Vibrio mimicus MB451", "rank": "Strain"}, "675807": {"name": "Vibrio cholerae RC27", "rank": "Strain"}, "1310702": {"name": "Acinetobacter baumannii 831240", "rank": "Strain"}, "675808": {"name": "Vibrio cholerae INDRE 91/1", "rank": "Strain"}, "675809": {"name": "Vibrio cholerae CT 5369-93", "rank": "Strain"}, "1310700": {"name": "Acinetobacter baumannii 1598530", "rank": "Strain"}, "104102": {"name": "Acetobacter tropicalis", "rank": "Species"}, "1229793": {"name": "Propionibacterium phage ATCC29399B_T", "rank": "Species"}, "1535326": {"name": "Candida", "rank": "Genus"}, "48936": {"name": "Novosphingobium subterraneum", "rank": "Species"}, "48935": {"name": "Novosphingobium aromaticivorans", "rank": "Species"}, "1535325": {"name": "Candida/Lodderomyces clade", "rank": "No rank"}, "1124971": {"name": "Salmonella enterica subsp. enterica serovar Typhimurium str. 34502", "rank": "Strain"}, "1124970": {"name": "Salmonella enterica subsp. enterica serovar Typhimurium str. 86-0368", "rank": "Strain"}, "1124973": {"name": "Salmonella enterica subsp. enterica serovar Typhimurium str. 36618", "rank": "Strain"}, "1124972": {"name": "Salmonella enterica subsp. enterica serovar Typhimurium str. 35423", "rank": "Strain"}, "278955": {"name": "Unclassified Opitutaceae", "rank": "No rank"}, "1158524": {"name": "Staphylococcus aureus M0351", "rank": "Strain"}, "278957": {"name": "Diplosphaera colitermitum TAV2", "rank": "Strain"}, "278956": {"name": "Opitutaceae bacterium TAV1", "rank": "Species"}, "1158521": {"name": "Staphylococcus aureus M0306", "rank": "Strain"}, "1158520": {"name": "Staphylococcus aureus M0280", "rank": "Strain"}, "933085": {"name": "Legionella pneumophila subsp. pneumophila ATCC 33215", "rank": "Strain"}, "933084": {"name": "Jaapia argillacea MUCL 33604", "rank": "Strain"}, "1158529": {"name": "Staphylococcus aureus M0396", "rank": "Strain"}, "1158528": {"name": "Staphylococcus aureus M0375", "rank": "Strain"}, "1379702": {"name": "Methanobacterium sp. MB1", "rank": "Species"}, "1379701": {"name": "Sphingomonas sp. FUKUSWIS1", "rank": "Species"}, "1285588": {"name": "Bidensovirus", "rank": "Genus"}, "1285589": {"name": "Bombyx mori bidensovirus", "rank": "Species"}, "1051362": {"name": "Vibrio cholerae HC-41B1", "rank": "Strain"}, "1285586": {"name": "Lysinibacillus sphaericus OT4b.31", "rank": "Strain"}, "1285587": {"name": "Bidnaviridae", "rank": "Family"}, "1285581": {"name": "Pseudomonas aeruginosa PA21_ST175", "rank": "Strain"}, "1285582": {"name": "Lactobacillus sakei subsp. sakei LS25", "rank": "Strain"}, "1285583": {"name": "Corynebacterium casei LMG S-19264", "rank": "Strain"}, "47770": {"name": "Lactobacillus crispatus", "rank": "Species"}, "545774": {"name": "Streptococcus gallolyticus subsp. gallolyticus TX20005", "rank": "Strain"}, "545776": {"name": "Treponema paraluiscuniculi Cuniculi A", "rank": "Strain"}, "190485": {"name": "Xanthomonas campestris pv. campestris str. ATCC 33913", "rank": "Strain"}, "1229790": {"name": "Propionibacterium phage P100_A", "rank": "Species"}, "640293": {"name": "Candidate division NC10", "rank": "No rank"}, "1029756": {"name": "Hyphomicrobium nitrativorans NL23", "rank": "Strain"}, "1177926": {"name": "Bacillus sp. M 2-6", "rank": "Species"}, "911237": {"name": "Mycobacterium tuberculosis CDC1551A", "rank": "Strain"}, "908290": {"name": "Methylobacterium mesophilicum SR1.6/6", "rank": "Strain"}, "333930": {"name": "Gammapapillomavirus 4", "rank": "Species"}, "696069": {"name": "Bat adenovirus 2", "rank": "Strain"}, "435646": {"name": "Radish leaf curl virus", "rank": "Species"}, "753085": {"name": "Synechococcus phage S-CBS3", "rank": "Species"}, "753084": {"name": "Synechococcus phage S-CBS2", "rank": "Species"}, "1149757": {"name": "Saccharomyces cerevisiae M3707", "rank": "Strain"}, "1177928": {"name": "Thalassospira profundimaris WP0211", "rank": "Strain"}, "641148": {"name": "Neisseria sp. oral taxon 014", "rank": "Species"}, "641149": {"name": "Neisseria sp. oral taxon 014 str. F0314", "rank": "Strain"}, "641146": {"name": "Scardovia inopinata F0304", "rank": "Strain"}, "641147": {"name": "Simonsiella muelleri ATCC 29453", "rank": "Strain"}, "641144": {"name": "Parascardovia denticolens F0305", "rank": "Strain"}, "459520": {"name": "Neptuniibacter", "rank": "Genus"}, "459527": {"name": "Saccharibacillus kuerlensis", "rank": "Species"}, "641143": {"name": "Capnocytophaga granulosa ATCC 51502", "rank": "Strain"}, "641140": {"name": "Brucella abortus str. 2308 A", "rank": "Strain"}, "5076": {"name": "Penicillium chrysogenum", "rank": "Species"}, "393124": {"name": "Listeria monocytogenes FSL N3-165", "rank": "Strain"}, "5075": {"name": "Penicillium camemberti", "rank": "Species"}, "41431": {"name": "Cyanothece sp. PCC 8801", "rank": "Species"}, "5073": {"name": "Penicillium", "rank": "Genus"}, "1041139": {"name": "Rhizobium giardinii bv. giardinii H152", "rank": "Strain"}, "1041138": {"name": "Rhizobium gallicum bv. gallicum R602sp", "rank": "Strain"}, "12145": {"name": "Tomato bushy stunt virus", "rank": "Species"}, "12144": {"name": "Cymbidium ringspot virus", "rank": "Species"}, "46429": {"name": "Sphingobium chlorophenolicum", "rank": "Species"}, "12141": {"name": "Tombusvirus", "rank": "Genus"}, "266009": {"name": "Methylovorus glucosotrophus", "rank": "Species"}, "12143": {"name": "Cucumber necrosis virus", "rank": "Species"}, "12142": {"name": "Artichoke mottled crinkle virus", "rank": "Species"}, "1105116": {"name": "Streptococcus pneumoniae GA56113", "rank": "Strain"}, "1105117": {"name": "Streptococcus pneumoniae GA56348", "rank": "Strain"}, "1105114": {"name": "Rickettsia montanensis str. OSU 85-930", "rank": "Strain"}, "1105115": {"name": "Streptococcus pneumoniae GA54354", "rank": "Strain"}, "1105112": {"name": "Rickettsia massiliae str. AZT80", "rank": "Strain"}, "1105113": {"name": "Rickettsia rhipicephali str. 3-7-female6-CWPP", "rank": "Strain"}, "1105110": {"name": "Rickettsia australis str. Cutlack", "rank": "Strain"}, "1105111": {"name": "Candidatus Rickettsia amblyommii str. GAT-30V", "rank": "Strain"}, "1105118": {"name": "Streptococcus pneumoniae GA58581", "rank": "Strain"}, "1105119": {"name": "Streptococcus pneumoniae GA60080", "rank": "Strain"}, "984892": {"name": "Staphylococcus pseudintermedius ED99", "rank": "Strain"}, "1422318": {"name": "Staphylococcus aureus DAR5858", "rank": "Strain"}, "1422319": {"name": "Staphylococcus aureus DAR5857", "rank": "Strain"}, "1422314": {"name": "Staphylococcus aureus DAR5863", "rank": "Strain"}, "1422315": {"name": "Staphylococcus aureus DAR5862", "rank": "Strain"}, "1422316": {"name": "Staphylococcus aureus DAR5861", "rank": "Strain"}, "1422317": {"name": "Staphylococcus aureus DAR5859", "rank": "Strain"}, "1422310": {"name": "Staphylococcus aureus DAR5868", "rank": "Strain"}, "1422311": {"name": "Staphylococcus aureus DAR5867", "rank": "Strain"}, "1422312": {"name": "Staphylococcus aureus DAR5865", "rank": "Strain"}, "1422313": {"name": "Staphylococcus aureus DAR5864", "rank": "Strain"}, "338969": {"name": "Rhodoferax ferrireducens T118", "rank": "Strain"}, "838561": {"name": "Spiroplasma mirum ATCC 29335", "rank": "Strain"}, "338963": {"name": "Pelobacter carbinolicus DSM 2380", "rank": "Strain"}, "338966": {"name": "Pelobacter propionicus DSM 2379", "rank": "Strain"}, "1310670": {"name": "Acinetobacter baumannii 907131", "rank": "Strain"}, "1151416": {"name": "Peptoclostridium difficile P38", "rank": "Strain"}, "92652": {"name": "Shrimp white spot syndrome virus", "rank": "Strain"}, "272559": {"name": "Bacteroides fragilis NCTC 9343", "rank": "Strain"}, "272558": {"name": "Bacillus halodurans C-125", "rank": "Strain"}, "1334187": {"name": "Haemophilus influenzae KR494", "rank": "Strain"}, "449447": {"name": "Microcystis aeruginosa NIES-843", "rank": "Strain"}, "272557": {"name": "Aeropyrum pernix K1", "rank": "Strain"}, "272556": {"name": "Aggregatibacter actinomycetemcomitans HK1651", "rank": "Strain"}, "1160721": {"name": "Ruminococcus bicirculans", "rank": "Species"}, "1276920": {"name": "Arthrobacter gangotriensis Lz1y", "rank": "Strain"}, "1437594": {"name": "Bifidobacterium asteroides DSM 20089", "rank": "Strain"}, "504553": {"name": "Propionibacterium phage PAS50", "rank": "Species"}, "226504": {"name": "Algoriphagus mannitolivorans", "rank": "Species"}, "456876": {"name": "Streptococcus plurextorum", "rank": "Species"}, "1096769": {"name": "Candidatus Pelagibacter ubique HIMB083", "rank": "Strain"}, "213422": {"name": "Geobacteraceae", "rank": "Family"}, "213423": {"name": "Pelobacteraceae", "rank": "Family"}, "213421": {"name": "Desulfuromonadaceae", "rank": "Family"}, "74320": {"name": "Buzura suppressaria nucleopolyhedrovirus", "rank": "Species"}, "388919": {"name": "Streptococcus sanguinis SK36", "rank": "Strain"}, "932069": {"name": "Sida mosaic Bolivia virus 1", "rank": "Species"}, "58095": {"name": "Salmonella enterica subsp. enterica serovar Agona", "rank": "Strain"}, "58097": {"name": "Salmonella enterica subsp. enterica serovar Bovismorbificans", "rank": "Strain"}, "58096": {"name": "Salmonella enterica subsp. enterica serovar Bareilly", "rank": "Strain"}, "68202": {"name": "Streptomyces fulvissimus", "rank": "Species"}, "68201": {"name": "Streptomyces floridae", "rank": "Species"}, "68204": {"name": "Streptomyces gancidicus", "rank": "Species"}, "390989": {"name": "Actinocatenispora sera", "rank": "Species"}, "12881": {"name": "Tobacco necrosis satellite virus", "rank": "Species"}, "382464": {"name": "Verrucomicrobiae bacterium DG1235", "rank": "Species"}, "1161401": {"name": "Maricaulis sp. JL2009", "rank": "Species"}, "1367492": {"name": "Salmonella enterica subsp. enterica serovar Abortusovis str. SS44", "rank": "Strain"}, "1161409": {"name": "Bifidobacterium sp. MSTE12", "rank": "Species"}, "310514": {"name": "Prevotella multisaccharivorax", "rank": "Species"}, "565648": {"name": "Enterococcus faecalis JH1", "rank": "Strain"}, "565649": {"name": "Enterococcus faecalis Fly1", "rank": "Strain"}, "565646": {"name": "Enterococcus faecalis HIP11704", "rank": "Strain"}, "565647": {"name": "Enterococcus faecalis E1Sol", "rank": "Strain"}, "565644": {"name": "Enterococcus faecalis CH188", "rank": "Strain"}, "565645": {"name": "Enterococcus faecalis Merz96", "rank": "Strain"}, "565642": {"name": "Enterococcus faecalis ATCC 4200", "rank": "Strain"}, "565643": {"name": "Enterococcus faecalis DS5", "rank": "Strain"}, "565640": {"name": "Enterococcus faecalis T11", "rank": "Strain"}, "565641": {"name": "Enterococcus faecalis X98", "rank": "Strain"}, "1053687": {"name": "Neisseria meningitidis NM220", "rank": "Strain"}, "1343158": {"name": "Saccharibacter sp. AM169", "rank": "Species"}, "75697": {"name": "Castellaniella defragrans", "rank": "Species"}, "1343157": {"name": "Spathaspora arborariae UFMG-19.1A", "rank": "Strain"}, "1423577": {"name": "Mycobacterium tuberculosis BTB13-276", "rank": "Strain"}, "419610": {"name": "Methylobacterium extorquens PA1", "rank": "Strain"}, "340435": {"name": "Microcystis aeruginosa phage Ma-LMM01", "rank": "Species"}, "1321815": {"name": "Treponema lecithinolyticum ATCC 700332", "rank": "Strain"}, "92490": {"name": "Erwinia toletana", "rank": "Species"}, "12167": {"name": "Potato virus M", "rank": "Species"}, "1446509": {"name": "Escherichia coli O111:H8 str. 2009EL-2169", "rank": "Strain"}, "1446508": {"name": "Escherichia coli O111:H8 str. 2009C-4126", "rank": "Strain"}, "12166": {"name": "Poplar mosaic virus", "rank": "Species"}, "1446503": {"name": "Escherichia coli O103:H2 str. 2009C-3279", "rank": "Strain"}, "1446502": {"name": "Escherichia coli O103:H11 str. 2010C-3214", "rank": "Strain"}, "1446501": {"name": "Escherichia coli O103:H11 str. 04-3023", "rank": "Strain"}, "1446500": {"name": "Escherichia coli O26:H11 str. 05-3646", "rank": "Strain"}, "1446507": {"name": "Escherichia coli O104:H4 str. 2011EL-1675A", "rank": "Strain"}, "1446506": {"name": "Escherichia coli O103:H25 str. 2010C-4529", "rank": "Strain"}, "1446505": {"name": "Escherichia coli O103:H2 str. 2011C-3750", "rank": "Strain"}, "1446504": {"name": "Escherichia coli O103:H2 str. 2010C-4433", "rank": "Strain"}, "12163": {"name": "Carlavirus", "rank": "Genus"}, "649996": {"name": "Tomato yellow leaf distortion virus", "rank": "Species"}, "12161": {"name": "Beet yellows virus", "rank": "Species"}, "229030": {"name": "Cactus mild mottle virus", "rank": "Species"}, "186794": {"name": "P22likevirus", "rank": "Genus"}, "216944": {"name": "Spiroplasma sabaudiense", "rank": "Species"}, "10398": {"name": "Ovine herpesvirus 2", "rank": "Species"}, "10397": {"name": "Tupaiid herpesvirus 1", "rank": "Species"}, "10390": {"name": "Gallid herpesvirus 2", "rank": "Species"}, "1163715": {"name": "Gyrovirus GyV3", "rank": "Species"}, "1287089": {"name": "Mesorhizobium sp. L103C131B0", "rank": "Species"}, "1410738": {"name": "Staphylococcus aureus M20676", "rank": "Strain"}, "1163710": {"name": "Cronobacter condimenti", "rank": "Species"}, "1287086": {"name": "Mesorhizobium sp. L103C120A0", "rank": "Species"}, "1287085": {"name": "Mesorhizobium sp. L103C119B0", "rank": "Species"}, "686602": {"name": "Unassigned Podoviridae", "rank": "No rank"}, "686603": {"name": "Unassigned Betaherpesvirinae", "rank": "No rank"}, "686606": {"name": "Unassigned Rhabdoviridae", "rank": "No rank"}, "686609": {"name": "Unassigned Nanoviridae", "rank": "No rank"}, "208596": {"name": "Carnobacterium sp. 17-4", "rank": "Species"}, "440497": {"name": "Lactobacillus jensenii 1153", "rank": "Strain"}, "440496": {"name": "Lactobacillus crispatus CTV-05", "rank": "Strain"}, "541095": {"name": "Corynebacterium lubricantis", "rank": "Species"}, "886559": {"name": "Geobacillus sp. WSUCF1", "rank": "Species"}, "1501348": {"name": "Amoebophilaceae", "rank": "Family"}, "1231626": {"name": "Cardinium endosymbiont cEper1 of Encarsia pergandiella", "rank": "Strain"}, "1380368": {"name": "Acinetobacter sp. UNC436CL71CviS28", "rank": "Species"}, "1231622": {"name": "Unassigned Picornavirales", "rank": "No rank"}, "109327": {"name": "Anaerovorax odorimutans", "rank": "Species"}, "109326": {"name": "Anaerovorax", "rank": "Genus"}, "109328": {"name": "Leptotrichia trevisanii", "rank": "Species"}, "1445858": {"name": "Enterococcus phage IME-EFm1", "rank": "Species"}, "1445859": {"name": "Shewanella phage Spp001", "rank": "Species"}, "150022": {"name": "Finegoldia", "rank": "Genus"}, "28289": {"name": "Cydia pomonella granulovirus", "rank": "Species"}, "28288": {"name": "Hyphantria cunea nucleopolyhedrovirus", "rank": "Species"}, "1159056": {"name": "Helicobacter pylori GAM83T", "rank": "Strain"}, "33945": {"name": "Enterococcus avium", "rank": "Species"}, "1159054": {"name": "Helicobacter pylori GAM80Ai", "rank": "Strain"}, "1287105": {"name": "Mesorhizobium sp. L2C066B000", "rank": "Species"}, "33940": {"name": "Geobacillus thermodenitrificans", "rank": "Species"}, "1159053": {"name": "Helicobacter pylori GAM71Ai", "rank": "Strain"}, "33942": {"name": "Brevibacillus thermoruber", "rank": "Species"}, "33943": {"name": "Kyrpidia tusciae", "rank": "Species"}, "10979": {"name": "Aquareovirus", "rank": "Genus"}, "1444079": {"name": "Escherichia coli 1-182-04_S1_C2", "rank": "Strain"}, "1444078": {"name": "Escherichia coli 1-176-05_S1_C2", "rank": "Strain"}, "1444075": {"name": "Escherichia coli 7-233-03_S1_C2", "rank": "Strain"}, "1444074": {"name": "Escherichia coli 2-474-04_S1_C2", "rank": "Strain"}, "1444077": {"name": "Escherichia coli 1-110-08_S1_C2", "rank": "Strain"}, "1444076": {"name": "Escherichia coli 8-415-05_S1_C2", "rank": "Strain"}, "1444071": {"name": "Escherichia coli 2-316-03_S1_C2", "rank": "Strain"}, "1444070": {"name": "Escherichia coli 2-222-05_S1_C2", "rank": "Strain"}, "1444073": {"name": "Escherichia coli 2-460-02_S1_C2", "rank": "Strain"}, "1444072": {"name": "Escherichia coli 2-427-07_S1_C2", "rank": "Strain"}, "29482": {"name": "Salmonella enterica subsp. enterica serovar Abony", "rank": "Strain"}, "29483": {"name": "Yersinia aldovae", "rank": "Species"}, "29486": {"name": "Yersinia ruckeri", "rank": "Species"}, "29487": {"name": "Photorhabdus", "rank": "Genus"}, "29484": {"name": "Yersinia frederiksenii", "rank": "Species"}, "29485": {"name": "Yersinia rohdei", "rank": "Species"}, "29488": {"name": "Photorhabdus luminescens", "rank": "Species"}, "29489": {"name": "Aeromonas enteropelogenes", "rank": "Species"}, "549779": {"name": "Mimiviridae", "rank": "Family"}, "1123296": {"name": "Stenoxybacter acetivorans DSM 19021", "rank": "Strain"}, "688353": {"name": "Lichtheimia", "rank": "Genus"}, "1225522": {"name": "Salmonella enterica subsp. enterica serovar Gallinarum/pullorum str. CDC1983-67", "rank": "Strain"}, "440534": {"name": "Salmonella enterica subsp. enterica serovar 4,5,12:i:- str. CVM23701", "rank": "Strain"}, "1209364": {"name": "Bacillus sp. WBUNB004", "rank": "Species"}, "1525173": {"name": "Human circovirus VS6600022", "rank": "Species"}, "1250005": {"name": "Polaribacter sp. Hel1_85", "rank": "Species"}, "1250004": {"name": "Psychroserpens sp. Hel_I_66", "rank": "Species"}, "693444": {"name": "Enterobacteriaceae bacterium strain FGI 57", "rank": "Species"}, "994672": {"name": "Titi monkey adenovirus ECC-2011", "rank": "Species"}, "1422299": {"name": "Staphylococcus aureus DAR5889", "rank": "Strain"}, "1422298": {"name": "Staphylococcus aureus DAR5890", "rank": "Strain"}, "1422291": {"name": "Staphylococcus aureus DAR3176", "rank": "Strain"}, "1422290": {"name": "Staphylococcus aureus DAR3175", "rank": "Strain"}, "1422293": {"name": "Staphylococcus aureus DAR3178", "rank": "Strain"}, "1422292": {"name": "Staphylococcus aureus DAR3177", "rank": "Strain"}, "1422295": {"name": "Staphylococcus aureus DAR3183", "rank": "Strain"}, "1381007": {"name": "Grapevine red-blotch associated virus", "rank": "Species"}, "1422297": {"name": "Staphylococcus aureus DAR3236", "rank": "Strain"}, "1422296": {"name": "Staphylococcus aureus DAR3198", "rank": "Strain"}, "453816": {"name": "Bdellovibrio exovorus", "rank": "Species"}, "12530": {"name": "Leishmania RNA virus 1 - 4", "rank": "Species"}, "1154756": {"name": "Serratia plymuthica PRI-2C", "rank": "Strain"}, "1154757": {"name": "Leuconostoc pseudomesenteroides 4882", "rank": "Strain"}, "12538": {"name": "Mokola virus", "rank": "Species"}, "312009": {"name": "Nemesia ring necrosis virus", "rank": "Species"}, "1154758": {"name": "Pseudomonas avellanae BPIC 631", "rank": "Strain"}, "1243620": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20110355", "rank": "Strain"}, "423351": {"name": "Mucilaginibacter paludis", "rank": "Species"}, "764100": {"name": "Saccharomyces cerevisiae VL3", "rank": "Strain"}, "423358": {"name": "Bicaudaviridae", "rank": "Family"}, "764102": {"name": "Saccharomyces cerevisiae FostersB", "rank": "Strain"}, "764103": {"name": "Mixia osmundae IAM 14324", "rank": "Strain"}, "51173": {"name": "Ureibacillus thermosphaericus", "rank": "Species"}, "1112213": {"name": "Sphingomonas sp. PAMC 26621", "rank": "Species"}, "1173691": {"name": "Citrobacter sp. A1", "rank": "Species"}, "380174": {"name": "Cohnella laeviribosi", "rank": "Species"}, "487317": {"name": "Aequorivita capsosiphonis", "rank": "Species"}, "487316": {"name": "Acinetobacter soli", "rank": "Species"}, "40979": {"name": "Cocksfoot mottle virus", "rank": "Species"}, "487319": {"name": "Shewanella marina", "rank": "Species"}, "269145": {"name": "Sulfolobus turreted icosahedral virus 1", "rank": "Species"}, "990285": {"name": "Rhizobium grahamii CCGE 502", "rank": "Strain"}, "990282": {"name": "Salmonella enterica subsp. enterica serovar Typhimurium str. UK-1", "rank": "Strain"}, "1158168": {"name": "Thioalkalivibrio sp. ALE14", "rank": "Species"}, "990288": {"name": "Acidithiobacillus caldus SM-1", "rank": "Strain"}, "1388242": {"name": "Staphylococcus aureus M0362", "rank": "Strain"}, "488222": {"name": "Streptococcus pneumoniae JJA", "rank": "Strain"}, "488223": {"name": "Streptococcus pneumoniae P1031", "rank": "Strain"}, "488221": {"name": "Streptococcus pneumoniae 70585", "rank": "Strain"}, "860575": {"name": "Cyanothece sp. ATCC 51472", "rank": "Species"}, "578822": {"name": "Methylobacterium extorquens group", "rank": "Species group"}, "314315": {"name": "Lactobacillus sakei subsp. sakei 23K", "rank": "Strain"}, "648800": {"name": "Solibacillus", "rank": "Genus"}, "648801": {"name": "Passionfruit severe leaf distortion virus", "rank": "Species"}, "1390079": {"name": "Streptococcus pyogenes SP4-LAU", "rank": "Strain"}, "1244111": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20110357", "rank": "Strain"}, "1244112": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20110358", "rank": "Strain"}, "1244113": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20110359", "rank": "Strain"}, "1155007": {"name": "Nematocida sp. 1", "rank": "Species"}, "158372": {"name": "Penicillium chrysogenum virus", "rank": "Species"}, "1094715": {"name": "Fluoribacter dumoffii NY 23", "rank": "Strain"}, "1094714": {"name": "Fluoribacter dumoffii Tex-KL", "rank": "Strain"}, "168807": {"name": "Escherichia coli O127:H6", "rank": "Strain"}, "521097": {"name": "Capnocytophaga ochracea DSM 7271", "rank": "Strain"}, "1234884": {"name": "Dragonfly-associated circular virus 3", "rank": "Species"}, "521096": {"name": "Tsukamurella paurometabola DSM 20162", "rank": "Strain"}, "1233950": {"name": "Chryseobacterium sp. JM1", "rank": "Species"}, "1234880": {"name": "Dragonfly cyclovirus 2", "rank": "Species"}, "1506553": {"name": "Lachnoclostridium", "rank": "Genus"}, "1546178": {"name": "Southwest baboon virus 1", "rank": "Species"}, "218667": {"name": "Oyster mushroom spherical virus", "rank": "Species"}, "1546177": {"name": "Mikumi yellow baboon virus 1", "rank": "Species"}, "340177": {"name": "Chlorobium chlorochromatii CaD3", "rank": "Strain"}, "1410808": {"name": "Staphylococcus aureus W51776", "rank": "Strain"}, "651580": {"name": "Human adenovirus 54", "rank": "Strain"}, "340170": {"name": "Spathaspora passalidarum", "rank": "Species"}, "1410801": {"name": "Staphylococcus aureus H24884", "rank": "Strain"}, "1410800": {"name": "Staphylococcus aureus T62848", "rank": "Strain"}, "1410803": {"name": "Staphylococcus aureus F62010", "rank": "Strain"}, "1410802": {"name": "Staphylococcus aureus F62007", "rank": "Strain"}, "83561": {"name": "Simkania negevensis", "rank": "Species"}, "1410804": {"name": "Staphylococcus aureus F62013", "rank": "Strain"}, "1410807": {"name": "Staphylococcus aureus M20916", "rank": "Strain"}, "1410806": {"name": "Staphylococcus aureus M20913", "rank": "Strain"}, "663887": {"name": "Mycobacterium tuberculosis KZN V2475", "rank": "Strain"}, "663886": {"name": "Mycobacterium tuberculosis KZN R506", "rank": "Strain"}, "1160707": {"name": "Ureibacillus thermosphaericus str. Thermo-BF", "rank": "Strain"}, "53461": {"name": "Nakamurella multipartita", "rank": "Species"}, "1159100": {"name": "Streptococcus pneumoniae PNI0360", "rank": "Strain"}, "53462": {"name": "Mycobacterium mageritense", "rank": "Species"}, "1234888": {"name": "Dragonfly-associated microphage 1", "rank": "Species"}, "416273": {"name": "Natronomonas moolapensis", "rank": "Species"}, "416276": {"name": "Rickettsia massiliae MTU5", "rank": "Strain"}, "156889": {"name": "Magnetococcus marinus MC-1", "rank": "Strain"}, "156885": {"name": "Thioflavicoccus", "rank": "Genus"}, "1160703": {"name": "Oenococcus oeni AWRIB202", "rank": "Strain"}, "2745": {"name": "Halomonas", "rank": "Genus"}, "2747": {"name": "Carnobacterium", "rank": "Genus"}, "2746": {"name": "Halomonas elongata", "rank": "Species"}, "1513300": {"name": "Tupavirus", "rank": "Genus"}, "2743": {"name": "Marinobacter hydrocarbonoclasticus", "rank": "Species"}, "2742": {"name": "Marinobacter", "rank": "Genus"}, "1513308": {"name": "Velarivirus", "rank": "Genus"}, "2748": {"name": "Carnobacterium divergens", "rank": "Species"}, "1411521": {"name": "Staphylococcus aureus F77930", "rank": "Strain"}, "1411520": {"name": "Staphylococcus aureus F74220", "rank": "Strain"}, "1221637": {"name": "Bat polyomavirus", "rank": "Species"}, "1411523": {"name": "Staphylococcus aureus H24662", "rank": "Strain"}, "1312873": {"name": "Alphamesonivirus", "rank": "Genus"}, "672794": {"name": "Cardinium endosymbiont of Bemisia tabaci", "rank": "Species"}, "1411522": {"name": "Staphylococcus aureus H24637", "rank": "Strain"}, "622312": {"name": "Roseburia inulinivorans DSM 16841", "rank": "Strain"}, "1312874": {"name": "Alphamesonivirus 1", "rank": "Species"}, "180332": {"name": "Robinsoniella peoriensis", "rank": "Species"}, "1312879": {"name": "Enterobacter cloacae MR2", "rank": "Strain"}, "1411524": {"name": "Staphylococcus aureus H27858", "rank": "Strain"}, "1526927": {"name": "Planococcus sp. PAMC 21323", "rank": "Species"}, "288000": {"name": "Bradyrhizobium sp. BTAi1", "rank": "Species"}, "165695": {"name": "Sphingobium", "rank": "Genus"}, "165694": {"name": "Bartonella schoenbuchensis", "rank": "Species"}, "77344": {"name": "Japanese iris necrotic ring virus", "rank": "Species"}, "165696": {"name": "Novosphingobium", "rank": "Genus"}, "390845": {"name": "Aedes flavivirus", "rank": "Species"}, "1348500": {"name": "Cyclovirus VN", "rank": "Species"}, "390842": {"name": "Lactobacillus parafarraginis", "rank": "Species"}, "1105260": {"name": "Streptococcus agalactiae CCUG 37740", "rank": "Strain"}, "1105261": {"name": "Streptococcus agalactiae CCUG 44050", "rank": "Strain"}, "1105262": {"name": "Streptococcus agalactiae CCUG 44074", "rank": "Strain"}, "1105263": {"name": "Streptococcus agalactiae CCUG 44104", "rank": "Strain"}, "1105264": {"name": "Streptococcus agalactiae CCUG 44110", "rank": "Strain"}, "1105265": {"name": "Streptococcus agalactiae CCUG 44140", "rank": "Strain"}, "1105266": {"name": "Streptococcus agalactiae CCUG 44186", "rank": "Strain"}, "1105267": {"name": "Streptococcus agalactiae CCUG 45061", "rank": "Strain"}, "1105268": {"name": "Streptococcus agalactiae CCUG 47293", "rank": "Strain"}, "1105269": {"name": "Streptococcus agalactiae CCUG 49072", "rank": "Strain"}, "1405807": {"name": "Razdan virus", "rank": "Species"}, "1405806": {"name": "Bhanja serogroup", "rank": "No rank"}, "1405803": {"name": "Pseudomonas alcaligenes MRY13-0052", "rank": "Strain"}, "1500257": {"name": "Rhizobium sp. YR295", "rank": "Species"}, "1055684": {"name": "Human papillomavirus type 126", "rank": "Strain"}, "1045010": {"name": "Escherichia coli O157", "rank": "Strain"}, "1045012": {"name": "Clostridium clariflavum 4-2a", "rank": "Strain"}, "181069": {"name": "Proteocatella", "rank": "Genus"}, "1389417": {"name": "Escherichia coli LAU-EC6", "rank": "Strain"}, "1389416": {"name": "Escherichia coli LAU-EC5", "rank": "Strain"}, "1389419": {"name": "Escherichia coli LAU-EC8", "rank": "Strain"}, "1389418": {"name": "Escherichia coli LAU-EC7", "rank": "Strain"}, "119910": {"name": "Ryegrass mottle virus", "rank": "Species"}, "119912": {"name": "Salmonella enterica subsp. enterica serovar Choleraesuis", "rank": "Strain"}, "471285": {"name": "Lettuce yellow mottle virus", "rank": "Species"}, "118884": {"name": "Unclassified Gammaproteobacteria", "rank": "No rank"}, "908612": {"name": "Alistipes sp. HGB5", "rank": "Species"}, "1434212": {"name": "Acinetobacter baumannii MRSN 57", "rank": "Strain"}, "1434210": {"name": "Burkholderia pseudomallei TSV 25", "rank": "Strain"}, "580327": {"name": "Thermoanaerobacterium thermosaccharolyticum DSM 571", "rank": "Strain"}, "979535": {"name": "Vibrio phage ICP3", "rank": "Species"}, "151038": {"name": "Anaeroarcus", "rank": "Genus"}, "992169": {"name": "Yersinia pestis PY-76", "rank": "Strain"}, "979533": {"name": "Vibrio phage ICP2", "rank": "Species"}, "992165": {"name": "Yersinia pestis PY-65", "rank": "Strain"}, "388739": {"name": "Roseobacter sp. SK209-2-6", "rank": "Species"}, "992167": {"name": "Yersinia pestis PY-71", "rank": "Strain"}, "1434214": {"name": "Mannheimia varigena USDA-ARS-USMARC-1312", "rank": "Strain"}, "1434215": {"name": "Mannheimia varigena USDA-ARS-USMARC-1388", "rank": "Strain"}, "1405396": {"name": "Chlamydia ibidis", "rank": "Species"}, "261594": {"name": "Bacillus anthracis str. 'Ames Ancestor'", "rank": "Strain"}, "146891": {"name": "Prochlorococcus marinus str. AS9601", "rank": "Strain"}, "1418236": {"name": "Pseudomonas aeruginosa BWH050", "rank": "Strain"}, "361689": {"name": "Unclassified Begomovirus-associated DNA beta-like sequences", "rank": "No rank"}, "1418235": {"name": "Pseudomonas aeruginosa BWH049", "rank": "Strain"}, "1418238": {"name": "Pseudomonas aeruginosa BWH052", "rank": "Strain"}, "1418239": {"name": "Pseudomonas aeruginosa BWH053", "rank": "Strain"}, "111564": {"name": "Kineosphaera limosa", "rank": "Species"}, "481145": {"name": "Acetobacter pasteurianus subsp. pasteurianus", "rank": "Subspecies"}, "159148": {"name": "Shuni virus", "rank": "Species"}, "481147": {"name": "Simian T-cell lymphotropic virus 6", "rank": "Species"}, "234829": {"name": "Tomato begomovirus satellite DNA beta", "rank": "Species"}, "234828": {"name": "Corynebacterium caspium", "rank": "Species"}, "420890": {"name": "Lactococcus garvieae Lg2", "rank": "Strain"}, "234827": {"name": "Candidatus Midichloria mitochondrii", "rank": "Species"}, "159141": {"name": "Sathuperi virus", "rank": "Species"}, "1143323": {"name": "Chlamydia gallinacea 08-1274/3", "rank": "Strain"}, "1526762": {"name": "Vibrio sp. B183", "rank": "Species"}, "1388168": {"name": "Staphylococcus aureus M0256", "rank": "Strain"}, "1388169": {"name": "Staphylococcus aureus M0258", "rank": "Strain"}, "1388166": {"name": "Staphylococcus aureus M0254", "rank": "Strain"}, "1388167": {"name": "Staphylococcus aureus M0255", "rank": "Strain"}, "1388164": {"name": "Staphylococcus aureus M0249", "rank": "Strain"}, "1388165": {"name": "Staphylococcus aureus M0251", "rank": "Strain"}, "1388162": {"name": "Staphylococcus aureus M0247", "rank": "Strain"}, "1388163": {"name": "Staphylococcus aureus M0248", "rank": "Strain"}, "1388160": {"name": "Staphylococcus aureus M0245", "rank": "Strain"}, "1388161": {"name": "Staphylococcus aureus M0246", "rank": "Strain"}, "1151269": {"name": "Peptoclostridium difficile CD46", "rank": "Strain"}, "1151268": {"name": "Peptoclostridium difficile CD45", "rank": "Strain"}, "1151261": {"name": "Peptoclostridium difficile CD38", "rank": "Strain"}, "1151260": {"name": "Peptoclostridium difficile CD34", "rank": "Strain"}, "1352343": {"name": "Helicobacter pylori UM038", "rank": "Strain"}, "1151262": {"name": "Peptoclostridium difficile CD39", "rank": "Strain"}, "1231719": {"name": "Helicobacter pylori A45", "rank": "Strain"}, "1352344": {"name": "Helicobacter pylori UM085", "rank": "Strain"}, "1151267": {"name": "Peptoclostridium difficile CD44", "rank": "Strain"}, "1151266": {"name": "Peptoclostridium difficile CD43", "rank": "Strain"}, "1311069": {"name": "Acinetobacter baumannii 26016_2", "rank": "Strain"}, "1410790": {"name": "Staphylococcus aureus H18813", "rank": "Strain"}, "1410793": {"name": "Staphylococcus aureus M16220", "rank": "Strain"}, "1410792": {"name": "Staphylococcus aureus S72396", "rank": "Strain"}, "1410795": {"name": "Staphylococcus aureus H21935", "rank": "Strain"}, "1410794": {"name": "Staphylococcus aureus H18811", "rank": "Strain"}, "1410797": {"name": "Staphylococcus aureus F59156", "rank": "Strain"}, "1410796": {"name": "Staphylococcus aureus H21924", "rank": "Strain"}, "1410799": {"name": "Staphylococcus aureus W48906", "rank": "Strain"}, "1410798": {"name": "Staphylococcus aureus T62854", "rank": "Strain"}, "1311065": {"name": "Acinetobacter baumannii 44839_8", "rank": "Strain"}, "1311067": {"name": "Acinetobacter baumannii 44839_10", "rank": "Strain"}, "1311066": {"name": "Acinetobacter baumannii 44839_9", "rank": "Strain"}, "1566628": {"name": "Microbispora sp. NBRC 110460", "rank": "Species"}, "99479": {"name": "Tetrasphaera", "rank": "Genus"}, "1257080": {"name": "Paenibacillus sp. PAMC 26794", "rank": "Species"}, "1046983": {"name": "Hydrogenedentes bacterium JGI 0000059-N10", "rank": "Species"}, "1032506": {"name": "Prevotella sp. MSX73", "rank": "Species"}, "1286840": {"name": "Ensifer sp. JGI 0001011-A08", "rank": "Species"}, "1286843": {"name": "Comamonadaceae bacterium JGI 0001013-A16", "rank": "Species"}, "1365647": {"name": "Xanthomonas alfalfae subsp. alfalfae CFBP 3836", "rank": "Strain"}, "351607": {"name": "Acidothermus cellulolyticus 11B", "rank": "Strain"}, "351605": {"name": "Geobacter uraniireducens Rf4", "rank": "Strain"}, "351604": {"name": "Geobacter uraniireducens", "rank": "Species"}, "1418297": {"name": "Staphylococcus aureus H12662", "rank": "Strain"}, "1365648": {"name": "Xanthomonas axonopodis pv. glycines CFBP 2526", "rank": "Strain"}, "1365649": {"name": "Xanthomonas axonopodis pv. glycines CFBP 7119", "rank": "Strain"}, "1114969": {"name": "Propionibacterium acnes TypeIA2 P.acn31", "rank": "Strain"}, "1114965": {"name": "Streptococcus parasanguinis FW213", "rank": "Strain"}, "1114964": {"name": "Sphingobium baderi LL03", "rank": "Strain"}, "1114967": {"name": "Propionibacterium acnes TypeIA2 P.acn17", "rank": "Strain"}, "1114966": {"name": "Propionibacterium acnes TypeIA2 P.acn33", "rank": "Strain"}, "1046981": {"name": "Unclassified Hydrogenedentes", "rank": "No rank"}, "1114960": {"name": "Rhodococcus pyridinivorans AK37", "rank": "Strain"}, "759364": {"name": "Chlamydia trachomatis D-LC", "rank": "Strain"}, "103796": {"name": "Pseudomonas syringae pv. actinidiae", "rank": "Strain"}, "1194708": {"name": "Sinorhizobium meliloti A0641M", "rank": "Strain"}, "714": {"name": "Aggregatibacter actinomycetemcomitans", "rank": "Species"}, "1194707": {"name": "Sinorhizobium meliloti 5A14", "rank": "Strain"}, "1194706": {"name": "Sinorhizobium meliloti 1A42", "rank": "Strain"}, "1169414": {"name": "Thermobifida fusca TM51", "rank": "Strain"}, "1169411": {"name": "Bacillus licheniformis 10-1-A", "rank": "Strain"}, "1169410": {"name": "Pasteurella multocida subsp. gallicida X73", "rank": "Strain"}, "1385664": {"name": "Hymenobacter sp. DG25B", "rank": "Species"}, "1169412": {"name": "Bacillus licheniformis 5-2-D", "rank": "Strain"}, "1046980": {"name": "Unclassified Microgenomates", "rank": "No rank"}, "1417188": {"name": "Staphylococcus aureus M70013", "rank": "Strain"}, "759362": {"name": "Ketogulonicigenium vulgare WSH-001", "rank": "Strain"}, "759363": {"name": "Chlamydia trachomatis D-EC", "rank": "Strain"}, "72197": {"name": "Human erythrovirus V9", "rank": "Species"}, "1046987": {"name": "Parcubacteria bacterium SCGC AAA011-A09", "rank": "Species"}, "367682": {"name": "Narcissus symptomless virus", "rank": "Species"}, "1262350": {"name": "Pseudomonas syringae pv. syringae SM", "rank": "Strain"}, "1116068": {"name": "Escherichia coli P0301867.4", "rank": "Strain"}, "1116069": {"name": "Escherichia coli P0301867.5", "rank": "Strain"}, "1116066": {"name": "Escherichia coli P0301867.1", "rank": "Strain"}, "1116067": {"name": "Escherichia coli P0301867.3", "rank": "Strain"}, "1116064": {"name": "Escherichia coli MP021017.10", "rank": "Strain"}, "1116065": {"name": "Escherichia coli MP021017.11", "rank": "Strain"}, "1116062": {"name": "Escherichia coli MP021017.6", "rank": "Strain"}, "1116063": {"name": "Escherichia coli MP021017.9", "rank": "Strain"}, "1116060": {"name": "Escherichia coli MP021017.4", "rank": "Strain"}, "1116061": {"name": "Escherichia coli MP021017.5", "rank": "Strain"}, "888439": {"name": "Actinomyces neuii BVS029A5", "rank": "Strain"}, "1212765": {"name": "Candidatus Mycoplasma haemolamae str. Purdue", "rank": "Strain"}, "1167737": {"name": "Burkholderia sp. JGI 001009-G21", "rank": "Species"}, "1148757": {"name": "Brucella melitensis S66", "rank": "Strain"}, "569836": {"name": "Unclassified Chitinophagaceae", "rank": "No rank"}, "430557": {"name": "Francisella tularensis subsp. tularensis FSC033", "rank": "Strain"}, "102684": {"name": "Streptococcus infantarius", "rank": "Species"}, "686990": {"name": "Treponema pallidum subsp. pallidum str. Mexico A", "rank": "Strain"}, "430558": {"name": "Francisella tularensis subsp. novicida GA99-3549", "rank": "Strain"}, "1490528": {"name": "Sweet potato leaf curl virus associated satellite", "rank": "Species"}, "314565": {"name": "Xanthomonas campestris pv. campestris str. 8004", "rank": "Strain"}, "644563": {"name": "Vibrio phage N4", "rank": "Species"}, "1304": {"name": "Streptococcus salivarius", "rank": "Species"}, "1305": {"name": "Streptococcus sanguinis", "rank": "Species"}, "1046984": {"name": "Unclassified Parcubacteria", "rank": "No rank"}, "1307": {"name": "Streptococcus suis", "rank": "Species"}, "1300": {"name": "Streptococcaceae", "rank": "Family"}, "1301": {"name": "Streptococcus", "rank": "Genus"}, "1302": {"name": "Streptococcus gordonii", "rank": "Species"}, "1303": {"name": "Streptococcus oralis", "rank": "Species"}, "1308": {"name": "Streptococcus thermophilus", "rank": "Species"}, "1309": {"name": "Streptococcus mutans", "rank": "Species"}, "1126011": {"name": "Listeria monocytogenes 07PF0776", "rank": "Strain"}, "1232139": {"name": "Pseudomonas oleovorans/pseudoalcaligenes group", "rank": "Species subgroup"}, "764348": {"name": "Magnaporthe oryzae chrysovirus 1", "rank": "Species"}, "256319": {"name": "Chlorobaculum", "rank": "Genus"}, "1441459": {"name": "Pseudomonas aeruginosa C2773C", "rank": "Strain"}, "267850": {"name": "Nitrincola lacisaponensis", "rank": "Species"}, "709032": {"name": "Sulfuricurvum kujiense DSM 16994", "rank": "Strain"}, "1207041": {"name": "Idiomarina xiamenensis", "rank": "Species"}, "1051006": {"name": "Propionibacterium acnes SK182B-JCVI", "rank": "Strain"}, "1051004": {"name": "Pseudomonas aeruginosa 213BR", "rank": "Strain"}, "1051005": {"name": "Pseudomonas aeruginosa 9BR", "rank": "Strain"}, "1051003": {"name": "Pseudomonas aeruginosa 19BR", "rank": "Strain"}, "176275": {"name": "Beauveria bassiana", "rank": "Species"}, "265669": {"name": "Listeria monocytogenes serotype 4b str. F2365", "rank": "Strain"}, "265668": {"name": "Vibrio ponticus", "rank": "Species"}, "42882": {"name": "Cherry virus A", "rank": "Species"}, "1154876": {"name": "Streptococcus agalactiae MRI Z1-213", "rank": "Strain"}, "434309": {"name": "Saffold virus", "rank": "Strain"}, "320373": {"name": "Burkholderia pseudomallei 668", "rank": "Strain"}, "1154875": {"name": "Streptococcus agalactiae MRI Z1-212", "rank": "Strain"}, "194924": {"name": "Desulfovibrionaceae", "rank": "Family"}, "1123522": {"name": "Neisseria meningitidis DE9938", "rank": "Strain"}, "1123521": {"name": "Neisseria meningitidis DE9622", "rank": "Strain"}, "1505530": {"name": "Pagoda yellow mosaic associated virus", "rank": "Species"}, "267747": {"name": "Propionibacterium acnes KPA171202", "rank": "Strain"}, "267748": {"name": "Mycoplasma mobile 163K", "rank": "Strain"}, "1167731": {"name": "Bacillus sp. JGI 001005-J19", "rank": "Species"}, "759914": {"name": "Brachyspira pilosicoli 95/1000", "rank": "Strain"}, "759913": {"name": "Streptococcus dysgalactiae subsp. equisimilis AC-2713", "rank": "Strain"}, "221817": {"name": "Unclassified Oceanospirillaceae", "rank": "No rank"}, "504346": {"name": "Pseudomonas phage PAJU2", "rank": "Species"}, "1154873": {"name": "Streptococcus agalactiae MRI Z1-209", "rank": "Strain"}, "44100": {"name": "Mycoplasma mycoides subsp. capri LC", "rank": "Strain"}, "44101": {"name": "Mycoplasma mycoides subsp. mycoides SC", "rank": "Strain"}, "1154872": {"name": "Streptococcus agalactiae MRI Z1-049", "rank": "Strain"}, "1408258": {"name": "Turkey adenovirus 5", "rank": "Species"}, "140052": {"name": "Betaretrovirus", "rank": "Genus"}, "369829": {"name": "Saccharomonospora saliphila", "rank": "Species"}, "1408250": {"name": "Cellulomonas cellasea DSM 20118", "rank": "Strain"}, "1408254": {"name": "Brevibacillus panacihumi W25", "rank": "Strain"}, "1408257": {"name": "Turkey adenovirus 4", "rank": "Species"}, "694005": {"name": "Murine coronavirus", "rank": "Species"}, "1203549": {"name": "Microbacterium sp. oral taxon 186 str. F0373", "rank": "Strain"}, "1203546": {"name": "Klebsiella pneumoniae subsp. pneumoniae WGLW3", "rank": "Strain"}, "1203547": {"name": "Klebsiella pneumoniae subsp. pneumoniae WGLW5", "rank": "Strain"}, "5139": {"name": "Sordariales", "rank": "Order"}, "1203545": {"name": "Klebsiella pneumoniae subsp. pneumoniae WGLW2", "rank": "Strain"}, "1541743": {"name": "Candidatus Ruthia", "rank": "Genus"}, "1203540": {"name": "Bifidobacterium breve HPH0326", "rank": "Strain"}, "1409708": {"name": "Staphylococcus aureus PLAC6043", "rank": "Strain"}, "1409709": {"name": "Staphylococcus aureus WAMC6055", "rank": "Strain"}, "1409704": {"name": "Staphylococcus aureus OCMM6124", "rank": "Strain"}, "1409705": {"name": "Staphylococcus aureus OCMM6125", "rank": "Strain"}, "1409706": {"name": "Staphylococcus aureus WMCS6114", "rank": "Strain"}, "1396830": {"name": "Burkholderia cenocepacia KC-01", "rank": "Strain"}, "1409700": {"name": "Staphylococcus aureus SCLE6040", "rank": "Strain"}, "1409701": {"name": "Staphylococcus aureus LAMC6117", "rank": "Strain"}, "1409702": {"name": "Staphylococcus aureus GGMC6027", "rank": "Strain"}, "1409703": {"name": "Staphylococcus aureus LAMC6115", "rank": "Strain"}, "106578": {"name": "Thermoanaerobacter siderophilus", "rank": "Species"}, "1422459": {"name": "Staphylococcus aureus VET0136R", "rank": "Strain"}, "40480": {"name": "Mycoplasma capricolum subsp. capripneumoniae", "rank": "Subspecies"}, "1154870": {"name": "Streptococcus agalactiae MRI Z1-039", "rank": "Strain"}, "1422456": {"name": "Staphylococcus aureus VET0132R", "rank": "Strain"}, "1422455": {"name": "Staphylococcus aureus VET0130R", "rank": "Strain"}, "1422454": {"name": "Staphylococcus aureus VET0129R", "rank": "Strain"}, "1422453": {"name": "Staphylococcus aureus VET0128R", "rank": "Strain"}, "1422452": {"name": "Staphylococcus aureus VET0127R", "rank": "Strain"}, "1422451": {"name": "Staphylococcus aureus VET0126R", "rank": "Strain"}, "173479": {"name": "Gemmatimonas", "rank": "Genus"}, "42837": {"name": "Ammonifex", "rank": "Genus"}, "279359": {"name": "Gramella echinicola", "rank": "Species"}, "1111126": {"name": "Jonquetella sp. BV3C21", "rank": "Species"}, "1412799": {"name": "Staphylococcus aureus W29641", "rank": "Strain"}, "1412798": {"name": "Staphylococcus aureus W29625", "rank": "Strain"}, "1412797": {"name": "Staphylococcus aureus W23225", "rank": "Strain"}, "1412796": {"name": "Staphylococcus aureus W23214", "rank": "Strain"}, "1412795": {"name": "Staphylococcus aureus W23207", "rank": "Strain"}, "1412794": {"name": "Staphylococcus aureus T67327", "rank": "Strain"}, "1412793": {"name": "Staphylococcus aureus T67319", "rank": "Strain"}, "1412792": {"name": "Staphylococcus aureus T64318", "rank": "Strain"}, "1412791": {"name": "Staphylococcus aureus T60805", "rank": "Strain"}, "1412790": {"name": "Staphylococcus aureus T60795", "rank": "Strain"}, "1464554": {"name": "Aeromicrobium massiliense", "rank": "Species"}, "1423490": {"name": "Mycobacterium tuberculosis BTB08-309", "rank": "Strain"}, "1423492": {"name": "Mycobacterium tuberculosis BTB08-356", "rank": "Strain"}, "1423493": {"name": "Mycobacterium tuberculosis BTB08-362", "rank": "Strain"}, "1423494": {"name": "Mycobacterium tuberculosis BTB08-394", "rank": "Strain"}, "1423495": {"name": "Mycobacterium tuberculosis BTB08-395", "rank": "Strain"}, "1218148": {"name": "Salmonella enterica subsp. enterica serovar Typhimurium str. STm8", "rank": "Strain"}, "1218149": {"name": "Salmonella enterica subsp. enterica serovar Typhimurium str. STm9", "rank": "Strain"}, "1423498": {"name": "Mycobacterium tuberculosis BTB09-058", "rank": "Strain"}, "1218147": {"name": "Salmonella enterica subsp. enterica serovar Typhimurium str. STm6", "rank": "Strain"}, "1218144": {"name": "Salmonella enterica subsp. enterica serovar Typhimurium str. STm2", "rank": "Strain"}, "1218145": {"name": "Salmonella enterica subsp. enterica serovar Typhimurium str. STm3", "rank": "Strain"}, "1281781": {"name": "Bifidobacterium animalis subsp. lactis Bl12", "rank": "Strain"}, "444612": {"name": "Rickettsia endosymbiont of Ixodes scapularis", "rank": "Species"}, "1076549": {"name": "Pantoea rodasii", "rank": "Species"}, "679897": {"name": "Helicobacter mustelae 12198", "rank": "Strain"}, "553574": {"name": "Staphylococcus aureus A8117", "rank": "Strain"}, "679895": {"name": "Escherichia coli BW25113", "rank": "Strain"}, "553571": {"name": "Staphylococcus aureus A6300", "rank": "Strain"}, "553573": {"name": "Staphylococcus aureus A8115", "rank": "Strain"}, "40222": {"name": "Methylophaga", "rank": "Genus"}, "136094": {"name": "Thermocrinis albus", "rank": "Species"}, "300028": {"name": "Rhodococcus triatomae", "rank": "Species"}, "300020": {"name": "Microbacterium maritypicum", "rank": "Species"}, "136099": {"name": "Knoellia", "rank": "Genus"}, "933093": {"name": "Legionella pneumophila subsp. pneumophila ATCC 43290", "rank": "Strain"}, "81": {"name": "Hyphomicrobium", "rank": "Genus"}, "1423724": {"name": "Lactobacillus apodemi DSM 16634 = JCM 16172", "rank": "Strain"}, "52133": {"name": "Acinetobacter venetianus", "rank": "Species"}, "52135": {"name": "Tomato infectious chlorosis virus", "rank": "Species"}, "743709": {"name": "Bacillus atrophaeus ATCC 49822", "rank": "Strain"}, "1071778": {"name": "Chlamydia trachomatis L2b/Ams1", "rank": "Strain"}, "563769": {"name": "Stx2-converting phage 1717", "rank": "Species"}, "1157461": {"name": "Enterococcus faecium EnGen0166", "rank": "Strain"}, "1071777": {"name": "Chlamydia trachomatis L2b/795", "rank": "Strain"}, "1500713": {"name": "Vibrio phage X29", "rank": "Species"}, "1157463": {"name": "Enterococcus faecium EnGen0168", "rank": "Strain"}, "126740": {"name": "Thermotoga sp. RQ2", "rank": "Species"}, "1071775": {"name": "Chlamydia trachomatis L2b/LST", "rank": "Strain"}, "569195": {"name": "Porcine kobuvirus swine/S-1-HUN/2007/Hungary", "rank": "Strain"}, "1122173": {"name": "Leptotrichia trevisanii DSM 22070", "rank": "Strain"}, "273528": {"name": "Exiguobacterium marinum", "rank": "Species"}, "1071773": {"name": "Chlamydia trachomatis L2b/8200/07", "rank": "Strain"}, "1122171": {"name": "Leptotrichia hofstadii DSM 21651", "rank": "Strain"}, "1071771": {"name": "Chlamydia trachomatis L1/224", "rank": "Strain"}, "1154878": {"name": "Streptococcus agalactiae MRI Z1-215", "rank": "Strain"}, "1464081": {"name": "Streptomyces graminis", "rank": "Species"}, "227882": {"name": "Streptomyces avermitilis MA-4680 = NBRC 14893", "rank": "Strain"}, "857129": {"name": "Streptococcus mutans NLML4", "rank": "Strain"}, "857128": {"name": "Streptococcus mutans NLML5", "rank": "Strain"}, "1413423": {"name": "Staphylococcus aureus 110802495", "rank": "Strain"}, "857125": {"name": "Streptococcus mutans N3209", "rank": "Strain"}, "857124": {"name": "Streptococcus mutans N66", "rank": "Strain"}, "857127": {"name": "Streptococcus mutans NLML9", "rank": "Strain"}, "857126": {"name": "Streptococcus mutans M2A", "rank": "Strain"}, "857121": {"name": "Streptococcus mutans SF1", "rank": "Strain"}, "857120": {"name": "Streptococcus mutans SF14", "rank": "Strain"}, "857123": {"name": "Streptococcus mutans NV1996", "rank": "Strain"}, "857122": {"name": "Streptococcus mutans W6", "rank": "Strain"}, "676517": {"name": "Diplorickettsia massiliensis", "rank": "Species"}, "1506157": {"name": "Luffa puckering and leaf distortion-associated betasatellite India:Gurdaspur:Okra:2013", "rank": "Species"}, "1413427": {"name": "Staphylococcus aureus 1110904178", "rank": "Strain"}, "225906": {"name": "Paenibacillus sanguinis", "rank": "Species"}, "134392": {"name": "Saimiriine herpesvirus 3", "rank": "Species"}, "1094930": {"name": "Caulobacter sp. JGI 0001002-P11", "rank": "Species"}, "536229": {"name": "Bacillus pumilus ATCC 7061", "rank": "Strain"}, "1094937": {"name": "Pelomonas sp. JGI 0001002-B21", "rank": "Species"}, "1094936": {"name": "Nocardioides sp. JGI 0001003-L20", "rank": "Species"}, "1094939": {"name": "Sphingomonas sp. JGI 0001002-A17", "rank": "Species"}, "536227": {"name": "Clostridium carboxidivorans P7", "rank": "Strain"}, "643217": {"name": "Afifella", "rank": "Genus"}, "1439236": {"name": "Streptococcus pyogenes ABC020054184", "rank": "Strain"}, "306537": {"name": "Corynebacterium jeikeium K411", "rank": "Strain"}, "75787": {"name": "Rhodocyclaceae", "rank": "Family"}, "1047049": {"name": "Unclassified Atribacteria", "rank": "No rank"}, "1047041": {"name": "Aminicenantes bacterium SCGC AAA255-E10", "rank": "Species"}, "1047040": {"name": "Aminicenantes bacterium SCGC AAA255-E05", "rank": "Species"}, "1047043": {"name": "Aminicenantes bacterium SCGC AAA255-F09", "rank": "Species"}, "1047042": {"name": "Aminicenantes bacterium SCGC AAA255-F06", "rank": "Species"}, "1047045": {"name": "Aminicenantes bacterium SCGC AAA255-O15", "rank": "Species"}, "1047044": {"name": "Aminicenantes bacterium SCGC AAA255-K14", "rank": "Species"}, "503005": {"name": "Dasania", "rank": "Genus"}, "503006": {"name": "Unclassified Pseudomonadales", "rank": "No rank"}, "42417": {"name": "Halobacteroides", "rank": "Genus"}, "171674": {"name": "Inquilinus limosus", "rank": "Species"}, "313589": {"name": "Janibacter sp. HTCC2649", "rank": "Species"}, "171673": {"name": "Inquilinus", "rank": "Genus"}, "11652": {"name": "Primate lentivirus group", "rank": "No rank"}, "11653": {"name": "Ovine/caprine lentivirus group", "rank": "No rank"}, "11654": {"name": "Equine lentivirus group", "rank": "Subgenus"}, "11655": {"name": "Feline lentivirus group", "rank": "No rank"}, "11656": {"name": "Bovine lentivirus group", "rank": "No rank"}, "329157": {"name": "Unclassified T7-like viruses", "rank": "No rank"}, "329158": {"name": "Unclassified P22likevirus", "rank": "No rank"}, "1084228": {"name": "Yersinia pestis biovar Orientalis str. AS200901156", "rank": "Strain"}, "1084229": {"name": "Yersinia pestis biovar Orientalis str. BA200901703", "rank": "Strain"}, "626528": {"name": "Escherichia coli O157:NM", "rank": "Strain"}, "1084226": {"name": "Yersinia pestis biovar Orientalis str. BA200901799", "rank": "Strain"}, "1084227": {"name": "Yersinia pestis biovar Orientalis str. AS200901539", "rank": "Strain"}, "626523": {"name": "Shuttleworthia satelles DSM 14600", "rank": "Strain"}, "626522": {"name": "Prevotella tannerae ATCC 51259", "rank": "Strain"}, "207954": {"name": "Neptuniibacter caesariensis", "rank": "Species"}, "1330547": {"name": "Kosakonia", "rank": "Genus"}, "1409459": {"name": "Staphylococcus aureus SJOS6004", "rank": "Strain"}, "694440": {"name": "Methanomicrobium mobile BP", "rank": "Strain"}, "1269009": {"name": "Escherichia coli A35218R", "rank": "Strain"}, "1269008": {"name": "Escherichia coli A25922R", "rank": "Strain"}, "1269007": {"name": "Escherichia coli 909945-2", "rank": "Strain"}, "1269006": {"name": "Klebsiella pneumoniae 909957", "rank": "Strain"}, "1269005": {"name": "Escherichia coli 908691", "rank": "Strain"}, "1269004": {"name": "Escherichia coli 908675", "rank": "Strain"}, "1269003": {"name": "Escherichia coli 908658", "rank": "Strain"}, "1269002": {"name": "Escherichia coli 908632", "rank": "Strain"}, "1269001": {"name": "Escherichia coli 908624", "rank": "Strain"}, "1269000": {"name": "Escherichia coli 908616", "rank": "Strain"}, "29329": {"name": "Thermoanaerobacterium xylanolyticum", "rank": "Species"}, "338188": {"name": "Bacteroides finegoldii", "rank": "Species"}, "29325": {"name": "Thermoanaerobacter brockii subsp. finnii", "rank": "Subspecies"}, "29323": {"name": "Thermoanaerobacter brockii", "rank": "Species"}, "29322": {"name": "Eubacterium cellulosolvens", "rank": "Species"}, "29321": {"name": "Turicella otitidis", "rank": "Species"}, "29320": {"name": "Arthrobacter nicotinovorans", "rank": "Species"}, "41949": {"name": "Candidatus Microthrix", "rank": "Genus"}, "1422003": {"name": "Mycobacterium tuberculosis TB_RSA87", "rank": "Strain"}, "1310114": {"name": "Mycobacterium tuberculosis CAS/NITR204", "rank": "Strain"}, "1310115": {"name": "Mycobacterium tuberculosis EAI5/NITR206", "rank": "Strain"}, "12303": {"name": "Cowpea chlorotic mottle virus", "rank": "Species"}, "12302": {"name": "Brome mosaic virus", "rank": "Species"}, "12301": {"name": "Broad bean mottle virus", "rank": "Species"}, "12300": {"name": "Bromovirus", "rank": "Genus"}, "12305": {"name": "Cucumber mosaic virus", "rank": "Species"}, "12304": {"name": "Cucumovirus", "rank": "Genus"}, "198094": {"name": "Bacillus anthracis str. Ames", "rank": "Strain"}, "830": {"name": "Butyrivibrio", "rank": "Genus"}, "831": {"name": "Butyrivibrio fibrisolvens", "rank": "Species"}, "832": {"name": "Fibrobacter", "rank": "Genus"}, "833": {"name": "Fibrobacter succinogenes", "rank": "Species"}, "834": {"name": "Fibrobacter succinogenes subsp. succinogenes", "rank": "Subspecies"}, "1422153": {"name": "Staphylococcus aureus DAR3628", "rank": "Strain"}, "1422150": {"name": "Staphylococcus aureus DAR3617", "rank": "Strain"}, "837": {"name": "Porphyromonas gingivalis", "rank": "Species"}, "838": {"name": "Prevotella", "rank": "Genus"}, "839": {"name": "Prevotella ruminicola", "rank": "Species"}, "1422158": {"name": "Staphylococcus aureus DAR3760", "rank": "Strain"}, "1422159": {"name": "Staphylococcus aureus DAR3761", "rank": "Strain"}, "204525": {"name": "Roseomonas cervicalis", "rank": "Species"}, "1343836": {"name": "Escherichia coli O157:H7 str. F8092B", "rank": "Strain"}, "1303019": {"name": "Boa arenavirus NL", "rank": "Species"}, "522773": {"name": "Sphingobium lactosutens", "rank": "Species"}, "1076934": {"name": "Streptococcus lutetiensis 033", "rank": "Strain"}, "1158172": {"name": "Thioalkalivibrio sp. ALE16", "rank": "Species"}, "1324219": {"name": "Mycobacterium tuberculosis TKK-01-0002", "rank": "Strain"}, "1009858": {"name": "Buchnera aphidicola str. G002 (Myzus persicae)", "rank": "Strain"}, "1009859": {"name": "Buchnera aphidicola str. F009 (Myzus persicae)", "rank": "Strain"}, "525341": {"name": "Lactobacillus reuteri CF48-3A", "rank": "Strain"}, "1158173": {"name": "Thioalkalivibrio sp. ALE17", "rank": "Species"}, "1009852": {"name": "Comamonas testosteroni ATCC 11996", "rank": "Strain"}, "1009856": {"name": "Buchnera aphidicola str. USDA (Myzus persicae)", "rank": "Strain"}, "1009857": {"name": "Buchnera aphidicola str. W106 (Myzus persicae)", "rank": "Strain"}, "795665": {"name": "Hydrogenophaga sp. PBC", "rank": "Species"}, "553239": {"name": "Vibrio breoganii", "rank": "Species"}, "1439059": {"name": "Streptococcus pyogenes ABC020030020", "rank": "Strain"}, "324913": {"name": "Isavirus", "rank": "Genus"}, "1439056": {"name": "Streptococcus pyogenes ABC020029711", "rank": "Strain"}, "1439055": {"name": "Streptococcus pyogenes ABC020029706", "rank": "Strain"}, "1004952": {"name": "Streptococcus suis D12", "rank": "Strain"}, "1004953": {"name": "Staphylococcus aureus subsp. aureus MRSA_PR1", "rank": "Strain"}, "1138907": {"name": "Enterococcus faecium EnGen0025", "rank": "Strain"}, "1004951": {"name": "Streptococcus suis ST1", "rank": "Strain"}, "1004956": {"name": "Brucella melitensis bv. 1 str. M28-12", "rank": "Strain"}, "1004957": {"name": "Brucella melitensis bv. 1 str. M5", "rank": "Strain"}, "1138903": {"name": "Enterococcus faecium EnGen0029", "rank": "Strain"}, "659427": {"name": "Sediminimonas", "rank": "Genus"}, "36853": {"name": "Desulfitobacterium", "rank": "Genus"}, "36855": {"name": "Brucella canis", "rank": "Species"}, "1138908": {"name": "Enterococcus faecium EnGen0035", "rank": "Strain"}, "1292388": {"name": "Francisella tularensis subsp. tularensis 3571", "rank": "Strain"}, "1292389": {"name": "Francisella tularensis subsp. tularensis 1378", "rank": "Strain"}, "1232445": {"name": "Clostridiales bacterium VE202-16", "rank": "Species"}, "37108": {"name": "Meleagrid herpesvirus 1", "rank": "Species"}, "52274": {"name": "Saguaro cactus virus", "rank": "Species"}, "37105": {"name": "Lactobacillus phage JCL1032", "rank": "Species"}, "706570": {"name": "Serpens flexibilis", "rank": "Species"}, "327159": {"name": "Candidatus Accumulibacter", "rank": "Genus"}, "1158176": {"name": "Thioalkalivibrio sp. ALE22", "rank": "Species"}, "381638": {"name": "Unclassified Orthoreovirus", "rank": "No rank"}, "1158177": {"name": "Thioalkalivibrio sp. ALE25", "rank": "Species"}, "34365": {"name": "Saccharomycodaceae", "rank": "Family"}, "391597": {"name": "Limnobacter sp. MED105", "rank": "Species"}, "1306401": {"name": "Mycobacterium abscessus subsp. bolletii CRM-0020", "rank": "Strain"}, "495036": {"name": "Geobacillus sp. G11MC16", "rank": "Species"}, "1158174": {"name": "Thioalkalivibrio sp. ALE18", "rank": "Species"}, "791161": {"name": "Enterococcus faecium PC4.1", "rank": "Strain"}, "791166": {"name": "Enterococcus faecalis PC1.1", "rank": "Strain"}, "1355023": {"name": "Helicobacter pylori wls-5-12", "rank": "Strain"}, "356630": {"name": "Unclassified Plectrovirus", "rank": "No rank"}, "868198": {"name": "Escherichia coli DEC13C", "rank": "Strain"}, "868199": {"name": "Escherichia coli DEC13D", "rank": "Strain"}, "868192": {"name": "Escherichia coli DEC12B", "rank": "Strain"}, "868193": {"name": "Escherichia coli DEC12C", "rank": "Strain"}, "868190": {"name": "Escherichia coli DEC11E", "rank": "Strain"}, "868191": {"name": "Escherichia coli DEC12A", "rank": "Strain"}, "868196": {"name": "Escherichia coli DEC13A", "rank": "Strain"}, "868197": {"name": "Escherichia coli DEC13B", "rank": "Strain"}, "868194": {"name": "Escherichia coli DEC12D", "rank": "Strain"}, "868195": {"name": "Escherichia coli DEC12E", "rank": "Strain"}, "1281171": {"name": "Escherichia coli KOEGE 118 (317a)", "rank": "Strain"}, "61372": {"name": "Fusarium oxysporum f. sp. radicis-lycopersici", "rank": "Strain"}, "1281170": {"name": "Escherichia coli KOEGE 77 (202a)", "rank": "Strain"}, "1894": {"name": "Streptomyces aureofaciens", "rank": "Species"}, "1130302": {"name": "Crenarchaeote SCGC AAA261-L14", "rank": "Species"}, "1896": {"name": "Streptomyces bikiniensis", "rank": "Species"}, "1154857": {"name": "Streptococcus agalactiae STIR-CD-29", "rank": "Strain"}, "1892": {"name": "Streptomyces anulatus", "rank": "Species"}, "1893": {"name": "Streptomyces atratus", "rank": "Species"}, "1154856": {"name": "Streptococcus agalactiae STIR-CD-28", "rank": "Strain"}, "316279": {"name": "Synechococcus sp. CC9902", "rank": "Species"}, "316278": {"name": "Synechococcus sp. RCC307", "rank": "Species"}, "316277": {"name": "Syntrophus aciditrophicus", "rank": "Species"}, "1154851": {"name": "Streptococcus agalactiae STIR-CD-23", "rank": "Strain"}, "316275": {"name": "Aliivibrio salmonicida LFI1238", "rank": "Strain"}, "316274": {"name": "Herpetosiphon aurantiacus DSM 785", "rank": "Strain"}, "316273": {"name": "Xanthomonas campestris pv. vesicatoria str. 85-10", "rank": "Strain"}, "1281174": {"name": "Escherichia coli UMEA 3022-1", "rank": "Strain"}, "1281177": {"name": "Escherichia coli UMEA 3052-1", "rank": "Strain"}, "1069631": {"name": "Alcaligenes sp. HPC1271", "rank": "Species"}, "1141625": {"name": "Murine astrovirus", "rank": "Species"}, "1402811": {"name": "Staphylococcus aureus M1333", "rank": "Strain"}, "224135": {"name": "Candidatus Glomeribacter", "rank": "Genus"}, "754088": {"name": "Escherichia coli STEC_H.1.8", "rank": "Strain"}, "754089": {"name": "Escherichia coli STEC_MHI813", "rank": "Strain"}, "754086": {"name": "Escherichia coli STEC_DG131-3", "rank": "Strain"}, "754087": {"name": "Escherichia coli STEC_EH250", "rank": "Strain"}, "754084": {"name": "Escherichia coli STEC_B2F1", "rank": "Strain"}, "1269941": {"name": "Aliivibrio logei ATCC 35077", "rank": "Strain"}, "754082": {"name": "Escherichia coli STEC_7v", "rank": "Strain"}, "399314": {"name": "Strawberry chlorotic fleck-associated virus", "rank": "Species"}, "754080": {"name": "Escherichia coli 3030-1", "rank": "Strain"}, "754081": {"name": "Escherichia coli STEC_O31", "rank": "Strain"}, "1158179": {"name": "Thioalkalivibrio sp. ALE28", "rank": "Species"}, "1265616": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 33.A.05", "rank": "Strain"}, "1265617": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 36.H.00", "rank": "Strain"}, "1167694": {"name": "Escherichia coli O32:H37 str. P4", "rank": "Strain"}, "1167697": {"name": "Enterococcus faecium LCT-EF90", "rank": "Strain"}, "1167696": {"name": "Ikoma lyssavirus", "rank": "Species"}, "1189622": {"name": "Pseudomonas syringae pv. tabaci str. 6605", "rank": "Strain"}, "1167693": {"name": "Escherichia coli O32:H37", "rank": "Strain"}, "293613": {"name": "Rickettsia canadensis str. McKiel", "rank": "Strain"}, "712119": {"name": "Actinomyces sp. oral taxon 175", "rank": "Species"}, "293614": {"name": "Rickettsia akari str. Hartford", "rank": "Strain"}, "70600": {"name": "Epiphyas postvittana nucleopolyhedrovirus", "rank": "Species"}, "70601": {"name": "Pyrococcus horikoshii OT3", "rank": "Strain"}, "491081": {"name": "Treponema pallidum subsp. pallidum DAL-1", "rank": "Strain"}, "64303": {"name": "Aroa virus", "rank": "Species"}, "754330": {"name": "Escherichia sp. TW09276", "rank": "Species"}, "754331": {"name": "Escherichia sp. TW09308", "rank": "Species"}, "754332": {"name": "Escherichia sp. TW10509", "rank": "Species"}, "754333": {"name": "Escherichia sp. TW11588", "rank": "Species"}, "1158160": {"name": "Thioalkalivibrio sp. AKL17", "rank": "Species"}, "904742": {"name": "Staphylococcus aureus subsp. aureus 21251", "rank": "Strain"}, "1087469": {"name": "Mycobacterium abscessus subsp. bolletii INCQS 00594", "rank": "Strain"}, "39491": {"name": "Eubacterium rectale", "rank": "Species"}, "243090": {"name": "Rhodopirellula baltica SH 1", "rank": "Strain"}, "444451": {"name": "Escherichia coli O157:H7 str. EC4196", "rank": "Strain"}, "444450": {"name": "Escherichia coli O157:H7 str. EC4115", "rank": "Strain"}, "444453": {"name": "Escherichia coli O157:H7 str. EC4076", "rank": "Strain"}, "444452": {"name": "Escherichia coli O157:H7 str. EC4113", "rank": "Strain"}, "444454": {"name": "Escherichia coli O157:H7 str. EC4024", "rank": "Strain"}, "197483": {"name": "Unclassified Bacillaceae", "rank": "No rank"}, "904746": {"name": "Staphylococcus aureus subsp. aureus 21264", "rank": "Strain"}, "904747": {"name": "Staphylococcus aureus subsp. aureus 21266", "rank": "Strain"}, "1403913": {"name": "Staphylococcus aureus M1538", "rank": "Strain"}, "1403912": {"name": "Staphylococcus aureus M1536", "rank": "Strain"}, "1403911": {"name": "Staphylococcus aureus M1535", "rank": "Strain"}, "1403910": {"name": "Staphylococcus aureus M1534", "rank": "Strain"}, "1403917": {"name": "Staphylococcus aureus M1543", "rank": "Strain"}, "1403916": {"name": "Staphylococcus aureus M1542", "rank": "Strain"}, "1403915": {"name": "Staphylococcus aureus M1541", "rank": "Strain"}, "1403914": {"name": "Staphylococcus aureus M1539", "rank": "Strain"}, "1403918": {"name": "Staphylococcus aureus M1545", "rank": "Strain"}, "64311": {"name": "Kedougou virus", "rank": "Species"}, "1130348": {"name": "Cloacimonetes bacterium JGI 0000014-K11", "rank": "Species"}, "1130343": {"name": "Gracilibacteria bacterium JGI 0000069-P22", "rank": "Species"}, "1130342": {"name": "Gracilibacteria bacterium JGI 0000069-K10", "rank": "Species"}, "214675": {"name": "Leptospira interrogans serovar Manilae", "rank": "Strain"}, "1130347": {"name": "Cloacimonetes bacterium JGI 0000014-H19", "rank": "Species"}, "1130346": {"name": "Cloacimonetes bacterium JGI 0000014-D18", "rank": "Species"}, "284042": {"name": "Streptomyces violaceorubidus", "rank": "Species"}, "47929": {"name": "Macacine herpesvirus 3", "rank": "Species"}, "1527522": {"name": "Unclassified Virgaviridae", "rank": "No rank"}, "1100842": {"name": "Acinetobacter baumannii TYTH-2", "rank": "Strain"}, "1100841": {"name": "Acinetobacter baumannii TYTH-1", "rank": "Strain"}, "1100847": {"name": "Acinetobacter baumannii TYTH-7", "rank": "Strain"}, "1100846": {"name": "Acinetobacter baumannii TYTH-6", "rank": "Strain"}, "1100845": {"name": "Acinetobacter baumannii TYTH-5", "rank": "Strain"}, "1100844": {"name": "Acinetobacter baumannii TYTH-4", "rank": "Strain"}, "113553": {"name": "Poinsettia mosaic virus", "rank": "Species"}, "1412772": {"name": "Staphylococcus aureus M91141", "rank": "Strain"}, "113557": {"name": "Lactobacillus paracasei subsp. tolerans", "rank": "Subspecies"}, "185959": {"name": "Spiroplasma phage 1-C74", "rank": "Species"}, "180504": {"name": "Burkholderia phage phiE125", "rank": "Species"}, "1412774": {"name": "Staphylococcus aureus M91160", "rank": "Strain"}, "911135": {"name": "Methanobrevibacter smithii TS96C", "rank": "Strain"}, "911134": {"name": "Methanobrevibacter smithii TS96B", "rank": "Strain"}, "911133": {"name": "Methanobrevibacter smithii TS96A", "rank": "Strain"}, "911132": {"name": "Methanobrevibacter smithii TS95D", "rank": "Strain"}, "673839": {"name": "Enterococcus phage phiFL4A", "rank": "Species"}, "911130": {"name": "Methanobrevibacter smithii TS95B", "rank": "Strain"}, "673837": {"name": "Enterococcus phage phiFL3A", "rank": "Species"}, "673835": {"name": "Enterococcus phage phiFL2A", "rank": "Species"}, "673832": {"name": "Enterococcus phage phiFL1A", "rank": "Species"}, "1144708": {"name": "Pseudomonas sp. GM41(2012)", "rank": "Species"}, "64312": {"name": "Montana myotis leukoencephalitis virus", "rank": "Species"}, "1181778": {"name": "Escherichia coli KTE234", "rank": "Strain"}, "29554": {"name": "Mycoplasma canadense", "rank": "Species"}, "98668": {"name": "Mycobacterium septicum", "rank": "Species"}, "1068608": {"name": "Escherichia coli XH140A", "rank": "Strain"}, "1233171": {"name": "Clostridium bifermentans ATCC 638", "rank": "Strain"}, "686340": {"name": "Methylomicrobium album BG8", "rank": "Strain"}, "29559": {"name": "Mycoplasma hyosynoviae", "rank": "Species"}, "1304916": {"name": "Klebsiella pneumoniae 140_1040", "rank": "Strain"}, "365659": {"name": "Streptococcus mitis B6", "rank": "Strain"}, "311230": {"name": "Burkholderia terrae", "rank": "Species"}, "723892": {"name": "Bacillus atrophaeus ATCC 9372-2", "rank": "Strain"}, "40137": {"name": "Oligotropha carboxidovorans", "rank": "Species"}, "666684": {"name": "Afipia sp. 1NLS2", "rank": "Species"}, "666685": {"name": "Rhodanobacter denitrificans", "rank": "Species"}, "1188234": {"name": "Mycoplasma alkalescens 14918", "rank": "Strain"}, "1188235": {"name": "Mycoplasma bovigenitalium 51080", "rank": "Strain"}, "1188236": {"name": "Mycoplasma arginini 7264", "rank": "Strain"}, "985867": {"name": "Candidatus Odyssella thessalonicensis L13", "rank": "Strain"}, "1188231": {"name": "Mariprofundus ferrooxydans M34", "rank": "Strain"}, "1188233": {"name": "Mycoplasma auris 15026", "rank": "Strain"}, "457392": {"name": "Bacteroides sp. 3_2_5", "rank": "Species"}, "1188238": {"name": "Mycoplasma capricolum subsp. capricolum 14232", "rank": "Strain"}, "1188239": {"name": "Mycoplasma ovipneumoniae 14811", "rank": "Strain"}, "995019": {"name": "Sutterellaceae", "rank": "Family"}, "70793": {"name": "Turkey astrovirus", "rank": "Species"}, "513557": {"name": "Syntrophorhabdus", "rank": "Genus"}, "457391": {"name": "Bacteroides sp. 3_1_33FAA", "rank": "Species"}, "304899": {"name": "Actinospica acidiphila", "rank": "Species"}, "513556": {"name": "Syntrophorhabdaceae", "rank": "Family"}, "1537702": {"name": "Delftia sp. 670", "rank": "Species"}, "878260": {"name": "Rhododendron virus A", "rank": "Species"}, "935791": {"name": "Nematocida parisii ERTm3", "rank": "Strain"}, "1001730": {"name": "Mycobacterium abscessus 5S-0708", "rank": "Strain"}, "456481": {"name": "Leptospira biflexa serovar Patoc strain 'Patoc 1 (Paris)'", "rank": "Strain"}, "543152": {"name": "Mycobacterium phage Nigel", "rank": "Species"}, "543153": {"name": "Mycobacterium phage Predator", "rank": "Species"}, "1001735": {"name": "Mycobacterium abscessus 5S-0817", "rank": "Strain"}, "1170234": {"name": "Feline morbillivirus", "rank": "Species"}, "1329365": {"name": "Yersinia enterocolitica subsp. palearctica YE-149", "rank": "Strain"}, "1329364": {"name": "Yersinia enterocolitica subsp. palearctica YE-P4", "rank": "Strain"}, "1329366": {"name": "Yersinia enterocolitica subsp. palearctica YE-150", "rank": "Strain"}, "1388467": {"name": "Staphylococcus aureus M0698", "rank": "Strain"}, "1388466": {"name": "Staphylococcus aureus M0697", "rank": "Strain"}, "1388465": {"name": "Staphylococcus aureus M0696", "rank": "Strain"}, "1388464": {"name": "Staphylococcus aureus M0693", "rank": "Strain"}, "1388463": {"name": "Staphylococcus aureus M0691", "rank": "Strain"}, "1388462": {"name": "Staphylococcus aureus M0690", "rank": "Strain"}, "1388461": {"name": "Staphylococcus aureus M0689", "rank": "Strain"}, "1388460": {"name": "Staphylococcus aureus M0686", "rank": "Strain"}, "1388469": {"name": "Staphylococcus aureus M0700", "rank": "Strain"}, "1266911": {"name": "Thioalkalivibrio sp. ALRh", "rank": "Species"}, "1201294": {"name": "Methanoculleus bourgensis MS2", "rank": "Strain"}, "1201295": {"name": "Shewanella sp. POL2", "rank": "Species"}, "1160168": {"name": "Brucella abortus NI422", "rank": "Strain"}, "1160169": {"name": "Brucella abortus NI492", "rank": "Strain"}, "1201290": {"name": "Bacteriovorax sp. BAL6_X", "rank": "Species"}, "1331238": {"name": "Bordetella bronchiseptica MBORD901", "rank": "Strain"}, "1201292": {"name": "Enterococcus faecalis ATCC 29212", "rank": "Strain"}, "1201293": {"name": "Moritella dasanensis ArB 0140", "rank": "Strain"}, "1160162": {"name": "Brucella abortus NI649", "rank": "Strain"}, "1160163": {"name": "Brucella abortus NI240", "rank": "Strain"}, "1160160": {"name": "Brucella abortus NI628", "rank": "Strain"}, "1331239": {"name": "Bordetella bronchiseptica MO211", "rank": "Strain"}, "1160166": {"name": "Brucella abortus NI380", "rank": "Strain"}, "1160167": {"name": "Brucella abortus NI388", "rank": "Strain"}, "1160164": {"name": "Brucella abortus NI274", "rank": "Strain"}, "1160165": {"name": "Brucella abortus NI352", "rank": "Strain"}, "237561": {"name": "Candida albicans SC5314", "rank": "Strain"}, "374005": {"name": "Gremmeniella abietina type B RNA virus XL1", "rank": "Strain"}, "307461": {"name": "Apocheima cinerarium nucleopolyhedrovirus", "rank": "Species"}, "535898": {"name": "Rosa rugosa leaf distortion virus", "rank": "Species"}, "307467": {"name": "Euproctis pseudoconspersa nucleopolyhedrovirus", "rank": "Species"}, "346096": {"name": "Paludibacter", "rank": "Genus"}, "331278": {"name": "Yersinia phage phiR1-37", "rank": "Species"}, "391228": {"name": "Beet curly top Iran virus", "rank": "Species"}, "642248": {"name": "Unclassified Circoviridae", "rank": "No rank"}, "496058": {"name": "Spirosoma panaciterrae", "rank": "Species"}, "1442012": {"name": "Pigeon pea latent virus", "rank": "Species"}, "1266738": {"name": "Proteus mirabilis BB2000", "rank": "Strain"}, "1266739": {"name": "Chlamydia trachomatis E/CS88(f)", "rank": "Strain"}, "1517": {"name": "Thermoanaerobacterium thermosaccharolyticum", "rank": "Species"}, "1516": {"name": "Thermoanaerobacter thermohydrosulfuricus", "rank": "Species"}, "1511": {"name": "Clostridium sticklandii", "rank": "Species"}, "1510": {"name": "Clostridium stercorarium", "rank": "Species"}, "1513": {"name": "Clostridium tetani", "rank": "Species"}, "1512": {"name": "Clostridium symbiosum", "rank": "Species"}, "1519": {"name": "Clostridium tyrobutyricum", "rank": "Species"}, "1123304": {"name": "Streptococcus henryi DSM 19005", "rank": "Strain"}, "135826": {"name": "Jeotgalibacillus alimentarius", "rank": "Species"}, "1123302": {"name": "Streptococcus entericus DSM 14446", "rank": "Strain"}, "1123300": {"name": "Streptococcus devriesei DSM 19639", "rank": "Strain"}, "938672": {"name": "Alpha proteobacterium SCGC AAA487-M09", "rank": "Species"}, "682147": {"name": "Gardnerella vaginalis AMD", "rank": "Strain"}, "457286": {"name": "Rhynchosia golden mosaic Yucatan virus", "rank": "Species"}, "682148": {"name": "Gardnerella vaginalis 5-1", "rank": "Strain"}, "1423532": {"name": "Mycobacterium tuberculosis BTB10-487", "rank": "Strain"}, "1395575": {"name": "Klebsiella pneumoniae subsp. pneumoniae KpQ15", "rank": "Strain"}, "1445557": {"name": "Ilomantsi virus", "rank": "Species"}, "1121832": {"name": "Fodinicurvata sediminis", "rank": "Species"}, "1121830": {"name": "Fodinicurvata fenggangensis", "rank": "Species"}, "497321": {"name": "Thauera sp. 63", "rank": "Species"}, "44252": {"name": "Paenibacillus macerans", "rank": "Species"}, "11095": {"name": "Pestivirus", "rank": "Genus"}, "44250": {"name": "Paenibacillus alvei", "rank": "Species"}, "1093773": {"name": "Mirabilis jalapa mottle virus", "rank": "Species"}, "72361": {"name": "Bacillus vallismortis", "rank": "Species"}, "72360": {"name": "Bacillus mojavensis", "rank": "Species"}, "457424": {"name": "Bacteroides fragilis 3_1_12", "rank": "Strain"}, "457425": {"name": "Streptomyces albus J1074", "rank": "Strain"}, "457427": {"name": "Streptomyces himastatinicus ATCC 53653", "rank": "Strain"}, "619693": {"name": "Prevotella sp. oral taxon 472 str. F0295", "rank": "Strain"}, "868141": {"name": "Escherichia coli DEC2D", "rank": "Strain"}, "46206": {"name": "Pseudobutyrivibrio ruminis", "rank": "Species"}, "46205": {"name": "Pseudobutyrivibrio", "rank": "Genus"}, "44255": {"name": "Bradyrhizobium oligotrophicum", "rank": "Species"}, "393049": {"name": "Small anellovirus", "rank": "Species"}, "46200": {"name": "Geovibrio", "rank": "Genus"}, "1409533": {"name": "Staphylococcus aureus SJUD6022", "rank": "Strain"}, "1409532": {"name": "Staphylococcus aureus COLL6021", "rank": "Strain"}, "5346": {"name": "Coprinopsis cinerea", "rank": "Species"}, "1409530": {"name": "Staphylococcus aureus KINW6010", "rank": "Strain"}, "1444307": {"name": "Brevibacillus agri 5-2", "rank": "Strain"}, "1409536": {"name": "Staphylococcus aureus SJUD6021", "rank": "Strain"}, "1409535": {"name": "Staphylococcus aureus SJUD6028", "rank": "Strain"}, "1409534": {"name": "Staphylococcus aureus SJUD6040", "rank": "Strain"}, "1444309": {"name": "Brevibacillus borstelensis 3096-7", "rank": "Strain"}, "1409538": {"name": "Staphylococcus aureus SCLE6010", "rank": "Strain"}, "1499973": {"name": "Escherichia sp. HT073016", "rank": "Species"}, "577309": {"name": "Paraprevotella", "rank": "Genus"}, "448384": {"name": "Enterobacteria phage Phi1", "rank": "Species"}, "352476": {"name": "Salterprovirus", "rank": "Genus"}, "632335": {"name": "Caldicellulosiruptor kristjanssonii I77R1B", "rank": "Strain"}, "1120746": {"name": "Bacterium MS4", "rank": "Species"}, "1082932": {"name": "Agrobacterium tumefaciens CCNWGS0286", "rank": "Strain"}, "1082933": {"name": "Mesorhizobium amorphae CCNWGS0123", "rank": "Strain"}, "1082930": {"name": "Pelagibacterium", "rank": "Genus"}, "1082931": {"name": "Pelagibacterium halotolerans B2", "rank": "Strain"}, "1422394": {"name": "Staphylococcus aureus VET0054R", "rank": "Strain"}, "1422395": {"name": "Staphylococcus aureus VET0055R", "rank": "Strain"}, "40522": {"name": "Listeria phage A500", "rank": "Species"}, "1422397": {"name": "Staphylococcus aureus VET0058R", "rank": "Strain"}, "1422390": {"name": "Staphylococcus aureus VET0050R", "rank": "Strain"}, "1422391": {"name": "Staphylococcus aureus VET0051R", "rank": "Strain"}, "1422392": {"name": "Staphylococcus aureus VET0052R", "rank": "Strain"}, "1422393": {"name": "Staphylococcus aureus VET0053R", "rank": "Strain"}, "348296": {"name": "Atlantic salmon swim bladder sarcoma virus", "rank": "Species"}, "1422398": {"name": "Staphylococcus aureus VET0059R", "rank": "Strain"}, "1422399": {"name": "Staphylococcus aureus VET0060R", "rank": "Strain"}, "1137960": {"name": "Allokutzneria", "rank": "Genus"}, "1088866": {"name": "Mycobacterium phage Nappy", "rank": "Species"}, "1088865": {"name": "Mycobacterium phage MoMoMixon", "rank": "Species"}, "1129771": {"name": "Leptotrichiaceae", "rank": "Family"}, "1088868": {"name": "Commensalibacter intestini A911", "rank": "Strain"}, "1088869": {"name": "Gluconobacter morbifer G707", "rank": "Strain"}, "1042378": {"name": "Oceanicola sp. S124", "rank": "Species"}, "438753": {"name": "Azorhizobium caulinodans ORS 571", "rank": "Strain"}, "1042375": {"name": "Marinobacterium stanieri S30", "rank": "Strain"}, "1042376": {"name": "Flavobacteriaceae bacterium S85", "rank": "Species"}, "1042377": {"name": "Microbulbifer agarilyticus S89", "rank": "Strain"}, "1089119": {"name": "Mycobacterium phage Courthouse", "rank": "Species"}, "1089118": {"name": "Mycobacterium phage Bruns", "rank": "Species"}, "1089111": {"name": "Mycobacterium phage Alma", "rank": "Species"}, "158852": {"name": "Trabulsiella guamensis", "rank": "Species"}, "158851": {"name": "Trabulsiella", "rank": "Genus"}, "158850": {"name": "Providencia rustigianii", "rank": "Species"}, "1089115": {"name": "Mycobacterium phage Babsiella", "rank": "Species"}, "1089117": {"name": "Mycobacterium phage Blue7", "rank": "Species"}, "1089116": {"name": "Mycobacterium phage BillKnuckles", "rank": "Species"}, "249567": {"name": "Streptomyces decoyicus", "rank": "Species"}, "1423519": {"name": "Mycobacterium tuberculosis BTB10-253", "rank": "Strain"}, "1423518": {"name": "Mycobacterium tuberculosis BTB10-142", "rank": "Strain"}, "1423515": {"name": "Mycobacterium tuberculosis BTB10-092", "rank": "Strain"}, "1423514": {"name": "Mycobacterium tuberculosis BTB10-005", "rank": "Strain"}, "1423517": {"name": "Mycobacterium tuberculosis BTB10-120", "rank": "Strain"}, "1423516": {"name": "Mycobacterium tuberculosis BTB10-097", "rank": "Strain"}, "1423511": {"name": "Mycobacterium tuberculosis BTB09-554", "rank": "Strain"}, "1423510": {"name": "Mycobacterium tuberculosis BTB09-553", "rank": "Strain"}, "1423513": {"name": "Mycobacterium tuberculosis BTB10-001", "rank": "Strain"}, "1423512": {"name": "Mycobacterium tuberculosis BTB09-565", "rank": "Strain"}, "1123248": {"name": "Segetibacter koreensis DSM 18137", "rank": "Strain"}, "1123249": {"name": "Selenomonas artemidis DSM 19719", "rank": "Strain"}, "337702": {"name": "Donghicola xiamenensis", "rank": "Species"}, "1123240": {"name": "Sandarakinorhabdus limnophila DSM 17366", "rank": "Strain"}, "1123241": {"name": "Nakamurella lactea DSM 19367", "rank": "Strain"}, "340322": {"name": "Corynebacterium glutamicum R", "rank": "Strain"}, "1123247": {"name": "Sediminimonas qiaohouensis DSM 21189", "rank": "Strain"}, "1123244": {"name": "Sciscionella marina DSM 45152", "rank": "Strain"}, "132144": {"name": "Candidatus Glomeribacter gigasporarum", "rank": "Species"}, "718221": {"name": "Bacillus cereus str. Schrouff", "rank": "Strain"}, "1431545": {"name": "Candidatus Halobonum tyrrellensis", "rank": "Species"}, "1431544": {"name": "Candidatus Halobonum", "rank": "Genus"}, "1431547": {"name": "Chlamydia trachomatis C/TW-3", "rank": "Strain"}, "1075397": {"name": "Halolamina", "rank": "Genus"}, "1151123": {"name": "Pseudomonas sp. 35MFCvi1.1", "rank": "Species"}, "1151120": {"name": "Bacillus sp. 105MF", "rank": "Species"}, "1151121": {"name": "Bacillus sp. 95MFCvi2.1", "rank": "Species"}, "124252": {"name": "Nocardiopsis halotolerans", "rank": "Species"}, "341189": {"name": "Serpula lacrymans var. lacrymans", "rank": "Varietas"}, "1151126": {"name": "Microbacterium paraoxydans 77MFTsu3.2", "rank": "Strain"}, "349171": {"name": "Unclassified Cytorhabdovirus", "rank": "No rank"}, "880724": {"name": "Methanotorris igneus Kol 5", "rank": "Strain"}, "1151124": {"name": "Pseudomonas sp. 45MFCol3.1", "rank": "Species"}, "1513489": {"name": "Bitter gourd yellow vein virus", "rank": "Species"}, "1476391": {"name": "Pseudomonas phage vB_PaeP_C2-10_Ab09", "rank": "Species"}, "551789": {"name": "Ponticaulis koreensis DSM 19734", "rank": "Strain"}, "75105": {"name": "Burkholderia caribensis", "rank": "Species"}, "1123866": {"name": "SAR86 cluster bacterium SAR86A", "rank": "Species"}, "1123867": {"name": "SAR86 cluster bacterium SAR86B", "rank": "Species"}, "1123864": {"name": "SAR86 cluster bacterium SAR86C", "rank": "Species"}, "1123865": {"name": "SAR86 cluster bacterium SAR86D", "rank": "Species"}, "1123862": {"name": "Klebsiella pneumoniae subsp. pneumoniae Kp13", "rank": "Strain"}, "1123863": {"name": "Pantoea ananatis LMG 5342", "rank": "Strain"}, "1034125": {"name": "Mycobacterium phage Faith1", "rank": "Species"}, "1412588": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20130345", "rank": "Strain"}, "1412589": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20130346", "rank": "Strain"}, "1412587": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20090195", "rank": "Strain"}, "1412584": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20100131", "rank": "Strain"}, "1412585": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20090530", "rank": "Strain"}, "1412582": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20121970", "rank": "Strain"}, "1412583": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20121969", "rank": "Strain"}, "1412580": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20121986", "rank": "Strain"}, "1412581": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20121976", "rank": "Strain"}, "1169398": {"name": "Escherichia coli KTE167", "rank": "Strain"}, "396513": {"name": "Staphylococcus carnosus subsp. carnosus TM300", "rank": "Strain"}, "68170": {"name": "Lechevalieria aerocolonigenes", "rank": "Species"}, "1380430": {"name": "Halolamina rubra", "rank": "Species"}, "1248417": {"name": "Clostridium botulinum Af84", "rank": "Strain"}, "1248411": {"name": "Staphylococcus epidermidis 36-1", "rank": "Strain"}, "1124654": {"name": "Escherichia phage TL-2011b", "rank": "Species"}, "1124655": {"name": "Escherichia phage TL-2011c", "rank": "Species"}, "1182571": {"name": "Deinococcus swuensis", "rank": "Species"}, "10401": {"name": "Ictalurid herpesvirus 1", "rank": "Species"}, "10406": {"name": "Ground squirrel hepatitis virus", "rank": "Species"}, "10407": {"name": "Hepatitis B virus", "rank": "Species"}, "10404": {"name": "Hepadnaviridae", "rank": "Family"}, "10405": {"name": "Orthohepadnavirus", "rank": "Genus"}, "1121352": {"name": "Conchiformibius steedae DSM 2580", "rank": "Strain"}, "1121353": {"name": "Corynebacterium callunae DSM 20147", "rank": "Strain"}, "1413356": {"name": "Staphylococcus aureus 09S01694", "rank": "Strain"}, "1121351": {"name": "Conchiformibius kuhniae DSM 17694", "rank": "Strain"}, "1121356": {"name": "Corynebacterium ciconiae DSM 44920", "rank": "Strain"}, "1413351": {"name": "Staphylococcus aureus 07-03451", "rank": "Strain"}, "1121354": {"name": "Corynebacterium capitovis DSM 44611", "rank": "Strain"}, "1121355": {"name": "Corynebacterium caspium DSM 44850", "rank": "Strain"}, "1173754": {"name": "Salmonella phage FSL SP-030", "rank": "Species"}, "1121358": {"name": "Corynebacterium doosanense", "rank": "Species"}, "288": {"name": "Pseudoalteromonas atlantica", "rank": "Species"}, "1413359": {"name": "Staphylococcus aureus 11S00605", "rank": "Strain"}, "1427325": {"name": "Mycobacterium tuberculosis XTB13-265", "rank": "Strain"}, "760799": {"name": "Streptococcus pneumoniae GA19451", "rank": "Strain"}, "760798": {"name": "Streptococcus pneumoniae GA19101", "rank": "Strain"}, "760795": {"name": "Streptococcus pneumoniae GA18523", "rank": "Strain"}, "1388074": {"name": "Staphylococcus aureus M0123", "rank": "Strain"}, "760797": {"name": "Streptococcus pneumoniae GA19077", "rank": "Strain"}, "938131": {"name": "Mycobacterium phage Wee", "rank": "Species"}, "760791": {"name": "Streptococcus pneumoniae GA17570", "rank": "Strain"}, "760790": {"name": "Streptococcus pneumoniae GA17328", "rank": "Strain"}, "760793": {"name": "Streptococcus pneumoniae GA17971", "rank": "Strain"}, "760792": {"name": "Streptococcus pneumoniae GA17719", "rank": "Strain"}, "1229758": {"name": "Leuconostoc carnosum JB16", "rank": "Strain"}, "1427320": {"name": "Mycobacterium tuberculosis XTB13-252", "rank": "Strain"}, "1229753": {"name": "Escherichia phage phAPEC8", "rank": "Species"}, "688449": {"name": "Salivirus", "rank": "Genus"}, "242619": {"name": "Porphyromonas gingivalis W83", "rank": "Strain"}, "1427321": {"name": "Mycobacterium tuberculosis XTB13-253", "rank": "Strain"}, "1229756": {"name": "Leuconostoc gelidum JB7", "rank": "Strain"}, "1229755": {"name": "Vibrio phage vB_VpaS_MAR10", "rank": "Species"}, "1229754": {"name": "Vibrio phage vB_VpaM_MAR", "rank": "Species"}, "1345558": {"name": "Helicobacter pylori SA158A", "rank": "Strain"}, "1345559": {"name": "Helicobacter pylori SA158C", "rank": "Strain"}, "1340708": {"name": "Mycobacterium phage Bobi", "rank": "Species"}, "1340709": {"name": "Mycobacterium phage Redno2", "rank": "Species"}, "1345550": {"name": "Helicobacter pylori SA302C", "rank": "Strain"}, "1345551": {"name": "Helicobacter pylori SA303C", "rank": "Strain"}, "1345552": {"name": "Helicobacter pylori SA155A", "rank": "Strain"}, "1345553": {"name": "Helicobacter pylori SA155C", "rank": "Strain"}, "1345554": {"name": "Helicobacter pylori SA156A", "rank": "Strain"}, "1345555": {"name": "Helicobacter pylori SA156C", "rank": "Strain"}, "1345556": {"name": "Helicobacter pylori SA157A", "rank": "Strain"}, "1345557": {"name": "Helicobacter pylori SA157C", "rank": "Strain"}, "155905": {"name": "Pestivirus Giraffe-1", "rank": "Species"}, "864178": {"name": "Clostridium phage phiCD6356", "rank": "Species"}, "1301220": {"name": "Citrus vein enation virus", "rank": "Species"}, "1273687": {"name": "Mycobacterium sp. VKM Ac-1817D", "rank": "Species"}, "996306": {"name": "Streptococcus suis R61", "rank": "Strain"}, "202907": {"name": "Collimonas", "rank": "Genus"}, "1287240": {"name": "Mesorhizobium sp. LNHC229A00", "rank": "Species"}, "1287243": {"name": "Mesorhizobium sp. LNHC232B00", "rank": "Species"}, "1263550": {"name": "Edwardsiella piscicida", "rank": "Species"}, "659": {"name": "Photobacterium phosphoreum", "rank": "Species"}, "650": {"name": "Aeromonas jandaei", "rank": "Species"}, "651": {"name": "Aeromonas media", "rank": "Species"}, "652": {"name": "Aeromonas schubertii", "rank": "Species"}, "654": {"name": "Aeromonas veronii", "rank": "Species"}, "656": {"name": "Aeromonas allosaccharophila", "rank": "Species"}, "657": {"name": "Photobacterium", "rank": "Genus"}, "1337957": {"name": "Amycolatopsis orientalis DSM 43388", "rank": "Strain"}, "1410698": {"name": "Staphylococcus aureus W31947", "rank": "Strain"}, "1410699": {"name": "Staphylococcus aureus W31852", "rank": "Strain"}, "1410694": {"name": "Staphylococcus aureus F41902", "rank": "Strain"}, "1410695": {"name": "Staphylococcus aureus M85201", "rank": "Strain"}, "1410696": {"name": "Staphylococcus aureus T49441", "rank": "Strain"}, "1410697": {"name": "Staphylococcus aureus W31936", "rank": "Strain"}, "1410690": {"name": "Staphylococcus aureus F41886", "rank": "Strain"}, "1410691": {"name": "Staphylococcus aureus F41906", "rank": "Strain"}, "1410692": {"name": "Staphylococcus aureus F41913", "rank": "Strain"}, "1410693": {"name": "Staphylococcus aureus F41882", "rank": "Strain"}, "51665": {"name": "Aerococcus urinaeequi", "rank": "Species"}, "51669": {"name": "Tetragenococcus halophilus", "rank": "Species"}, "51668": {"name": "Tetragenococcus", "rank": "Genus"}, "1128959": {"name": "Salmonella enterica subsp. enterica serovar Heidelberg str. 41573", "rank": "Strain"}, "1128958": {"name": "Salmonella enterica subsp. enterica serovar Heidelberg str. 41567", "rank": "Strain"}, "329562": {"name": "Planktothrix prolifica NIVA-CYA 98", "rank": "Strain"}, "1128953": {"name": "Klebsiella pneumoniae subsp. pneumoniae KPNIH19", "rank": "Strain"}, "1128952": {"name": "Klebsiella pneumoniae subsp. pneumoniae KPNIH18", "rank": "Strain"}, "1128951": {"name": "Klebsiella pneumoniae subsp. pneumoniae KPNIH17", "rank": "Strain"}, "1128950": {"name": "Klebsiella pneumoniae subsp. pneumoniae KPNIH16", "rank": "Strain"}, "1128957": {"name": "Salmonella enterica subsp. enterica serovar Heidelberg str. N15757", "rank": "Strain"}, "1128956": {"name": "Salmonella enterica subsp. enterica serovar Heidelberg str. N4630", "rank": "Strain"}, "1128955": {"name": "Salmonella enterica subsp. enterica serovar Heidelberg str. 21381", "rank": "Strain"}, "1128954": {"name": "Klebsiella pneumoniae subsp. pneumoniae KPNIH20", "rank": "Strain"}, "1388665": {"name": "Staphylococcus aureus M0891", "rank": "Strain"}, "1388664": {"name": "Staphylococcus aureus M0890", "rank": "Strain"}, "1388667": {"name": "Staphylococcus aureus M0894", "rank": "Strain"}, "1388666": {"name": "Staphylococcus aureus M0893", "rank": "Strain"}, "1388661": {"name": "Staphylococcus aureus M0887", "rank": "Strain"}, "1388660": {"name": "Staphylococcus aureus M0886", "rank": "Strain"}, "1388663": {"name": "Staphylococcus aureus M0889", "rank": "Strain"}, "1388662": {"name": "Staphylococcus aureus M0888", "rank": "Strain"}, "1388669": {"name": "Staphylococcus aureus M0896", "rank": "Strain"}, "1388668": {"name": "Staphylococcus aureus M0895", "rank": "Strain"}, "204711": {"name": "Theilovirus", "rank": "Species"}, "1425363": {"name": "Carrot betaflexivirus 1", "rank": "Species"}, "1302649": {"name": "Tetragenococcus muriaticus PMC-11-5", "rank": "Strain"}, "1302648": {"name": "Tetragenococcus muriaticus 3MR10-3", "rank": "Strain"}, "556548": {"name": "Corynebacterium freiburgense", "rank": "Species"}, "198112": {"name": "Deformed wing virus", "rank": "Species"}, "198110": {"name": "Pseudomonas phage 201phi2-1", "rank": "Species"}, "1007082": {"name": "Candidatus Nitrosoarchaeum", "rank": "Genus"}, "1382995": {"name": "Chaetoceros sp. DNA virus 7", "rank": "Species"}, "1007084": {"name": "Candidatus Nitrosoarchaeum limnia", "rank": "Species"}, "386056": {"name": "Burkholderia ferrariae", "rank": "Species"}, "158463": {"name": "Tomato severe rugose virus", "rank": "Species"}, "1400053": {"name": "Bacteroidales bacterium CF", "rank": "Species"}, "599651": {"name": "Bermanella", "rank": "Genus"}, "1394178": {"name": "Actinomadura madurae LIID-AJ290", "rank": "Strain"}, "1394179": {"name": "Mycoplasma iowae DK-CPA", "rank": "Strain"}, "1394175": {"name": "Bifidobacterium sp. 7101", "rank": "Species"}, "1394176": {"name": "Bifidobacterium sp. A11", "rank": "Species"}, "1439158": {"name": "Streptococcus pyogenes ABC020047395", "rank": "Strain"}, "1439159": {"name": "Streptococcus pyogenes ABC020047506", "rank": "Strain"}, "1439152": {"name": "Streptococcus pyogenes ABC020047076", "rank": "Strain"}, "1439153": {"name": "Streptococcus pyogenes ABC020047086", "rank": "Strain"}, "1439150": {"name": "Streptococcus pyogenes ABC020046688", "rank": "Strain"}, "1439151": {"name": "Streptococcus pyogenes ABC020046986", "rank": "Strain"}, "1439157": {"name": "Streptococcus pyogenes ABC020047328", "rank": "Strain"}, "1073969": {"name": "Teredinibacter turnerae T8402", "rank": "Strain"}, "1223259": {"name": "Pseudomonas phage JBD24", "rank": "Species"}, "1663": {"name": "Arthrobacter", "rank": "Genus"}, "304767": {"name": "Dehalobacter sp. E1", "rank": "Species"}, "1661": {"name": "Trueperella pyogenes", "rank": "Species"}, "1660": {"name": "Actinomyces odontolyticus", "rank": "Species"}, "1665": {"name": "Arthrobacter globiformis", "rank": "Species"}, "1112008": {"name": "Escherichia phage bV_EcoS_AKFV33", "rank": "Species"}, "1168280": {"name": "Cronobacter phage phiES15", "rank": "Species"}, "1514896": {"name": "Yerba mate endornavirus", "rank": "Species"}, "64104": {"name": "Bacillus pseudomycoides", "rank": "Species"}, "1302241": {"name": "Propionibacterium acnes JCM 18909", "rank": "Strain"}, "1302243": {"name": "Propionibacterium acnes JCM 18918", "rank": "Strain"}, "1302242": {"name": "Propionibacterium acnes JCM 18916", "rank": "Strain"}, "1302244": {"name": "Propionibacterium acnes JCM 18920", "rank": "Strain"}, "128827": {"name": "Erysipelotrichaceae", "rank": "Family"}, "240292": {"name": "Anabaena variabilis ATCC 29413", "rank": "Strain"}, "178214": {"name": "Facklamia hominis", "rank": "Species"}, "191675": {"name": "Unclassified Enterobacteriaceae", "rank": "No rank"}, "191676": {"name": "Unclassified Xanthomonadaceae", "rank": "No rank"}, "460086": {"name": "Kribbella catacumbae", "rank": "Species"}, "1392039": {"name": "Staphylococcus aureus M1024", "rank": "Strain"}, "1392038": {"name": "Staphylococcus aureus M1023", "rank": "Strain"}, "1392037": {"name": "Staphylococcus aureus M1022", "rank": "Strain"}, "1392036": {"name": "Staphylococcus aureus M1021", "rank": "Strain"}, "1392035": {"name": "Staphylococcus aureus M1019", "rank": "Strain"}, "1392034": {"name": "Staphylococcus aureus M1018", "rank": "Strain"}, "1392033": {"name": "Staphylococcus aureus M1017", "rank": "Strain"}, "1392032": {"name": "Staphylococcus aureus M1014", "rank": "Strain"}, "1392031": {"name": "Staphylococcus aureus M1013", "rank": "Strain"}, "1392030": {"name": "Staphylococcus aureus M1012", "rank": "Strain"}, "1267359": {"name": "Mycobacterium tuberculosis TKK-01-0023", "rank": "Strain"}, "1410880": {"name": "Staphylococcus aureus W20433", "rank": "Strain"}, "1410883": {"name": "Staphylococcus aureus H79477", "rank": "Strain"}, "1410882": {"name": "Staphylococcus aureus T45945", "rank": "Strain"}, "1410885": {"name": "Staphylococcus aureus T49833", "rank": "Strain"}, "1410884": {"name": "Staphylococcus aureus H79484", "rank": "Strain"}, "1410887": {"name": "Staphylococcus aureus H23830", "rank": "Strain"}, "1410886": {"name": "Staphylococcus aureus H23829", "rank": "Strain"}, "1410889": {"name": "Staphylococcus aureus W48973", "rank": "Strain"}, "1410888": {"name": "Staphylococcus aureus W48969", "rank": "Strain"}, "1267355": {"name": "Mycobacterium tuberculosis TKK-01-0008", "rank": "Strain"}, "1267357": {"name": "Mycobacterium tuberculosis TKK-01-0020", "rank": "Strain"}, "1267356": {"name": "Mycobacterium tuberculosis TKK-01-0017", "rank": "Strain"}, "665959": {"name": "Bacillus sp. 2_A_57_CT2", "rank": "Species"}, "665958": {"name": "Bacillus sp. BT1B_CT2", "rank": "Species"}, "715989": {"name": "Sordariomyceta", "rank": "No rank"}, "665953": {"name": "Bacteroides eggerthii 1_2_48FAA", "rank": "Strain"}, "665952": {"name": "Bacillus smithii 7_3_47FAA", "rank": "Strain"}, "665951": {"name": "Lachnospiraceae bacterium 8_1_57FAA", "rank": "Species"}, "665950": {"name": "Lachnospiraceae bacterium 3_1_46FAA", "rank": "Species"}, "665957": {"name": "Bacillus sp. 7_6_55CFAA_CT2", "rank": "Species"}, "665956": {"name": "Subdoligranulum sp. 4_3_54A2FAA", "rank": "Species"}, "665954": {"name": "Bacteroides ovatus 3_8_47FAA", "rank": "Strain"}, "1538101": {"name": "Small begomovirus-associated satellite", "rank": "Species"}, "270": {"name": "Thermus", "rank": "Genus"}, "271": {"name": "Thermus aquaticus", "rank": "Species"}, "276": {"name": "Thermus filiformis", "rank": "Species"}, "277": {"name": "Meiothermus ruber", "rank": "Species"}, "274": {"name": "Thermus thermophilus", "rank": "Species"}, "1990": {"name": "Actinomadura atramentaria", "rank": "Species"}, "1993": {"name": "Actinomadura madurae", "rank": "Species"}, "279": {"name": "Xanthobacter", "rank": "Genus"}, "1995": {"name": "Microtetraspora", "rank": "Genus"}, "1996": {"name": "Microtetraspora glauca", "rank": "Species"}, "1412725": {"name": "Staphylococcus aureus F46780", "rank": "Strain"}, "1236958": {"name": "Sneathiella glossodoripedis JCM 23214", "rank": "Strain"}, "1195796": {"name": "Human papillomavirus type 154", "rank": "Species"}, "196895": {"name": "Unclassified Podoviridae", "rank": "No rank"}, "196894": {"name": "Unclassified Siphoviridae", "rank": "No rank"}, "196896": {"name": "Unclassified Myoviridae", "rank": "No rank"}, "873565": {"name": "Diplorickettsia", "rank": "Genus"}, "447020": {"name": "Adlercreutzia", "rank": "Genus"}, "1215343": {"name": "Liberibacter crescens BT-1", "rank": "Strain"}, "508527": {"name": "Leptospira interrogans serovar Naam", "rank": "Strain"}, "1165868": {"name": "Burkholderia cenocepacia S2AES", "rank": "Strain"}, "1165869": {"name": "Burkholderia cenocepacia D2AES", "rank": "Strain"}, "78537": {"name": "Unclassified Actinobacteria (miscellaneous)", "rank": "No rank"}, "265726": {"name": "Photobacterium halotolerans", "rank": "Species"}, "1353980": {"name": "Shigella dysenteriae SD1D", "rank": "Strain"}, "1353981": {"name": "Enterococcus faecalis SDVK1A", "rank": "Strain"}, "1353982": {"name": "Morganella morganii subsp. morganii GM1DA1", "rank": "Strain"}, "1353983": {"name": "Cladonia macilenta KoLRI003786", "rank": "Strain"}, "398580": {"name": "Dinoroseobacter shibae DFL 12 = DSM 16493", "rank": "Strain"}, "1508420": {"name": "Thermotoga profunda", "rank": "Species"}, "1095700": {"name": "Neisseria meningitidis 87255", "rank": "Strain"}, "168480": {"name": "Gordonia namibiensis", "rank": "Species"}, "285107": {"name": "Thioclava", "rank": "Genus"}, "399183": {"name": "Escherichia phage rv5", "rank": "Species"}, "399185": {"name": "Staphylococcus phage PH15", "rank": "Species"}, "148942": {"name": "Streptococcus equi subsp. equi", "rank": "Subspecies"}, "148943": {"name": "Rhodothermus phage RM378", "rank": "Species"}, "1453498": {"name": "Flavobacterium aquatile LMG 4008", "rank": "Strain"}, "1453492": {"name": "Chryseobacterium hispalense", "rank": "Species"}, "1453496": {"name": "Hafnia alvei FB1", "rank": "Strain"}, "324831": {"name": "Lactobacillus gasseri ATCC 33323 = JCM 1131", "rank": "Strain"}, "1413371": {"name": "Staphylococcus aureus 12-ST01988", "rank": "Strain"}, "1421948": {"name": "Mycobacterium tuberculosis TB_RSA32", "rank": "Strain"}, "544875": {"name": "Enterococcus faecium E1636", "rank": "Strain"}, "1354514": {"name": "Mycobacterium phage Quink", "rank": "Species"}, "404770": {"name": "Marinobacterium litorale", "rank": "Species"}, "1481187": {"name": "Acinetobacter phage vB_AbaP_Acibel007", "rank": "Species"}, "1354510": {"name": "Mycobacterium phage Fredward", "rank": "Species"}, "1310624": {"name": "Acinetobacter baumannii 1202252", "rank": "Strain"}, "1310625": {"name": "Acinetobacter baumannii 496487", "rank": "Strain"}, "1310626": {"name": "Acinetobacter baumannii 21871", "rank": "Strain"}, "1310620": {"name": "Acinetobacter baumannii 1294217", "rank": "Strain"}, "1310621": {"name": "Acinetobacter baumannii 869535", "rank": "Strain"}, "1310622": {"name": "Acinetobacter baumannii 1035119", "rank": "Strain"}, "1310623": {"name": "Acinetobacter baumannii 146457", "rank": "Strain"}, "1310628": {"name": "Acinetobacter baumannii 1267820", "rank": "Strain"}, "1310629": {"name": "Acinetobacter baumannii 135867", "rank": "Strain"}, "1418412": {"name": "Staphylococcus aureus M67953", "rank": "Strain"}, "1418413": {"name": "Staphylococcus aureus M67957", "rank": "Strain"}, "1418410": {"name": "Staphylococcus aureus M66410", "rank": "Strain"}, "1418411": {"name": "Staphylococcus aureus M67929_020413", "rank": "Strain"}, "1418416": {"name": "Staphylococcus aureus M91652", "rank": "Strain"}, "1418417": {"name": "Staphylococcus aureus T15898", "rank": "Strain"}, "1151199": {"name": "Enterococcus faecalis EnGen0080", "rank": "Strain"}, "1403819": {"name": "Verrucomicrobium sp. BvORR106", "rank": "Species"}, "1406860": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 24249", "rank": "Strain"}, "1151196": {"name": "Enterococcus faecalis EnGen0058", "rank": "Strain"}, "1151195": {"name": "Enterococcus faecalis EnGen0075", "rank": "Strain"}, "1408847": {"name": "Borrelia garinii IPT124", "rank": "Strain"}, "1408840": {"name": "Borrelia garinii IPT107", "rank": "Strain"}, "1408841": {"name": "Borrelia garinii IPT108", "rank": "Strain"}, "1406866": {"name": "Sulfitobacter pontiacus 3SOLIMAR09", "rank": "Strain"}, "1408843": {"name": "Borrelia garinii IPT114", "rank": "Strain"}, "389469": {"name": "Pseudomonas phage DMS3", "rank": "Species"}, "876269": {"name": "Methyloferula stellata AR4", "rank": "Strain"}, "486410": {"name": "Streptococcus dysgalactiae subsp. equisimilis GGS_124", "rank": "Strain"}, "1421947": {"name": "Mycobacterium tuberculosis TB_RSA31", "rank": "Strain"}, "291644": {"name": "Bacteroides salyersiae", "rank": "Species"}, "291645": {"name": "Bacteroides nordii", "rank": "Species"}, "944481": {"name": "Hippea sp. KM1", "rank": "Species"}, "944480": {"name": "Hippea alviniae EP5-r", "rank": "Strain"}, "64958": {"name": "Parietaria mottle virus", "rank": "Species"}, "64952": {"name": "Ilarvirus subgroup 5", "rank": "No rank"}, "64951": {"name": "Ilarvirus subgroup 4", "rank": "No rank"}, "64950": {"name": "Ilarvirus subgroup 3", "rank": "No rank"}, "269801": {"name": "Bacillus cereus G9241", "rank": "Strain"}, "269800": {"name": "Thermobifida fusca YX", "rank": "Strain"}, "1388258": {"name": "Staphylococcus aureus M0388", "rank": "Strain"}, "1388259": {"name": "Staphylococcus aureus M0389", "rank": "Strain"}, "76857": {"name": "Fusobacterium nucleatum subsp. polymorphum", "rank": "Subspecies"}, "76856": {"name": "Fusobacterium nucleatum subsp. nucleatum", "rank": "Subspecies"}, "76853": {"name": "Solibacillus silvestris", "rank": "Species"}, "1388250": {"name": "Staphylococcus aureus M0377", "rank": "Strain"}, "1388251": {"name": "Staphylococcus aureus M0378", "rank": "Strain"}, "1388252": {"name": "Staphylococcus aureus M0380", "rank": "Strain"}, "1388253": {"name": "Staphylococcus aureus M0382", "rank": "Strain"}, "344021": {"name": "Enterobacteria phage K1F", "rank": "Species"}, "1388255": {"name": "Staphylococcus aureus M0384", "rank": "Strain"}, "1388256": {"name": "Staphylococcus aureus M0385", "rank": "Strain"}, "344022": {"name": "Enterobacteria phage K1E", "rank": "Species"}, "361606": {"name": "Patulibacteraceae", "rank": "Family"}, "361607": {"name": "Patulibacter", "rank": "Genus"}, "1168548": {"name": "Salmonella phage vB_SemP_Emek", "rank": "Species"}, "1168549": {"name": "Salmonella phage vB_SosS_Oslo", "rank": "Species"}, "1311573": {"name": "Helicobacter pylori UM032", "rank": "Strain"}, "683083": {"name": "Campylobacter jejuni subsp. jejuni 414", "rank": "Strain"}, "683082": {"name": "Campylobacter jejuni subsp. jejuni 1336", "rank": "Strain"}, "1311576": {"name": "Chloroflexi bacterium oral taxon 439 isolate Chl1-2", "rank": "Strain"}, "1311575": {"name": "Chloroflexi bacterium oral taxon 439 isolate Chl2", "rank": "Strain"}, "1311574": {"name": "Chloroflexi bacterium oral taxon 439 isolate Chl1", "rank": "Strain"}, "1129374": {"name": "Alishewanella jeotgali KCTC 22429", "rank": "Strain"}, "46919": {"name": "Whitewater Arroyo virus", "rank": "Species"}, "236756": {"name": "Candidatus Scalindua", "rank": "Genus"}, "984218": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. 642044 4-1", "rank": "Strain"}, "984219": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. 642046 4-7", "rank": "Strain"}, "984214": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. 22558", "rank": "Strain"}, "984215": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. 543463 22-17", "rank": "Strain"}, "984216": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. 543463 40-18", "rank": "Strain"}, "984217": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. 561362 1-1", "rank": "Strain"}, "46917": {"name": "Papaya leaf distortion mosaic virus", "rank": "Species"}, "984211": {"name": "Salmonella enterica subsp. enterica serovar Anatum str. ATCC BAA-1592", "rank": "Strain"}, "984212": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. 17927", "rank": "Strain"}, "984213": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. CHS4", "rank": "Strain"}, "310684": {"name": "Cheravirus", "rank": "Genus"}, "480813": {"name": "Tatumella saanichensis", "rank": "Species"}, "80341": {"name": "Equid herpesvirus 3", "rank": "Species"}, "1215068": {"name": "Peptoclostridium difficile T11", "rank": "Strain"}, "1215069": {"name": "Peptoclostridium difficile E15", "rank": "Strain"}, "1215066": {"name": "Peptoclostridium difficile E25", "rank": "Strain"}, "1215064": {"name": "Peptoclostridium difficile T22", "rank": "Strain"}, "1215065": {"name": "Peptoclostridium difficile E16", "rank": "Strain"}, "1215062": {"name": "Peptoclostridium difficile E13", "rank": "Strain"}, "1215063": {"name": "Peptoclostridium difficile CD002", "rank": "Strain"}, "1215060": {"name": "Peptoclostridium difficile T20", "rank": "Strain"}, "1215061": {"name": "Peptoclostridium difficile E10", "rank": "Strain"}, "38345": {"name": "Leptospira kirschneri serovar Grippotyphosa", "rank": "Strain"}, "1402789": {"name": "Staphylococcus aureus M1304", "rank": "Strain"}, "1402788": {"name": "Staphylococcus aureus M1303", "rank": "Strain"}, "317655": {"name": "Sphingopyxis alaskensis RB2256", "rank": "Strain"}, "1402781": {"name": "Staphylococcus aureus M1296", "rank": "Strain"}, "1402780": {"name": "Staphylococcus aureus M1295", "rank": "Strain"}, "1535287": {"name": "Devosia sp. 17-2-E-8", "rank": "Species"}, "1402782": {"name": "Staphylococcus aureus M1297", "rank": "Strain"}, "1402785": {"name": "Staphylococcus aureus M1300", "rank": "Strain"}, "1402784": {"name": "Staphylococcus aureus M1299", "rank": "Strain"}, "1402787": {"name": "Staphylococcus aureus M1302", "rank": "Strain"}, "1402786": {"name": "Staphylococcus aureus M1301", "rank": "Strain"}, "1121028": {"name": "Aureimonas ureilytica DSM 18598", "rank": "Strain"}, "1121024": {"name": "Atopococcus tabaci DSM 17538", "rank": "Strain"}, "1121027": {"name": "Aurantimonas coralicida DSM 14790", "rank": "Strain"}, "1121020": {"name": "Arthrobacter sanguinis DSM 21259", "rank": "Strain"}, "1121022": {"name": "Asticcacaulis benevestitus DSM 16100 = ATCC BAA-896", "rank": "Strain"}, "1121023": {"name": "Atopobium fossor DSM 15642", "rank": "Strain"}, "1261622": {"name": "Thioalkalivibrio sp. ALJ2", "rank": "Species"}, "1261621": {"name": "Azoarcus toluclasticus ATCC 700605", "rank": "Strain"}, "405955": {"name": "Escherichia coli APEC O1", "rank": "Strain"}, "1354112": {"name": "Mycobacterium tuberculosis MAL020202", "rank": "Strain"}, "1354113": {"name": "Mycobacterium tuberculosis MAL020205", "rank": "Strain"}, "1354111": {"name": "Mycobacterium tuberculosis MAL020201", "rank": "Strain"}, "1354116": {"name": "Mycobacterium tuberculosis MAL020209", "rank": "Strain"}, "1354117": {"name": "Mycobacterium tuberculosis MAL020211", "rank": "Strain"}, "1354114": {"name": "Mycobacterium tuberculosis MAL020206", "rank": "Strain"}, "340907": {"name": "Papiine herpesvirus 2", "rank": "Species"}, "1354115": {"name": "Mycobacterium tuberculosis MAL020208", "rank": "Strain"}, "858517": {"name": "Cleome golden mosaic virus", "rank": "Species"}, "387342": {"name": "Halopiger", "rank": "Genus"}, "313598": {"name": "Polaribacter sp. MED152", "rank": "Species"}, "1315272": {"name": "Agrobacterium tumefaciens GW4", "rank": "Strain"}, "1315273": {"name": "Pseudoalteromonas flavipulchra NCIMB 2033 = ATCC BAA-314", "rank": "Strain"}, "313590": {"name": "Dokdonia sp. MED134", "rank": "Species"}, "313595": {"name": "Psychroflexus torquis ATCC 700755", "rank": "Strain"}, "313594": {"name": "Polaribacter irgensii 23-P", "rank": "Strain"}, "313596": {"name": "Robiginitalea biformata HTCC2501", "rank": "Strain"}, "1472720": {"name": "Staphylococcus sp. TE8", "rank": "Species"}, "1472721": {"name": "Alphacoronavirus 2", "rank": "Species"}, "39741": {"name": "Barnaviridae", "rank": "Family"}, "344971": {"name": "Mouse parvovirus 2", "rank": "Species"}, "344970": {"name": "Mouse parvovirus 3", "rank": "Species"}, "1234592": {"name": "Vibrio sp. 712i1", "rank": "Species"}, "1422509": {"name": "Staphylococcus aureus VET0213R", "rank": "Strain"}, "225422": {"name": "Oceanibulbus indolifex", "rank": "Species"}, "225421": {"name": "Oceanibulbus", "rank": "Genus"}, "202813": {"name": "Adeno-associated virus - 8", "rank": "Strain"}, "1535751": {"name": "Anoxybacillus sp. KU2-6(11)", "rank": "Species"}, "1535750": {"name": "Thermoactinomyces sp. Gus2-1", "rank": "Species"}, "202812": {"name": "Adeno-associated virus - 7", "rank": "Strain"}, "10882": {"name": "Orthoreovirus", "rank": "Genus"}, "10880": {"name": "Reoviridae", "rank": "Family"}, "230759": {"name": "Agaricales incertae sedis", "rank": "No rank"}, "634956": {"name": "Geobacillus thermoglucosidasius C56-YS93", "rank": "Strain"}, "544581": {"name": "Actinomyces johnsonii", "rank": "Species"}, "187137": {"name": "Oceanithermus profundus", "rank": "Species"}, "1464786": {"name": "Laodelphax striatella honeydew virus 1", "rank": "Species"}, "1431455": {"name": "Klebsiella pneumoniae NB60", "rank": "Strain"}, "1094484": {"name": "Acinetobacter baumannii ABNIH20", "rank": "Strain"}, "1094487": {"name": "Acinetobacter baumannii ABNIH23", "rank": "Strain"}, "1094486": {"name": "Acinetobacter baumannii ABNIH22", "rank": "Strain"}, "1094481": {"name": "Acinetobacter baumannii ABNIH17", "rank": "Strain"}, "107401": {"name": "Tenacibaculum maritimum", "rank": "Species"}, "1094483": {"name": "Acinetobacter baumannii ABNIH19", "rank": "Strain"}, "1094482": {"name": "Acinetobacter baumannii ABNIH18", "rank": "Strain"}, "1422143": {"name": "Staphylococcus aureus DAR3596", "rank": "Strain"}, "1443995": {"name": "Salmonella enterica subsp. enterica serovar Typhi str. STH2370", "rank": "Strain"}, "1443993": {"name": "Herbaspirillum sp. RV1423", "rank": "Species"}, "1094488": {"name": "Acinetobacter baumannii ABNIH24", "rank": "Strain"}, "744995": {"name": "OMG group", "rank": "No rank"}, "280500": {"name": "Leptospira interrogans serovar Pyrogenes", "rank": "Strain"}, "1151116": {"name": "Rahnella aquatilis HX2", "rank": "Strain"}, "744996": {"name": "OM60 clade", "rank": "No rank"}, "280505": {"name": "Leptospira borgpetersenii serovar Ballum", "rank": "Strain"}, "280504": {"name": "Leptospira borgpetersenii serovar Javanica", "rank": "Strain"}, "280507": {"name": "Leptospira borgpetersenii serovar Mini", "rank": "Strain"}, "221235": {"name": "Candidate division SR1", "rank": "No rank"}, "744998": {"name": "BD1-7 clade", "rank": "No rank"}, "1500890": {"name": "Luteibacter sp. 9143", "rank": "Species"}, "1500891": {"name": "Luteibacter sp. 9133", "rank": "Species"}, "1500892": {"name": "Luteibacter sp. 9145", "rank": "Species"}, "1500893": {"name": "Luteibacter sp. 9135", "rank": "Species"}, "1500894": {"name": "Massilia sp. 9096", "rank": "Species"}, "1500895": {"name": "Erwinia sp. 9145", "rank": "Species"}, "1500896": {"name": "Pantoea sp. 9140", "rank": "Species"}, "1500897": {"name": "Burkholderia sp. 9120", "rank": "Species"}, "1095688": {"name": "Neisseria meningitidis NM586", "rank": "Strain"}, "1095689": {"name": "Neisseria meningitidis NM418", "rank": "Strain"}, "1095680": {"name": "Neisseria meningitidis 12888", "rank": "Strain"}, "1095681": {"name": "Neisseria meningitidis 9757", "rank": "Strain"}, "1095682": {"name": "Neisseria meningitidis 9506", "rank": "Strain"}, "1095683": {"name": "Neisseria meningitidis NM126", "rank": "Strain"}, "1095684": {"name": "Neisseria meningitidis NM174", "rank": "Strain"}, "1095685": {"name": "Neisseria meningitidis M7124", "rank": "Strain"}, "1095686": {"name": "Neisseria meningitidis M7089", "rank": "Strain"}, "1095687": {"name": "Neisseria meningitidis NM762", "rank": "Strain"}, "1408435": {"name": "Entomoplasma melaleucae ATCC 49191", "rank": "Strain"}, "1408434": {"name": "Deinococcus radiodurans ATCC 13939", "rank": "Strain"}, "1408437": {"name": "Eubacterium desmolans ATCC 43058", "rank": "Strain"}, "1408436": {"name": "Eubacterium cellulosolvens LD2006", "rank": "Strain"}, "1408431": {"name": "Butyrivibrio proteoclasticus FD2007", "rank": "Strain"}, "1408430": {"name": "Brachyspira alvinipulli ATCC 51933", "rank": "Strain"}, "1408433": {"name": "Crocinitomix catalasitica ATCC 23190", "rank": "Strain"}, "1408439": {"name": "Fusobacterium perfoetens ATCC 29250", "rank": "Strain"}, "1408438": {"name": "Facklamia sourekii ATCC 700629", "rank": "Strain"}, "95619": {"name": "Pseudomonas sp. M1", "rank": "Species"}, "1234594": {"name": "Pseudomonas sp. 313", "rank": "Species"}, "1169289": {"name": "Enterococcus faecalis EnGen0363", "rank": "Strain"}, "933290": {"name": "Neisseria meningitidis NS44", "rank": "Strain"}, "46123": {"name": "Abiotrophia", "rank": "Genus"}, "46126": {"name": "Staphylococcus chromogenes", "rank": "Species"}, "46124": {"name": "Granulicatella adiacens", "rank": "Species"}, "46125": {"name": "Abiotrophia defectiva", "rank": "Species"}, "983918": {"name": "Pseudomonas aeruginosa HB13", "rank": "Strain"}, "1094992": {"name": "Candida albicans P37037", "rank": "Strain"}, "373126": {"name": "Sodalis phage phiSG1", "rank": "Species"}, "1116177": {"name": "Escherichia coli P0304816.1", "rank": "Strain"}, "1123053": {"name": "Rheinheimera baltica DSM 14885", "rank": "Strain"}, "1123052": {"name": "Rathayibacter toxicus DSM 7488", "rank": "Strain"}, "1123057": {"name": "Rhodonellum psychrophilum GCM71 = DSM 17998", "rank": "Strain"}, "935835": {"name": "Bacillus sp. J13", "rank": "Species"}, "935836": {"name": "Bacillus sp. J33", "rank": "Species"}, "1123054": {"name": "Rheinheimera perlucida DSM 18276", "rank": "Strain"}, "935839": {"name": "Cellulosimicrobium cellulans J36", "rank": "Strain"}, "1123059": {"name": "Robiginitomaculum antarcticum DSM 21748", "rank": "Strain"}, "1123058": {"name": "Riemerella columbina DSM 16469", "rank": "Strain"}, "1422647": {"name": "Staphylococcus aureus VET0423R", "rank": "Strain"}, "1208319": {"name": "Francisella tularensis subsp. tularensis 70001275", "rank": "Strain"}, "1208314": {"name": "Gordonia namibiensis NBRC 108229", "rank": "Strain"}, "493475": {"name": "Glaciecola arctica BSs20135", "rank": "Strain"}, "227377": {"name": "Coxiella burnetii RSA 493", "rank": "Strain"}, "481805": {"name": "Escherichia coli ATCC 8739", "rank": "Strain"}, "1154842": {"name": "Streptococcus agalactiae MRI Z1-205", "rank": "Strain"}, "1154843": {"name": "Streptococcus agalactiae MRI Z1-206", "rank": "Strain"}, "1154840": {"name": "Streptococcus agalactiae MRI Z1-203", "rank": "Strain"}, "1154841": {"name": "Streptococcus agalactiae MRI Z1-204", "rank": "Strain"}, "1154846": {"name": "Streptococcus agalactiae STIR-CD-09", "rank": "Strain"}, "1154847": {"name": "Streptococcus agalactiae STIR-CD-13", "rank": "Strain"}, "1154844": {"name": "Streptococcus agalactiae STIR-CD-01", "rank": "Strain"}, "1154845": {"name": "Streptococcus agalactiae STIR-CD-07", "rank": "Strain"}, "1409570": {"name": "Staphylococcus aureus SJUD6104", "rank": "Strain"}, "1069609": {"name": "Neisseria meningitidis 93004", "rank": "Strain"}, "1069608": {"name": "Neisseria meningitidis 93003", "rank": "Strain"}, "695982": {"name": "Halogranum", "rank": "Genus"}, "1409784": {"name": "Staphylococcus aureus KINW6047", "rank": "Strain"}, "1409785": {"name": "Staphylococcus aureus KINW6048", "rank": "Strain"}, "1409786": {"name": "Escherichia coli K02", "rank": "Strain"}, "1409787": {"name": "Klebsiella oxytoca G54", "rank": "Strain"}, "1409780": {"name": "Staphylococcus aureus FVRH6118", "rank": "Strain"}, "1409781": {"name": "Staphylococcus aureus OCMM6129", "rank": "Strain"}, "1409782": {"name": "Staphylococcus aureus CHAP6022", "rank": "Strain"}, "1409783": {"name": "Staphylococcus aureus KINW6046", "rank": "Strain"}, "1281166": {"name": "Escherichia coli KOEGE 68 (182a)", "rank": "Strain"}, "1003185": {"name": "Salmonella enterica subsp. enterica serovar Agona str. SA-1", "rank": "Strain"}, "1003186": {"name": "Salmonella enterica subsp. enterica serovar Agona str. SA-2", "rank": "Strain"}, "1003187": {"name": "Salmonella enterica subsp. enterica serovar Agona str. SA-3", "rank": "Strain"}, "702": {"name": "Plesiomonas", "rank": "Genus"}, "703": {"name": "Plesiomonas shigelloides", "rank": "Species"}, "885384": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. CDC_2010K_0895", "rank": "Strain"}, "885385": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. CDC_2010K_0899", "rank": "Strain"}, "1402806": {"name": "Staphylococcus aureus M1328", "rank": "Strain"}, "1402807": {"name": "Staphylococcus aureus M1329", "rank": "Strain"}, "1402804": {"name": "Staphylococcus aureus M1325", "rank": "Strain"}, "1402805": {"name": "Staphylococcus aureus M1326", "rank": "Strain"}, "1402802": {"name": "Staphylococcus aureus M1323", "rank": "Strain"}, "1402803": {"name": "Staphylococcus aureus M1324", "rank": "Strain"}, "1402800": {"name": "Staphylococcus aureus M1318", "rank": "Strain"}, "1402801": {"name": "Staphylococcus aureus M1319", "rank": "Strain"}, "1402808": {"name": "Staphylococcus aureus M1330", "rank": "Strain"}, "1402809": {"name": "Staphylococcus aureus M1331", "rank": "Strain"}, "660596": {"name": "Pantoea stewartii subsp. stewartii DC283", "rank": "Strain"}, "690850": {"name": "Desulfovibrio africanus str. Walvis Bay", "rank": "Strain"}, "223323": {"name": "Squash leaf curl China virus", "rank": "Species"}, "223321": {"name": "Sida yellow vein virus", "rank": "Species"}, "1137848": {"name": "Clostridium arbusti", "rank": "Species"}, "223324": {"name": "Squash mild leaf curl virus", "rank": "Species"}, "1412717": {"name": "Staphylococcus aureus F36670", "rank": "Strain"}, "1412716": {"name": "Staphylococcus aureus W92106", "rank": "Strain"}, "1412715": {"name": "Staphylococcus aureus W92100", "rank": "Strain"}, "1412714": {"name": "Staphylococcus aureus W92052", "rank": "Strain"}, "1412713": {"name": "Staphylococcus aureus W85326", "rank": "Strain"}, "1412711": {"name": "Staphylococcus aureus W81816", "rank": "Strain"}, "1412710": {"name": "Staphylococcus aureus W75539", "rank": "Strain"}, "1418320": {"name": "Staphylococcus aureus M20726", "rank": "Strain"}, "469621": {"name": "Fusobacterium periodonticum 1_1_41FAA", "rank": "Strain"}, "1412719": {"name": "Staphylococcus aureus F36687", "rank": "Strain"}, "1412718": {"name": "Staphylococcus aureus F36683", "rank": "Strain"}, "1352598": {"name": "Mycobacterium tuberculosis PanR1006", "rank": "Strain"}, "461393": {"name": "Actinomyces massiliensis", "rank": "Species"}, "1352599": {"name": "Mycobacterium tuberculosis PanR1007", "rank": "Strain"}, "508748": {"name": "Mesta yellow vein mosaic Bahraich virus", "rank": "Species"}, "613121": {"name": "Smaragdicoccus", "rank": "Genus"}, "1331255": {"name": "Bordetella hinzii 1277", "rank": "Strain"}, "1331256": {"name": "Bordetella hinzii 4161", "rank": "Strain"}, "1331257": {"name": "Bordetella hinzii 5132", "rank": "Strain"}, "1469557": {"name": "Lacinutrix sp. PAMC 27137", "rank": "Species"}, "1331251": {"name": "Bordetella holmseii H620", "rank": "Strain"}, "1331252": {"name": "Bordetella pertussis STO1-SEAT-0006", "rank": "Strain"}, "1331253": {"name": "Bordetella pertussis STO1-SEAT-0007", "rank": "Strain"}, "1108849": {"name": "Penicillium rubens", "rank": "Species"}, "1331258": {"name": "Bordetella hinzii 8-296-03", "rank": "Strain"}, "1331259": {"name": "Bordetella hinzii CA90 BAL1384", "rank": "Strain"}, "1352590": {"name": "Mycobacterium tuberculosis PanR0805", "rank": "Strain"}, "1352591": {"name": "Mycobacterium tuberculosis PanR0902", "rank": "Strain"}, "340047": {"name": "Mycoplasma capricolum subsp. capricolum ATCC 27343", "rank": "Strain"}, "1352592": {"name": "Mycobacterium tuberculosis PanR0903", "rank": "Strain"}, "340044": {"name": "Blattabacterium sp. (Panesthia angustipennis spadica)", "rank": "Species"}, "1444215": {"name": "Escherichia coli 1-110-08_S4_C1", "rank": "Strain"}, "1352593": {"name": "Mycobacterium tuberculosis PanR0904", "rank": "Strain"}, "1444214": {"name": "Escherichia coli 8-415-05_S4_C1", "rank": "Strain"}, "1444217": {"name": "Escherichia coli 1-182-04_S4_C1", "rank": "Strain"}, "1231376": {"name": "Zymomonas mobilis subsp. mobilis ATCC 31822", "rank": "Strain"}, "1231377": {"name": "Lactococcus garvieae DCC43", "rank": "Strain"}, "565140": {"name": "Bacillus phage TP21-L", "rank": "Species"}, "565143": {"name": "Bacillus subtilis subsp. subtilis str. AUSI98", "rank": "Strain"}, "1444216": {"name": "Escherichia coli 1-176-05_S4_C1", "rank": "Strain"}, "568394": {"name": "Pseudogulbenkiania", "rank": "Genus"}, "1344580": {"name": "Staphylococcus aureus S100", "rank": "Strain"}, "1444211": {"name": "Escherichia coli 5-172-05_S4_C1", "rank": "Strain"}, "1344582": {"name": "Vibrio owensii 47666-1", "rank": "Strain"}, "1344584": {"name": "Archaeoglobus fulgidus DSM 8774", "rank": "Strain"}, "1344585": {"name": "Winogradskyella psychrotolerans", "rank": "Species"}, "1409600": {"name": "Staphylococcus aureus FVRH6026", "rank": "Strain"}, "1444213": {"name": "Escherichia coli 7-233-03_S4_C1", "rank": "Strain"}, "1409602": {"name": "Staphylococcus aureus LAMC6066", "rank": "Strain"}, "1281026": {"name": "Escherichia coli HVH 89 (4-5885604)", "rank": "Strain"}, "1351836": {"name": "Brucella melitensis ADMAS-G1", "rank": "Strain"}, "191301": {"name": "Caminibacter", "rank": "Genus"}, "191303": {"name": "Turicibacter", "rank": "Genus"}, "1151119": {"name": "Arthrobacter sp. 162MFSha1.1", "rank": "Species"}, "1444219": {"name": "Escherichia coli 1-392-07_S4_C1", "rank": "Strain"}, "1444218": {"name": "Escherichia coli 1-250-04_S4_C1", "rank": "Strain"}, "533267": {"name": "Actinopolymorpha alba", "rank": "Species"}, "1287474": {"name": "Atopobium parvulum DNF00906", "rank": "Strain"}, "1287475": {"name": "Corynebacterium freneyi DNF00450", "rank": "Strain"}, "1048434": {"name": "Rose yellow mosaic virus", "rank": "Species"}, "1108972": {"name": "Pseudomonas syringae pv. actinidiae str. Shaanxi_M228", "rank": "Strain"}, "857581": {"name": "Moraxella catarrhalis 7169", "rank": "Strain"}, "372787": {"name": "Fischerella thermalis", "rank": "Species"}, "1412647": {"name": "Staphylococcus aureus F88369", "rank": "Strain"}, "469599": {"name": "Fusobacterium periodonticum 2_1_31", "rank": "Strain"}, "469598": {"name": "Escherichia sp. 3_2_53FAA", "rank": "Species"}, "1429851": {"name": "Stenotrophomonas maltophilia 5BA-I-2", "rank": "Strain"}, "469594": {"name": "Bifidobacterium sp. 12_1_47BFAA", "rank": "Species"}, "469597": {"name": "Coprobacillus sp. 8_2_54BFAA", "rank": "Species"}, "469596": {"name": "Coprobacillus sp. 29_1", "rank": "Species"}, "469591": {"name": "Parabacteroides sp. 20_3", "rank": "Species"}, "874267": {"name": "Staphylococcus phage phi5967PVL", "rank": "Species"}, "469593": {"name": "Bacteroides sp. 3_1_40A", "rank": "Species"}, "469592": {"name": "Bacteroides sp. 3_1_19", "rank": "Species"}, "341711": {"name": "Tomato leaf curl Pakistan virus", "rank": "Species"}, "1422538": {"name": "Staphylococcus aureus VET0260R", "rank": "Strain"}, "1514668": {"name": "Ruminococcus sp. HUN007", "rank": "Species"}, "1085386": {"name": "Bacillus cereus VDM021", "rank": "Strain"}, "1085388": {"name": "Bacillus cereus BAG3O-1", "rank": "Strain"}, "1085389": {"name": "Bacillus cereus B5-2", "rank": "Strain"}, "1131317": {"name": "Enterobacteria phage vB_EcoM-FV3", "rank": "Species"}, "1131316": {"name": "Rhodobacter phage RcapNL", "rank": "Species"}, "1131315": {"name": "Erwinia phage PEp14", "rank": "Species"}, "295319": {"name": "Salmonella enterica subsp. enterica serovar Paratyphi A str. ATCC 9150", "rank": "Strain"}, "1268350": {"name": "Burkholderia sp. JGI 0001005-I06", "rank": "Species"}, "1225176": {"name": "Cecembia lonarensis LW9", "rank": "Strain"}, "1225174": {"name": "Pseudomonas mendocina S5.2", "rank": "Strain"}, "295090": {"name": "Olive mild mosaic virus", "rank": "Species"}, "143387": {"name": "Fusobacterium necrophorum subsp. funduliforme", "rank": "Subspecies"}, "1225179": {"name": "Bartonella quintana RM-11", "rank": "Strain"}, "10293": {"name": "Alphaherpesvirinae", "rank": "Subfamily"}, "10292": {"name": "Herpesviridae", "rank": "Family"}, "156578": {"name": "Alteromonadales bacterium TW-7", "rank": "Species"}, "749499": {"name": "Enterococcus faecalis TX0031", "rank": "Strain"}, "10294": {"name": "Simplexvirus", "rank": "Genus"}, "1141101": {"name": "Salmonella enterica subsp. enterica serovar Typhimurium str. ST1660/06", "rank": "Strain"}, "749496": {"name": "Enterococcus faecalis TX0012", "rank": "Strain"}, "749495": {"name": "Enterococcus faecalis TX4248", "rank": "Strain"}, "10298": {"name": "Human herpesvirus 1", "rank": "Species"}, "1141105": {"name": "Staphylococcus delphini 8086", "rank": "Strain"}, "749492": {"name": "Enterococcus faecalis TX2141", "rank": "Strain"}, "749491": {"name": "Enterococcus faecalis TX2137", "rank": "Strain"}, "1141106": {"name": "Staphylococcus intermedius NCTC 11048", "rank": "Strain"}, "657314": {"name": "Ruminococcus obeum A2-162", "rank": "Strain"}, "657315": {"name": "Roseburia intestinalis M50/1", "rank": "Strain"}, "1125646": {"name": "Escherichia coli p0305293.14", "rank": "Strain"}, "657317": {"name": "Eubacterium rectale M104/1", "rank": "Strain"}, "657310": {"name": "Enterococcus sp. 7L76", "rank": "Species"}, "1125641": {"name": "Escherichia coli P0301867.2", "rank": "Strain"}, "1125642": {"name": "Escherichia coli P0301867.13", "rank": "Strain"}, "1041826": {"name": "Flavobacterium columnare ATCC 49512", "rank": "Strain"}, "205876": {"name": "Mycobacterium phage Che9d", "rank": "Species"}, "205877": {"name": "Mycobacterium phage Bxz1", "rank": "Species"}, "205874": {"name": "Mycobacterium phage Rosebush", "rank": "Species"}, "205875": {"name": "Mycobacterium phage Corndog", "rank": "Species"}, "657318": {"name": "Eubacterium rectale DSM 17629", "rank": "Strain"}, "657319": {"name": "Eubacterium siraeum 70/3", "rank": "Strain"}, "205870": {"name": "Mycobacterium phage Bxz2", "rank": "Species"}, "333138": {"name": "Bacillus okhensis", "rank": "Species"}, "378753": {"name": "Kocuria rhizophila DC2201", "rank": "Strain"}, "271108": {"name": "Bombyx mori nucleopolyhedrovirus", "rank": "Species"}, "1573535": {"name": "Holdemanella", "rank": "Genus"}, "1573534": {"name": "Faecalitalea", "rank": "Genus"}, "1573536": {"name": "Faecalicoccus", "rank": "Genus"}, "1458849": {"name": "Salmonella phage vB_SalM_SJ2", "rank": "Species"}, "1458848": {"name": "Enterobacteria phage Bp4", "rank": "Species"}, "1418388": {"name": "Staphylococcus aureus F87619", "rank": "Strain"}, "1418389": {"name": "Staphylococcus aureus F92121", "rank": "Strain"}, "1041148": {"name": "Sinorhizobium medicae DI28", "rank": "Strain"}, "1458841": {"name": "Mycobacterium phage CRB1", "rank": "Species"}, "1418383": {"name": "Staphylococcus aureus F48603", "rank": "Strain"}, "1458843": {"name": "Pseudomonas phage phiPsa374", "rank": "Species"}, "1458842": {"name": "Geobacillus phage GBK2", "rank": "Species"}, "1418386": {"name": "Staphylococcus aureus F56969", "rank": "Strain"}, "1418387": {"name": "Staphylococcus aureus F76253", "rank": "Strain"}, "1418384": {"name": "Staphylococcus aureus F48607", "rank": "Strain"}, "1458846": {"name": "Mycobacterium phage RhynO", "rank": "Species"}, "941429": {"name": "Shigella dysenteriae CDC 74-1112", "rank": "Strain"}, "446807": {"name": "Burkholderia phage BcepNY3", "rank": "Species"}, "1318635": {"name": "Lactobacillus casei LOCK919", "rank": "Strain"}, "1318634": {"name": "Lactobacillus rhamnosus LOCK908", "rank": "Strain"}, "1318633": {"name": "Streptococcus iniae SF1", "rank": "Strain"}, "167539": {"name": "Prochlorococcus marinus subsp. marinus str. CCMP1375", "rank": "Strain"}, "376849": {"name": "Lumpy skin disease virus NI-2490", "rank": "Strain"}, "363848": {"name": "Dyella ginsengisoli", "rank": "Species"}, "142627": {"name": "Rhizobium gallicum bv. gallicum", "rank": "Strain"}, "441999": {"name": "Magnaporthe oryzae virus 2", "rank": "Species"}, "1041144": {"name": "Rhizobium leguminosarum bv. viciae UPM1137", "rank": "Strain"}, "1448551": {"name": "Mycobacterium tuberculosis TKK_05SA_0050", "rank": "Strain"}, "582382": {"name": "Pseudomonas phage SN", "rank": "Species"}, "1399775": {"name": "Enterobacter cloacae JD8715", "rank": "Strain"}, "1399774": {"name": "Enterobacter cloacae JD6301", "rank": "Strain"}, "1399771": {"name": "Haemophilus parasuis ST4-1", "rank": "Strain"}, "1399772": {"name": "Haemophilus parasuis ST4-2", "rank": "Strain"}, "1438829": {"name": "Mycobacterium tuberculosis Wt 21419", "rank": "Strain"}, "1438828": {"name": "Mycobacterium tuberculosis Wt 21231", "rank": "Strain"}, "1400158": {"name": "Escherichia coli BIDMC 49a", "rank": "Strain"}, "1400159": {"name": "Escherichia coli BIDMC 49b", "rank": "Strain"}, "149682": {"name": "Streptomyces roseochromogenus subsp. oscitans", "rank": "Subspecies"}, "1400152": {"name": "Enterobacter cloacae UCI 39", "rank": "Strain"}, "1400150": {"name": "Enterobacter cloacae UCI 35", "rank": "Strain"}, "1400151": {"name": "Enterobacter cloacae UCI 36", "rank": "Strain"}, "1400156": {"name": "Escherichia coli BIDMC 43a", "rank": "Strain"}, "1400157": {"name": "Escherichia coli BIDMC 43b", "rank": "Strain"}, "1400154": {"name": "Enterobacter cloacae UCI 49", "rank": "Strain"}, "1400155": {"name": "Enterobacter cloacae UCI 50", "rank": "Strain"}, "59610": {"name": "Desulfotomaculum reducens", "rank": "Species"}, "1384550": {"name": "Klebsiella pneumoniae subsp. pneumoniae KKBO-4", "rank": "Strain"}, "154288": {"name": "Turicibacter sanguinis", "rank": "Species"}, "1260770": {"name": "Tomato leaf curl Karnataka alphasatellite", "rank": "Species"}, "1435357": {"name": "Bacillus anthracis str. V770-NP1-R", "rank": "Strain"}, "1435359": {"name": "Staphylococcus aureus CUHK_HK2007", "rank": "Strain"}, "1814": {"name": "Amycolatopsis methanolica", "rank": "Species"}, "1817": {"name": "Nocardia", "rank": "Genus"}, "1810": {"name": "Mycobacterium vaccae", "rank": "Species"}, "1813": {"name": "Amycolatopsis", "rank": "Genus"}, "318996": {"name": "Bradyrhizobium sp. WSM1743", "rank": "Species"}, "1263867": {"name": "Rhodopirellula europaea 6C", "rank": "Strain"}, "1263866": {"name": "Rhodopirellula europaea", "rank": "Species"}, "1263865": {"name": "Pseudomonas chloritidismutans AW-1", "rank": "Strain"}, "1263864": {"name": "Enterococcus faecalis MA1", "rank": "Strain"}, "1263869": {"name": "Rhodopirellula sallentina", "rank": "Species"}, "1263868": {"name": "Rhodopirellula europaea SH398", "rank": "Strain"}, "37636": {"name": "Thermus scotoductus", "rank": "Species"}, "37637": {"name": "Corynebacterium pseudodiphtheriticum", "rank": "Species"}, "71245": {"name": "Kazachstania", "rank": "Genus"}, "83191": {"name": "Melanoplus sanguinipes entomopoxvirus", "rank": "Species"}, "105260": {"name": "Listonella anguillarum serovar O2", "rank": "Strain"}, "146032": {"name": "Goose circovirus", "rank": "Species"}, "2316": {"name": "Methanosphaera", "rank": "Genus"}, "2317": {"name": "Methanosphaera stadtmanae", "rank": "Species"}, "2314": {"name": "Methanoplanus", "rank": "Genus"}, "2315": {"name": "Methanoplanus limicola", "rank": "Species"}, "1441607": {"name": "Vibrio parahaemolyticus TUMSAT_DE1_S1", "rank": "Strain"}, "2319": {"name": "Methanopyrus", "rank": "Genus"}, "1410383": {"name": "Symbiont bacterium UwTKB of Urostylis westwoodii", "rank": "Species"}, "1494964": {"name": "Listeria riparia", "rank": "Species"}, "1494962": {"name": "Listeria floridensis", "rank": "Species"}, "1494963": {"name": "Listeria grandensis", "rank": "Species"}, "1410384": {"name": "Wolbachia endosymbiont of Onchocerca volvulus str. Cameroon", "rank": "Strain"}, "1494961": {"name": "Listeria cornellensis", "rank": "Species"}, "1265846": {"name": "Listeria rocourtiae FSL F6-920", "rank": "Strain"}, "10811": {"name": "Geminiviridae", "rank": "Family"}, "10813": {"name": "Curtovirus", "rank": "Genus"}, "1438795": {"name": "Klebsiella pneumoniae MGH 72", "rank": "Strain"}, "637914": {"name": "Methanococcus maripaludis KA1", "rank": "Strain"}, "637915": {"name": "Methanococcus maripaludis OS7", "rank": "Strain"}, "1437596": {"name": "Bifidobacterium thermophilum DSM 20210", "rank": "Strain"}, "1437597": {"name": "Bifidobacterium longum subsp. suis DSM 20211", "rank": "Strain"}, "637910": {"name": "Citrobacter rodentium ICC168", "rank": "Strain"}, "637911": {"name": "Actinobacillus minor NM305", "rank": "Strain"}, "637913": {"name": "Helicobacter pylori v225d", "rank": "Strain"}, "1537917": {"name": "Sulfuricurvum sp. MLSB", "rank": "Species"}, "1537915": {"name": "Sulfurospirillum sp. SCADC", "rank": "Species"}, "1396418": {"name": "Verrucomicrobium sp. BvORR034", "rank": "Species"}, "129922": {"name": "Saccharomonospora halophila", "rank": "Species"}, "1324300": {"name": "Mycobacterium tuberculosis TKK-01-0093", "rank": "Strain"}, "1324301": {"name": "Mycobacterium tuberculosis TKK-01-0094", "rank": "Strain"}, "212742": {"name": "Morococcus", "rank": "Genus"}, "212743": {"name": "Rhizobacter", "rank": "Genus"}, "212745": {"name": "Serpens", "rank": "Genus"}, "217510": {"name": "Fulvimarina", "rank": "Genus"}, "217511": {"name": "Fulvimarina pelagi", "rank": "Species"}, "265570": {"name": "Sulfurovum", "rank": "Genus"}, "651660": {"name": "Paenisporosarcina", "rank": "Genus"}, "1244083": {"name": "Campylobacter showae CSUNSWCD", "rank": "Strain"}, "1401659": {"name": "Cronobacter sakazakii CMCC 45402", "rank": "Strain"}, "102148": {"name": "Solobacterium moorei", "rank": "Species"}, "140295": {"name": "Varicosavirus", "rank": "Genus"}, "712622": {"name": "Streptococcus sp. oral taxon 058", "rank": "Species"}, "1246628": {"name": "Pseudomonas fuscovaginae DAR 77795", "rank": "Strain"}, "1246626": {"name": "Bacillus lehensis G1", "rank": "Strain"}, "1246622": {"name": "Escherichia coli O10:K5(L):H4", "rank": "Strain"}, "1246623": {"name": "Escherichia coli O10:K5(L):H4 str. ATCC 23506", "rank": "Strain"}, "40640": {"name": "Potato virus V", "rank": "Species"}, "754004": {"name": "Sulfolobus turreted icosahedral virus 2", "rank": "Species"}, "196914": {"name": "Actinoplanes friuliensis", "rank": "Species"}, "344609": {"name": "Shigella boydii CDC 3083-94", "rank": "Strain"}, "165795": {"name": "Mixiaceae", "rank": "Family"}, "1288394": {"name": "Aeromonas hydrophila ML09-119", "rank": "Strain"}, "344601": {"name": "Escherichia coli B171", "rank": "Strain"}, "90371": {"name": "Salmonella enterica subsp. enterica serovar Typhimurium", "rank": "Strain"}, "1288391": {"name": "Actinomyces timonensis", "rank": "Species"}, "1403339": {"name": "Pseudomonas mosselii DSM 17497", "rank": "Strain"}, "11142": {"name": "Murine hepatitis virus strain A59", "rank": "Strain"}, "1403330": {"name": "Listeria monocytogenes Lm21045", "rank": "Strain"}, "666714": {"name": "Treponema pallidum subsp. pallidum str. Chicago", "rank": "Strain"}, "11144": {"name": "Murine hepatitis virus strain JHM", "rank": "Strain"}, "345074": {"name": "Vibrio cholerae RC385", "rank": "Strain"}, "519427": {"name": "Sharpea", "rank": "Genus"}, "29382": {"name": "Staphylococcus cohnii", "rank": "Species"}, "1151388": {"name": "Peptoclostridium difficile Y343", "rank": "Strain"}, "40519": {"name": "Ruminococcus callidus", "rank": "Species"}, "1339247": {"name": "Leuconostoc pseudomesenteroides PS12", "rank": "Strain"}, "1046937": {"name": "Unclassified Aenigmarchaeota", "rank": "No rank"}, "1151384": {"name": "Peptoclostridium difficile Y266", "rank": "Strain"}, "1151385": {"name": "Peptoclostridium difficile Y270", "rank": "Strain"}, "1339243": {"name": "Carnobacterium sp. ZWU0011", "rank": "Species"}, "1151383": {"name": "Peptoclostridium difficile Y247", "rank": "Strain"}, "1339241": {"name": "Comamonas testosteroni ZNC0007", "rank": "Strain"}, "1151381": {"name": "Peptoclostridium difficile Y215", "rank": "Strain"}, "1327947": {"name": "Mycobacterium phage Chy4", "rank": "Species"}, "40518": {"name": "Ruminococcus bromii", "rank": "Species"}, "1327948": {"name": "Mycobacterium phage Chy5", "rank": "Species"}, "1310581": {"name": "Acinetobacter baumannii 34654", "rank": "Strain"}, "1310580": {"name": "Acinetobacter baumannii 1297", "rank": "Strain"}, "1310583": {"name": "Acinetobacter baumannii 1051176", "rank": "Strain"}, "1310582": {"name": "Acinetobacter baumannii 662545-1347", "rank": "Strain"}, "1310585": {"name": "Acinetobacter baumannii 1051830", "rank": "Strain"}, "1310584": {"name": "Acinetobacter baumannii 23037", "rank": "Strain"}, "1310587": {"name": "Acinetobacter baumannii 947299", "rank": "Strain"}, "1310586": {"name": "Acinetobacter baumannii 1031433", "rank": "Strain"}, "1310589": {"name": "Acinetobacter baumannii 929679-2095", "rank": "Strain"}, "1310588": {"name": "Acinetobacter baumannii 562700", "rank": "Strain"}, "1409753": {"name": "Staphylococcus aureus DAR5897", "rank": "Strain"}, "1448749": {"name": "Mycobacterium tuberculosis M2084", "rank": "Strain"}, "1505932": {"name": "Mesorhizobium sp. ORS3324", "rank": "Species"}, "369333": {"name": "Paenibacillus terrigena", "rank": "Species"}, "1448745": {"name": "Mycobacterium tuberculosis M2010", "rank": "Strain"}, "180586": {"name": "Casphalia extranea densovirus", "rank": "Strain"}, "180587": {"name": "Honeysuckle yellow vein mosaic virus", "rank": "Species"}, "1448742": {"name": "Mycobacterium tuberculosis M2003", "rank": "Strain"}, "1093928": {"name": "Porcine astrovirus 5", "rank": "Species"}, "1049946": {"name": "Leptospira kirschneri serovar Grippotyphosa str. RM52", "rank": "Strain"}, "1049947": {"name": "Leptospira kirschneri serovar Grippotyphosa str. UT130", "rank": "Strain"}, "1049944": {"name": "Leptospira kirschneri serovar Grippotyphosa str. Duyster-Boelhouwer", "rank": "Strain"}, "1448740": {"name": "Mycobacterium tuberculosis M1979", "rank": "Strain"}, "1049942": {"name": "Leptospira kirschneri serovar Cynopteri str. 3522 CT", "rank": "Strain"}, "69476": {"name": "Unclassified Planctomycetaceae", "rank": "No rank"}, "1049940": {"name": "Leptospira interrogans str. UT126", "rank": "Strain"}, "69474": {"name": "Orientia", "rank": "Genus"}, "644076": {"name": "Silicibacter sp. TrichCH4B", "rank": "Species"}, "904799": {"name": "Staphylococcus aureus subsp. aureus CO-49", "rank": "Strain"}, "904798": {"name": "Staphylococcus aureus subsp. aureus CO-41", "rank": "Strain"}, "1346502": {"name": "Agrococcus pavilionensis", "rank": "Species"}, "904794": {"name": "Staphylococcus aureus subsp. aureus CO-08", "rank": "Strain"}, "904796": {"name": "Staphylococcus aureus subsp. aureus CO-30", "rank": "Strain"}, "904791": {"name": "Staphylococcus epidermidis IS-K", "rank": "Strain"}, "904793": {"name": "Staphylococcus aureus subsp. aureus CO-06", "rank": "Strain"}, "904792": {"name": "Staphylococcus aureus subsp. aureus IS-M", "rank": "Strain"}, "108486": {"name": "Corynebacterium falsenii", "rank": "Species"}, "1050347": {"name": "Pseudomonas brassicacearum 51MFCVI2.1", "rank": "Strain"}, "1448446": {"name": "Mycobacterium tuberculosis TKK_03_0112", "rank": "Strain"}, "1448447": {"name": "Mycobacterium tuberculosis TKK_03_0113", "rank": "Strain"}, "1448440": {"name": "Mycobacterium tuberculosis TKK_03_0106", "rank": "Strain"}, "1244087": {"name": "Paenibacillus lentimorbus NRRL B-30488", "rank": "Strain"}, "1448442": {"name": "Mycobacterium tuberculosis TKK_03_0108", "rank": "Strain"}, "1448443": {"name": "Mycobacterium tuberculosis TKK_03_0109", "rank": "Strain"}, "1365218": {"name": "Salmonella enterica subsp. enterica serovar Typhimurium str. ST1489", "rank": "Strain"}, "1244088": {"name": "Streptococcus agalactiae SGBS001", "rank": "Strain"}, "357804": {"name": "Psychromonas ingrahamii 37", "rank": "Strain"}, "1448448": {"name": "Mycobacterium tuberculosis TKK_03_0114", "rank": "Strain"}, "1448449": {"name": "Mycobacterium tuberculosis TKK_03_0115", "rank": "Strain"}, "1174684": {"name": "Sphingopyxis sp. MC1", "rank": "Species"}, "1245935": {"name": "Tolypothrix campylonemoides VB511288", "rank": "Strain"}, "665032": {"name": "Deftia phage phiW-14", "rank": "Species"}, "665033": {"name": "Escherichia phage D108", "rank": "Species"}, "197772": {"name": "Thetapapillomavirus 1", "rank": "Species"}, "197771": {"name": "Etapapillomavirus 1", "rank": "Species"}, "182452": {"name": "Gentian mosaic virus", "rank": "Species"}, "189385": {"name": "Candidatus Tremblaya princeps", "rank": "Species"}, "189384": {"name": "Candidatus Tremblaya", "rank": "Genus"}, "1169025": {"name": "Streptomyces pratensis", "rank": "Species"}, "630588": {"name": "Neisseria meningitidis alpha710", "rank": "Strain"}, "189382": {"name": "Bacillus aquimaris", "rank": "Species"}, "296014": {"name": "Algicola", "rank": "Genus"}, "1235785": {"name": "Bacteroides thetaiotaomicron dnLKV9", "rank": "Strain"}, "1235787": {"name": "Bacteroides uniformis dnLKV2", "rank": "Strain"}, "1235786": {"name": "Bacteroides vulgatus dnLKV7", "rank": "Strain"}, "910939": {"name": "Streptococcus hongkongensis", "rank": "Species"}, "1235789": {"name": "Parabacteroides goldsteinii dnLKV18", "rank": "Strain"}, "1235788": {"name": "Bacteroides massiliensis dnLKV3", "rank": "Strain"}, "1229494": {"name": "Vibrio jasicida CAIM 1864 = LMG 25398", "rank": "Strain"}, "889956": {"name": "Prochlorococcus phage MED4-213", "rank": "Species"}, "889955": {"name": "Prochlorococcus phage MED4-184", "rank": "Species"}, "889954": {"name": "Cyanophage MED4-117", "rank": "Species"}, "889953": {"name": "Cyanophage KBS-S-2A", "rank": "Species"}, "1229491": {"name": "Rhizobium lupini HPC(L)", "rank": "Strain"}, "1229492": {"name": "Staphylococcus aureus 08BA02176", "rank": "Strain"}, "889950": {"name": "Synechococcus phage KBS-M-1A", "rank": "Species"}, "1423891": {"name": "Brucella ceti TE10759-12", "rank": "Strain"}, "1423892": {"name": "Ehrlichia muris AS145", "rank": "Strain"}, "1423893": {"name": "Burkholderia andropogonis Ba3549", "rank": "Strain"}, "1158712": {"name": "Staphylococcus aureus M1037", "rank": "Strain"}, "396716": {"name": "Lactobacillus hayakitensis", "rank": "Species"}, "1158711": {"name": "Staphylococcus aureus M1036", "rank": "Strain"}, "1112258": {"name": "Chlamydia psittaci 02DC22", "rank": "Strain"}, "1402626": {"name": "Staphylococcus aureus M1108", "rank": "Strain"}, "1402627": {"name": "Staphylococcus aureus M1110", "rank": "Strain"}, "1402624": {"name": "Staphylococcus aureus M1106", "rank": "Strain"}, "1402625": {"name": "Staphylococcus aureus M1107", "rank": "Strain"}, "1402622": {"name": "Staphylococcus aureus M1442", "rank": "Strain"}, "1402623": {"name": "Staphylococcus aureus M1105", "rank": "Strain"}, "1402620": {"name": "Staphylococcus aureus M1439", "rank": "Strain"}, "1402621": {"name": "Staphylococcus aureus M1440", "rank": "Strain"}, "1476909": {"name": "Banana streak MY virus", "rank": "Species"}, "1402628": {"name": "Staphylococcus aureus M1111", "rank": "Strain"}, "1402629": {"name": "Staphylococcus aureus M1112", "rank": "Strain"}, "904338": {"name": "Staphylococcus warneri VCU121", "rank": "Strain"}, "1279365": {"name": "Bacillus thuringiensis serovar kurstaki str. HD73", "rank": "Strain"}, "13562": {"name": "Heterobasidion", "rank": "Genus"}, "170965": {"name": "Trichomonas vaginalis virus 3", "rank": "Species"}, "1244086": {"name": "Francisella tularensis subsp. holarctica BD11-00177", "rank": "Strain"}, "186188": {"name": "Xylanimonas", "rank": "Genus"}, "186189": {"name": "Xylanimonas cellulosilytica", "rank": "Species"}, "1435036": {"name": "Acinetobacter bohemicus", "rank": "Species"}, "93827": {"name": "Gymnopus", "rank": "Genus"}, "1415146": {"name": "Xylella phage Prado", "rank": "Species"}, "1415145": {"name": "Xylella phage Paz", "rank": "Species"}, "41254": {"name": "Mycosphaerella", "rank": "Genus"}, "904335": {"name": "Staphylococcus epidermidis VCU117", "rank": "Strain"}, "228229": {"name": "Lactobacillus saerimneri", "rank": "Species"}, "130327": {"name": "Ovine adenovirus D", "rank": "Species"}, "679202": {"name": "Escherichia coli MS 85-1", "rank": "Strain"}, "679200": {"name": "Johnsonella ignava ATCC 51276", "rank": "Strain"}, "1191460": {"name": "Acinetobacter venetianus RAG-1 = CIP 110063", "rank": "Strain"}, "679206": {"name": "Escherichia coli MS 119-7", "rank": "Strain"}, "679207": {"name": "Escherichia coli MS 107-1", "rank": "Strain"}, "679204": {"name": "Escherichia coli MS 145-7", "rank": "Strain"}, "1191464": {"name": "Helicobacter pylori FD535", "rank": "Strain"}, "1244085": {"name": "Klebsiella pneumoniae CG43", "rank": "Strain"}, "262967": {"name": "Thottapalayam virus", "rank": "Species"}, "262968": {"name": "Singapore grouper iridovirus", "rank": "Species"}, "10726": {"name": "Enterobacteria phage T5", "rank": "Species"}, "10724": {"name": "Bacillus phage SPP1", "rank": "Species"}, "307796": {"name": "Saccharomyces cerevisiae YJM789", "rank": "Varietas"}, "1154877": {"name": "Streptococcus agalactiae MRI Z1-214", "rank": "Strain"}, "47157": {"name": "Desulfovibrio bastinii", "rank": "Species"}, "356862": {"name": "Peruvian horse sickness virus", "rank": "Species"}, "11234": {"name": "Measles virus", "rank": "Species"}, "11232": {"name": "Canine distemper virus", "rank": "Species"}, "929563": {"name": "Leptonema illini DSM 21528", "rank": "Strain"}, "929562": {"name": "Emticicia oligotrophica DSM 17448", "rank": "Strain"}, "1297857": {"name": "Streptococcus dentisani 7747", "rank": "Strain"}, "11946": {"name": "Avian leukemia virus", "rank": "Strain"}, "882868": {"name": "Salmonella enterica subsp. enterica serovar Montevideo str. IA_2010008286", "rank": "Strain"}, "882869": {"name": "Salmonella enterica subsp. enterica serovar Montevideo str. IA_2010008287", "rank": "Strain"}, "882862": {"name": "Salmonella enterica subsp. enterica serovar Montevideo str. CT_02035327", "rank": "Strain"}, "882863": {"name": "Salmonella enterica subsp. enterica serovar Montevideo str. IA_2009159199", "rank": "Strain"}, "882860": {"name": "Salmonella enterica subsp. enterica serovar Montevideo str. CT_02035321", "rank": "Strain"}, "882866": {"name": "Salmonella enterica subsp. enterica serovar Montevideo str. IA_2010008284", "rank": "Strain"}, "882867": {"name": "Salmonella enterica subsp. enterica serovar Montevideo str. IA_2010008285", "rank": "Strain"}, "882864": {"name": "Salmonella enterica subsp. enterica serovar Montevideo str. IA_2010008282", "rank": "Strain"}, "882865": {"name": "Salmonella enterica subsp. enterica serovar Montevideo str. IA_2010008283", "rank": "Strain"}, "263378": {"name": "Salipiger mucosus", "rank": "Species"}, "886379": {"name": "Anaerophaga thermohalophila DSM 12881", "rank": "Strain"}, "987060": {"name": "Vibrio rotiferianus DAT722", "rank": "Strain"}, "1244089": {"name": "Streptococcus agalactiae SGBS002", "rank": "Strain"}, "231213": {"name": "Sporidiobolales", "rank": "Order"}, "263375": {"name": "Bordetella phage BIP-1", "rank": "Species"}, "886377": {"name": "Muricauda ruestringensis DSM 13258", "rank": "Strain"}, "263377": {"name": "Salipiger", "rank": "Genus"}, "579921": {"name": "Unclassified Cyclobacteriaceae", "rank": "No rank"}, "642493": {"name": "Malvastrum yellow vein Baoshan virus", "rank": "Species"}, "642492": {"name": "Clostridium lentocellum DSM 5427", "rank": "Strain"}, "1344012": {"name": "Tatumella sp. NML 06-3099", "rank": "Strain"}, "1309806": {"name": "Streptococcus agalactiae 09mas018883", "rank": "Strain"}, "1309807": {"name": "Streptococcus agalactiae ILRI005", "rank": "Strain"}, "616991": {"name": "Arenibacter algicola", "rank": "Species"}, "616992": {"name": "Polycyclovorans algicola", "rank": "Species"}, "406563": {"name": "Streptococcus pneumoniae SP23-BS72", "rank": "Strain"}, "588726": {"name": "Kazachstania naganishii", "rank": "Species"}, "29833": {"name": "Hanseniaspora uvarum", "rank": "Species"}, "29832": {"name": "Hanseniaspora", "rank": "Genus"}, "28123": {"name": "Porphyromonas asaccharolytica", "rank": "Species"}, "406560": {"name": "Streptococcus pneumoniae SP14-BS69", "rank": "Strain"}, "28126": {"name": "Prevotella buccae", "rank": "Species"}, "28127": {"name": "Prevotella buccalis", "rank": "Species"}, "28124": {"name": "Porphyromonas endodontalis", "rank": "Species"}, "28125": {"name": "Prevotella bivia", "rank": "Species"}, "28128": {"name": "Prevotella corporis", "rank": "Species"}, "28129": {"name": "Prevotella denticola", "rank": "Species"}, "928212": {"name": "Pan troglodytes verus polyomavirus 2a", "rank": "Strain"}, "928213": {"name": "Pan troglodytes verus polyomavirus 2c", "rank": "Strain"}, "928210": {"name": "Bartonella sp. R4(2010)", "rank": "Species"}, "928211": {"name": "Pan troglodytes verus polyomavirus 1a", "rank": "Strain"}, "414878": {"name": "Catenulispora", "rank": "Genus"}, "414877": {"name": "Catenulisporaceae", "rank": "Family"}, "349564": {"name": "Finch polyomavirus", "rank": "Species"}, "349563": {"name": "Crow polyomavirus", "rank": "Species"}, "1541959": {"name": "Mollicutes bacterium HR1", "rank": "Species"}, "1340818": {"name": "Mycobacterium phage LittleCherry", "rank": "Species"}, "1340819": {"name": "Mycobacterium phage Catdawg", "rank": "Species"}, "1340812": {"name": "Synechococcus phage S-MbCM100", "rank": "Species"}, "1340810": {"name": "Synechococcus phage ACG-2014h", "rank": "Species"}, "1422646": {"name": "Staphylococcus aureus VET0422R", "rank": "Strain"}, "765177": {"name": "Desulfurococcus mucosus DSM 2162", "rank": "Strain"}, "1422644": {"name": "Staphylococcus aureus VET0418R", "rank": "Strain"}, "1422645": {"name": "Staphylococcus aureus VET0421R", "rank": "Strain"}, "1422642": {"name": "Staphylococcus aureus VET0415R", "rank": "Strain"}, "1422643": {"name": "Staphylococcus aureus VET0417R", "rank": "Strain"}, "1422640": {"name": "Staphylococcus aureus VET0413R", "rank": "Strain"}, "1422641": {"name": "Staphylococcus aureus VET0414R", "rank": "Strain"}, "36745": {"name": "Clostridium saccharoperbutylacetonicum", "rank": "Species"}, "36744": {"name": "Mycoplasma simbae", "rank": "Species"}, "36746": {"name": "Pseudomonas cichorii", "rank": "Species"}, "36740": {"name": "Dermabacter hominis", "rank": "Species"}, "1422648": {"name": "Staphylococcus aureus VET0424R", "rank": "Strain"}, "1422649": {"name": "Staphylococcus aureus VET0425R", "rank": "Strain"}, "32054": {"name": "Calothrix parietina", "rank": "Species"}, "32057": {"name": "Calothrix sp. PCC 7103", "rank": "Species"}, "32051": {"name": "Synechococcus sp. WH 7803", "rank": "Species"}, "640897": {"name": "Phytophthora infestans RNA virus 1", "rank": "Species"}, "1408192": {"name": "Tatumella sp. UCD-D_suzukii", "rank": "Species"}, "1408193": {"name": "Pseudomonas aeruginosa VRFPA05", "rank": "Strain"}, "535": {"name": "Chromobacterium", "rank": "Genus"}, "926034": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. 77-1427", "rank": "Strain"}, "536": {"name": "Chromobacterium violaceum", "rank": "Species"}, "531": {"name": "Polaribacter irgensii", "rank": "Species"}, "1352941": {"name": "Streptomyces niveus NCIMB 11891", "rank": "Strain"}, "533": {"name": "Beijerinckia indica", "rank": "Species"}, "532": {"name": "Beijerinckia", "rank": "Genus"}, "539": {"name": "Eikenella corrodens", "rank": "Species"}, "538": {"name": "Eikenella", "rank": "Genus"}, "399739": {"name": "Pseudomonas mendocina ymp", "rank": "Strain"}, "1276652": {"name": "Klebsiella pneumoniae ATCC BAA-1705", "rank": "Strain"}, "1276653": {"name": "Klebsiella pneumoniae 700603", "rank": "Strain"}, "1417158": {"name": "Staphylococcus aureus F92125", "rank": "Strain"}, "1417159": {"name": "Staphylococcus aureus F92127", "rank": "Strain"}, "1417156": {"name": "Staphylococcus aureus F92105_080312", "rank": "Strain"}, "1417157": {"name": "Staphylococcus aureus F92119_080312", "rank": "Strain"}, "1417154": {"name": "Staphylococcus aureus F92073", "rank": "Strain"}, "1417155": {"name": "Staphylococcus aureus F92089", "rank": "Strain"}, "1417152": {"name": "Staphylococcus aureus F89078", "rank": "Strain"}, "1417153": {"name": "Staphylococcus aureus F92047", "rank": "Strain"}, "1417150": {"name": "Staphylococcus aureus F89073", "rank": "Strain"}, "1417151": {"name": "Staphylococcus aureus F89075", "rank": "Strain"}, "453591": {"name": "Ignicoccus hospitalis KIN4/I", "rank": "Strain"}, "44449": {"name": "Borrelia recurrentis", "rank": "Species"}, "150830": {"name": "Roseibium", "rank": "Genus"}, "370776": {"name": "Arenimonas composti", "rank": "Species"}, "211586": {"name": "Shewanella oneidensis MR-1", "rank": "Strain"}, "857578": {"name": "Moraxella catarrhalis 46P47B1", "rank": "Strain"}, "857579": {"name": "Moraxella catarrhalis 103P14B1", "rank": "Strain"}, "857576": {"name": "Moraxella catarrhalis BC1", "rank": "Strain"}, "857577": {"name": "Moraxella catarrhalis 12P80B1", "rank": "Strain"}, "857574": {"name": "Moraxella catarrhalis BC8", "rank": "Strain"}, "857575": {"name": "Moraxella catarrhalis BC7", "rank": "Strain"}, "857572": {"name": "Moraxella catarrhalis 101P30B1", "rank": "Strain"}, "857573": {"name": "Moraxella catarrhalis CO72", "rank": "Strain"}, "857571": {"name": "Moraxella catarrhalis O35E", "rank": "Strain"}, "1200352": {"name": "Corynebacterium terpenotabidum Y-11", "rank": "Strain"}, "1200350": {"name": "Acinetobacter baumannii ABIsac_ColiS", "rank": "Strain"}, "1200351": {"name": "Acinetobacter baumannii ABIsac_ColiR", "rank": "Strain"}, "85655": {"name": "Ranid herpesvirus 1", "rank": "Species"}, "85651": {"name": "Omegatetravirus", "rank": "Genus"}, "85650": {"name": "Betatetravirus", "rank": "Genus"}, "85652": {"name": "Nudaurelia capensis beta virus", "rank": "Species"}, "1185699": {"name": "Xanthomonas axonopodis pv. manihotis str. IBSBF 726", "rank": "Strain"}, "1185698": {"name": "Xanthomonas axonopodis pv. manihotis str. IBSBF 725", "rank": "Strain"}, "1185691": {"name": "Xanthomonas axonopodis pv. manihotis str. IBSBF 285", "rank": "Strain"}, "1185690": {"name": "Xanthomonas axonopodis pv. manihotis str. IBSBF 2822", "rank": "Strain"}, "1185693": {"name": "Xanthomonas axonopodis pv. manihotis str. IBSBF 320", "rank": "Strain"}, "1185692": {"name": "Xanthomonas axonopodis pv. manihotis str. IBSBF 289", "rank": "Strain"}, "1185695": {"name": "Xanthomonas axonopodis pv. manihotis str. IBSBF 356", "rank": "Strain"}, "447604": {"name": "Tomato yellow leaf curl Vietnam virus satellite DNA beta", "rank": "Species"}, "1185696": {"name": "Xanthomonas axonopodis pv. manihotis str. IBSBF 436", "rank": "Strain"}, "110539": {"name": "Mycobacterium vanbaalenii", "rank": "Species"}, "1122623": {"name": "Ottowia thiooxydans DSM 14619", "rank": "Strain"}, "1122622": {"name": "Ornithinimicrobium pekingense DSM 21552", "rank": "Strain"}, "1122621": {"name": "Olivibacter sitiensis DSM 17696", "rank": "Strain"}, "1122620": {"name": "Oligella urethralis DSM 7531", "rank": "Strain"}, "1005511": {"name": "Escherichia coli PA45", "rank": "Strain"}, "1005510": {"name": "Escherichia coli PA42", "rank": "Strain"}, "1005513": {"name": "Escherichia coli PA48", "rank": "Strain"}, "328301": {"name": "Syntrophorhabdus aromaticivorans", "rank": "Species"}, "1005515": {"name": "Escherichia coli TW06591", "rank": "Strain"}, "1005514": {"name": "Escherichia coli PA49", "rank": "Strain"}, "1005517": {"name": "Escherichia coli TW10246", "rank": "Strain"}, "1005516": {"name": "Escherichia coli TW07945", "rank": "Strain"}, "1005519": {"name": "Escherichia coli TW09098", "rank": "Strain"}, "1005518": {"name": "Escherichia coli TW11039", "rank": "Strain"}, "511434": {"name": "Candidatus Azobacteroides", "rank": "Genus"}, "511435": {"name": "Candidatus Azobacteroides pseudotrichonymphae", "rank": "Species"}, "271091": {"name": "Psychrilyobacter atlanticus", "rank": "Species"}, "453229": {"name": "Desulfarculus", "rank": "Genus"}, "271097": {"name": "Shewanella sediminis", "rank": "Species"}, "795747": {"name": "Ignavibacteria", "rank": "Class"}, "912594": {"name": "Mycobacterium iranicum", "rank": "Species"}, "1209984": {"name": "Mycobacterium mageritense DSM 44476", "rank": "Strain"}, "243563": {"name": "Strawberry necrotic shock virus", "rank": "Species"}, "795748": {"name": "Ignavibacteriales", "rank": "Order"}, "795749": {"name": "Ignavibacteriaceae", "rank": "Family"}, "453227": {"name": "Desulfarculales", "rank": "Order"}, "1412506": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. SA20083456", "rank": "Strain"}, "1412507": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. SA20095309", "rank": "Strain"}, "1412504": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. SA20094350", "rank": "Strain"}, "1412505": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. SA20094301", "rank": "Strain"}, "1412502": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. SA19982831", "rank": "Strain"}, "1412503": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. SA20094803", "rank": "Strain"}, "283810": {"name": "Stackebrandtia", "rank": "Genus"}, "283811": {"name": "Stackebrandtia nassauensis", "rank": "Species"}, "1412508": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. SA20092320", "rank": "Strain"}, "1412509": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. SA20093784", "rank": "Strain"}, "1122191": {"name": "Maribacter antarcticus DSM 21422", "rank": "Strain"}, "1122190": {"name": "Mannheimia granulomatis DSM 19156", "rank": "Strain"}, "1122194": {"name": "Marinimicrobium agarilyticum DSM 16975", "rank": "Strain"}, "1122197": {"name": "Marinobacter daepoensis DSM 16072", "rank": "Strain"}, "45404": {"name": "Beijerinckiaceae", "rank": "Family"}, "376730": {"name": "Zhouia amylolytica", "rank": "Species"}, "376733": {"name": "Paracoccus halophilus", "rank": "Species"}, "526997": {"name": "Bacillus mycoides DSM 2048", "rank": "Strain"}, "526994": {"name": "Bacillus cereus AH1273", "rank": "Strain"}, "526993": {"name": "Bacillus cereus AH1272", "rank": "Strain"}, "526992": {"name": "Bacillus cereus AH1271", "rank": "Strain"}, "526991": {"name": "Bacillus cereus AH676", "rank": "Strain"}, "526990": {"name": "Bacillus cereus AH603", "rank": "Strain"}, "1355388": {"name": "Elizabethkingia meningoseptica 502", "rank": "Strain"}, "526999": {"name": "Bacillus mycoides Rock3-17", "rank": "Strain"}, "526998": {"name": "Bacillus mycoides Rock1-4", "rank": "Strain"}, "979215": {"name": "Staphylococcus epidermidis NIHLM018", "rank": "Strain"}, "35304": {"name": "Bunyamwera virus", "rank": "Species"}, "35305": {"name": "California encephalitis virus", "rank": "Species"}, "35306": {"name": "Simbu virus", "rank": "Species"}, "35301": {"name": "SsRNA negative-strand viruses", "rank": "No rank"}, "35303": {"name": "Unclassified Rhabdoviridae", "rank": "No rank"}, "527020": {"name": "Bacillus thuringiensis IBL 4222", "rank": "Strain"}, "527021": {"name": "Bacillus thuringiensis Bt407", "rank": "Strain"}, "527022": {"name": "Bacillus thuringiensis serovar monterrey BGSC 4AJ1", "rank": "Strain"}, "527023": {"name": "Bacillus thuringiensis serovar kurstaki str. T03a001", "rank": "Strain"}, "527024": {"name": "Bacillus thuringiensis serovar tochigiensis BGSC 4Y1", "rank": "Strain"}, "527025": {"name": "Bacillus thuringiensis serovar thuringiensis str. T01001", "rank": "Strain"}, "527026": {"name": "Bacillus thuringiensis serovar sotto str. T04001", "rank": "Strain"}, "527027": {"name": "Bacillus thuringiensis serovar pakistani str. T13001", "rank": "Strain"}, "1074108": {"name": "Streptococcus mutans TCI-86", "rank": "Strain"}, "1074109": {"name": "Streptococcus mutans TCI-92", "rank": "Strain"}, "1074106": {"name": "Streptococcus mutans TCI-82", "rank": "Strain"}, "1074107": {"name": "Streptococcus mutans TCI-85", "rank": "Strain"}, "1074104": {"name": "Streptococcus mutans TCI-75", "rank": "Strain"}, "1074105": {"name": "Streptococcus mutans TCI-78", "rank": "Strain"}, "1074102": {"name": "Streptococcus mutans TCI-70", "rank": "Strain"}, "1074100": {"name": "Streptococcus mutans TCI-51", "rank": "Strain"}, "1074101": {"name": "Streptococcus mutans TCI-62", "rank": "Strain"}, "1416757": {"name": "Serratia marcescens H1q", "rank": "Strain"}, "1416756": {"name": "Pseudomonas aeruginosa H1l", "rank": "Strain"}, "1416755": {"name": "Lysinibacillus fusiformis H1k", "rank": "Strain"}, "1416754": {"name": "Klebsiella oxytoca H1g", "rank": "Strain"}, "1416753": {"name": "Ensifer adhaerens OV14", "rank": "Strain"}, "1416752": {"name": "Microbacterium paraoxydans DH1b", "rank": "Strain"}, "1416759": {"name": "Leifsonia aquatica H1aii", "rank": "Strain"}, "1052121": {"name": "Enterobacteria phage Bp7", "rank": "Species"}, "871237": {"name": "Streptococcus infantis SK1302", "rank": "Strain"}, "1130277": {"name": "Unclassified candidate division EM 3", "rank": "No rank"}, "710696": {"name": "Intrasporangium calvum DSM 43043", "rank": "Strain"}, "749518": {"name": "Enterococcus faecalis TX2134", "rank": "Strain"}, "749512": {"name": "Enterococcus faecalis TX0860", "rank": "Strain"}, "749513": {"name": "Enterococcus faecalis TX1302", "rank": "Strain"}, "749510": {"name": "Enterococcus faecalis TX0645", "rank": "Strain"}, "749511": {"name": "Enterococcus faecalis TX0855", "rank": "Strain"}, "749516": {"name": "Enterococcus faecalis TX1346", "rank": "Strain"}, "749517": {"name": "Enterococcus faecalis TX1467", "rank": "Strain"}, "749514": {"name": "Enterococcus faecalis TX1341", "rank": "Strain"}, "749515": {"name": "Enterococcus faecalis TX1342", "rank": "Strain"}, "1191298": {"name": "Vibrio genomosp. F6 str. FF-238", "rank": "Strain"}, "1354030": {"name": "Enterobacter cloacae P101", "rank": "Strain"}, "1191299": {"name": "Vibrio kanaloae 5S-149", "rank": "Strain"}, "363277": {"name": "Ktedonobacter racemifer", "rank": "Species"}, "363276": {"name": "Ktedonobacter", "rank": "Genus"}, "904293": {"name": "Streptococcus downei F0415", "rank": "Strain"}, "1397696": {"name": "Exiguobacterium marinum DSM 16307", "rank": "Strain"}, "1324960": {"name": "Aeromonas salmonicida subsp. pectinolytica 34mel", "rank": "Strain"}, "182210": {"name": "Desulfovibrio aespoeensis", "rank": "Species"}, "182217": {"name": "Helicobacter cetorum MIT 00-7128", "rank": "Strain"}, "1324966": {"name": "Bacillus thuringiensis T01-328", "rank": "Strain"}, "1324967": {"name": "Campylobacter jejuni 255", "rank": "Strain"}, "362692": {"name": "Oryza rufipogon endornavirus", "rank": "Species"}, "362693": {"name": "Oryza sativa endornavirus", "rank": "Species"}, "128": {"name": "Isosphaera pallida", "rank": "Species"}, "126": {"name": "Planctomycetaceae", "rank": "Family"}, "127": {"name": "Isosphaera", "rank": "Genus"}, "124": {"name": "Blastopirellula marina", "rank": "Species"}, "125": {"name": "Pirellula staleyi", "rank": "Species"}, "122": {"name": "Planctomyces maris", "rank": "Species"}, "123": {"name": "Pirellula", "rank": "Genus"}, "120": {"name": "Planctomyces limnophilus", "rank": "Species"}, "511995": {"name": "Candidatus Azobacteroides pseudotrichonymphae genomovar. CFP2", "rank": "Strain"}, "1427356": {"name": "Hyphomicrobium nitrativorans", "rank": "Species"}, "979216": {"name": "Staphylococcus epidermidis NIHLM015", "rank": "Strain"}, "1072467": {"name": "Blattabacterium sp. (Blatta orientalis) str. Tarazona", "rank": "Strain"}, "1293054": {"name": "Halanaerobium saccharolyticum subsp. saccharolyticum DSM 6643", "rank": "Strain"}, "1410614": {"name": "Prevotella sp. P6B4", "rank": "Species"}, "1410615": {"name": "Propionibacterium sp. MB3007", "rank": "Species"}, "1407502": {"name": "Stenotrophomonas maltophilia SeITE02", "rank": "Strain"}, "1410617": {"name": "Ruminococcus sp. FC2018", "rank": "Species"}, "1410610": {"name": "Butyrivibrio sp. NC2002", "rank": "Species"}, "1410611": {"name": "Butyrivibrio sp. WCE2006", "rank": "Species"}, "1410612": {"name": "Oribacterium sp. P6A1", "rank": "Species"}, "1410613": {"name": "Prevotella sp. P6B1", "rank": "Species"}, "374468": {"name": "Nakaseomyces", "rank": "Genus"}, "374469": {"name": "Vanderwaltozyma", "rank": "Genus"}, "1410618": {"name": "Selenomonas sp. ND2010", "rank": "Species"}, "1410619": {"name": "Serratia sp. DD3", "rank": "Species"}, "1223571": {"name": "Dickeya chrysanthemi NCPPB 516", "rank": "Strain"}, "1223570": {"name": "Dickeya dianthicola NCPPB 3534", "rank": "Strain"}, "1223573": {"name": "Dickeya zeae NCPPB 2538", "rank": "Strain"}, "1144329": {"name": "Pseudomonas sp. GM33", "rank": "Species"}, "1223574": {"name": "Dickeya dadantii subsp. dieffenbachiae NCPPB 2976", "rank": "Strain"}, "1144322": {"name": "Pseudomonas sp. GM16", "rank": "Species"}, "1144323": {"name": "Pseudomonas sp. GM17", "rank": "Species"}, "1144320": {"name": "Pantoea sp. GM01", "rank": "Species"}, "1144321": {"name": "Pseudomonas sp. GM102", "rank": "Species"}, "1144326": {"name": "Pseudomonas sp. GM24", "rank": "Species"}, "1144327": {"name": "Pseudomonas sp. GM25", "rank": "Species"}, "1144324": {"name": "Pseudomonas sp. GM18", "rank": "Species"}, "1144325": {"name": "Pseudomonas sp. GM21", "rank": "Species"}, "556270": {"name": "Coprobacillus sp. D7", "rank": "Species"}, "10331": {"name": "Equid herpesvirus 4", "rank": "Species"}, "203275": {"name": "Tannerella forsythia ATCC 43037", "rank": "Strain"}, "1122915": {"name": "Paenibacillus alginolyticus DSM 5050 = NBRC 15375", "rank": "Strain"}, "1438678": {"name": "Escherichia coli BIDMC 74", "rank": "Strain"}, "1172": {"name": "Anabaena variabilis", "rank": "Species"}, "1177": {"name": "Nostoc", "rank": "Genus"}, "1176": {"name": "Aphanizomenon flos-aquae", "rank": "Species"}, "1175": {"name": "Aphanizomenon", "rank": "Genus"}, "1438670": {"name": "Escherichia coli BIDMC 62", "rank": "Strain"}, "1438671": {"name": "Escherichia coli BIDMC 63", "rank": "Strain"}, "1262673": {"name": "Chlamydia trachomatis L2/434/Bu(f)", "rank": "Strain"}, "1438673": {"name": "Escherichia coli BIDMC 65", "rank": "Strain"}, "1438674": {"name": "Escherichia coli BIDMC 70", "rank": "Strain"}, "1438675": {"name": "Escherichia coli BIDMC 71", "rank": "Strain"}, "1438676": {"name": "Escherichia coli BIDMC 72", "rank": "Strain"}, "1438677": {"name": "Escherichia coli BIDMC 73", "rank": "Strain"}, "869216": {"name": "Streptococcus pneumoniae INV200", "rank": "Strain"}, "61458": {"name": "Coniosporium", "rank": "Genus"}, "869214": {"name": "Neisseria lactamica Y92-1009", "rank": "Strain"}, "869215": {"name": "Streptococcus pneumoniae OXC141", "rank": "Strain"}, "869212": {"name": "Turneriella parva DSM 21527", "rank": "Strain"}, "869213": {"name": "Cytophaga fermentans DSM 9555 = JCM 21142", "rank": "Strain"}, "869210": {"name": "Marinithermus hydrothermalis DSM 14884", "rank": "Strain"}, "869211": {"name": "Spirochaeta thermophila DSM 6578", "rank": "Strain"}, "327045": {"name": "Orthoretrovirinae", "rank": "Subfamily"}, "327046": {"name": "Spumaretrovirinae", "rank": "Subfamily"}, "1182675": {"name": "Escherichia coli KTE68", "rank": "Strain"}, "1525371": {"name": "Neorhizobium", "rank": "Genus"}, "1073841": {"name": "Escherichia coli O104:H4 str. GOS2", "rank": "Strain"}, "146919": {"name": "Salinibacter ruber", "rank": "Species"}, "146918": {"name": "Salinibacter", "rank": "Genus"}, "1301088": {"name": "Rhodococcus sp. EsD8", "rank": "Species"}, "1154871": {"name": "Streptococcus agalactiae MRI Z1-048", "rank": "Strain"}, "1448608": {"name": "Mycobacterium tuberculosis TKK_04_0159", "rank": "Strain"}, "1448609": {"name": "Mycobacterium tuberculosis TKK_04_0104", "rank": "Strain"}, "585161": {"name": "Staphylococcus aureus subsp. aureus WW2703/97", "rank": "Strain"}, "585160": {"name": "Staphylococcus aureus subsp. aureus WBG10049", "rank": "Strain"}, "271848": {"name": "Burkholderia thailandensis E264", "rank": "Strain"}, "1448600": {"name": "Mycobacterium tuberculosis TKK_04_0148", "rank": "Strain"}, "1448601": {"name": "Mycobacterium tuberculosis TKK_04_0149", "rank": "Strain"}, "1448606": {"name": "Mycobacterium tuberculosis TKK_04_0157", "rank": "Strain"}, "1448607": {"name": "Mycobacterium tuberculosis TKK_04_0158", "rank": "Strain"}, "1448604": {"name": "Mycobacterium tuberculosis TKK_04_0153", "rank": "Strain"}, "1448605": {"name": "Mycobacterium tuberculosis TKK_04_0155", "rank": "Strain"}, "138336": {"name": "Blastococcus saxobsidens", "rank": "Species"}, "517433": {"name": "Pantoea sp. aB", "rank": "Species"}, "796891": {"name": "Rhizobium mesoamericanum STM6155", "rank": "Strain"}, "517437": {"name": "Anaplasma marginale str. Puerto Rico", "rank": "Strain"}, "671232": {"name": "Streptococcus anginosus group", "rank": "Species group"}, "671230": {"name": "Parvimonas sp. oral taxon 110", "rank": "Species"}, "547045": {"name": "Neisseria sicca ATCC 29256", "rank": "Strain"}, "547046": {"name": "Yersinia pestis biovar Orientalis str. PEXU2", "rank": "Strain"}, "547047": {"name": "Yersinia pestis biovar Orientalis str. India 195", "rank": "Strain"}, "547042": {"name": "Bacteroides coprophilus DSM 18228 = JCM 13818", "rank": "Strain"}, "547043": {"name": "Bifidobacterium pseudocatenulatum DSM 20438 = JCM 1200 = LMG 10505", "rank": "Strain"}, "547048": {"name": "Yersinia pestis biovar Medievalis str. Harbin 35", "rank": "Strain"}, "86192": {"name": "Pseudomonas chlororaphis subsp. aurantiaca", "rank": "Subspecies"}, "1169339": {"name": "Escherichia coli KTE20", "rank": "Strain"}, "118748": {"name": "Bulleidia extructa", "rank": "Species"}, "118747": {"name": "Bulleidia", "rank": "Genus"}, "1567504": {"name": "Brucella abortus bv. 6", "rank": "Strain"}, "55208": {"name": "Pectobacterium wasabiae", "rank": "Species"}, "1213406": {"name": "Jatropha mosaic Nigerian virus", "rank": "Species"}, "143222": {"name": "Salegentibacter", "rank": "Genus"}, "358681": {"name": "Brevibacillus brevis NBRC 100599", "rank": "Strain"}, "716925": {"name": "Ensifer sojae", "rank": "Species"}, "1217722": {"name": "Pseudomonas sp. S13.1.2", "rank": "Species"}, "1217721": {"name": "Dyella japonica A8", "rank": "Strain"}, "1217720": {"name": "Roseomonas sp. B5", "rank": "Species"}, "1310905": {"name": "Acinetobacter baumannii 25977_1", "rank": "Strain"}, "1310904": {"name": "Acinetobacter baumannii 45002_10", "rank": "Strain"}, "1310907": {"name": "Acinetobacter baumannii 25977_3", "rank": "Strain"}, "1310906": {"name": "Acinetobacter baumannii 25977_2", "rank": "Strain"}, "1310901": {"name": "Acinetobacter baumannii 45002_7", "rank": "Strain"}, "1310900": {"name": "Acinetobacter baumannii 45002_6", "rank": "Strain"}, "1310903": {"name": "Acinetobacter baumannii 45002_9", "rank": "Strain"}, "1310908": {"name": "Acinetobacter baumannii 25977_4", "rank": "Strain"}, "321332": {"name": "Synechococcus sp. JA-2-3B'a(2-13)", "rank": "Species"}, "1432135": {"name": "Lamium mild mosaic virus", "rank": "Species"}, "101510": {"name": "Rhodococcus jostii RHA1", "rank": "Strain"}, "500654": {"name": "Bandicoot papillomatosis carcinomatosis virus type 2", "rank": "Species"}, "501328": {"name": "Tomato leaf curl Ghana virus", "rank": "Species"}, "1348562": {"name": "Salmonella enterica subsp. enterica serovar Namur", "rank": "Strain"}, "698776": {"name": "Cellulosilyticum", "rank": "Genus"}, "1199187": {"name": "Mycobacterium avium subsp. paratuberculosis MAP4", "rank": "Strain"}, "1194165": {"name": "Microbacterium yannicii PS01", "rank": "Strain"}, "700508": {"name": "Mycobacterium neoaurum VKM Ac-1815D", "rank": "Strain"}, "1194162": {"name": "Salmonella enterica subsp. enterica serovar Norwich", "rank": "Strain"}, "82367": {"name": "Paracoccus pantotrophus", "rank": "Species"}, "420662": {"name": "Methylibium petroleiphilum PM1", "rank": "Strain"}, "470145": {"name": "Bacteroides coprocola DSM 17136", "rank": "Strain"}, "470146": {"name": "Coprococcus comes ATCC 27758", "rank": "Strain"}, "103855": {"name": "Bordetella hinzii", "rank": "Species"}, "49267": {"name": "Tomato pseudo-curly top virus", "rank": "Species"}, "1439246": {"name": "Streptococcus pyogenes ABC020054973", "rank": "Strain"}, "1439245": {"name": "Streptococcus pyogenes ABC020054955", "rank": "Strain"}, "1439243": {"name": "Streptococcus pyogenes ABC020054871", "rank": "Strain"}, "293178": {"name": "Enterobacteria phage JS98", "rank": "Strain"}, "213554": {"name": "Halomonas campaniensis", "rank": "Species"}, "753642": {"name": "Escherichia coli NC101", "rank": "Strain"}, "57723": {"name": "Acidobacteria", "rank": "Phylum"}, "1455312": {"name": "Mycobacterium tuberculosis NRITLD38", "rank": "Strain"}, "1455311": {"name": "Mycobacterium tuberculosis NRITLD37", "rank": "Strain"}, "1455316": {"name": "Acinetobacter baumannii R1B", "rank": "Strain"}, "1455315": {"name": "Acinetobacter baumannii LAC-4", "rank": "Strain"}, "904781": {"name": "Staphylococcus aureus subsp. aureus IS-105", "rank": "Strain"}, "221664": {"name": "Chaetothyriomycetidae incertae sedis", "rank": "No rank"}, "1211851": {"name": "Dyadobacter tibetensis", "rank": "Species"}, "546808": {"name": "Mycobacterium phage Spud", "rank": "Species"}, "546807": {"name": "Mycobacterium phage ScottMcG", "rank": "Species"}, "546806": {"name": "Mycobacterium phage Rizal", "rank": "Species"}, "546805": {"name": "Mycobacterium phage Myrna", "rank": "Species"}, "546803": {"name": "Mycobacterium phage Cali", "rank": "Species"}, "140625": {"name": "Lachnobacterium", "rank": "Genus"}, "140626": {"name": "Lachnobacterium bovis", "rank": "Species"}, "231023": {"name": "Pseudomonas putida ND6", "rank": "Strain"}, "342108": {"name": "Magnetospirillum magneticum AMB-1", "rank": "Strain"}, "342109": {"name": "Xanthomonas oryzae pv. oryzae MAFF 311018", "rank": "Strain"}, "768726": {"name": "Streptococcus mitis bv. 2 str. F0392", "rank": "Strain"}, "768727": {"name": "Veillonella parvula ACS-068-V-Sch12", "rank": "Strain"}, "1237085": {"name": "Candidatus Nitrososphaera gargensis Ga9.2", "rank": "Strain"}, "768728": {"name": "Lactobacillus salivarius ACS-116-V-Col5a", "rank": "Strain"}, "342107": {"name": "Unclassified Betabaculovirus", "rank": "No rank"}, "1169389": {"name": "Escherichia coli KTE139", "rank": "Strain"}, "1169388": {"name": "Escherichia coli KTE138", "rank": "Strain"}, "1169385": {"name": "Escherichia coli KTE131", "rank": "Strain"}, "1054480": {"name": "Escherichia phage wV7", "rank": "Species"}, "1169387": {"name": "Escherichia coli KTE137", "rank": "Strain"}, "1169386": {"name": "Escherichia coli KTE133", "rank": "Strain"}, "1169381": {"name": "Escherichia coli KTE124", "rank": "Strain"}, "1169380": {"name": "Escherichia coli KTE122", "rank": "Strain"}, "1169383": {"name": "Escherichia coli KTE128", "rank": "Strain"}, "1169382": {"name": "Escherichia coli KTE125", "rank": "Strain"}, "260797": {"name": "Heliothis virescens ascovirus 3e", "rank": "Strain"}, "1151061": {"name": "Tsukamurella sp. 1534", "rank": "Species"}, "260799": {"name": "Bacillus anthracis str. Sterne", "rank": "Strain"}, "38420": {"name": "Simian adenovirus 3", "rank": "Strain"}, "475178": {"name": "Lactococcus phage 1706", "rank": "Species"}, "336096": {"name": "Unclassified Avulavirus", "rank": "No rank"}, "102129": {"name": "Leptolyngbya sp. PCC 7375", "rank": "Species"}, "1094470": {"name": "Acinetobacter baumannii ABNIH6", "rank": "Strain"}, "78119": {"name": "Succinispira", "rank": "Genus"}, "1094471": {"name": "Acinetobacter baumannii ABNIH7", "rank": "Strain"}, "122706": {"name": "Unclassified Deltaproteobacteria (miscellaneous)", "rank": "No rank"}, "564065": {"name": "Ralstonia solanacearum MolK2", "rank": "Strain"}, "327277": {"name": "Bifidobacterium crudilactis", "rank": "Species"}, "34073": {"name": "Variovorax paradoxus", "rank": "Species"}, "34072": {"name": "Variovorax", "rank": "Genus"}, "711470": {"name": "Mycobacterium phage RedRock", "rank": "Species"}, "34079": {"name": "Unclassified Cyanobacteria", "rank": "No rank"}, "34078": {"name": "Scytonema hofmanni", "rank": "Species"}, "212365": {"name": "Bifidobacterium thermacidophilum subsp. porcinum", "rank": "Subspecies"}, "1333519": {"name": "Pseudoalteromonas sp. S8-38", "rank": "Species"}, "1412635": {"name": "Staphylococcus aureus F29993", "rank": "Strain"}, "1412636": {"name": "Staphylococcus aureus F29997", "rank": "Strain"}, "1412637": {"name": "Staphylococcus aureus F77917", "rank": "Strain"}, "1412630": {"name": "Staphylococcus aureus F23368", "rank": "Strain"}, "1412631": {"name": "Staphylococcus aureus F26858", "rank": "Strain"}, "376804": {"name": "Bacteroides barnesiae", "rank": "Species"}, "1412633": {"name": "Staphylococcus aureus F26884", "rank": "Strain"}, "1333511": {"name": "Pseudoalteromonas haloplanktis TAB23", "rank": "Strain"}, "1333513": {"name": "Pseudoalteromonas haloplanktis TAE56", "rank": "Strain"}, "1333512": {"name": "Pseudoalteromonas haloplanktis TAE79", "rank": "Strain"}, "1412638": {"name": "Staphylococcus aureus F77919", "rank": "Strain"}, "891391": {"name": "Lactobacillus acidophilus 30SC", "rank": "Strain"}, "203907": {"name": "Candidatus Blochmannia floridanus", "rank": "Species"}, "1215914": {"name": "Lactobacillus casei W56", "rank": "Strain"}, "670484": {"name": "Citrobacter freundii str. ballerup 7851/39", "rank": "Strain"}, "425009": {"name": "Botryotinia fuckeliana totivirus 1", "rank": "Species"}, "1417008": {"name": "Mycobacterium tuberculosis KT-0004", "rank": "Strain"}, "1417009": {"name": "Mycobacterium tuberculosis KT-0010", "rank": "Strain"}, "1218083": {"name": "Burkholderia oxyphila NBRC 105797", "rank": "Strain"}, "1417005": {"name": "Mycobacterium tuberculosis XDR KZN 605", "rank": "Strain"}, "1218081": {"name": "Burkholderia kururiensis subsp. thiooxydans NBRC 107107", "rank": "Strain"}, "1218080": {"name": "Burkholderia heleia NBRC 101817", "rank": "Strain"}, "1218086": {"name": "Citrobacter sedlakii NBRC 105722", "rank": "Strain"}, "1218085": {"name": "Citrobacter rodentium NBRC 105723", "rank": "Strain"}, "1218084": {"name": "Burkholderia terrae NBRC 100964", "rank": "Strain"}, "335659": {"name": "Bradyrhizobium sp. S23321", "rank": "Species"}, "1005999": {"name": "Leminorella grimontii ATCC 33999 = DSM 5078", "rank": "Strain"}, "192021": {"name": "Chicory yellow mottle virus large satellite RNA", "rank": "Species"}, "192022": {"name": "Chicory yellow mottle virus satellite RNA", "rank": "Species"}, "192023": {"name": "Cymbidium ringspot virus satellite RNA", "rank": "Species"}, "1005995": {"name": "Tatumella ptyseos ATCC 33301", "rank": "Strain"}, "1005994": {"name": "Trabulsiella guamensis ATCC 49490", "rank": "Strain"}, "1005996": {"name": "Raoultella planticola ATCC 33531", "rank": "Strain"}, "122277": {"name": "Pectobacterium", "rank": "Genus"}, "1435485": {"name": "Bovine astrovirus", "rank": "Species"}, "245836": {"name": "Nocardiopsis salina", "rank": "Species"}, "340188": {"name": "Salmonella enterica subsp. enterica serovar Cerro", "rank": "Strain"}, "340189": {"name": "Salmonella enterica subsp. enterica serovar Manhattan", "rank": "Strain"}, "340186": {"name": "Escherichia coli E110019", "rank": "Strain"}, "340187": {"name": "Acyrthosiphon pisum virus", "rank": "Species"}, "340184": {"name": "Escherichia coli B7A", "rank": "Strain"}, "340185": {"name": "Escherichia coli E22", "rank": "Strain"}, "765420": {"name": "Oscillochloris trichoides DG-6", "rank": "Strain"}, "1231058": {"name": "Vibrio alginolyticus E0666", "rank": "Strain"}, "1231054": {"name": "Candidatus Microthrix parvicella Bio17-1", "rank": "Strain"}, "1231057": {"name": "Paenisporosarcina sp. TG-14", "rank": "Species"}, "74109": {"name": "Photobacterium profundum", "rank": "Species"}, "494416": {"name": "Psychrobacter sp. TB15", "rank": "Species"}, "370405": {"name": "Gallionella capsiferriformans", "rank": "Species"}, "1387345": {"name": "Salmonella enterica subsp. enterica serovar Typhimurium str. 116045", "rank": "Strain"}, "693999": {"name": "Scotophilus bat coronavirus 512", "rank": "Species"}, "1387341": {"name": "Salmonella enterica subsp. enterica serovar Typhimurium str. 108402", "rank": "Strain"}, "693991": {"name": "Fusobacterium nucleatum subsp. polymorphum F0401", "rank": "Strain"}, "693996": {"name": "Alphacoronavirus", "rank": "Genus"}, "693997": {"name": "Alphacoronavirus 1", "rank": "Species"}, "693995": {"name": "Coronavirinae", "rank": "Subfamily"}, "1265484": {"name": "Pseudomonas sp. LAIL14HWK12:I5", "rank": "Species"}, "1409720": {"name": "Staphylococcus aureus COAS6117", "rank": "Strain"}, "1287313": {"name": "Mesorhizobium sp. LSJC255A00", "rank": "Species"}, "1084662": {"name": "Xanthomonas sacchari NCPPB 4393", "rank": "Strain"}, "1388569": {"name": "Staphylococcus aureus M0774", "rank": "Strain"}, "1138384": {"name": "Ruminiclostridium thermocellum AD2", "rank": "Strain"}, "1138383": {"name": "Mycobacterium intracellulare MOTT-64", "rank": "Strain"}, "1138382": {"name": "Mycobacterium intracellulare MOTT-02", "rank": "Strain"}, "1335618": {"name": "Oenococcus oeni X2L", "rank": "Strain"}, "1409726": {"name": "Staphylococcus aureus HBHO6021", "rank": "Strain"}, "1577887": {"name": "Dickeya sp. 2B12", "rank": "Species"}, "1386967": {"name": "Salmonella enterica subsp. arizonae serovar 62:z36:- str. RKS2983", "rank": "Strain"}, "1386969": {"name": "Gordonia amicalis CCMA-559", "rank": "Strain"}, "1400914": {"name": "Mycobacterium tuberculosis KT-0070", "rank": "Strain"}, "1409727": {"name": "Staphylococcus aureus CHAP6035", "rank": "Strain"}, "1410748": {"name": "Staphylococcus aureus T25611", "rank": "Strain"}, "1410749": {"name": "Staphylococcus aureus W12461", "rank": "Strain"}, "1410742": {"name": "Staphylococcus aureus T66292", "rank": "Strain"}, "1410743": {"name": "Staphylococcus aureus W48872", "rank": "Strain"}, "1410740": {"name": "Staphylococcus aureus T66282", "rank": "Strain"}, "1410741": {"name": "Staphylococcus aureus T66286", "rank": "Strain"}, "1410746": {"name": "Staphylococcus aureus H57070", "rank": "Strain"}, "1410747": {"name": "Staphylococcus aureus F12874", "rank": "Strain"}, "1410744": {"name": "Staphylococcus aureus M45245", "rank": "Strain"}, "1410745": {"name": "Staphylococcus aureus F90608", "rank": "Strain"}, "1226675": {"name": "Lactobacillus acidophilus CIP 76.13", "rank": "Strain"}, "1226677": {"name": "Lactobacillus acidophilus CIRM-BIA 442", "rank": "Strain"}, "1226676": {"name": "Lactobacillus acidophilus DSM 9126", "rank": "Strain"}, "1226679": {"name": "Lactobacillus acidophilus DSM 20242", "rank": "Strain"}, "1226678": {"name": "Lactobacillus acidophilus CIRM-BIA 445", "rank": "Strain"}, "1451261": {"name": "Microbacterium sp. MRS-1", "rank": "Species"}, "1451266": {"name": "Helicobacter pylori wls-5-2", "rank": "Strain"}, "1451267": {"name": "Helicobacter pylori wls-5-1", "rank": "Strain"}, "1451264": {"name": "Escherichia coli JT5", "rank": "Strain"}, "1451265": {"name": "Citrobacter sp. JT3", "rank": "Species"}, "1523023": {"name": "Gentian ovary ring-spot virus", "rank": "Species"}, "334211": {"name": "Pipapillomavirus", "rank": "Genus"}, "334213": {"name": "Thetapapillomavirus", "rank": "Genus"}, "334212": {"name": "Pipapillomavirus 1", "rank": "Species"}, "281186": {"name": "Nonomuraea kuesteri", "rank": "Species"}, "39759": {"name": "Deltavirus", "rank": "Genus"}, "1124780": {"name": "Nafulsella turpanensis ZLM-10", "rank": "Strain"}, "1085539": {"name": "Leptospira noguchii serovar Autumnalis", "rank": "Strain"}, "10374": {"name": "Gammaherpesvirinae", "rank": "Subfamily"}, "10375": {"name": "Lymphocryptovirus", "rank": "Genus"}, "10376": {"name": "Human herpesvirus 4", "rank": "Species"}, "1545915": {"name": "Sphingomonas sp. 35-24ZXX", "rank": "Species"}, "10372": {"name": "Human herpesvirus 7", "rank": "Species"}, "10379": {"name": "Rhadinovirus", "rank": "Genus"}, "1173469": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN000216", "rank": "Strain"}, "1173468": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN000200", "rank": "Strain"}, "1173463": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN000183", "rank": "Strain"}, "1173462": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN000182", "rank": "Strain"}, "1173461": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN000212", "rank": "Strain"}, "1173460": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN000194", "rank": "Strain"}, "1173467": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN000197", "rank": "Strain"}, "1173466": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN000180", "rank": "Strain"}, "1173465": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN000179", "rank": "Strain"}, "1173464": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN000178", "rank": "Strain"}, "189426": {"name": "Paenibacillus odorifer", "rank": "Species"}, "574375": {"name": "Bacillus gaemokensis", "rank": "Species"}, "1131492": {"name": "Aspergillaceae", "rank": "Family"}, "70692": {"name": "Unclassified Geminiviridae", "rank": "No rank"}, "574376": {"name": "Bacillus manliponensis", "rank": "Species"}, "554290": {"name": "Salmonella enterica subsp. enterica serovar Paratyphi A str. AKU_12601", "rank": "Strain"}, "200667": {"name": "Flammeovirgaceae", "rank": "Family"}, "32636": {"name": "Halothermothrix", "rank": "Genus"}, "427078": {"name": "Salsuginibacillus kocurii", "rank": "Species"}, "46473": {"name": "Breda virus", "rank": "Strain"}, "427072": {"name": "Bacillus chagannorensis", "rank": "Species"}, "1055808": {"name": "Psychrobacter sp. TB2", "rank": "Species"}, "427077": {"name": "Salsuginibacillus", "rank": "Genus"}, "1382595": {"name": "Saccharopolyspora erythraea D", "rank": "Strain"}, "1074493": {"name": "Sphingobium yanoikuyae XLDN2-5", "rank": "Strain"}, "1074494": {"name": "Streptococcus salivarius M18", "rank": "Strain"}, "470": {"name": "Acinetobacter baumannii", "rank": "Species"}, "471": {"name": "Acinetobacter calcoaceticus", "rank": "Species"}, "475": {"name": "Moraxella", "rank": "Genus"}, "1331809": {"name": "Kordiimonadaceae", "rank": "Family"}, "1157450": {"name": "Enterococcus faecium EnGen0155", "rank": "Strain"}, "1157451": {"name": "Enterococcus faecium EnGen0156", "rank": "Strain"}, "1157453": {"name": "Enterococcus faecium EnGen0158", "rank": "Strain"}, "1157454": {"name": "Enterococcus faecium EnGen0159", "rank": "Strain"}, "1157455": {"name": "Enterococcus faecium EnGen0160", "rank": "Strain"}, "1157456": {"name": "Enterococcus faecium EnGen0161", "rank": "Strain"}, "1157457": {"name": "Enterococcus faecium EnGen0162", "rank": "Strain"}, "1157458": {"name": "Enterococcus faecium EnGen0163", "rank": "Strain"}, "1157459": {"name": "Enterococcus faecium EnGen0164", "rank": "Strain"}, "270161": {"name": "Pyrobaculum spherical virus", "rank": "Species"}, "1137739": {"name": "Salmonella enterica subsp. enterica serovar Heidelberg str. SARA33", "rank": "Strain"}, "35753": {"name": "Dactylosporangium", "rank": "Genus"}, "1115512": {"name": "Escherichia hermannii NBRC 105704", "rank": "Strain"}, "35751": {"name": "Sporichthya polymorpha", "rank": "Species"}, "35750": {"name": "Sporichthya", "rank": "Genus"}, "350054": {"name": "Mycobacterium gilvum PYR-GCK", "rank": "Strain"}, "1115515": {"name": "Escherichia vulneris NBRC 102420", "rank": "Strain"}, "35754": {"name": "Dactylosporangium aurantiacum", "rank": "Species"}, "350058": {"name": "Mycobacterium vanbaalenii PYR-1", "rank": "Strain"}, "217168": {"name": "Microvirga flocculans", "rank": "Species"}, "35758": {"name": "Streptomyces ghanaensis", "rank": "Species"}, "589537": {"name": "Prevotella dentasini", "rank": "Species"}, "1411510": {"name": "Staphylococcus aureus F19383", "rank": "Strain"}, "1411511": {"name": "Staphylococcus aureus F22893", "rank": "Strain"}, "1411512": {"name": "Staphylococcus aureus F22898", "rank": "Strain"}, "1411513": {"name": "Staphylococcus aureus F26088", "rank": "Strain"}, "1411514": {"name": "Staphylococcus aureus F32119", "rank": "Strain"}, "1411515": {"name": "Staphylococcus aureus F35307", "rank": "Strain"}, "1411516": {"name": "Staphylococcus aureus F63154", "rank": "Strain"}, "1411517": {"name": "Staphylococcus aureus F63179", "rank": "Strain"}, "1411518": {"name": "Staphylococcus aureus F66300", "rank": "Strain"}, "1411519": {"name": "Staphylococcus aureus F66307", "rank": "Strain"}, "1151328": {"name": "Peptoclostridium difficile DA00141", "rank": "Strain"}, "1151329": {"name": "Peptoclostridium difficile DA00142", "rank": "Strain"}, "1047007": {"name": "Omnitrophica bacterium SCGC AAA257-O07", "rank": "Species"}, "65959": {"name": "Acetobacter pomorum", "rank": "Species"}, "749965": {"name": "Salmonella enterica subsp. enterica serovar Senftenberg str. 361154004", "rank": "Strain"}, "749964": {"name": "Salmonella enterica subsp. enterica serovar Senftenberg str. 316235162", "rank": "Strain"}, "749962": {"name": "Salmonella enterica subsp. enterica serovar Senftenberg str. NC_MB012510-0038", "rank": "Strain"}, "749961": {"name": "Salmonella enterica subsp. enterica serovar Senftenberg str. 423984-2", "rank": "Strain"}, "749960": {"name": "Salmonella enterica subsp. enterica serovar Senftenberg str. 423984-1", "rank": "Strain"}, "687329": {"name": "Anelloviridae", "rank": "Family"}, "225725": {"name": "Bacillus phage phBC6A51", "rank": "Species"}, "225726": {"name": "Bacillus phage phBC6A52", "rank": "Species"}, "475067": {"name": "Mesorhizobium alhagi", "rank": "Species"}, "1930": {"name": "Streptomyces scabiei", "rank": "Species"}, "1217052": {"name": "Ralstonia sp. A12", "rank": "Species"}, "1938": {"name": "Streptomyces viridochromogenes", "rank": "Species"}, "1046990": {"name": "Unclassified Acetothermia", "rank": "No rank"}, "1046991": {"name": "Acetothermia bacterium SCGC AAA255-C06", "rank": "Species"}, "1198451": {"name": "Methanoregulaceae", "rank": "Family"}, "1198452": {"name": "Janthinobacterium sp. HH01", "rank": "Species"}, "1151322": {"name": "Peptoclostridium difficile DA00128", "rank": "Strain"}, "1154948": {"name": "Streptococcus agalactiae GB00914", "rank": "Strain"}, "60547": {"name": "Burkholderia glathei", "rank": "Species"}, "60548": {"name": "Burkholderia graminis", "rank": "Species"}, "1339225": {"name": "Vibrio sp. ZOR0018", "rank": "Species"}, "1151325": {"name": "Peptoclostridium difficile DA00131", "rank": "Strain"}, "317865": {"name": "Rickettsia conorii subsp. indica", "rank": "Subspecies"}, "1151326": {"name": "Peptoclostridium difficile DA00132", "rank": "Strain"}, "1151327": {"name": "Peptoclostridium difficile DA00134", "rank": "Strain"}, "1681": {"name": "Bifidobacterium bifidum", "rank": "Species"}, "1680": {"name": "Bifidobacterium adolescentis", "rank": "Species"}, "1683": {"name": "Bifidobacterium angulatum", "rank": "Species"}, "1682": {"name": "Bifidobacterium longum subsp. infantis", "rank": "Subspecies"}, "1685": {"name": "Bifidobacterium breve", "rank": "Species"}, "1684": {"name": "Bifidobacterium asteroides", "rank": "Species"}, "1687": {"name": "Bifidobacterium coryneforme", "rank": "Species"}, "1686": {"name": "Bifidobacterium catenulatum", "rank": "Species"}, "1689": {"name": "Bifidobacterium dentium", "rank": "Species"}, "1688": {"name": "Bifidobacterium cuniculi", "rank": "Species"}, "216389": {"name": "Dehalococcoides mccartyi BAV1", "rank": "Strain"}, "200255": {"name": "Mirafiori lettuce big-vein virus", "rank": "Species"}, "60892": {"name": "Desulfobacca", "rank": "Genus"}, "60893": {"name": "Desulfobacca acetoxidans", "rank": "Species"}, "60890": {"name": "Phaeobacter gallaeciensis", "rank": "Species"}, "63577": {"name": "Trichoderma atroviride", "rank": "Species"}, "60894": {"name": "Saccharopolyspora spinosa", "rank": "Species"}, "114881": {"name": "Mycoplasma columbinum", "rank": "Species"}, "114882": {"name": "Mycoplasma elephantis", "rank": "Species"}, "114884": {"name": "Mycoplasma lipofaciens", "rank": "Species"}, "114886": {"name": "Mycoplasma opalescens", "rank": "Species"}, "913337": {"name": "Nitrospina sp. SCGC AAA288-L16", "rank": "Species"}, "940614": {"name": "Granulicella mallensis", "rank": "Species"}, "940615": {"name": "Granulicella tundricola", "rank": "Species"}, "46626": {"name": "Salmonella enterica subsp. enterica serovar Give", "rank": "Strain"}, "264076": {"name": "Horseradish latent virus", "rank": "Species"}, "1392059": {"name": "Staphylococcus aureus M1053", "rank": "Strain"}, "1392058": {"name": "Staphylococcus aureus M1051", "rank": "Strain"}, "160484": {"name": "Discula destructiva virus 2", "rank": "Species"}, "1392051": {"name": "Staphylococcus aureus M1043", "rank": "Strain"}, "1392050": {"name": "Staphylococcus aureus M1041", "rank": "Strain"}, "1392053": {"name": "Staphylococcus aureus M1046", "rank": "Strain"}, "1392052": {"name": "Staphylococcus aureus M1045", "rank": "Strain"}, "1392055": {"name": "Staphylococcus aureus M1048", "rank": "Strain"}, "1392054": {"name": "Staphylococcus aureus M1047", "rank": "Strain"}, "1392057": {"name": "Staphylococcus aureus M1050", "rank": "Strain"}, "160488": {"name": "Pseudomonas putida KT2440", "rank": "Strain"}, "516075": {"name": "Providencia sneebia", "rank": "Species"}, "516074": {"name": "Providencia burhodogranariea", "rank": "Species"}, "1139996": {"name": "Enterococcus saccharolyticus ATCC 43076", "rank": "Strain"}, "1324245": {"name": "Mycobacterium tuberculosis TKK-01-0035", "rank": "Strain"}, "1324244": {"name": "Mycobacterium tuberculosis TKK-01-0034", "rank": "Strain"}, "1324247": {"name": "Mycobacterium tuberculosis TKK-01-0037", "rank": "Strain"}, "1324246": {"name": "Mycobacterium tuberculosis TKK-01-0036", "rank": "Strain"}, "1324241": {"name": "Mycobacterium tuberculosis TKK-01-0030", "rank": "Strain"}, "1324240": {"name": "Mycobacterium tuberculosis TKK-01-0029", "rank": "Strain"}, "1324243": {"name": "Mycobacterium tuberculosis TKK-01-0033", "rank": "Strain"}, "1324242": {"name": "Mycobacterium tuberculosis TKK-01-0031", "rank": "Strain"}, "1221300": {"name": "Acinetobacter johnsonii TG19605", "rank": "Strain"}, "1221301": {"name": "Acinetobacter johnsonii TG19625", "rank": "Strain"}, "1221302": {"name": "Acinetobacter sp. 528", "rank": "Species"}, "1221303": {"name": "Acinetobacter sp. TG19627", "rank": "Species"}, "1324249": {"name": "Mycobacterium tuberculosis TKK-01-0039", "rank": "Strain"}, "1324248": {"name": "Mycobacterium tuberculosis TKK-01-0038", "rank": "Strain"}, "1221306": {"name": "Acinetobacter junii TG19608", "rank": "Strain"}, "1412491": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. SA20094352", "rank": "Strain"}, "1123958": {"name": "Chimpanzee adenovirus Y25", "rank": "Strain"}, "367301": {"name": "Black raspberry necrosis virus", "rank": "Species"}, "1086011": {"name": "Flavobacterium frigoris PS1", "rank": "Strain"}, "1134819": {"name": "Enterococcus faecium ERV1", "rank": "Strain"}, "1134818": {"name": "Enterococcus faecium E422", "rank": "Strain"}, "1086014": {"name": "Acinetobacter pittii D499", "rank": "Strain"}, "1134813": {"name": "Enterococcus faecium 515", "rank": "Strain"}, "1134812": {"name": "Enterococcus faecium 514", "rank": "Strain"}, "1134811": {"name": "Enterococcus faecium 513", "rank": "Strain"}, "1134810": {"name": "Enterococcus faecium 511", "rank": "Strain"}, "1134817": {"name": "Enterococcus faecium E417", "rank": "Strain"}, "1134816": {"name": "Enterococcus faecium C621", "rank": "Strain"}, "1134815": {"name": "Enterococcus faecium C497", "rank": "Strain"}, "1134814": {"name": "Enterococcus faecium C1904", "rank": "Strain"}, "720569": {"name": "Porcine circovirus type 1/2a", "rank": "Species"}, "332471": {"name": "Fritillary virus Y", "rank": "Species"}, "90410": {"name": "Streptococcus phage DT1", "rank": "Species"}, "13769": {"name": "Natrialba magadii", "rank": "Species"}, "699248": {"name": "Streptococcus ratti FA-1 = DSM 20564", "rank": "Strain"}, "668607": {"name": "Buchnera aphidicola (Acyrthosiphon kondoi)", "rank": "Strain"}, "699245": {"name": "Clostridiales genomosp. BVAB3", "rank": "Species"}, "699246": {"name": "Clostridiales genomosp. BVAB3 str. UPII9-5", "rank": "Strain"}, "1388735": {"name": "Staphylococcus aureus M0975", "rank": "Strain"}, "1437882": {"name": "Pseudomonas nitroreducens HBP1", "rank": "Strain"}, "1385522": {"name": "Lysobacter arseniciresistens", "rank": "Species"}, "1409661": {"name": "Staphylococcus aureus UCIM6104", "rank": "Strain"}, "81459": {"name": "Entomoplasma melaleucae", "rank": "Species"}, "98228": {"name": "Bacillus sp. OxB-1", "rank": "Species"}, "408753": {"name": "Clostridiisalibacter paucivorans", "rank": "Species"}, "395349": {"name": "Tomato yellow leaf curl Indonesia virus-Lembang", "rank": "Strain"}, "398525": {"name": "Bradyrhizobium elkanii USDA 76", "rank": "Strain"}, "398524": {"name": "Bradyrhizobium elkanii USDA 94", "rank": "Strain"}, "398527": {"name": "Burkholderia phytofirmans PsJN", "rank": "Strain"}, "1116081": {"name": "Escherichia coli P0305260.7", "rank": "Strain"}, "1409660": {"name": "Staphylococcus aureus WMCS6087", "rank": "Strain"}, "86959": {"name": "Zymophilus raffinosivorans", "rank": "Species"}, "1311277": {"name": "Capraria yellow spot Yucatan virus", "rank": "Species"}, "107819": {"name": "Clostridium perfringens D", "rank": "Strain"}, "102862": {"name": "Proteus penneri", "rank": "Species"}, "438853": {"name": "Unclassified Campylobacterales", "rank": "No rank"}, "1411554": {"name": "Staphylococcus aureus M65003", "rank": "Strain"}, "347538": {"name": "Marine Group III", "rank": "No rank"}, "182640": {"name": "Kribbella flavida", "rank": "Species"}, "1409666": {"name": "Staphylococcus aureus FVRH6066", "rank": "Strain"}, "1169253": {"name": "Enterococcus faecalis EnGen0333", "rank": "Strain"}, "1247411": {"name": "Brucella melitensis B115", "rank": "Strain"}, "1169251": {"name": "Enterococcus faecalis EnGen0332", "rank": "Strain"}, "1169250": {"name": "Enterococcus faecalis EnGen0331", "rank": "Strain"}, "1169257": {"name": "Staphylococcus aureus M0978", "rank": "Strain"}, "1169256": {"name": "Staphylococcus aureus M0964", "rank": "Strain"}, "1169255": {"name": "Staphylococcus aureus M0946", "rank": "Strain"}, "1212819": {"name": "Burkholderia pyrrocinia CH-67", "rank": "Strain"}, "213849": {"name": "Campylobacterales", "rank": "Order"}, "1169259": {"name": "Staphylococcus aureus M1034", "rank": "Strain"}, "1169258": {"name": "Staphylococcus aureus M0994", "rank": "Strain"}, "1411551": {"name": "Staphylococcus aureus M31588", "rank": "Strain"}, "1310646": {"name": "Acinetobacter baumannii 1462234", "rank": "Strain"}, "1310647": {"name": "Acinetobacter baumannii 1461402", "rank": "Strain"}, "195522": {"name": "Thermococcus nautili", "rank": "Species"}, "1310645": {"name": "Acinetobacter baumannii 1461963", "rank": "Strain"}, "1310643": {"name": "Acinetobacter baumannii 299505", "rank": "Strain"}, "1310640": {"name": "Acinetobacter baumannii 342950", "rank": "Strain"}, "1310641": {"name": "Acinetobacter baumannii 1440422", "rank": "Strain"}, "1310648": {"name": "Acinetobacter baumannii 110912", "rank": "Strain"}, "1310649": {"name": "Acinetobacter baumannii 1465485", "rank": "Strain"}, "572511": {"name": "Blautia", "rank": "Genus"}, "1408828": {"name": "Borrelia garinii IPT88", "rank": "Strain"}, "1408829": {"name": "Borrelia garinii IPT89", "rank": "Strain"}, "1408826": {"name": "Borrelia garinii IPT76", "rank": "Strain"}, "1408824": {"name": "Borrelia garinii IPT74", "rank": "Strain"}, "1408825": {"name": "Borrelia garinii IPT75", "rank": "Strain"}, "1408823": {"name": "Clostridium mangenotii TR", "rank": "Strain"}, "702447": {"name": "Bacteroides xylanisolvens SD CC 1b", "rank": "Strain"}, "702446": {"name": "Bacteroides vulgatus PC510", "rank": "Strain"}, "445219": {"name": "Reyranella", "rank": "Genus"}, "1049803": {"name": "Leptospira interrogans serovar Bataviae str. Kariadi-Satu", "rank": "Strain"}, "1049802": {"name": "Leptospira interrogans serovar Bataviae str. 2006006976", "rank": "Strain"}, "1049801": {"name": "Leptospira interrogans serovar Bataviae str. 2006006959", "rank": "Strain"}, "1049807": {"name": "Leptospira interrogans serovar Bataviae str. UT234", "rank": "Strain"}, "1049806": {"name": "Leptospira interrogans serovar Bataviae str. UI 08561", "rank": "Strain"}, "1049805": {"name": "Leptospira interrogans serovar Bataviae str. Swart", "rank": "Strain"}, "1049804": {"name": "Leptospira interrogans serovar Bataviae str. L1111", "rank": "Strain"}, "992186": {"name": "Rhodobacter sphaeroides WS8N", "rank": "Strain"}, "992182": {"name": "Yersinia pestis PY-101", "rank": "Strain"}, "992181": {"name": "Yersinia pestis PY-100", "rank": "Strain"}, "204431": {"name": "Fibrobacteraceae", "rank": "Family"}, "1443128": {"name": "Clostridium botulinum C/D str. DC5", "rank": "Strain"}, "1443122": {"name": "Clostridium novyi B str. NCTC 9691", "rank": "Strain"}, "1443123": {"name": "Clostridium novyi B str. ATCC 27606", "rank": "Strain"}, "1443120": {"name": "Clostridium novyi A str. NCTC 538", "rank": "Strain"}, "1443121": {"name": "Clostridium novyi A str. 4540", "rank": "Strain"}, "1443126": {"name": "Clostridium botulinum C/D str. It1", "rank": "Strain"}, "1443127": {"name": "Clostridium botulinum C/D str. BKT2873", "rank": "Strain"}, "1443124": {"name": "Clostridium botulinum C/D str. BKT75002", "rank": "Strain"}, "1443125": {"name": "Clostridium botulinum C/D str. BKT12695", "rank": "Strain"}, "1399115": {"name": "Exiguobacterium sp. MH3", "rank": "Species"}, "1399116": {"name": "Lactococcus lactis subsp. lactis KLDS 4.0325", "rank": "Strain"}, "76833": {"name": "Actinobaculum", "rank": "Genus"}, "43263": {"name": "Pseudomonas alcaligenes", "rank": "Species"}, "76831": {"name": "Myroides", "rank": "Genus"}, "1448589": {"name": "Mycobacterium tuberculosis TKK_04_0129", "rank": "Strain"}, "1448588": {"name": "Mycobacterium tuberculosis TKK_04_0126", "rank": "Strain"}, "1215331": {"name": "Trichophyton soudanense CBS 452.61", "rank": "Strain"}, "1005421": {"name": "Escherichia coli 99.0672", "rank": "Strain"}, "1005420": {"name": "Escherichia coli 97.0007", "rank": "Strain"}, "1005423": {"name": "Escherichia coli 99.0670", "rank": "Strain"}, "1005422": {"name": "Escherichia coli 99.0678", "rank": "Strain"}, "1448580": {"name": "Mycobacterium tuberculosis TKK_04_0118", "rank": "Strain"}, "1050201": {"name": "Allobaculum stercoricanis DSM 13633", "rank": "Strain"}, "1448582": {"name": "Mycobacterium tuberculosis TKK_04_0120", "rank": "Strain"}, "1448585": {"name": "Mycobacterium tuberculosis TKK_04_0123", "rank": "Strain"}, "1448584": {"name": "Mycobacterium tuberculosis TKK_04_0122", "rank": "Strain"}, "1448587": {"name": "Mycobacterium tuberculosis TKK_04_0125", "rank": "Strain"}, "1448586": {"name": "Mycobacterium tuberculosis TKK_04_0124", "rank": "Strain"}, "1005536": {"name": "Escherichia coli EC1734", "rank": "Strain"}, "1193010": {"name": "Leptospira borgpetersenii str. 200901122", "rank": "Strain"}, "1193011": {"name": "Leptospira fainei serovar Hurstbridge str. BUT 6", "rank": "Strain"}, "1193012": {"name": "Leptospira sp. Fiocruz LV3954", "rank": "Species"}, "1193013": {"name": "Leptospira sp. Fiocruz LV4135", "rank": "Species"}, "1193014": {"name": "Leptospira interrogans serovar Canicola str. Fiocruz LV133", "rank": "Strain"}, "1193017": {"name": "Leptospira interrogans serovar Grippotyphosa str. 2006006986", "rank": "Strain"}, "1193018": {"name": "Leptospira interrogans serovar Grippotyphosa str. Andaman", "rank": "Strain"}, "1193019": {"name": "Leptospira interrogans serovar Icterohaemorrhagiae str. Verdun LP", "rank": "Strain"}, "1313304": {"name": "Chitinivibrio alkaliphilus ACht1", "rank": "Strain"}, "1313303": {"name": "Xanthomonas oryzae ATCC 35933", "rank": "Strain"}, "1245814": {"name": "Mycobacterium phage First", "rank": "Species"}, "1313301": {"name": "Thermonema rossianum DSM 10300", "rank": "Strain"}, "1131462": {"name": "Dehalobacter sp. CF", "rank": "Species"}, "548478": {"name": "Corynebacterium glucuronolyticum ATCC 51866", "rank": "Strain"}, "548479": {"name": "Mobiluncus curtisii ATCC 43063", "rank": "Strain"}, "548474": {"name": "Staphylococcus aureus subsp. aureus TCH130", "rank": "Strain"}, "548475": {"name": "Staphylococcus aureus subsp. aureus TCH70", "rank": "Strain"}, "548476": {"name": "Corynebacterium aurimucosum ATCC 700975", "rank": "Strain"}, "548477": {"name": "Corynebacterium glucuronolyticum ATCC 51867", "rank": "Strain"}, "548470": {"name": "Staphylococcus aureus subsp. aureus MN8", "rank": "Strain"}, "548473": {"name": "Staphylococcus aureus subsp. aureus TCH60", "rank": "Strain"}, "242231": {"name": "Neisseria gonorrhoeae FA 1090", "rank": "Strain"}, "1234777": {"name": "Herbaspirillum rubrisubalbicans Os45", "rank": "Strain"}, "563177": {"name": "Acidianus hospitalis", "rank": "Species"}, "563174": {"name": "Listeria monocytogenes L99", "rank": "Strain"}, "520973": {"name": "Calicivirus pig/AB90/CAN", "rank": "Strain"}, "563178": {"name": "Buchnera aphidicola str. 5A (Acyrthosiphon pisum)", "rank": "Strain"}, "134034": {"name": "Corynebacterium freneyi", "rank": "Species"}, "1158477": {"name": "Staphylococcus aureus M1216", "rank": "Strain"}, "1158476": {"name": "Staphylococcus aureus M1215", "rank": "Strain"}, "1158475": {"name": "Staphylococcus aureus M1199", "rank": "Strain"}, "1158474": {"name": "Staphylococcus aureus M1198", "rank": "Strain"}, "1158473": {"name": "Staphylococcus aureus M1188", "rank": "Strain"}, "1158472": {"name": "Staphylococcus aureus M1170", "rank": "Strain"}, "1158471": {"name": "Staphylococcus aureus M1167", "rank": "Strain"}, "1158470": {"name": "Staphylococcus aureus M1119", "rank": "Strain"}, "41997": {"name": "Enterococcus saccharolyticus", "rank": "Species"}, "41995": {"name": "Unclassified Birnaviridae", "rank": "No rank"}, "1158479": {"name": "Staphylococcus aureus M1248", "rank": "Strain"}, "1158478": {"name": "Staphylococcus aureus M1229", "rank": "Strain"}, "1402729": {"name": "Staphylococcus aureus M1232", "rank": "Strain"}, "1402728": {"name": "Staphylococcus aureus M1231", "rank": "Strain"}, "1402723": {"name": "Staphylococcus aureus M1222", "rank": "Strain"}, "1402722": {"name": "Staphylococcus aureus M1221", "rank": "Strain"}, "1402721": {"name": "Staphylococcus aureus M1220", "rank": "Strain"}, "1402720": {"name": "Staphylococcus aureus M1219", "rank": "Strain"}, "1402727": {"name": "Staphylococcus aureus M1230", "rank": "Strain"}, "1402726": {"name": "Staphylococcus aureus M1227", "rank": "Strain"}, "1402725": {"name": "Staphylococcus aureus M1226", "rank": "Strain"}, "1402724": {"name": "Staphylococcus aureus M1225", "rank": "Strain"}, "445932": {"name": "Elusimicrobium minutum Pei191", "rank": "Strain"}, "29000": {"name": "Pucciniomycotina", "rank": "Subphylum"}, "578107": {"name": "Daphne mosaic virus", "rank": "Species"}, "1214063": {"name": "Mycobacterium intracellulare M.i.198", "rank": "Strain"}, "1214065": {"name": "Enterobacteriaceae bacterium B14", "rank": "Species"}, "1214066": {"name": "Methanobrevibacter boviskoreani JH1", "rank": "Strain"}, "649841": {"name": "Sulfuricella denitrificans", "rank": "Species"}, "529709": {"name": "Pyrococcus yayanosii CH1", "rank": "Strain"}, "97081": {"name": "Enterobacteria phage VT2-Sakai", "rank": "Strain"}, "97084": {"name": "Bacteriovorax marinus", "rank": "Species"}, "1439133": {"name": "Streptococcus pyogenes ABC020044188", "rank": "Strain"}, "1168612": {"name": "Staphylococcus phage SMSAP5", "rank": "Species"}, "1168613": {"name": "Staphylococcus phage TEM123", "rank": "Species"}, "1439134": {"name": "Streptococcus pyogenes ABC020044193", "rank": "Strain"}, "1159082": {"name": "Streptococcus pneumoniae PCS8203", "rank": "Strain"}, "1432565": {"name": "Spinach yellow vein Sikar virus", "rank": "Species"}, "1412525": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20121541", "rank": "Strain"}, "106370": {"name": "Frankia sp. CcI3", "rank": "Species"}, "403905": {"name": "Streptococcus phage P9", "rank": "Species"}, "202789": {"name": "Actinobaculum massiliense", "rank": "Species"}, "1417170": {"name": "Staphylococcus aureus H65794", "rank": "Strain"}, "1315212": {"name": "Exiguobacterium sp. 8-11-1", "rank": "Species"}, "329186": {"name": "Flavobacterium saliperosum", "rank": "Species"}, "28351": {"name": "Strawberry latent ringspot virus", "rank": "Species"}, "28350": {"name": "Tomato leaf curl virus", "rank": "Species"}, "1268339": {"name": "Rhizobium sp. JGI 0001002-E20", "rank": "Species"}, "1232736": {"name": "Unclassified Deltacoronavirus", "rank": "No rank"}, "28355": {"name": "Peanut clump virus", "rank": "Species"}, "28354": {"name": "Plantago asiatica mosaic virus", "rank": "Species"}, "28358": {"name": "Corynebacterium phage BFK20", "rank": "Species"}, "319458": {"name": "Leadbetterella", "rank": "Genus"}, "1090974": {"name": "Melissococcus plutonius DAT561", "rank": "Strain"}, "1030595": {"name": "Eragrostis minor streak virus", "rank": "Species"}, "566277": {"name": "Lentisphaeraceae", "rank": "Family"}, "1234887": {"name": "Dragonfly-associated circular virus 1", "rank": "Species"}, "1234886": {"name": "Dragonfly-associated circular virus 2", "rank": "Species"}, "1234881": {"name": "Dragonfly cyclovirus 3", "rank": "Species"}, "38323": {"name": "Bartonella henselae", "rank": "Species"}, "566270": {"name": "Spodoptera litura nucleopolyhedrovirus II", "rank": "Species"}, "1234882": {"name": "Dragonfly cyclovirus 4", "rank": "Species"}, "104204": {"name": "Streptomonospora", "rank": "Genus"}, "1234889": {"name": "Leuconostoc mesenteroides subsp. cremoris TIFN8", "rank": "Strain"}, "1159101": {"name": "Streptococcus pneumoniae PNI0427", "rank": "Strain"}, "1159102": {"name": "Streptococcus pneumoniae PNI0446", "rank": "Strain"}, "936578": {"name": "Streptococcus sp. AS20", "rank": "Species"}, "1230390": {"name": "Poacevirus", "rank": "Genus"}, "936572": {"name": "Selenomonas sp. FOBRC6", "rank": "Species"}, "936573": {"name": "Selenomonas sp. FOBRC9", "rank": "Species"}, "936574": {"name": "Shuttleworthia sp. MSX8B", "rank": "Species"}, "936575": {"name": "Streptococcus sp. AC15", "rank": "Species"}, "936576": {"name": "Streptococcus sp. ACS2", "rank": "Species"}, "936577": {"name": "Streptococcus sp. AS14", "rank": "Species"}, "487797": {"name": "Flavobacteria bacterium MS024-3C", "rank": "Species"}, "487796": {"name": "Flavobacteria bacterium MS024-2A", "rank": "Species"}, "1176165": {"name": "Brevibacterium massiliense 5401308", "rank": "Strain"}, "99906": {"name": "Alkalibacterium", "rank": "Genus"}, "915429": {"name": "Human papillomavirus type 121", "rank": "Strain"}, "1151276": {"name": "Peptoclostridium difficile CD86", "rank": "Strain"}, "1202962": {"name": "Moritella marina ATCC 15381", "rank": "Strain"}, "256994": {"name": "Sulfolobus virus Ragged Hills", "rank": "Species"}, "915428": {"name": "Human papillomavirus 116", "rank": "Strain"}, "392827": {"name": "Halalkalibacillus halophilus", "rank": "Species"}, "392825": {"name": "Halalkalibacillus", "rank": "Genus"}, "768667": {"name": "Thermogemmatisporales", "rank": "Order"}, "229480": {"name": "Arsenicicoccus bolidensis", "rank": "Species"}, "768669": {"name": "Thermogemmatispora", "rank": "Genus"}, "768668": {"name": "Thermogemmatisporaceae", "rank": "Family"}, "483011": {"name": "Lactobacillus fabifermentans", "rank": "Species"}, "696748": {"name": "Actinobacillus suis H91-0380", "rank": "Strain"}, "696749": {"name": "Acinetobacter baumannii 1656-2", "rank": "Strain"}, "523829": {"name": "Salmonella enterica subsp. enterica serovar Paratyphi B str. ATCC BAA-1585", "rank": "Strain"}, "696747": {"name": "Arthrospira platensis NIES-39", "rank": "Strain"}, "29910": {"name": "Tolypocladium inflatum", "rank": "Species"}, "567106": {"name": "Campylobacter jejuni subsp. jejuni IA3902", "rank": "Strain"}, "121723": {"name": "Photobacterium sp. SKA34", "rank": "Species"}, "312153": {"name": "Polynucleobacter necessarius subsp. asymbioticus QLW-P1DMWA-1", "rank": "Strain"}, "1159084": {"name": "Streptococcus pneumoniae PCS125219", "rank": "Strain"}, "1154689": {"name": "Haloarcula hispanica icosahedral virus 2", "rank": "Species"}, "12429": {"name": "Unclassified viruses", "rank": "No rank"}, "1159087": {"name": "Streptococcus pneumoniae PNI0002", "rank": "Strain"}, "1159086": {"name": "Streptococcus pneumoniae PCS81218", "rank": "Strain"}, "414999": {"name": "Opitutae", "rank": "Class"}, "723802": {"name": "Simian retrovirus 4", "rank": "Species"}, "1159081": {"name": "Streptococcus pneumoniae PCS8106", "rank": "Strain"}, "414996": {"name": "Actinopolyspora erythraea", "rank": "Species"}, "220618": {"name": "Cucumber Bulgarian virus", "rank": "Species"}, "1413422": {"name": "Staphylococcus aureus 1110701127", "rank": "Strain"}, "446138": {"name": "Sus scrofa papillomavirus 1", "rank": "Strain"}, "1413420": {"name": "Staphylococcus aureus 1110700562", "rank": "Strain"}, "1413421": {"name": "Staphylococcus aureus 1110700610", "rank": "Strain"}, "1413426": {"name": "Staphylococcus aureus 1110807699", "rank": "Strain"}, "1159083": {"name": "Streptococcus pneumoniae PCS8235", "rank": "Strain"}, "1413424": {"name": "Staphylococcus aureus 1110802883", "rank": "Strain"}, "1413425": {"name": "Staphylococcus aureus 1110803248", "rank": "Strain"}, "1413428": {"name": "Staphylococcus aureus 1111000175", "rank": "Strain"}, "1413429": {"name": "Staphylococcus aureus 1111000177", "rank": "Strain"}, "1281232": {"name": "Escherichia coli UMEA 3268-1", "rank": "Strain"}, "1281233": {"name": "Escherichia coli UMEA 3271-1", "rank": "Strain"}, "1281230": {"name": "Escherichia coli UMEA 3257-1", "rank": "Strain"}, "1281231": {"name": "Escherichia coli UMEA 3264-1", "rank": "Strain"}, "1281236": {"name": "Escherichia coli UMEA 3298-1", "rank": "Strain"}, "1281237": {"name": "Escherichia coli UMEA 3304-1", "rank": "Strain"}, "1281234": {"name": "Escherichia coli UMEA 3290-1", "rank": "Strain"}, "1281235": {"name": "Escherichia coli UMEA 3292-1", "rank": "Strain"}, "1281238": {"name": "Escherichia coli UMEA 3314-1", "rank": "Strain"}, "1281239": {"name": "Escherichia coli UMEA 3317-1", "rank": "Strain"}, "1224930": {"name": "Staphylococcus aureus M0415", "rank": "Strain"}, "1224931": {"name": "Staphylococcus aureus M0455", "rank": "Strain"}, "1224932": {"name": "Staphylococcus aureus M0460", "rank": "Strain"}, "1224933": {"name": "Staphylococcus aureus M0493", "rank": "Strain"}, "1409458": {"name": "Staphylococcus aureus SJOS6001", "rank": "Strain"}, "1330546": {"name": "Pluralibacter", "rank": "Genus"}, "1330545": {"name": "Lelliottia", "rank": "Genus"}, "1409450": {"name": "Staphylococcus aureus FVRH6002", "rank": "Strain"}, "1409451": {"name": "Staphylococcus aureus SMMC6097", "rank": "Strain"}, "1409452": {"name": "Staphylococcus aureus AGEN6033", "rank": "Strain"}, "1409453": {"name": "Staphylococcus aureus LAMC6065", "rank": "Strain"}, "1409454": {"name": "Staphylococcus aureus HOAG6084", "rank": "Strain"}, "1409455": {"name": "Staphylococcus aureus OCMM6052", "rank": "Strain"}, "1409456": {"name": "Staphylococcus aureus SJOS6003", "rank": "Strain"}, "1409457": {"name": "Staphylococcus aureus SJOS6002", "rank": "Strain"}, "1074120": {"name": "Streptococcus mutans TCI-125", "rank": "Strain"}, "1422709": {"name": "Staphylococcus aureus VET1853R", "rank": "Strain"}, "1422708": {"name": "Staphylococcus aureus VET1852R", "rank": "Strain"}, "233263": {"name": "Unclassified coronaviruses", "rank": "No rank"}, "1074121": {"name": "Streptococcus mutans TCI-138", "rank": "Strain"}, "1422703": {"name": "Staphylococcus aureus VET1846R", "rank": "Strain"}, "1422702": {"name": "Staphylococcus aureus VET1845R", "rank": "Strain"}, "1422701": {"name": "Staphylococcus aureus VET1844R", "rank": "Strain"}, "1422700": {"name": "Staphylococcus aureus VET1843R", "rank": "Strain"}, "1422707": {"name": "Staphylococcus aureus VET1851R", "rank": "Strain"}, "1422706": {"name": "Staphylococcus aureus VET1850R", "rank": "Strain"}, "1422705": {"name": "Staphylococcus aureus VET1849R", "rank": "Strain"}, "1422704": {"name": "Staphylococcus aureus VET1848R", "rank": "Strain"}, "1001747": {"name": "Streptococcus pneumoniae ND6012", "rank": "Strain"}, "760858": {"name": "Streptococcus pneumoniae GA52612", "rank": "Strain"}, "760859": {"name": "Streptococcus pneumoniae GA54644", "rank": "Strain"}, "760856": {"name": "Streptococcus pneumoniae GA52306", "rank": "Strain"}, "1001740": {"name": "Mycobacterium abscessus 6G-0125-R", "rank": "Strain"}, "760854": {"name": "Streptococcus pneumoniae GA49447", "rank": "Strain"}, "760855": {"name": "Streptococcus pneumoniae GA49542", "rank": "Strain"}, "760852": {"name": "Streptococcus pneumoniae GA49194", "rank": "Strain"}, "760850": {"name": "Streptococcus pneumoniae GA47976", "rank": "Strain"}, "760851": {"name": "Streptococcus pneumoniae GA49138", "rank": "Strain"}, "1424280": {"name": "Sierra Nevada virus", "rank": "Species"}, "1427233": {"name": "Mycobacterium tuberculosis XTB13-144", "rank": "Strain"}, "1507404": {"name": "Mint-like virus", "rank": "Species"}, "1507402": {"name": "Unclassified Bocaparvovirus", "rank": "No rank"}, "1507403": {"name": "Mirabilis leaf curl India virus associated betasatellite", "rank": "Species"}, "1507401": {"name": "Bocaparvovirus", "rank": "Genus"}, "915424": {"name": "Macaca fascicularis papillomavirus 2", "rank": "Strain"}, "1469607": {"name": "Scytonema hofmanni UTEX 2349", "rank": "Strain"}, "420246": {"name": "Geobacillus thermodenitrificans NG80-2", "rank": "Strain"}, "420247": {"name": "Methanobrevibacter smithii ATCC 35061", "rank": "Strain"}, "470565": {"name": "Prevotella histicola", "rank": "Species"}, "1154952": {"name": "Streptococcus agalactiae GB00924", "rank": "Strain"}, "660537": {"name": "Burkholderia acidipaludis", "rank": "Species"}, "512649": {"name": "Vibrio azureus", "rank": "Species"}, "1345539": {"name": "Helicobacter pylori SA253C", "rank": "Strain"}, "1249649": {"name": "Dragonfly-associated alphasatellite", "rank": "Species"}, "1244098": {"name": "Streptococcus agalactiae SGBS016", "rank": "Strain"}, "1412771": {"name": "Staphylococcus aureus M87665", "rank": "Strain"}, "1412770": {"name": "Staphylococcus aureus M87641", "rank": "Strain"}, "1412773": {"name": "Staphylococcus aureus M91155", "rank": "Strain"}, "266779": {"name": "Chelativorans sp. BNC1", "rank": "Species"}, "1412775": {"name": "Staphylococcus aureus T40867", "rank": "Strain"}, "283686": {"name": "Kosakonia radicincitans", "rank": "Species"}, "1412777": {"name": "Staphylococcus aureus T44444", "rank": "Strain"}, "1412779": {"name": "Staphylococcus aureus T44811", "rank": "Strain"}, "1412778": {"name": "Staphylococcus aureus T44461", "rank": "Strain"}, "152161": {"name": "Stappia", "rank": "Genus"}, "74712": {"name": "Frankiaceae", "rank": "Family"}, "647933": {"name": "Trichophyton tonsurans CBS 112818", "rank": "Strain"}, "1244097": {"name": "Streptococcus agalactiae SGBS015", "rank": "Strain"}, "1331236": {"name": "Bordetella bronchiseptica MBORD839", "rank": "Strain"}, "1331237": {"name": "Bordetella bronchiseptica MBORD849", "rank": "Strain"}, "1331234": {"name": "Bordetella bronchiseptica MBORD782", "rank": "Strain"}, "1331235": {"name": "Bordetella bronchiseptica MBORD785", "rank": "Strain"}, "1331232": {"name": "Bordetella bronchiseptica MBORD731", "rank": "Strain"}, "1331233": {"name": "Bordetella bronchiseptica MBORD762", "rank": "Strain"}, "1331230": {"name": "Bordetella bronchiseptica MBORD698", "rank": "Strain"}, "1331231": {"name": "Bordetella bronchiseptica MBORD707", "rank": "Strain"}, "1266914": {"name": "Thioalkalivibrio sp. AKL19", "rank": "Species"}, "1424301": {"name": "Staphylococcus aureus subsp. aureus ST 1413", "rank": "Strain"}, "304895": {"name": "Catenulispora acidiphila", "rank": "Species"}, "1266912": {"name": "Thioalkalivibrio sp. ALMg9", "rank": "Species"}, "1266913": {"name": "Thioalkalivibrio sp. HL-Eb18", "rank": "Species"}, "331271": {"name": "Burkholderia cenocepacia AU 1054", "rank": "Strain"}, "331272": {"name": "Burkholderia cenocepacia HI2424", "rank": "Strain"}, "1463913": {"name": "Streptomyces sp. NRRL S-515", "rank": "Species"}, "204037": {"name": "Dickeya", "rank": "Genus"}, "204039": {"name": "Dickeya dianthicola", "rank": "Species"}, "204038": {"name": "Dickeya dadantii", "rank": "Species"}, "331978": {"name": "Burkholderia pseudomallei Pasteur 52237", "rank": "Strain"}, "1123307": {"name": "Streptococcus massiliensis DSM 18628", "rank": "Strain"}, "553596": {"name": "Staphylococcus aureus A9781", "rank": "Strain"}, "1123305": {"name": "Streptococcus hyovaginalis DSM 12219", "rank": "Strain"}, "553594": {"name": "Staphylococcus aureus A9765", "rank": "Strain"}, "1123303": {"name": "Streptococcus ferus DSM 20646", "rank": "Strain"}, "553592": {"name": "Staphylococcus aureus A9763", "rank": "Strain"}, "1123301": {"name": "Streptococcus didelphis DSM 15616", "rank": "Strain"}, "553590": {"name": "Staphylococcus aureus A9754", "rank": "Strain"}, "1123309": {"name": "Streptococcus minor DSM 17118", "rank": "Strain"}, "1123308": {"name": "Streptococcus merionis DSM 19192", "rank": "Strain"}, "393011": {"name": "Francisella tularensis subsp. holarctica OSU18", "rank": "Strain"}, "44258": {"name": "Caloramator", "rank": "Genus"}, "44259": {"name": "Filifactor", "rank": "Genus"}, "868149": {"name": "Escherichia coli DEC4A", "rank": "Strain"}, "868148": {"name": "Escherichia coli DEC3F", "rank": "Strain"}, "868145": {"name": "Escherichia coli DEC3C", "rank": "Strain"}, "868144": {"name": "Escherichia coli DEC3B", "rank": "Strain"}, "868147": {"name": "Escherichia coli DEC3E", "rank": "Strain"}, "868146": {"name": "Escherichia coli DEC3D", "rank": "Strain"}, "44256": {"name": "Caldanaerobius polysaccharolyticus", "rank": "Species"}, "868140": {"name": "Escherichia coli DEC2C", "rank": "Strain"}, "868143": {"name": "Escherichia coli DEC3A", "rank": "Strain"}, "868142": {"name": "Escherichia coli DEC2E", "rank": "Strain"}, "315277": {"name": "Chlamydia trachomatis A/HAR-13", "rank": "Strain"}, "1075399": {"name": "Blattabacterium sp. (Cryptocercus punctulatus) str. Cpu", "rank": "Strain"}, "1388350": {"name": "Staphylococcus aureus M0532", "rank": "Strain"}, "292639": {"name": "Thermoproteus tenax spherical virus 1", "rank": "Species"}, "243629": {"name": "Hydrocarboniphaga effusa", "rank": "Species"}, "1341112": {"name": "Cyphellophoraceae", "rank": "Family"}, "562742": {"name": "Roseobacter phage RDJL Phi 1", "rank": "Species"}, "562743": {"name": "Amphibacillus jilinensis Y1", "rank": "Strain"}, "224719": {"name": "Methanobrevibacter sp. AbM4", "rank": "Species"}, "1341118": {"name": "Luminiphilus", "rank": "Genus"}, "1341119": {"name": "Luminiphilus syltensis", "rank": "Species"}, "243627": {"name": "Hydrocarboniphaga", "rank": "Genus"}, "1154959": {"name": "Streptococcus agalactiae GB00954", "rank": "Strain"}, "376619": {"name": "Francisella tularensis subsp. holarctica LVS", "rank": "Strain"}, "699257": {"name": "Parcubacteria bacterium SCGC AAA011-N16", "rank": "Species"}, "1417230": {"name": "Borrelia persica No12", "rank": "Strain"}, "710394": {"name": "Helicobacter suis HS5", "rank": "Strain"}, "710393": {"name": "Helicobacter suis HS1", "rank": "Strain"}, "84023": {"name": "Clostridium autoethanogenum", "rank": "Species"}, "84025": {"name": "Clostridium haemolyticum", "rank": "Species"}, "84026": {"name": "Clostridium methylpentosum", "rank": "Species"}, "944995": {"name": "Ageratum conyzoides associated symptomless alphasatellite", "rank": "Species"}, "944994": {"name": "Hollyhock yellow vein mosaic virus", "rank": "Species"}, "940289": {"name": "Yersinia enterocolitica subsp. palearctica YO527", "rank": "Strain"}, "940288": {"name": "Yersinia enterocolitica subsp. palearctica 647/5307", "rank": "Strain"}, "1268622": {"name": "Acidovorax sp. MR-S7", "rank": "Species"}, "940283": {"name": "Komagataeibacter europaeus LMG 18890", "rank": "Strain"}, "940282": {"name": "Acetobacter pasteurianus 3P3", "rank": "Strain"}, "940280": {"name": "Carnation yellow fleck virus", "rank": "Species"}, "940287": {"name": "Yersinia enterocolitica subsp. palearctica 556/8265", "rank": "Strain"}, "290633": {"name": "Gluconobacter oxydans 621H", "rank": "Strain"}, "940285": {"name": "Komagataeibacter europaeus 5P3", "rank": "Strain"}, "940284": {"name": "Komagataeibacter europaeus LMG 18494", "rank": "Strain"}, "1304284": {"name": "Clostridiaceae bacterium L21-TH-D2", "rank": "Species"}, "486809": {"name": "Ramie mosaic virus", "rank": "Species"}, "1278070": {"name": "Acinetobacter baumannii MSP4-16", "rank": "Strain"}, "1278071": {"name": "Staphylococcus aureus 3957", "rank": "Strain"}, "1278072": {"name": "Staphylococcus aureus LVP2", "rank": "Strain"}, "1278073": {"name": "Myxococcus stipitatus DSM 14675", "rank": "Strain"}, "1278074": {"name": "Staphylococcus aureus VH221", "rank": "Strain"}, "1278075": {"name": "Staphylococcus aureus LVP5", "rank": "Strain"}, "1278076": {"name": "Rhodococcus ruber BKS 20-38", "rank": "Strain"}, "1278077": {"name": "Rhodococcus qingshengii BKS 20-40", "rank": "Strain"}, "1278078": {"name": "Rhodococcus triatomae BKS 15-14", "rank": "Strain"}, "668994": {"name": "Thermus phage P23-77", "rank": "Species"}, "334390": {"name": "Lactobacillus fermentum IFO 3956", "rank": "Strain"}, "1421949": {"name": "Mycobacterium tuberculosis TB_RSA33", "rank": "Strain"}, "1421940": {"name": "Mycobacterium tuberculosis TB_RSA24", "rank": "Strain"}, "1421941": {"name": "Mycobacterium tuberculosis TB_RSA25", "rank": "Strain"}, "1421942": {"name": "Mycobacterium tuberculosis TB_RSA26", "rank": "Strain"}, "1421943": {"name": "Mycobacterium tuberculosis TB_RSA27", "rank": "Strain"}, "1421944": {"name": "Mycobacterium tuberculosis TB_RSA28", "rank": "Strain"}, "1421945": {"name": "Mycobacterium tuberculosis TB_RSA29", "rank": "Strain"}, "1421946": {"name": "Mycobacterium tuberculosis TB_RSA30", "rank": "Strain"}, "417948": {"name": "Brevibacterium album", "rank": "Species"}, "718224": {"name": "Bacillus cereus VD142", "rank": "Strain"}, "718222": {"name": "Bacillus cereus TIAC219", "rank": "Strain"}, "718223": {"name": "Bacillus cereus VD022", "rank": "Strain"}, "718220": {"name": "Bacillus cereus IS075", "rank": "Strain"}, "46189": {"name": "Sphaerisporangium viridialbum", "rank": "Species"}, "328671": {"name": "Banana streak OL virus", "rank": "Species"}, "1100890": {"name": "Hibiscus green spot virus", "rank": "Species"}, "1354119": {"name": "Mycobacterium tuberculosis MAL020179", "rank": "Strain"}, "754503": {"name": "Mycoplasma hyopneumoniae 7422", "rank": "Strain"}, "754502": {"name": "Burkholderia sprentiae WSM5005", "rank": "Strain"}, "1354110": {"name": "Mycobacterium tuberculosis MAL020200", "rank": "Strain"}, "754500": {"name": "Bradyrhizobium sp. WSM1417", "rank": "Species"}, "754507": {"name": "Aggregatibacter actinomycetemcomitans ANH9381", "rank": "Strain"}, "754506": {"name": "Aggregatibacter actinomycetemcomitans serotype c str. D17P-2", "rank": "Strain"}, "754505": {"name": "Aggregatibacter actinomycetemcomitans D17P-3", "rank": "Strain"}, "754504": {"name": "Bradyrhizobium diazoefficiens SEMIA 5080", "rank": "Strain"}, "1053228": {"name": "Bacillus cereus VD102", "rank": "Strain"}, "1053229": {"name": "Bacillus cereus VD107", "rank": "Strain"}, "182337": {"name": "Erwinia billingiae", "rank": "Species"}, "1151398": {"name": "Peptoclostridium difficile P7", "rank": "Strain"}, "1053224": {"name": "Bacillus cereus VD021", "rank": "Strain"}, "1053225": {"name": "Bacillus cereus VD045", "rank": "Strain"}, "1053226": {"name": "Bacillus cereus VD048", "rank": "Strain"}, "1053227": {"name": "Bacillus cereus VD078", "rank": "Strain"}, "1053220": {"name": "Bacillus cereus MSX-A1", "rank": "Strain"}, "1053221": {"name": "Bacillus cereus MSX-A12", "rank": "Strain"}, "1053222": {"name": "Bacillus cereus MSX-D12", "rank": "Strain"}, "1053223": {"name": "Bacillus cereus VD014", "rank": "Strain"}, "998090": {"name": "Mycobacterium bovis BCG str. ATCC 35733", "rank": "Strain"}, "1427274": {"name": "Mycobacterium tuberculosis XTB13-196", "rank": "Strain"}, "1427275": {"name": "Mycobacterium tuberculosis XTB13-197", "rank": "Strain"}, "1427276": {"name": "Mycobacterium tuberculosis XTB13-198", "rank": "Strain"}, "1427277": {"name": "Mycobacterium tuberculosis XTB13-199", "rank": "Strain"}, "1427270": {"name": "Mycobacterium tuberculosis XTB13-192", "rank": "Strain"}, "1427271": {"name": "Mycobacterium tuberculosis XTB13-193", "rank": "Strain"}, "1427272": {"name": "Mycobacterium tuberculosis XTB13-194", "rank": "Strain"}, "1427273": {"name": "Mycobacterium tuberculosis XTB13-195", "rank": "Strain"}, "1036719": {"name": "Verticillium", "rank": "Genus"}, "1427278": {"name": "Mycobacterium tuberculosis XTB13-200", "rank": "Strain"}, "1427279": {"name": "Mycobacterium tuberculosis XTB13-201", "rank": "Strain"}, "1151390": {"name": "Peptoclostridium difficile Y381", "rank": "Strain"}, "1238214": {"name": "Vibrio parahaemolyticus EKP-008", "rank": "Strain"}, "1151393": {"name": "Peptoclostridium difficile P1", "rank": "Strain"}, "369584": {"name": "Rousettus aegyptiacus papillomavirus 1", "rank": "Strain"}, "1418324": {"name": "Staphylococcus aureus M35158", "rank": "Strain"}, "1418325": {"name": "Staphylococcus aureus M42212", "rank": "Strain"}, "1418326": {"name": "Staphylococcus aureus M45726", "rank": "Strain"}, "1418327": {"name": "Staphylococcus aureus M54162", "rank": "Strain"}, "1315179": {"name": "Acinetobacter baumannii TG27383", "rank": "Strain"}, "1418321": {"name": "Staphylococcus aureus M24416", "rank": "Strain"}, "1418322": {"name": "Staphylococcus aureus M24418", "rank": "Strain"}, "1418323": {"name": "Staphylococcus aureus M24419", "rank": "Strain"}, "1453870": {"name": "Staphylococcus aureus subsp. aureus 300-169", "rank": "Strain"}, "1418328": {"name": "Staphylococcus aureus M57729", "rank": "Strain"}, "1418329": {"name": "Staphylococcus aureus M57746", "rank": "Strain"}, "1339277": {"name": "Bacteroides fragilis str. DS-71", "rank": "Strain"}, "1151397": {"name": "Peptoclostridium difficile P6", "rank": "Strain"}, "658172": {"name": "Candidatus Liberibacter solanacearum CLso-ZC1", "rank": "Strain"}, "381445": {"name": "Amycolatopsis nigrescens", "rank": "Species"}, "67348": {"name": "Streptomyces prunicolor", "rank": "Species"}, "542960": {"name": "Epsilon15likevirus", "rank": "Genus"}, "161378": {"name": "Sri Lankan cassava mosaic virus", "rank": "Species"}, "1449437": {"name": "Pseudomonas phage vB_PaeP_Tr60_Ab31", "rank": "Species"}, "1146887": {"name": "Aspergillus oryzae RIB326", "rank": "Strain"}, "1146883": {"name": "Blastococcus saxobsidens DD2", "rank": "Strain"}, "413066": {"name": "Streptococcus phage SMP", "rank": "Species"}, "1069082": {"name": "Halomicrobium katesii DSM 19301", "rank": "Strain"}, "1257": {"name": "Peptostreptococcus", "rank": "Genus"}, "1254": {"name": "Pediococcus acidilactici", "rank": "Species"}, "1255": {"name": "Pediococcus pentosaceus", "rank": "Species"}, "1252": {"name": "Leuconostoc carnosum", "rank": "Species"}, "1253": {"name": "Pediococcus", "rank": "Genus"}, "1435356": {"name": "Rhodococcus pyridinivorans SB3094", "rank": "Strain"}, "1251": {"name": "Leuconostoc fallax", "rank": "Species"}, "1435358": {"name": "Vibrio parahaemolyticus VP49", "rank": "Strain"}, "38294": {"name": "Photobacterium damselae subsp. piscicida", "rank": "Subspecies"}, "1160234": {"name": "Brucella sp. UK38/05", "rank": "Species"}, "38293": {"name": "Photobacterium damselae", "rank": "Species"}, "1266070": {"name": "Streptococcus agalactiae SS1014", "rank": "Strain"}, "1281131": {"name": "Escherichia coli HVH 204 (4-3112802)", "rank": "Strain"}, "888049": {"name": "Streptococcus oralis ATCC 49296", "rank": "Strain"}, "756012": {"name": "Vibrio mimicus SX-4", "rank": "Strain"}, "365007": {"name": "Unclassified SPO1-like viruses", "rank": "No rank"}, "712620": {"name": "Streptococcus sp. oral taxon 056", "rank": "Species"}, "378806": {"name": "Stigmatella aurantiaca DW4/3-1", "rank": "Strain"}, "411466": {"name": "Actinomyces odontolyticus ATCC 17982", "rank": "Strain"}, "1438881": {"name": "Mycobacterium tuberculosis UT0006", "rank": "Strain"}, "1438887": {"name": "Mycobacterium tuberculosis UT0032", "rank": "Strain"}, "1281133": {"name": "Escherichia coli HVH 206 (4-3128229)", "rank": "Strain"}, "1438884": {"name": "Mycobacterium tuberculosis UT0047", "rank": "Strain"}, "985259": {"name": "Psychrobacter sp. TB47", "rank": "Species"}, "1528106": {"name": "Thalassospira australica", "rank": "Species"}, "1448748": {"name": "Mycobacterium tuberculosis M2032", "rank": "Strain"}, "1448747": {"name": "Mycobacterium tuberculosis M2021", "rank": "Strain"}, "1448746": {"name": "Mycobacterium tuberculosis M2020", "rank": "Strain"}, "1147754": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. LA5", "rank": "Strain"}, "1448744": {"name": "Mycobacterium tuberculosis M2007", "rank": "Strain"}, "1448743": {"name": "Mycobacterium tuberculosis M2006", "rank": "Strain"}, "1147753": {"name": "Salmonella enterica subsp. enterica serovar Senftenberg str. SS209", "rank": "Strain"}, "985255": {"name": "Gillisia sp. CAL575", "rank": "Species"}, "1142503": {"name": "Rhizophydiales incertae sedis", "rank": "No rank"}, "543891": {"name": "Comamonas testosteroni CNB-1", "rank": "Strain"}, "1281132": {"name": "Escherichia coli HVH 205 (4-3094677)", "rank": "Strain"}, "1112251": {"name": "Chlamydia psittaci 99DC5", "rank": "Strain"}, "1873": {"name": "Micromonospora", "rank": "Genus"}, "1112253": {"name": "Chlamydia psittaci 02DC14", "rank": "Strain"}, "1112252": {"name": "Chlamydia psittaci 01DC11", "rank": "Strain"}, "1112255": {"name": "Chlamydia psittaci 02DC16", "rank": "Strain"}, "1112254": {"name": "Chlamydia psittaci 02DC15", "rank": "Strain"}, "1112257": {"name": "Chlamydia psittaci 02DC21", "rank": "Strain"}, "1112256": {"name": "Chlamydia psittaci 02DC18", "rank": "Strain"}, "1112259": {"name": "Chlamydia psittaci 02DC23", "rank": "Strain"}, "1298861": {"name": "Lysobacter sp. URHA0019", "rank": "Species"}, "645663": {"name": "Enterococcus faecium E1039", "rank": "Strain"}, "910028": {"name": "BRC1 bacterium SCGC AAA252-M09", "rank": "Species"}, "759846": {"name": "Anoxybacillus flavithermus subsp. yunnanensis", "rank": "Subspecies"}, "214906": {"name": "Histophilus", "rank": "Genus"}, "1409491": {"name": "Staphylococcus aureus WAMC6003", "rank": "Strain"}, "114380": {"name": "Desulfurococcales", "rank": "Order"}, "696127": {"name": "Candidatus Midichloria mitochondrii IricVA", "rank": "Strain"}, "411468": {"name": "Clostridium scindens ATCC 35704", "rank": "Strain"}, "411469": {"name": "Eubacterium hallii DSM 3353", "rank": "Strain"}, "990303": {"name": "Papio hamadryas papillomavirus type 1", "rank": "Species"}, "222441": {"name": "Ageratum yellow vein Taiwan virus", "rank": "Species"}, "142577": {"name": "Prauserella", "rank": "Genus"}, "555970": {"name": "Bifidobacterium animalis subsp. lactis DSM 10140", "rank": "Strain"}, "437752": {"name": "Leptospira kirschneri serovar Mozdok", "rank": "Strain"}, "1304918": {"name": "Klebsiella pneumoniae 120_1020", "rank": "Strain"}, "1284832": {"name": "Klebsiella pneumoniae VAKPC309", "rank": "Strain"}, "1304917": {"name": "Klebsiella pneumoniae 160_1080", "rank": "Strain"}, "1284831": {"name": "Klebsiella pneumoniae VAKPC297", "rank": "Strain"}, "60550": {"name": "Burkholderia pyrrocinia", "rank": "Species"}, "1336241": {"name": "Eubacterium xylanophilum ATCC 35991", "rank": "Strain"}, "336989": {"name": "Pontibacter roseus", "rank": "Species"}, "1422227": {"name": "Staphylococcus aureus DAR1276", "rank": "Strain"}, "1437068": {"name": "Haemophilus parasuis 84-17975", "rank": "Strain"}, "1329828": {"name": "Enterobacter sp. MGH 24", "rank": "Species"}, "1329829": {"name": "Enterobacter sp. MGH 25", "rank": "Species"}, "1231725": {"name": "Dickeya solani D s0432-1", "rank": "Strain"}, "519441": {"name": "Streptobacillus moniliformis DSM 12112", "rank": "Strain"}, "519440": {"name": "Deinococcus aquatilis", "rank": "Species"}, "1329822": {"name": "Enterobacter sp. MGH 13", "rank": "Species"}, "1329823": {"name": "Enterobacter sp. MGH 14", "rank": "Species"}, "1329820": {"name": "Enterobacter sp. MGH 11", "rank": "Species"}, "1329821": {"name": "Enterobacter sp. MGH 12", "rank": "Species"}, "1329826": {"name": "Enterobacter sp. MGH 22", "rank": "Species"}, "1329827": {"name": "Enterobacter sp. MGH 23", "rank": "Species"}, "1329824": {"name": "Enterobacter sp. MGH 15", "rank": "Species"}, "1329825": {"name": "Enterobacter sp. MGH 16", "rank": "Species"}, "1288484": {"name": "Deinococcus wulumuqiensis R12", "rank": "Strain"}, "1288483": {"name": "Thermotoga neapolitana LA10", "rank": "Strain"}, "910238": {"name": "Escherichia albertii TW15818", "rank": "Strain"}, "1281139": {"name": "Escherichia coli HVH 212 (3-9305343)", "rank": "Strain"}, "1397698": {"name": "Exiguobacterium sibiricum 7-3", "rank": "Strain"}, "1397699": {"name": "Exiguobacterium oxidotolerans JCM 12280", "rank": "Strain"}, "1397694": {"name": "Exiguobacterium aurantiacum DSM 6208", "rank": "Strain"}, "1397695": {"name": "Exiguobacterium undae 190-11", "rank": "Strain"}, "140458": {"name": "Thermacetogenium", "rank": "Genus"}, "1397697": {"name": "Exiguobacterium acetylicum DSM 20416", "rank": "Strain"}, "1397693": {"name": "Exiguobacterium undae DSM 14481", "rank": "Strain"}, "570832": {"name": "Ludwigia leaf distortion betasatellite India:Amadalavalasa:Hibiscus:2007", "rank": "Strain"}, "41170": {"name": "Exiguobacterium acetylicum", "rank": "Species"}, "41171": {"name": "Mycovirus FusoV", "rank": "Strain"}, "570835": {"name": "Edaphobacter aggregans", "rank": "Species"}, "1447527": {"name": "Mycobacterium tuberculosis MD15762", "rank": "Strain"}, "59839": {"name": "Paenibacillus alginolyticus", "rank": "Species"}, "399550": {"name": "Staphylothermus marinus F1", "rank": "Strain"}, "143221": {"name": "Salmonella enterica subsp. enterica serovar Tennessee", "rank": "Strain"}, "1397528": {"name": "Halomonas sp. PBN3", "rank": "Species"}, "143224": {"name": "Zobellia uliginosa", "rank": "Species"}, "1397526": {"name": "Alcanivorax sp. PN-3", "rank": "Species"}, "1397527": {"name": "Alcanivorax sp. P2S70", "rank": "Species"}, "1397525": {"name": "Acinetobacter sp. COS3", "rank": "Species"}, "256548": {"name": "Bovine adeno-associated virus", "rank": "Strain"}, "1447524": {"name": "Mycobacterium tuberculosis MD15584", "rank": "Strain"}, "1439309": {"name": "Streptococcus pyogenes ABC020062474", "rank": "Strain"}, "1439303": {"name": "Streptococcus pyogenes ABC020061424", "rank": "Strain"}, "651609": {"name": "Actinomyces sp. oral taxon 180", "rank": "Species"}, "1439300": {"name": "Streptococcus pyogenes ABC020060793", "rank": "Strain"}, "1536592": {"name": "Idiomarinaceae phage 1N2-2", "rank": "Species"}, "316056": {"name": "Rhodopseudomonas palustris BisB18", "rank": "Strain"}, "1042122": {"name": "Clostridium phage phiCP13O", "rank": "Species"}, "932037": {"name": "Actinobacterium SCGC AAA023-D18", "rank": "Species"}, "932036": {"name": "Actinobacterium SCGC AAA028-A23", "rank": "Species"}, "1243032": {"name": "Campylobacter concisus ATCC 51561", "rank": "Strain"}, "1229782": {"name": "Propionibacterium phage P9.1", "rank": "Species"}, "932039": {"name": "Actinobacterium SCGC AAA024-D14", "rank": "Species"}, "932038": {"name": "Actinobacterium SCGC AAA023-J06", "rank": "Species"}, "1455076": {"name": "Citrobacter phage CR8", "rank": "Species"}, "1455075": {"name": "Citrobacter phage CR44b", "rank": "Species"}, "1455074": {"name": "Enterobacter phage PG7", "rank": "Species"}, "102125": {"name": "Xenococcus sp. PCC 7305", "rank": "Species"}, "102127": {"name": "Geitlerinema sp. PCC 7105", "rank": "Species"}, "1246644": {"name": "Mycobacterium abscessus 9808", "rank": "Strain"}, "754064": {"name": "Ostreococcus lucimarinus virus OlV5", "rank": "Species"}, "754066": {"name": "Halorubrum phage CGphi46", "rank": "Species"}, "754067": {"name": "Salicola phage CGphi29", "rank": "Species"}, "754069": {"name": "Dunaliella viridis virus SI2", "rank": "Species"}, "348137": {"name": "Burkholderia phage Bcep176", "rank": "Species"}, "1400916": {"name": "Mycobacterium tuberculosis KT-0072", "rank": "Strain"}, "317878": {"name": "Cyprinid herpesvirus 2", "rank": "Species"}, "1400915": {"name": "Mycobacterium tuberculosis KT-0071", "rank": "Strain"}, "1400912": {"name": "Mycobacterium tuberculosis KT-0064", "rank": "Strain"}, "1400911": {"name": "Mycobacterium tuberculosis KT-0063", "rank": "Strain"}, "85031": {"name": "Nakamurellaceae", "rank": "Family"}, "85030": {"name": "Geodermatophilaceae", "rank": "Family"}, "85033": {"name": "Sporichthyaceae", "rank": "Family"}, "85032": {"name": "Acidothermaceae", "rank": "Family"}, "85034": {"name": "Glycomycetaceae", "rank": "Family"}, "1400918": {"name": "Mycobacterium tuberculosis KT-0075", "rank": "Strain"}, "1409729": {"name": "Staphylococcus aureus CHAP6102", "rank": "Strain"}, "768066": {"name": "Halomonas elongata DSM 2581", "rank": "Strain"}, "768065": {"name": "Haloquadratum walsbyi C23", "rank": "Strain"}, "1339229": {"name": "Acinetobacter sp. ZOR0008", "rank": "Species"}, "1339228": {"name": "Aeromonas sp. ZOR0002", "rank": "Species"}, "1154941": {"name": "Streptococcus agalactiae GB00897", "rank": "Strain"}, "1154947": {"name": "Streptococcus agalactiae GB00911", "rank": "Strain"}, "1154946": {"name": "Streptococcus agalactiae GB00909", "rank": "Strain"}, "1154945": {"name": "Streptococcus agalactiae GB00904", "rank": "Strain"}, "1409723": {"name": "Staphylococcus aureus WAMC6062", "rank": "Strain"}, "1151320": {"name": "Peptoclostridium difficile DA00114", "rank": "Strain"}, "1151321": {"name": "Peptoclostridium difficile DA00126", "rank": "Strain"}, "1154949": {"name": "Streptococcus agalactiae GB00919", "rank": "Strain"}, "1151323": {"name": "Peptoclostridium difficile DA00129", "rank": "Strain"}, "1151324": {"name": "Peptoclostridium difficile DA00130", "rank": "Strain"}, "1281106": {"name": "Escherichia coli HVH 177 (4-2876612)", "rank": "Strain"}, "1339227": {"name": "Aeromonas sp. ZOR0001", "rank": "Species"}, "1339226": {"name": "Exiguobacterium sp. ZOR0005", "rank": "Species"}, "935568": {"name": "Pseudoxanthomonas suwonensis J47", "rank": "Strain"}, "1409721": {"name": "Staphylococcus aureus WMCA6100", "rank": "Strain"}, "1420545": {"name": "Human papillomavirus type 167", "rank": "Species"}, "935563": {"name": "Sinorhizobium meliloti WSM4191", "rank": "Strain"}, "935566": {"name": "Pseudoxanthomonas suwonensis J42", "rank": "Strain"}, "935567": {"name": "Pseudoxanthomonas suwonensis J43", "rank": "Strain"}, "935565": {"name": "Paracoccus pantotrophus J46", "rank": "Strain"}, "1409724": {"name": "Staphylococcus aureus WMCA6126", "rank": "Strain"}, "1409725": {"name": "Staphylococcus aureus FVRH6138", "rank": "Strain"}, "335187": {"name": "Streptocarpus flower break virus", "rank": "Species"}, "1254432": {"name": "Sorangium cellulosum So0157-2", "rank": "Strain"}, "1054217": {"name": "Thermoplasmatales archaeon BRNA1", "rank": "Species"}, "1054211": {"name": "Sulfuritalea", "rank": "Genus"}, "1054213": {"name": "Acetobacteraceae bacterium AT-5844", "rank": "Species"}, "1254439": {"name": "Bifidobacterium thermophilum RBL67", "rank": "Strain"}, "396014": {"name": "Brachybacterium phenoliresistens", "rank": "Species"}, "752786": {"name": "Escherichia coli 541-1", "rank": "Strain"}, "752785": {"name": "Escherichia coli 541-15", "rank": "Strain"}, "752784": {"name": "Escherichia coli KD2", "rank": "Strain"}, "752783": {"name": "Escherichia coli KD1", "rank": "Strain"}, "1265681": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 26.F.98", "rank": "Strain"}, "181123": {"name": "Puccinia psidii", "rank": "Species"}, "752789": {"name": "Escherichia coli HM605", "rank": "Strain"}, "752788": {"name": "Escherichia coli 75", "rank": "Strain"}, "456828": {"name": "Cloacimonetes", "rank": "Phylum"}, "742030": {"name": "Salinisphaerales", "rank": "Order"}, "742031": {"name": "Salinisphaeraceae", "rank": "Family"}, "1444153": {"name": "Escherichia coli 2-222-05_S3_C2", "rank": "Strain"}, "445217": {"name": "Erinaceus europaeus papillomavirus 1", "rank": "Strain"}, "456827": {"name": "Candidatus Cloacimonas acidaminovorans", "rank": "Species"}, "456826": {"name": "Candidatus Cloacimonas", "rank": "Genus"}, "1513354": {"name": "Acinetobacter sp. MN12", "rank": "Species"}, "391090": {"name": "Tomato yellow leaf curl betasatellite", "rank": "Species"}, "1310596": {"name": "Acinetobacter baumannii 1075025", "rank": "Strain"}, "551208": {"name": "Chitinilyticum", "rank": "Genus"}, "1471532": {"name": "Prochlorococcus sp. scB245a_521O23", "rank": "Species"}, "303": {"name": "Pseudomonas putida", "rank": "Species"}, "300": {"name": "Pseudomonas mendocina", "rank": "Species"}, "301": {"name": "Pseudomonas oleovorans", "rank": "Species"}, "305": {"name": "Ralstonia solanacearum", "rank": "Species"}, "709986": {"name": "Deinococcus maricopensis DSM 21211", "rank": "Strain"}, "296745": {"name": "Caldalkalibacillus thermarum", "rank": "Species"}, "1448426": {"name": "Mycobacterium tuberculosis TKK_03_0089", "rank": "Strain"}, "1448427": {"name": "Mycobacterium tuberculosis TKK_03_0090", "rank": "Strain"}, "1448421": {"name": "Mycobacterium tuberculosis TKK_03_0083", "rank": "Strain"}, "904782": {"name": "Staphylococcus aureus subsp. aureus IS-111", "rank": "Strain"}, "508458": {"name": "Synergistetes", "rank": "Phylum"}, "508459": {"name": "Cloacibacillus", "rank": "Genus"}, "1448428": {"name": "Mycobacterium tuberculosis TKK_03_0092", "rank": "Strain"}, "335283": {"name": "Nitrosomonas eutropha C91", "rank": "Strain"}, "1249648": {"name": "Dragonfly-associated mastrevirus", "rank": "Species"}, "335284": {"name": "Psychrobacter cryohalolentis K5", "rank": "Strain"}, "223184": {"name": "Kocuria marina", "rank": "Species"}, "933801": {"name": "Acidianus hospitalis W1", "rank": "Strain"}, "187400": {"name": "Paracoccus zeaxanthinifaciens", "rank": "Species"}, "712532": {"name": "Selenomonas sp. oral taxon 138", "rank": "Species"}, "336487": {"name": "Unclassified Avipoxvirus", "rank": "No rank"}, "1431339": {"name": "Bacillus thuringiensis DB27", "rank": "Strain"}, "629295": {"name": "Streptomyces griseus group", "rank": "Species subgroup"}, "1004149": {"name": "Mesoflavibacter zeaxanthinifaciens S86", "rank": "Strain"}, "11250": {"name": "Human respiratory syncytial virus", "rank": "Species"}, "938698": {"name": "Bacteroidetes bacterium SCGC AAA027-G08", "rank": "Species"}, "649638": {"name": "Truepera radiovictrix DSM 17093", "rank": "Strain"}, "187": {"name": "Aquaspirillum", "rank": "Genus"}, "1205908": {"name": "Vibrio breoganii 1C10", "rank": "Strain"}, "1403898": {"name": "Staphylococcus aureus M1516", "rank": "Strain"}, "570156": {"name": "Pseudoalteromonas lipolytica", "rank": "Species"}, "1069080": {"name": "Succinispira mobilis DSM 6222", "rank": "Strain"}, "1069083": {"name": "Methanocaldococcus villosus KIN24-T80", "rank": "Strain"}, "383610": {"name": "Leptospira weilii serovar Topaz", "rank": "Strain"}, "1328348": {"name": "Brucella abortus 89-0363", "rank": "Strain"}, "1328349": {"name": "Brucella abortus 90-0962", "rank": "Strain"}, "888048": {"name": "Streptococcus parasanguinis ATCC 903", "rank": "Strain"}, "1160235": {"name": "Brucella sp. 63/311", "rank": "Species"}, "1160232": {"name": "Brucella suis 63/252", "rank": "Strain"}, "1160233": {"name": "Brucella suis 92/29", "rank": "Strain"}, "1160230": {"name": "Brucella suis 92/63", "rank": "Strain"}, "1160231": {"name": "Brucella suis F8/06-2", "rank": "Strain"}, "1328340": {"name": "Brucella abortus 76-1413", "rank": "Strain"}, "1328341": {"name": "Brucella abortus 80-1399", "rank": "Strain"}, "1328342": {"name": "Brucella abortus 82-2330", "rank": "Strain"}, "1328343": {"name": "Brucella abortus 82-3893", "rank": "Strain"}, "1328344": {"name": "Brucella abortus 84-0928", "rank": "Strain"}, "1328345": {"name": "Brucella abortus 85-1058", "rank": "Strain"}, "1328346": {"name": "Brucella abortus 87-0095", "rank": "Strain"}, "1328347": {"name": "Brucella abortus 87-2211", "rank": "Strain"}, "1298865": {"name": "Alteromonas sp. ALT199", "rank": "Species"}, "1298864": {"name": "Mycobacterium sp. URHD0025", "rank": "Species"}, "1298867": {"name": "Bradyrhizobium sp. URHA0002", "rank": "Species"}, "1298866": {"name": "Bacillus sp. URHB0009", "rank": "Species"}, "1446792": {"name": "Bacillus sp. Pc3", "rank": "Species"}, "1298860": {"name": "Microbacterium sp. URHA0036", "rank": "Species"}, "1298863": {"name": "Marmoricola sp. URHB0036", "rank": "Species"}, "1298862": {"name": "Caulobacter sp. URHA0033", "rank": "Species"}, "1298868": {"name": "Flavobacterium sp. URHB0058", "rank": "Species"}, "1284833": {"name": "Klebsiella pneumoniae KP-7", "rank": "Strain"}, "1336243": {"name": "Microvirga flocculans ATCC BAA-817", "rank": "Strain"}, "1336240": {"name": "Shewanella colwelliana ATCC 39565", "rank": "Strain"}, "1206458": {"name": "Novosphingobium sp. MBES04", "rank": "Species"}, "1336247": {"name": "Shewanella fidelis ATCC BAA-318", "rank": "Strain"}, "1336244": {"name": "Curvibacter gracilis ATCC BAA-807", "rank": "Strain"}, "1284834": {"name": "Klebsiella pneumoniae KP-11", "rank": "Strain"}, "1336249": {"name": "Rhizobium larrymoorei ATCC 51759", "rank": "Strain"}, "1414836": {"name": "Xanthomonas arboricola pv. pruni str. MAFF 311562", "rank": "Strain"}, "1229788": {"name": "Propionibacterium phage P105", "rank": "Species"}, "1229789": {"name": "Propionibacterium phage P100D", "rank": "Species"}, "1229784": {"name": "Propionibacterium phage P14.4", "rank": "Species"}, "1229785": {"name": "Burkholderia pseudomallei BPC006", "rank": "Strain"}, "1229786": {"name": "Propionibacterium phage P101A", "rank": "Species"}, "1229787": {"name": "Propionibacterium phage P104A", "rank": "Species"}, "1229780": {"name": "Candidatus Microthrix parvicella RN1", "rank": "Strain"}, "1229781": {"name": "Brevibacterium casei S18", "rank": "Strain"}, "1159197": {"name": "Mycoplasma gallisepticum VA94_7994-1-7P", "rank": "Strain"}, "1229783": {"name": "Staphylococcus massiliensis S46", "rank": "Strain"}, "33807": {"name": "Unclassified Alphaproteobacteria (miscellaneous)", "rank": "No rank"}, "33809": {"name": "Unclassified Betaproteobacteria (miscellaneous)", "rank": "No rank"}, "1444152": {"name": "Escherichia coli 2-210-07_S3_C2", "rank": "Strain"}, "604276": {"name": "TYLCAxV-Sic1-IT:Sic2/2:04", "rank": "Species"}, "1444150": {"name": "Escherichia coli 2-156-04_S3_C2", "rank": "Strain"}, "1444151": {"name": "Escherichia coli 2-177-06_S3_C2", "rank": "Strain"}, "1444156": {"name": "Escherichia coli 2-474-04_S3_C2", "rank": "Strain"}, "1444157": {"name": "Escherichia coli 5-366-08_S3_C2", "rank": "Strain"}, "1444154": {"name": "Escherichia coli 2-316-03_S3_C2", "rank": "Strain"}, "1444155": {"name": "Escherichia coli 2-460-02_S3_C2", "rank": "Strain"}, "1471530": {"name": "Prochlorococcus sp. scB245a_521N5", "rank": "Species"}, "1471531": {"name": "Prochlorococcus sp. scB245a_521O20", "rank": "Species"}, "1444158": {"name": "Escherichia coli 7-233-03_S3_C2", "rank": "Strain"}, "1444159": {"name": "Escherichia coli 8-415-05_S3_C2", "rank": "Strain"}, "1100070": {"name": "Bacteroidetes Order III. Incertae sedis", "rank": "Order"}, "1429873": {"name": "Xenorhabdus sp. NBAII XenSa04", "rank": "Species"}, "11786": {"name": "Murine leukemia virus", "rank": "Species"}, "11788": {"name": "Abelson murine leukemia virus", "rank": "Species"}, "1429877": {"name": "Staphylococcus aureus SA7-LAU", "rank": "Strain"}, "1162302": {"name": "Corynebacterium diphtheriae bv. mitis str. NC03529", "rank": "Strain"}, "1162303": {"name": "Unclassified Picovirinae", "rank": "No rank"}, "1162304": {"name": "Clostridium phage phiCP7R", "rank": "Species"}, "1162305": {"name": "Clostridium phage phiCPV4", "rank": "Species"}, "1162306": {"name": "Clostridium phage phiZP2", "rank": "Species"}, "903905": {"name": "Acinetobacter baumannii IS-235", "rank": "Strain"}, "10788": {"name": "Canine parvovirus", "rank": "Strain"}, "903907": {"name": "Acinetobacter baumannii OIFC0162", "rank": "Strain"}, "903906": {"name": "Acinetobacter baumannii IS-251", "rank": "Strain"}, "903901": {"name": "Acinetobacter baumannii OIFC074", "rank": "Strain"}, "903900": {"name": "Acinetobacter radioresistens WC-A-157", "rank": "Strain"}, "903903": {"name": "Acinetobacter baumannii OIFC180", "rank": "Strain"}, "642258": {"name": "Circovirus-like genome SAR-A", "rank": "Species"}, "642257": {"name": "Circovirus-like genome CB-B", "rank": "Species"}, "10780": {"name": "Parvoviridae", "rank": "Family"}, "642255": {"name": "Circovirus-like genome RW-E", "rank": "Species"}, "642254": {"name": "Circovirus-like genome RW-D", "rank": "Species"}, "642253": {"name": "Circovirus-like genome RW-C", "rank": "Species"}, "903908": {"name": "Acinetobacter baumannii Naval-72", "rank": "Strain"}, "642251": {"name": "Circovirus-like genome RW-A", "rank": "Species"}, "1631": {"name": "Fructobacillus fructosus", "rank": "Species"}, "247639": {"name": "Marine gamma proteobacterium HTCC2080", "rank": "Species"}, "247634": {"name": "Marine gamma proteobacterium HTCC2148", "rank": "Species"}, "247633": {"name": "Marine gamma proteobacterium HTCC2143", "rank": "Species"}, "280756": {"name": "Sapovirus isolates", "rank": "Strain"}, "1388716": {"name": "Staphylococcus aureus M0954", "rank": "Strain"}, "422296": {"name": "Cucumibacter marinus DSM 18995", "rank": "Strain"}, "336810": {"name": "Candidatus Sulcia muelleri", "rank": "Species"}, "1046629": {"name": "Streptococcus salivarius 57.I", "rank": "Strain"}, "12253": {"name": "Tomato mosaic virus", "rank": "Species"}, "903904": {"name": "Acinetobacter baumannii Naval-13", "rank": "Strain"}, "1204340": {"name": "Pandoraea sp. B-6", "rank": "Species"}, "1204343": {"name": "Bacillus subtilis BEST7613", "rank": "Strain"}, "1204342": {"name": "Bacillus subtilis BEST7003", "rank": "Strain"}, "12258": {"name": "Comovirus", "rank": "Genus"}, "936051": {"name": "Paracoccus pantotrophus J40", "rank": "Strain"}, "936057": {"name": "Rhopapillomavirus", "rank": "Genus"}, "936056": {"name": "Dyodeltapapillomavirus", "rank": "Genus"}, "5506": {"name": "Fusarium", "rank": "Genus"}, "5507": {"name": "Fusarium oxysporum", "rank": "Species"}, "936059": {"name": "Tursiops truncatus papillomavirus 1", "rank": "Strain"}, "936058": {"name": "Upsilonpapillomavirus", "rank": "Genus"}, "5502": {"name": "Curvularia", "rank": "Genus"}, "5503": {"name": "Curvularia lunata", "rank": "Species"}, "5500": {"name": "Coccidioides", "rank": "Genus"}, "5501": {"name": "Coccidioides immitis", "rank": "Species"}, "173362": {"name": "Brachybacterium paraconglomeratum", "rank": "Species"}, "1422005": {"name": "Mycobacterium tuberculosis TB_RSA89", "rank": "Strain"}, "1422006": {"name": "Mycobacterium tuberculosis TB_RSA90", "rank": "Strain"}, "1422007": {"name": "Mycobacterium tuberculosis TB_RSA91", "rank": "Strain"}, "173366": {"name": "Methylocystis rosea", "rank": "Species"}, "1422001": {"name": "Mycobacterium tuberculosis TB_RSA85", "rank": "Strain"}, "1422002": {"name": "Mycobacterium tuberculosis TB_RSA86", "rank": "Strain"}, "173365": {"name": "Methylobacter tundripaludum", "rank": "Species"}, "903902": {"name": "Acinetobacter baumannii OIFC098", "rank": "Strain"}, "1422008": {"name": "Mycobacterium tuberculosis TB_RSA92", "rank": "Strain"}, "66200": {"name": "Carrot red leaf virus", "rank": "Species"}, "642256": {"name": "Circovirus-like genome CB-A", "rank": "Species"}, "573395": {"name": "Salmonella enterica subsp. enterica serovar Tennessee str. CDC07-0191", "rank": "Strain"}, "431043": {"name": "Holospora elegans", "rank": "Species"}, "903909": {"name": "Acinetobacter baumannii Naval-83", "rank": "Strain"}, "642252": {"name": "Circovirus-like genome RW-B", "rank": "Species"}, "522306": {"name": "Candidatus Accumulibacter phosphatis clade IIA str. UW-1", "rank": "Strain"}, "642227": {"name": "Tatumella morbirosei", "rank": "Species"}, "10786": {"name": "Feline panleukopenia virus", "rank": "Strain"}, "702430": {"name": "Escherichia coli O157:H7 str. EC4009", "rank": "Strain"}, "1463883": {"name": "Streptomyces sp. NRRL S-1448", "rank": "Species"}, "1463882": {"name": "Streptomyces sp. NRRL S-1314", "rank": "Species"}, "1463881": {"name": "Streptomyces sp. NRRL S-118", "rank": "Species"}, "1463880": {"name": "Streptomyces sp. NRRL S-1022", "rank": "Species"}, "1463887": {"name": "Streptomyces sp. NRRL S-1777", "rank": "Species"}, "1463886": {"name": "Streptomyces sp. NRRL S-15", "rank": "Species"}, "1463885": {"name": "Streptomyces sp. NRRL S-149", "rank": "Species"}, "1463889": {"name": "Streptomyces sp. NRRL S-1824", "rank": "Species"}, "1463888": {"name": "Streptomyces sp. NRRL S-1813", "rank": "Species"}, "209249": {"name": "Nocardia niigatensis", "rank": "Species"}, "1178825": {"name": "Arenitalea lutea", "rank": "Species"}, "172148": {"name": "Alkhumra hemorrhagic fever virus", "rank": "Strain"}, "754259": {"name": "Actinobacillus pleuropneumoniae serovar 10 str. D13039", "rank": "Strain"}, "754258": {"name": "Actinobacillus pleuropneumoniae serovar 9 str. CVJ13261", "rank": "Strain"}, "1295826": {"name": "Lactococcus lactis subsp. cremoris KW2", "rank": "Strain"}, "1295827": {"name": "Lactococcus lactis subsp. cremoris HP", "rank": "Strain"}, "765110": {"name": "Propionibacterium acnes HL067PA1", "rank": "Strain"}, "765111": {"name": "Propionibacterium acnes HL027PA1", "rank": "Strain"}, "765112": {"name": "Propionibacterium acnes HL027PA2", "rank": "Strain"}, "765113": {"name": "Propionibacterium acnes HL063PA1", "rank": "Strain"}, "913319": {"name": "Cloacimonetes bacterium SCGC AAA252-N11", "rank": "Species"}, "765115": {"name": "Propionibacterium acnes HL002PA1", "rank": "Strain"}, "765116": {"name": "Propionibacterium acnes HL002PA2", "rank": "Strain"}, "754256": {"name": "Actinobacillus pleuropneumoniae serovar 6 str. Femo", "rank": "Strain"}, "765118": {"name": "Propionibacterium acnes HL007PA1", "rank": "Strain"}, "765119": {"name": "Propionibacterium acnes HL056PA1", "rank": "Strain"}, "913317": {"name": "Atribacteria bacterium SCGC AAA252-M02", "rank": "Species"}, "300418": {"name": "Catellicoccus", "rank": "Genus"}, "300419": {"name": "Catellicoccus marimammalium", "rank": "Species"}, "147645": {"name": "Paracoccus yeei", "rank": "Species"}, "249310": {"name": "Chrysoviridae", "rank": "Family"}, "32033": {"name": "Xanthomonadaceae", "rank": "Family"}, "300411": {"name": "Lindernia anagallis yellow vein virus", "rank": "Species"}, "32036": {"name": "Sulfur-oxidizing symbionts", "rank": "No rank"}, "754252": {"name": "Propionibacterium freudenreichii subsp. shermanii CIRM-BIA1", "rank": "Strain"}, "107673": {"name": "Acinetobacter calcoaceticus subsp. anitratus", "rank": "Subspecies"}, "1408133": {"name": "Rhizoctonia cerealis endornavirus 1", "rank": "Species"}, "1408137": {"name": "Mobuck virus", "rank": "Species"}, "1134445": {"name": "Streptomyces somaliensis DSM 40738", "rank": "Strain"}, "399795": {"name": "Comamonas testosteroni KF-1", "rank": "Strain"}, "668349": {"name": "Mycobacterium tuberculosis T67", "rank": "Strain"}, "33071": {"name": "Gloeobacter", "rank": "Genus"}, "33072": {"name": "Gloeobacter violaceus", "rank": "Species"}, "33073": {"name": "Zymobacter", "rank": "Genus"}, "33074": {"name": "Zymobacter palmae", "rank": "Species"}, "33075": {"name": "Acidobacterium capsulatum", "rank": "Species"}, "1123516": {"name": "Thiomicrospira halophila DSM 15072", "rank": "Strain"}, "1123517": {"name": "Thiomicrospira pelophila DSM 1534", "rank": "Strain"}, "1123514": {"name": "Thiomicrospira arctica DSM 13458", "rank": "Strain"}, "1123515": {"name": "Thiomicrospira chilensis DSM 12352", "rank": "Strain"}, "320360": {"name": "Taiwanofungus", "rank": "Genus"}, "1123513": {"name": "Hydrogenovibrio marinus DSM 11271", "rank": "Strain"}, "1123510": {"name": "Zymobacter palmae DSM 10491", "rank": "Strain"}, "1123511": {"name": "Zymophilus raffinosivorans DSM 20765", "rank": "Strain"}, "1123518": {"name": "Thiomicrospira sp. Kp2", "rank": "Species"}, "1123519": {"name": "Pseudomonas stutzeri DSM 10701", "rank": "Strain"}, "1150469": {"name": "Rhodospirillum photometricum DSM 122", "rank": "Strain"}, "1218169": {"name": "Pseudomonas putida S11", "rank": "Strain"}, "652718": {"name": "Sweet potato leaf curl Canary virus", "rank": "Species"}, "652713": {"name": "Peptoniphilus sp. oral taxon 386", "rank": "Species"}, "652712": {"name": "Lachnospiraceae oral taxon 107", "rank": "Species"}, "652717": {"name": "Sweet potato leaf curl Spain virus", "rank": "Species"}, "652716": {"name": "Prevotella sp. oral taxon 299", "rank": "Species"}, "652715": {"name": "Paenibacillus sp. oral taxon 786", "rank": "Species"}, "83331": {"name": "Mycobacterium tuberculosis CDC1551", "rank": "Strain"}, "83332": {"name": "Mycobacterium tuberculosis H37Rv", "rank": "Strain"}, "83333": {"name": "Escherichia coli K-12", "rank": "Strain"}, "83334": {"name": "Escherichia coli O157:H7", "rank": "Strain"}, "1440056": {"name": "Peptoclostridium difficile 5.3", "rank": "Strain"}, "1400902": {"name": "Mycobacterium tuberculosis KT-0051", "rank": "Strain"}, "360056": {"name": "Schlesneria paludicola", "rank": "Species"}, "360054": {"name": "Bryobacter aggregatus", "rank": "Species"}, "360055": {"name": "Zavarzinella formosa", "rank": "Species"}, "110662": {"name": "Synechococcus sp. CC9605", "rank": "Species"}, "110663": {"name": "Synechococcus sp. CC9616", "rank": "Species"}, "1128399": {"name": "Rhizobium phaseoli Ch24-10", "rank": "Strain"}, "1128398": {"name": "Clostridium acidurici 9a", "rank": "Strain"}, "516956": {"name": "Grapevine virus E", "rank": "Species"}, "85630": {"name": "16SrX (Apple proliferation group)", "rank": "Species group"}, "516950": {"name": "Streptococcus pneumoniae CGSP14", "rank": "Strain"}, "471798": {"name": "Shimazuella", "rank": "Genus"}, "911023": {"name": "Yokenella regensburgei ATCC 49455", "rank": "Strain"}, "911022": {"name": "Serratia marcescens subsp. marcescens ATCC 13880", "rank": "Strain"}, "722755": {"name": "Lilac leaf chlorosis virus", "rank": "Species"}, "89784": {"name": "Alicyclobacillus hesperidum", "rank": "Species"}, "306901": {"name": "Chaetomium globosum CBS 148.51", "rank": "Strain"}, "306902": {"name": "Clavispora lusitaniae ATCC 42720", "rank": "Strain"}, "1400904": {"name": "Mycobacterium tuberculosis KT-0053", "rank": "Strain"}, "120831": {"name": "Dyadobacter", "rank": "Genus"}, "1105367": {"name": "Paenirhodobacter enshiensis", "rank": "Species"}, "1310603": {"name": "Acinetobacter baumannii 1294596", "rank": "Strain"}, "1310600": {"name": "Acinetobacter baumannii 1289546", "rank": "Strain"}, "158484": {"name": "Cedecea davisae", "rank": "Species"}, "1310601": {"name": "Acinetobacter baumannii 479375", "rank": "Strain"}, "1310606": {"name": "Acinetobacter baumannii 1297549", "rank": "Strain"}, "1400907": {"name": "Mycobacterium tuberculosis KT-0056", "rank": "Strain"}, "1397884": {"name": "Mycobacterium tuberculosis TKK_02_0070", "rank": "Strain"}, "1169219": {"name": "Brucella abortus F10/05-11", "rank": "Strain"}, "1169218": {"name": "Brucella abortus F1/06-B21", "rank": "Strain"}, "158481": {"name": "Hahella", "rank": "Genus"}, "1501691": {"name": "Acinetobacter sp. YZS-X1-1", "rank": "Species"}, "1169217": {"name": "Brucella abortus 93/2", "rank": "Strain"}, "1422803": {"name": "Staphylococcus aureus VET1817S", "rank": "Strain"}, "283876": {"name": "Nootka lupine vein clearing virus", "rank": "Species"}, "1169216": {"name": "Brucella abortus 87/28", "rank": "Strain"}, "256003": {"name": "Heterobasidion annosum species complex", "rank": "No rank"}, "158483": {"name": "Cedecea", "rank": "Genus"}, "1310608": {"name": "Acinetobacter baumannii 1295259", "rank": "Strain"}, "256005": {"name": "Alteromonadales genera incertae sedis", "rank": "No rank"}, "1310609": {"name": "Acinetobacter baumannii 1289694", "rank": "Strain"}, "1340534": {"name": "Salmonella phage Jersey", "rank": "Species"}, "1265601": {"name": "Streptomyces sp. PAMC26508", "rank": "Species"}, "1071381": {"name": "Tetrapisispora phaffii CBS 4417", "rank": "Strain"}, "288965": {"name": "Clostridium clariflavum", "rank": "Species"}, "743724": {"name": "Aenigmarchaeota", "rank": "Phylum"}, "1150460": {"name": "Bifidobacterium kashiwanohense JCM 15439 = DSM 21854", "rank": "Strain"}, "1302626": {"name": "Listeria monocytogenes SHL006", "rank": "Strain"}, "1169210": {"name": "Brucella abortus 64/81", "rank": "Strain"}, "322053": {"name": "Konjac mosaic virus", "rank": "Species"}, "1422083": {"name": "Mycobacterium tuberculosis TB_RSA167", "rank": "Strain"}, "1465811": {"name": "Cellulomonas massiliensis", "rank": "Species"}, "723888": {"name": "Bacillus atrophaeus 1013-1", "rank": "Strain"}, "723889": {"name": "Bacillus atrophaeus 1013-2", "rank": "Strain"}, "85581": {"name": "Photobacterium damselae subsp. damselae", "rank": "Subspecies"}, "682795": {"name": "Granulicella mallensis MP5ACTX8", "rank": "Strain"}, "1073353": {"name": "Campylobacter showae CC57C", "rank": "Strain"}, "1073351": {"name": "Bacteroides stercoris CC31F", "rank": "Strain"}, "760777": {"name": "Streptococcus pneumoniae GA14688", "rank": "Strain"}, "760776": {"name": "Streptococcus pneumoniae GA14373", "rank": "Strain"}, "217169": {"name": "Marinospirillum insulare", "rank": "Species"}, "760774": {"name": "Streptococcus pneumoniae GA13723", "rank": "Strain"}, "760773": {"name": "Streptococcus pneumoniae GA13637", "rank": "Strain"}, "760772": {"name": "Streptococcus pneumoniae GA13494", "rank": "Strain"}, "760771": {"name": "Streptococcus pneumoniae GA13455", "rank": "Strain"}, "760770": {"name": "Streptococcus pneumoniae GA13430", "rank": "Strain"}, "1158709": {"name": "Staphylococcus aureus M1015", "rank": "Strain"}, "1128421": {"name": "Bacterium JKG1", "rank": "Species"}, "217160": {"name": "Ampelovirus", "rank": "Genus"}, "1128427": {"name": "Filamentous cyanobacterium ESFC-1", "rank": "Species"}, "1408860": {"name": "Borrelia burgdorferi IPT23", "rank": "Strain"}, "760779": {"name": "Streptococcus pneumoniae GA16121", "rank": "Strain"}, "760778": {"name": "Streptococcus pneumoniae GA14798", "rank": "Strain"}, "1500735": {"name": "Lactobacillus phage Ld3", "rank": "Species"}, "697279": {"name": "Bavariicoccus", "rank": "Genus"}, "1158705": {"name": "Staphylococcus aureus M0998", "rank": "Strain"}, "464095": {"name": "Picornavirales", "rank": "Order"}, "1158704": {"name": "Staphylococcus aureus M0953", "rank": "Strain"}, "384360": {"name": "Ralstonia phage RSS1", "rank": "Species"}, "1136158": {"name": "Vibrio cyclitrophicus 1F97", "rank": "Strain"}, "1136159": {"name": "Vibrio cyclitrophicus 1F111", "rank": "Strain"}, "888019": {"name": "Rothia aeria F0184", "rank": "Strain"}, "1136157": {"name": "Vibrio cyclitrophicus 1F53", "rank": "Strain"}, "119059": {"name": "Unclassified Oxalobacteraceae", "rank": "No rank"}, "237610": {"name": "Pseudomonas psychrotolerans", "rank": "Species"}, "180": {"name": "Leptospirillum ferrooxidans", "rank": "Species"}, "183": {"name": "Leptonema illini", "rank": "Species"}, "1407650": {"name": "Synechococcus sp. NKBG15041c", "rank": "Species"}, "482136": {"name": "Fangia", "rank": "Genus"}, "39103": {"name": "Lactobacillus phage PL-1", "rank": "Species"}, "189": {"name": "Novispirillum itersonii", "rank": "Species"}, "1388063": {"name": "Staphylococcus aureus M0110", "rank": "Strain"}, "1427330": {"name": "Mycobacterium tuberculosis XTB13-299", "rank": "Strain"}, "1427333": {"name": "Bartonella bacilliformis San Pedro600-02", "rank": "Strain"}, "1427332": {"name": "Bartonella bacilliformis str. Heidi Mejia", "rank": "Strain"}, "1388067": {"name": "Staphylococcus aureus M0115", "rank": "Strain"}, "1388066": {"name": "Staphylococcus aureus M0114", "rank": "Strain"}, "1388065": {"name": "Staphylococcus aureus M0112", "rank": "Strain"}, "1388064": {"name": "Staphylococcus aureus M0111", "rank": "Strain"}, "1388069": {"name": "Staphylococcus aureus M0117", "rank": "Strain"}, "1388068": {"name": "Staphylococcus aureus M0116", "rank": "Strain"}, "664785": {"name": "Sclerotinia sclerotiorum hypovirulence associated DNA virus 1", "rank": "Species"}, "1068978": {"name": "Amycolatopsis methanolica 239", "rank": "Strain"}, "1068979": {"name": "Amycolatopsis thermoflava N1165", "rank": "Strain"}, "1079455": {"name": "Rhizobium leguminosarum bv. viciae Vh3", "rank": "Strain"}, "1079454": {"name": "Rhizobium leguminosarum bv. viciae Ps8", "rank": "Strain"}, "909420": {"name": "Neisseria meningitidis H44/76", "rank": "Strain"}, "909421": {"name": "Vibrio coralliilyticus P1", "rank": "Strain"}, "1068975": {"name": "Acetobacterium dehalogenans DSM 11527", "rank": "Strain"}, "749490": {"name": "Enterococcus faecalis DAPTO 516", "rank": "Strain"}, "214326": {"name": "Lactobacillus sakei subsp. sakei", "rank": "Subspecies"}, "1410676": {"name": "Succinivibrio dextrinosolvens H5", "rank": "Strain"}, "1410674": {"name": "Sharpea azabuensis DSM 18934", "rank": "Strain"}, "1410675": {"name": "Streptococcus equinus 2B", "rank": "Strain"}, "1410672": {"name": "Ruminococcus flavefaciens ND2009", "rank": "Strain"}, "1410673": {"name": "Selenomonas bovis 8-14-1", "rank": "Strain"}, "1410670": {"name": "Ruminococcus flavefaciens MA2007", "rank": "Strain"}, "1410671": {"name": "Ruminococcus flavefaciens MC2020", "rank": "Strain"}, "559301": {"name": "Lactobacillus gasseri MV-22", "rank": "Strain"}, "559304": {"name": "Millerozyma farinosa CBS 7064", "rank": "Strain"}, "712121": {"name": "Actinomyces sp. oral taxon 181", "rank": "Species"}, "712124": {"name": "Actinomyces sp. oral taxon 448", "rank": "Species"}, "1296122": {"name": "Kwoniella mangroviensis CBS 8507", "rank": "Strain"}, "1296123": {"name": "Kwoniella mangroviensis CBS 8886", "rank": "Strain"}, "1296120": {"name": "Kwoniella heveanensis BCC8398", "rank": "Strain"}, "1296121": {"name": "Cryptococcus dejecticola CBS 10117", "rank": "Strain"}, "1217635": {"name": "Acinetobacter baumannii NIPH 527", "rank": "Strain"}, "1217634": {"name": "Acinetobacter baumannii NIPH 410", "rank": "Strain"}, "1217637": {"name": "Acinetobacter baumannii NIPH 601", "rank": "Strain"}, "1217636": {"name": "Acinetobacter baumannii NIPH 528", "rank": "Strain"}, "1217631": {"name": "Acinetobacter baumannii NIPH 290", "rank": "Strain"}, "1217630": {"name": "Acinetobacter baumannii NIPH 201", "rank": "Strain"}, "1217633": {"name": "Acinetobacter baumannii NIPH 335", "rank": "Strain"}, "1217632": {"name": "Acinetobacter baumannii NIPH 329", "rank": "Strain"}, "196082": {"name": "Parascardovia", "rank": "Genus"}, "196080": {"name": "Terasakiella", "rank": "Genus"}, "196081": {"name": "Scardovia", "rank": "Genus"}, "1217639": {"name": "Acinetobacter baumannii NIPH 146", "rank": "Strain"}, "1217638": {"name": "Acinetobacter baumannii ANC 4097", "rank": "Strain"}, "1310852": {"name": "Acinetobacter baumannii 24812_8", "rank": "Strain"}, "1310851": {"name": "Acinetobacter baumannii 24812_7", "rank": "Strain"}, "1310850": {"name": "Acinetobacter baumannii 24812_6", "rank": "Strain"}, "1310857": {"name": "Acinetobacter baumannii 24845_3", "rank": "Strain"}, "1310855": {"name": "Acinetobacter baumannii 24845_1", "rank": "Strain"}, "1310854": {"name": "Acinetobacter baumannii 24812_10", "rank": "Strain"}, "1310859": {"name": "Acinetobacter baumannii 24845_5", "rank": "Strain"}, "1310858": {"name": "Acinetobacter baumannii 24845_4", "rank": "Strain"}, "115531": {"name": "Unclassified Euryarchaeota (miscellaneous)", "rank": "No rank"}, "1108044": {"name": "Gordonia otitidis NBRC 100426", "rank": "Strain"}, "1422004": {"name": "Mycobacterium tuberculosis TB_RSA88", "rank": "Strain"}, "1422000": {"name": "Mycobacterium tuberculosis TB_RSA84", "rank": "Strain"}, "979203": {"name": "Staphylococcus epidermidis NIHLM067", "rank": "Strain"}, "1438767": {"name": "Klebsiella pneumoniae CHS 61", "rank": "Strain"}, "979201": {"name": "Staphylococcus epidermidis NIHLM087", "rank": "Strain"}, "1438765": {"name": "Klebsiella pneumoniae CHS 59", "rank": "Strain"}, "1281104": {"name": "Escherichia coli HVH 175 (4-3405184)", "rank": "Strain"}, "979206": {"name": "Staphylococcus epidermidis NIHLM053", "rank": "Strain"}, "979205": {"name": "Staphylococcus epidermidis NIHLM057", "rank": "Strain"}, "1438761": {"name": "Klebsiella pneumoniae CHS 55", "rank": "Strain"}, "979209": {"name": "Staphylococcus epidermidis NIHLM039", "rank": "Strain"}, "979208": {"name": "Staphylococcus epidermidis NIHLM040", "rank": "Strain"}, "1210006": {"name": "Streptococcus equinus ATCC 33317", "rank": "Strain"}, "1210005": {"name": "Stenotrophomonas maltophilia S028", "rank": "Strain"}, "1438769": {"name": "Klebsiella pneumoniae CHS 63", "rank": "Strain"}, "1411598": {"name": "Staphylococcus aureus W64953", "rank": "Strain"}, "1411599": {"name": "Staphylococcus aureus W68479", "rank": "Strain"}, "1069": {"name": "Rhodomicrobium vannielii", "rank": "Species"}, "1068": {"name": "Rhodomicrobium", "rank": "Genus"}, "1411590": {"name": "Staphylococcus aureus W52104", "rank": "Strain"}, "1411591": {"name": "Staphylococcus aureus W52117", "rank": "Strain"}, "1411592": {"name": "Staphylococcus aureus W52120", "rank": "Strain"}, "1411593": {"name": "Staphylococcus aureus W55442", "rank": "Strain"}, "1061": {"name": "Rhodobacter capsulatus", "rank": "Species"}, "1060": {"name": "Rhodobacter", "rank": "Genus"}, "1063": {"name": "Rhodobacter sphaeroides", "rank": "Species"}, "1281105": {"name": "Escherichia coli HVH 176 (4-3428664)", "rank": "Strain"}, "1173135": {"name": "Enterococcus phage BC-611", "rank": "Species"}, "666859": {"name": "Butterbur mosaic virus", "rank": "Species"}, "392484": {"name": "Methylophaga thiooxydans", "rank": "Species"}, "128975": {"name": "Salmonella phage Fels-1", "rank": "Species"}, "1422009": {"name": "Mycobacterium tuberculosis TB_RSA93", "rank": "Strain"}, "103985": {"name": "Pseudomonas syringae pv. theae", "rank": "Strain"}, "1051655": {"name": "Lactobacillus casei Lc-10", "rank": "Strain"}, "1216980": {"name": "Aeromonas salmonicida subsp. masoucida NBRC 13784", "rank": "Strain"}, "434068": {"name": "Honeysuckle yellow vein beta", "rank": "Species"}, "623282": {"name": "Psychrilyobacter", "rank": "Genus"}, "1437815": {"name": "Yarrowia lipolytica WSH-Z06", "rank": "Strain"}, "1508635": {"name": "Roseiflexaceae", "rank": "Family"}, "1116019": {"name": "Escherichia coli 2850750", "rank": "Strain"}, "1116018": {"name": "Escherichia coli 2850400", "rank": "Strain"}, "1116017": {"name": "Escherichia coli 2788150", "rank": "Strain"}, "1116016": {"name": "Escherichia coli 2785200", "rank": "Strain"}, "1116015": {"name": "Escherichia coli 2780750", "rank": "Strain"}, "1116014": {"name": "Escherichia coli 2770900", "rank": "Strain"}, "1116013": {"name": "Escherichia coli 2762100", "rank": "Strain"}, "1116012": {"name": "Escherichia coli 2756500", "rank": "Strain"}, "1116011": {"name": "Escherichia coli 2749250", "rank": "Strain"}, "1116010": {"name": "Escherichia coli 2747800", "rank": "Strain"}, "1281101": {"name": "Escherichia coli HVH 171 (4-3191958)", "rank": "Strain"}, "1329905": {"name": "Mannheimia haemolytica D35", "rank": "Strain"}, "137730": {"name": "Facklamia ignava", "rank": "Species"}, "1329907": {"name": "Escherichia coli APEC IMT5155", "rank": "Strain"}, "137732": {"name": "Granulicatella elegans", "rank": "Species"}, "1329901": {"name": "Salmonella enterica subsp. enterica serovar Infantis str. 119944", "rank": "Strain"}, "1329903": {"name": "Mannheimia haemolytica MhSwine2000", "rank": "Strain"}, "1329902": {"name": "Mannheimia haemolytica MhBrain2012", "rank": "Strain"}, "1329909": {"name": "Sphingobium quisquiliarum P25", "rank": "Strain"}, "1470558": {"name": "Cupriavidus sp. SK-3", "rank": "Species"}, "1470557": {"name": "Streptomyces sp. Tu 6176", "rank": "Species"}, "77635": {"name": "Bifidobacterium subtile", "rank": "Species"}, "1232554": {"name": "Bacillus subtilis subsp. subtilis str. JH642 substr. AG174", "rank": "Strain"}, "1281103": {"name": "Escherichia coli HVH 173 (3-9175482)", "rank": "Strain"}, "351054": {"name": "Unclassified Rudivirus", "rank": "No rank"}, "28134": {"name": "Prevotella oralis", "rank": "Species"}, "82105": {"name": "Cladophialophora", "rank": "Genus"}, "347219": {"name": "Citrus leprosis virus C", "rank": "Species"}, "46914": {"name": "Devosia riboflavina", "rank": "Species"}, "1402565": {"name": "Pseudomonas aeruginosa BL24", "rank": "Strain"}, "1402564": {"name": "Pseudomonas aeruginosa BL23", "rank": "Strain"}, "1402567": {"name": "Pseudomonas aeruginosa M8A.1", "rank": "Strain"}, "1051074": {"name": "Streptococcus thermophilus JIM 8232", "rank": "Strain"}, "1402561": {"name": "Pseudomonas aeruginosa BL20", "rank": "Strain"}, "1402560": {"name": "Pseudomonas aeruginosa BL19", "rank": "Strain"}, "1402563": {"name": "Pseudomonas aeruginosa BL22", "rank": "Strain"}, "1402562": {"name": "Pseudomonas aeruginosa BL21", "rank": "Strain"}, "392761": {"name": "Tomato leaf curl Arusha virus", "rank": "Species"}, "1402569": {"name": "Pseudomonas aeruginosa M8A.3", "rank": "Strain"}, "1402568": {"name": "Pseudomonas aeruginosa M8A.2", "rank": "Strain"}, "252598": {"name": "Saccharomyces sp. 'boulardii'", "rank": "Species"}, "1282356": {"name": "Pseudomonas poae RE*1-1-14", "rank": "Strain"}, "1282357": {"name": "Shigella flexneri 2003036", "rank": "Strain"}, "63298": {"name": "Pseudozyma", "rank": "Genus"}, "40270": {"name": "Snakehead retrovirus", "rank": "Species"}, "40271": {"name": "Hepatitis C virus genotype 2", "rank": "Strain"}, "40272": {"name": "Roseolovirus", "rank": "Genus"}, "40274": {"name": "Chlamydiamicrovirus", "rank": "Genus"}, "40276": {"name": "Trichovirus", "rank": "Genus"}, "40279": {"name": "Panicum mosaic virus", "rank": "Species"}, "346665": {"name": "Moraxella boevrei", "rank": "Species"}, "1423758": {"name": "Lactobacillus hominis DSM 23910 = CRBIP 24.179", "rank": "Strain"}, "1423757": {"name": "Lactobacillus hilgardii DSM 20176 = ATCC 8290", "rank": "Strain"}, "1423755": {"name": "Lactobacillus hayakitensis DSM 18933 = JCM 14209", "rank": "Strain"}, "1423754": {"name": "Lactobacillus hamsteri DSM 5661 = JCM 6256", "rank": "Strain"}, "1423751": {"name": "Lactobacillus gigeriorum DSM 23908 = CRBIP 24.85", "rank": "Strain"}, "1256209": {"name": "Lactobacillus paracasei subsp. paracasei Lpp221", "rank": "Strain"}, "478433": {"name": "Mycobacterium tuberculosis KZN 4207", "rank": "Strain"}, "478434": {"name": "Mycobacterium tuberculosis KZN 1435", "rank": "Strain"}, "478435": {"name": "Mycobacterium tuberculosis KZN 605", "rank": "Strain"}, "1048689": {"name": "Escherichia coli O55:H7 str. RM12579", "rank": "Strain"}, "1256203": {"name": "Lactobacillus paracasei subsp. paracasei Lpp189", "rank": "Strain"}, "1256202": {"name": "Lactobacillus paracasei subsp. paracasei CNCM I-4270", "rank": "Strain"}, "1003202": {"name": "Rickettsia typhi str. B9991CWPP", "rank": "Strain"}, "1048680": {"name": "Rhizobium sp. 42MFCr.1", "rank": "Species"}, "1003200": {"name": "Achromobacter insuavis AXX-A", "rank": "Strain"}, "1439047": {"name": "Streptococcus pyogenes ABC020026799", "rank": "Strain"}, "580033": {"name": "Campylobacter volucris LMG 24379", "rank": "Strain"}, "1244102": {"name": "Streptococcus agalactiae SGBS025", "rank": "Strain"}, "746691": {"name": "Oceanobacillus kimchii", "rank": "Species"}, "746697": {"name": "Aequorivita sublithincola DSM 14238", "rank": "Strain"}, "317936": {"name": "Nostoc sp. PCC 7107", "rank": "Species"}, "28099": {"name": "Agrobacterium rubi", "rank": "Species"}, "344747": {"name": "Planctomyces maris DSM 8797", "rank": "Strain"}, "1290430": {"name": "Rickettsia prowazekii str. Cairo 3", "rank": "Strain"}, "1126909": {"name": "Escherichia coli C586_05", "rank": "Strain"}, "1244105": {"name": "Streptococcus agalactiae SGBS029", "rank": "Strain"}, "1126902": {"name": "Escherichia coli C458_10", "rank": "Strain"}, "1126901": {"name": "Escherichia coli C418_89", "rank": "Strain"}, "1408206": {"name": "Pediococcus pentosaceus SL4", "rank": "Strain"}, "1408207": {"name": "Pseudomonas aeruginosa PK6", "rank": "Strain"}, "1126904": {"name": "Escherichia coli C496_10", "rank": "Strain"}, "1408205": {"name": "Lactobacillus rhamnosus LR231", "rank": "Strain"}, "1203539": {"name": "MW polyomavirus", "rank": "Species"}, "1235442": {"name": "Vibrio cholerae CP1117", "rank": "Strain"}, "1235443": {"name": "Vibrio cholerae CP1111", "rank": "Strain"}, "1235440": {"name": "Staphylococcus epidermidis 12142587", "rank": "Strain"}, "1235441": {"name": "Nocardiopsis gilva YIM 90087", "rank": "Strain"}, "1235444": {"name": "Vibrio cholerae CP1112", "rank": "Strain"}, "1287735": {"name": "Achromobacter insuavis", "rank": "Species"}, "907493": {"name": "Aggregatibacter actinomycetemcomitans serotype c str. SCC2302", "rank": "Strain"}, "907492": {"name": "Aggregatibacter actinomycetemcomitans serotype b str. I23C", "rank": "Strain"}, "907491": {"name": "Aggregatibacter actinomycetemcomitans serotype b str. SCC1398", "rank": "Strain"}, "907490": {"name": "Aggregatibacter actinomycetemcomitans serotype f str. D18P1", "rank": "Strain"}, "75746": {"name": "Wheat yellow mosaic virus", "rank": "Species"}, "75747": {"name": "Fusarium poae virus 1", "rank": "Species"}, "1281885": {"name": "Bordetella holmesii H558", "rank": "Strain"}, "1463904": {"name": "Streptomyces sp. NRRL S-378", "rank": "Species"}, "634498": {"name": "Methanobrevibacter ruminantium M1", "rank": "Strain"}, "634499": {"name": "Erwinia pyrifoliae Ep1/96", "rank": "Strain"}, "273135": {"name": "Candidatus Cardinium", "rank": "Genus"}, "634497": {"name": "Haloarcula hispanica ATCC 33960", "rank": "Strain"}, "1428433": {"name": "Oenococcus oeni IOEB_S450", "rank": "Strain"}, "1428432": {"name": "Oenococcus oeni IOEB_S436a", "rank": "Strain"}, "1428431": {"name": "Oenococcus oeni IOEB_S277", "rank": "Strain"}, "1428430": {"name": "Oenococcus oeni IOEB_L65_2", "rank": "Strain"}, "1428437": {"name": "Oenococcus oeni S13", "rank": "Strain"}, "1428436": {"name": "Oenococcus oeni S12", "rank": "Strain"}, "1156998": {"name": "Staphylococcus aureus HIF003_B2N-C", "rank": "Strain"}, "1156999": {"name": "Staphylococcus aureus HI022", "rank": "Strain"}, "1156996": {"name": "Staphylococcus aureus HI049B", "rank": "Strain"}, "1156997": {"name": "Staphylococcus aureus HI010B", "rank": "Strain"}, "1156994": {"name": "Staphylococcus aureus HI049", "rank": "Strain"}, "53633": {"name": "Sulfobacillus acidophilus", "rank": "Species"}, "53634": {"name": "Acidimicrobium", "rank": "Genus"}, "53635": {"name": "Acidimicrobium ferrooxidans", "rank": "Species"}, "641832": {"name": "Vibrio phage VP93", "rank": "Species"}, "1008459": {"name": "Taylorella asinigenitalis MCE3", "rank": "Strain"}, "1008457": {"name": "Myroides injenensis M09-0166", "rank": "Strain"}, "1008453": {"name": "Streptococcus mitis SK1080", "rank": "Strain"}, "1008452": {"name": "Streptococcus mitis SK1073", "rank": "Strain"}, "1151172": {"name": "Salmonella enterica subsp. enterica serovar Abaetetuba", "rank": "Strain"}, "1235990": {"name": "Halyomorpha halys symbiont", "rank": "Species"}, "1325933": {"name": "Clostridium sp. MS1", "rank": "Species"}, "1325934": {"name": "Actinomyces sp. MS2", "rank": "Species"}, "1281779": {"name": "Agrobacterium tumefaciens str. Cherry 2E-2-2", "rank": "Strain"}, "1281778": {"name": "Bacillus methylotrophicus SK19.001", "rank": "Strain"}, "1293961": {"name": "Sida yellow vein China alphasatellite", "rank": "Species"}, "907237": {"name": "Helicobacter pylori Lithuania75", "rank": "Strain"}, "931457": {"name": "Staphylococcus aureus subsp. aureus CIGC345D", "rank": "Strain"}, "931454": {"name": "Staphylococcus aureus subsp. aureus CIG1524", "rank": "Strain"}, "931455": {"name": "Staphylococcus aureus subsp. aureus CIGC340D", "rank": "Strain"}, "931452": {"name": "Staphylococcus aureus subsp. aureus CIG1267", "rank": "Strain"}, "931453": {"name": "Staphylococcus aureus subsp. aureus CIG149", "rank": "Strain"}, "931450": {"name": "Staphylococcus aureus subsp. aureus CIG2018", "rank": "Strain"}, "931451": {"name": "Staphylococcus aureus subsp. aureus CIG290", "rank": "Strain"}, "1070319": {"name": "Candidatus Glomeribacter gigasporarum BEG34", "rank": "Strain"}, "931458": {"name": "Staphylococcus aureus subsp. aureus CIGC348", "rank": "Strain"}, "931459": {"name": "Staphylococcus aureus subsp. aureus CIGC128", "rank": "Strain"}, "374833": {"name": "Neisseria meningitidis 053442", "rank": "Strain"}, "382685": {"name": "Lactococcus phage Q54", "rank": "Strain"}, "1231190": {"name": "Nitratireductor indicus C115", "rank": "Strain"}, "28090": {"name": "Acinetobacter lwoffii", "rank": "Species"}, "1448501": {"name": "Mycobacterium tuberculosis TKK_05MA_0025", "rank": "Strain"}, "1448502": {"name": "Mycobacterium tuberculosis TKK_05MA_0026", "rank": "Strain"}, "1448505": {"name": "Mycobacterium tuberculosis TKK_05MA_0033", "rank": "Strain"}, "1448504": {"name": "Mycobacterium tuberculosis TKK_05MA_0031", "rank": "Strain"}, "1448507": {"name": "Mycobacterium tuberculosis TKK_05MA_0036", "rank": "Strain"}, "1448506": {"name": "Mycobacterium tuberculosis TKK_05MA_0035", "rank": "Strain"}, "1448509": {"name": "Mycobacterium tuberculosis TKK_05MA_0040", "rank": "Strain"}, "1448508": {"name": "Mycobacterium tuberculosis TKK_05MA_0037", "rank": "Strain"}, "887065": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. 639016-6", "rank": "Strain"}, "887064": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. 622731-39", "rank": "Strain"}, "887067": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. 635290-58", "rank": "Strain"}, "887066": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. 640631", "rank": "Strain"}, "54958": {"name": "Amphisphaeriaceae", "rank": "Family"}, "887063": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. 576709", "rank": "Strain"}, "1287488": {"name": "Prevotella sp. S7 MS 2", "rank": "Species"}, "382359": {"name": "Synechococcus phage syn9", "rank": "Species"}, "887069": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. 607308-19", "rank": "Strain"}, "887068": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. 607308-16", "rank": "Strain"}, "1245890": {"name": "Enterobacteria phage JL1", "rank": "Species"}, "1050720": {"name": "Agrobacterium tumefaciens F2", "rank": "Strain"}, "765114": {"name": "Propionibacterium acnes HL063PA2", "rank": "Strain"}, "123214": {"name": "Persephonella marina EX-H1", "rank": "Strain"}, "1175296": {"name": "Methanomassiliicoccus luminyensis B10", "rank": "Strain"}, "1193095": {"name": "Lactobacillus hokkaidonensis", "rank": "Species"}, "913318": {"name": "Cloacimonetes bacterium SCGC AAA252-E13", "rank": "Species"}, "1422651": {"name": "Staphylococcus aureus VET0427R", "rank": "Strain"}, "1389203": {"name": "Puccinia psidii MF-1", "rank": "Strain"}, "1389204": {"name": "Feline astrovirus 2", "rank": "Species"}, "882096": {"name": "Listeria monocytogenes SLCC5850", "rank": "Strain"}, "882095": {"name": "Listeria monocytogenes ATCC 19117", "rank": "Strain"}, "938557": {"name": "Actinobacterium SCGC AAA278-I18", "rank": "Species"}, "882099": {"name": "Mycobacterium tuberculosis BTB05-552", "rank": "Strain"}, "882098": {"name": "Mycobacterium tuberculosis S96-129", "rank": "Strain"}, "1422653": {"name": "Staphylococcus aureus VET0431R", "rank": "Strain"}, "313606": {"name": "Microscilla marina ATCC 23134", "rank": "Strain"}, "1422652": {"name": "Staphylococcus aureus VET0428R", "rank": "Strain"}, "649775": {"name": "Synergistia", "rank": "Class"}, "649777": {"name": "Synergistaceae", "rank": "Family"}, "649776": {"name": "Synergistales", "rank": "Order"}, "698758": {"name": "Amphibacillus xylanus NBRC 15112", "rank": "Strain"}, "1385944": {"name": "Bifidobacterium breve 31L", "rank": "Strain"}, "888727": {"name": "Eubacterium sulci ATCC 35585", "rank": "Strain"}, "1422659": {"name": "Staphylococcus aureus VET0437R", "rank": "Strain"}, "186534": {"name": "Caulimoviridae", "rank": "Family"}, "186533": {"name": "Cavemovirus", "rank": "Genus"}, "170573": {"name": "Staphylococcus pettenkoferi", "rank": "Species"}, "1422658": {"name": "Staphylococcus aureus VET0436R", "rank": "Strain"}, "697581": {"name": "Thermofilum carboxyditrophus 1505", "rank": "Strain"}, "484770": {"name": "Pelosinus sp. UFO1", "rank": "Species"}, "186539": {"name": "Reston ebolavirus", "rank": "Species"}, "888728": {"name": "Haemophilus aegyptius ATCC 11116", "rank": "Strain"}, "1206557": {"name": "Yersinia phage phiR201", "rank": "Species"}, "1094960": {"name": "Oxalobacteraceae bacterium JGI 0001002-K6", "rank": "Species"}, "1279027": {"name": "Hippea alviniae", "rank": "Species"}, "1094966": {"name": "Rhizobiales bacterium JGI 0001003-E12", "rank": "Species"}, "1094967": {"name": "Xanthomonadaceae bacterium JGI 0001002-D18", "rank": "Species"}, "1094965": {"name": "Rhizobiales bacterium JGI 0001002-O7", "rank": "Species"}, "1094969": {"name": "Xanthomonadaceae bacterium JGI 0001002-F18", "rank": "Species"}, "1206558": {"name": "Yersinia phage phiR1-RT", "rank": "Species"}, "1206559": {"name": "Yersinia phage phi80-18", "rank": "Species"}, "1447504": {"name": "Mycobacterium tuberculosis MD14620", "rank": "Strain"}, "1120978": {"name": "Allofustis seminis DSM 15817", "rank": "Strain"}, "886738": {"name": "Candidatus Nitrosoarchaeum limnia SFB1", "rank": "Strain"}, "1447507": {"name": "Mycobacterium tuberculosis MD14844", "rank": "Strain"}, "1447500": {"name": "Mycobacterium tuberculosis MD15963", "rank": "Strain"}, "1447501": {"name": "Mycobacterium tuberculosis MD15855", "rank": "Strain"}, "1447502": {"name": "Mycobacterium tuberculosis MD16257", "rank": "Strain"}, "1447503": {"name": "Mycobacterium tuberculosis MD15774", "rank": "Strain"}, "1120971": {"name": "Alicyclobacillus contaminans DSM 17975", "rank": "Strain"}, "1120970": {"name": "Aliagarivorans taiwanensis DSM 22990", "rank": "Strain"}, "1120973": {"name": "Effusibacillus pohliae DSM 22757", "rank": "Strain"}, "1120972": {"name": "Alicyclobacillus herbarius DSM 13609", "rank": "Strain"}, "1447508": {"name": "Mycobacterium tuberculosis MD14847", "rank": "Strain"}, "1447509": {"name": "Mycobacterium tuberculosis MD15050", "rank": "Strain"}, "1120977": {"name": "Alkanindiges illinoisensis DSM 15370", "rank": "Strain"}, "1047018": {"name": "Aminicenantes bacterium SCGC AAA252-F08", "rank": "Species"}, "1047019": {"name": "Aminicenantes bacterium SCGC AAA252-G04", "rank": "Species"}, "93058": {"name": "Prochlorococcus marinus str. MIT 9202", "rank": "Strain"}, "93059": {"name": "Prochlorococcus marinus str. MIT 9211", "rank": "Strain"}, "10240": {"name": "Poxviridae", "rank": "Family"}, "10241": {"name": "Chordopoxvirinae", "rank": "Subfamily"}, "1047010": {"name": "Omnitrophica bacterium SCGC AAA011-L16", "rank": "Species"}, "93057": {"name": "Prochlorococcus marinus str. MIT 9201", "rank": "Strain"}, "1047016": {"name": "Aminicenantes bacterium SCGC AAA252-D06", "rank": "Species"}, "10245": {"name": "Vaccinia virus", "rank": "Species"}, "1047014": {"name": "Aminicenantes bacterium SCGC AAA252-B17", "rank": "Species"}, "706525": {"name": "Phocoena phocoena papillomavirus 1", "rank": "Species"}, "484895": {"name": "Pseudomonas phage LUZ24", "rank": "Species"}, "925129": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. CVM_76-3618", "rank": "Strain"}, "925128": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. CVM_56-3991", "rank": "Strain"}, "150286": {"name": "Anguillid herpesvirus 1", "rank": "Species"}, "150284": {"name": "Garlic virus X", "rank": "Species"}, "150285": {"name": "Garlic virus E", "rank": "Species"}, "1281005": {"name": "Escherichia coli HVH 59 (4-1119338)", "rank": "Strain"}, "925127": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. CVM_N202", "rank": "Strain"}, "925126": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. SE15-1", "rank": "Strain"}, "332090": {"name": "Unclassified Omegatetravirus", "rank": "No rank"}, "28026": {"name": "Bifidobacterium pseudocatenulatum", "rank": "Species"}, "28025": {"name": "Bifidobacterium animalis", "rank": "Species"}, "1219028": {"name": "Rhodococcus wratislaviensis NBRC 100605", "rank": "Strain"}, "765909": {"name": "Lamprocystis purpurea DSM 4197", "rank": "Strain"}, "410291": {"name": "Vibrio campbellii HY01", "rank": "Strain"}, "643867": {"name": "Marivirga tractuosa DSM 4126", "rank": "Strain"}, "1215083": {"name": "Peptoclostridium difficile T19", "rank": "Strain"}, "388272": {"name": "Pseudomonas aeruginosa PACS2", "rank": "Strain"}, "520465": {"name": "Brucella melitensis bv. 2 str. 63/9", "rank": "Strain"}, "520464": {"name": "Brucella melitensis bv. 1 str. Rev.1", "rank": "Strain"}, "306323": {"name": "Streptococcus phage 2972", "rank": "Species"}, "520461": {"name": "Brucella pinnipedialis B2/94", "rank": "Strain"}, "520460": {"name": "Brucella ceti M13/05/1", "rank": "Strain"}, "520463": {"name": "Brucella pinnipedialis M163/99/10", "rank": "Strain"}, "520462": {"name": "Brucella pinnipedialis M292/94/1", "rank": "Strain"}, "1208659": {"name": "Bordetella bronchiseptica Bbr77", "rank": "Strain"}, "1208658": {"name": "Bordetella bronchiseptica MO149", "rank": "Strain"}, "1234809": {"name": "Pestivirus strain Aydin/04-TR", "rank": "Strain"}, "10861": {"name": "Inovirus", "rank": "Genus"}, "10862": {"name": "Xanthomonas phage Cf1c", "rank": "Species"}, "454594": {"name": "Xanthomonas citri pv. mangiferaeindicae", "rank": "Strain"}, "642111": {"name": "Vibrio phage VEJphi", "rank": "Species"}, "1208657": {"name": "Bordetella bronchiseptica 1289", "rank": "Strain"}, "1208656": {"name": "Cronobacter dublinensis 1210", "rank": "Strain"}, "1238162": {"name": "Mungbean yellow mosaic India virus associated betasatellite India: Faizabad: Cow Pea:2012", "rank": "Species"}, "1081927": {"name": "Pseudomonas aeruginosa PA103", "rank": "Strain"}, "1505225": {"name": "Acinetobacter phage YMC-13-01-C62", "rank": "Species"}, "1505227": {"name": "Aeromonas phage pAh6-C", "rank": "Species"}, "644651": {"name": "Erwinia pyrifoliae DSM 12163", "rank": "Strain"}, "644652": {"name": "Gordonibacter", "rank": "Genus"}, "861047": {"name": "Mycobacterium phage LeBron", "rank": "Species"}, "861046": {"name": "Mycobacterium phage Eagle", "rank": "Species"}, "861045": {"name": "Mycobacterium phage CrimD", "rank": "Species"}, "861044": {"name": "Mycobacterium phage Angelica", "rank": "Species"}, "1277886": {"name": "Bacillus phage BPS10C", "rank": "Species"}, "696216": {"name": "Streptococcus constellatus subsp. pharyngis C232", "rank": "Strain"}, "60920": {"name": "Sanguibacter keddieii", "rank": "Species"}, "470166": {"name": "Tomato marchitez virus", "rank": "Species"}, "302912": {"name": "Bifidobacterium animalis subsp. animalis", "rank": "Subspecies"}, "302911": {"name": "Bifidobacterium animalis subsp. lactis", "rank": "Subspecies"}, "661087": {"name": "Olsenella sp. oral taxon 809 str. F0356", "rank": "Strain"}, "1280683": {"name": "Butyrivibrio sp. NC2007", "rank": "Species"}, "1281003": {"name": "Escherichia coli HVH 56 (4-2153033)", "rank": "Strain"}, "1203076": {"name": "Lactobacillus ingluviei str. Autruche 4", "rank": "Strain"}, "12353": {"name": "Enterobacteria phage RB69", "rank": "Species"}, "12355": {"name": "Enterobacteria phage T1", "rank": "Species"}, "1173709": {"name": "Labidocera aestiva circovirus", "rank": "Species"}, "213775": {"name": "Lactococcus phage jj50", "rank": "Strain"}, "1184267": {"name": "Bdellovibrio exovorus JSS", "rank": "Strain"}, "1281002": {"name": "Escherichia coli HVH 55 (4-2646161)", "rank": "Strain"}, "1184263": {"name": "Xanthomonas campestris pv. musacearum NCPPB 4392", "rank": "Strain"}, "881": {"name": "Desulfovibrio vulgaris", "rank": "Species"}, "864702": {"name": "Oscillatoriales cyanobacterium JSC-12", "rank": "Species"}, "883": {"name": "Desulfovibrio vulgaris str. 'Miyazaki F'", "rank": "Strain"}, "882": {"name": "Desulfovibrio vulgaris str. Hildenborough", "rank": "Strain"}, "1422123": {"name": "Staphylococcus aureus DAR3529", "rank": "Strain"}, "1422122": {"name": "Staphylococcus aureus DAR3525", "rank": "Strain"}, "1422121": {"name": "Staphylococcus aureus DAR3519", "rank": "Strain"}, "1422120": {"name": "Staphylococcus aureus DAR3518", "rank": "Strain"}, "889": {"name": "Desulfovibrio longus", "rank": "Species"}, "167875": {"name": "Unclassified Thermus/Deinococcus group", "rank": "No rank"}, "1422128": {"name": "Staphylococcus aureus DAR3562", "rank": "Strain"}, "585055": {"name": "Escherichia coli 55989", "rank": "Strain"}, "585054": {"name": "Escherichia fergusonii ATCC 35469", "rank": "Strain"}, "585057": {"name": "Escherichia coli IAI39", "rank": "Strain"}, "585056": {"name": "Escherichia coli UMN026", "rank": "Strain"}, "585059": {"name": "Simian adenovirus 20", "rank": "Species"}, "67761": {"name": "Cowpea mild mottle virus", "rank": "Species"}, "493906": {"name": "Vibrio phage kappa", "rank": "Species"}, "382638": {"name": "Helicobacter acinonychis str. Sheeba", "rank": "Strain"}, "309798": {"name": "Coprothermobacter proteolyticus DSM 5265", "rank": "Strain"}, "309799": {"name": "Dictyoglomus thermophilum H-6-12", "rank": "Strain"}, "309797": {"name": "Chrysiogenes arsenatis", "rank": "Species"}, "525337": {"name": "Lactobacillus paracasei subsp. paracasei ATCC 25302", "rank": "Strain"}, "525330": {"name": "Lactobacillus johnsonii ATCC 33200", "rank": "Strain"}, "525338": {"name": "Lactobacillus plantarum subsp. plantarum ATCC 14917 = JCM 1149 = CGMCC 1.2437", "rank": "Strain"}, "1439261": {"name": "Streptococcus pyogenes ABC020056064", "rank": "Strain"}, "36809": {"name": "Mycobacterium abscessus", "rank": "Species"}, "1439264": {"name": "Streptococcus pyogenes ABC020056181", "rank": "Strain"}, "869674": {"name": "Escherichia coli 95.0941", "rank": "Strain"}, "279813": {"name": "Thalassobacillus devorans", "rank": "Species"}, "869676": {"name": "Escherichia coli 97.0264", "rank": "Strain"}, "869677": {"name": "Escherichia coli 96.0497", "rank": "Strain"}, "869670": {"name": "Escherichia coli 97.0246", "rank": "Strain"}, "869671": {"name": "Escherichia coli 5.0588", "rank": "Strain"}, "869672": {"name": "Escherichia coli 97.0259", "rank": "Strain"}, "869673": {"name": "Escherichia coli H30", "rank": "Strain"}, "52228": {"name": "Hallella", "rank": "Genus"}, "52229": {"name": "Hallella seregens", "rank": "Species"}, "424182": {"name": "Rhizobium sp. IRBG74", "rank": "Species"}, "869678": {"name": "Escherichia coli 99.0741", "rank": "Strain"}, "869679": {"name": "Escherichia coli 3.2608", "rank": "Strain"}, "1300003": {"name": "Alteromonas phage vB_AmaP_AD45-P", "rank": "Species"}, "1121006": {"name": "Aquimarina latercula DSM 2041", "rank": "Strain"}, "191494": {"name": "Conexibacter", "rank": "Genus"}, "191495": {"name": "Conexibacter woesei", "rank": "Species"}, "1121007": {"name": "Aquimarina muelleri DSM 19832", "rank": "Strain"}, "243233": {"name": "Methylococcus capsulatus str. Bath", "rank": "Strain"}, "66891": {"name": "Streptomyces fulvoviridis", "rank": "Species"}, "66897": {"name": "Streptomyces griseorubens", "rank": "Species"}, "60137": {"name": "Sulfitobacter pontiacus", "rank": "Species"}, "1453367": {"name": "Staphylococcus phage GRCS", "rank": "Species"}, "996828": {"name": "Leptospira interrogans serovar Copenhageni str. Fiocruz LV2776", "rank": "Strain"}, "996829": {"name": "Leptospira interrogans serovar Copenhageni str. Fiocruz LV2787", "rank": "Strain"}, "60136": {"name": "Sulfitobacter", "rank": "Genus"}, "996820": {"name": "Leptospira interrogans serovar Copenhageni str. Fiocruz LV2756 C1", "rank": "Strain"}, "996822": {"name": "Leptospira interrogans serovar Copenhageni str. Fiocruz LV2752", "rank": "Strain"}, "996823": {"name": "Leptospira interrogans serovar Copenhageni str. Fiocruz LV2759", "rank": "Strain"}, "996824": {"name": "Leptospira interrogans serovar Copenhageni str. Fiocruz LV2763", "rank": "Strain"}, "996825": {"name": "Leptospira interrogans serovar Copenhageni str. Fiocruz LV2767", "rank": "Strain"}, "996827": {"name": "Leptospira interrogans serovar Copenhageni str. Fiocruz LV2772", "rank": "Strain"}, "60133": {"name": "Prevotella pallens", "rank": "Species"}, "290112": {"name": "Xenorhabdus szentirmaii", "rank": "Species"}, "492670": {"name": "Bacillus methylotrophicus", "rank": "Species"}, "1266994": {"name": "Sida yellow mosaic Alagoas virus", "rank": "Species"}, "878320": {"name": "Aeromonas caviae Ae398", "rank": "Strain"}, "1266996": {"name": "Mycoplasma orale ATCC 23714", "rank": "Strain"}, "1266997": {"name": "Mycoplasma salivarium ATCC 23064", "rank": "Strain"}, "244317": {"name": "Escherichia coli O128:H2", "rank": "Strain"}, "244319": {"name": "Escherichia coli O26:H11", "rank": "Strain"}, "1266998": {"name": "Paracoccus zeaxanthinifaciens ATCC 21588", "rank": "Strain"}, "1266999": {"name": "Mycoplasma arginini ATCC 23838", "rank": "Strain"}, "373412": {"name": "Mycobacterium phage PMC", "rank": "Species"}, "200940": {"name": "Thermodesulfobacteria", "rank": "Phylum"}, "373410": {"name": "Mycobacterium phage PBI1", "rank": "Species"}, "373411": {"name": "Mycobacterium phage PLot", "rank": "Species"}, "373414": {"name": "Mycobacterium phage Qyrzula", "rank": "Species"}, "373415": {"name": "Mycobacterium phage Wildcat", "rank": "Species"}, "1243178": {"name": "Rubus canadensis virus 1", "rank": "Species"}, "1133031": {"name": "Sputnik virophage 2", "rank": "Species"}, "1133032": {"name": "Sputnik virophage 3", "rank": "Species"}, "212791": {"name": "Enhydrobacter", "rank": "Genus"}, "212790": {"name": "Sulfurihydrogenibium", "rank": "Genus"}, "1281173": {"name": "Escherichia coli UMEA 3014-1", "rank": "Strain"}, "1354192": {"name": "Mycobacterium tuberculosis MAL020130", "rank": "Strain"}, "1354193": {"name": "Mycobacterium bovis MAL010093", "rank": "Strain"}, "1354191": {"name": "Mycobacterium africanum MAL020173", "rank": "Strain"}, "310907": {"name": "Enterovirus H", "rank": "Species"}, "151340": {"name": "Papillomaviridae", "rank": "Family"}, "151341": {"name": "Polyomaviridae", "rank": "Family"}, "205895": {"name": "Cypovirus 1", "rank": "Species"}, "205896": {"name": "Cypovirus 2", "rank": "Species"}, "205899": {"name": "Cypovirus 5", "rank": "Species"}, "11630": {"name": "Pichinde virus", "rank": "Species"}, "722419": {"name": "Pseudoalteromonas haloplanktis ANT/505", "rank": "Strain"}, "1590650": {"name": "Adelie penguin polyomavirus", "rank": "Species"}, "887294": {"name": "Campylobacter coli 1891", "rank": "Strain"}, "57479": {"name": "Microvirgula", "rank": "Genus"}, "1173817": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. 3402", "rank": "Strain"}, "129732": {"name": "Sunflower chlorotic mottle virus", "rank": "Species"}, "941639": {"name": "Bacillus coagulans 2-6", "rank": "Strain"}, "941638": {"name": "Rickettsia slovaca 13-B", "rank": "Strain"}, "626940": {"name": "Phascolarctobacterium succinatutens", "rank": "Species"}, "445983": {"name": "Borrelia burgdorferi 156a", "rank": "Strain"}, "518637": {"name": "Holdemanella biformis DSM 3989", "rank": "Strain"}, "518636": {"name": "Clostridium asparagiforme DSM 15981", "rank": "Strain"}, "518635": {"name": "Bifidobacterium angulatum DSM 20098 = JCM 7096", "rank": "Strain"}, "518634": {"name": "Bifidobacterium breve DSM 20213 = JCM 1192", "rank": "Strain"}, "1047021": {"name": "Aminicenantes bacterium SCGC AAA252-G21", "rank": "Species"}, "798074": {"name": "Tuhoko virus 3", "rank": "Species"}, "515414": {"name": "Prevotella falsenii", "rank": "Species"}, "515417": {"name": "Amphritea", "rank": "Genus"}, "1393702": {"name": "Staphylococcus aureus M1561", "rank": "Strain"}, "1393703": {"name": "Staphylococcus aureus M1562", "rank": "Strain"}, "1393701": {"name": "Staphylococcus aureus M1560", "rank": "Strain"}, "1393706": {"name": "Staphylococcus aureus M1569", "rank": "Strain"}, "1393707": {"name": "Staphylococcus aureus M1570", "rank": "Strain"}, "1393704": {"name": "Staphylococcus aureus M1566", "rank": "Strain"}, "1393705": {"name": "Staphylococcus aureus M1567", "rank": "Strain"}, "1393708": {"name": "Staphylococcus aureus M1571", "rank": "Strain"}, "1393709": {"name": "Staphylococcus aureus M1572", "rank": "Strain"}, "1281176": {"name": "Escherichia coli UMEA 3041-1", "rank": "Strain"}, "104355": {"name": "Gloeophyllum trabeum", "rank": "Species"}, "181604": {"name": "Vibrio phage VSK", "rank": "Species"}, "995049": {"name": "Sweet potato vein clearing virus", "rank": "Species"}, "665571": {"name": "Spirochaeta thermophila DSM 6192", "rank": "Strain"}, "665577": {"name": "Streptomyces viridosporus T7A", "rank": "Strain"}, "1157708": {"name": "Variovorax paradoxus 110B", "rank": "Strain"}, "1397939": {"name": "Mycobacterium tuberculosis TKK_04_0030", "rank": "Strain"}, "1397938": {"name": "Mycobacterium tuberculosis TKK_04_0029", "rank": "Strain"}, "1310558": {"name": "Acinetobacter baumannii 136706", "rank": "Strain"}, "1287116": {"name": "Mesorhizobium sp. L2C084A000", "rank": "Species"}, "1397931": {"name": "Mycobacterium tuberculosis TKK_04_0039", "rank": "Strain"}, "1397930": {"name": "Mycobacterium tuberculosis TKK_04_0038", "rank": "Strain"}, "1397933": {"name": "Mycobacterium tuberculosis TKK_04_0044", "rank": "Strain"}, "1397932": {"name": "Mycobacterium tuberculosis TKK_04_0040", "rank": "Strain"}, "1397935": {"name": "Mycobacterium tuberculosis TKK_04_0046", "rank": "Strain"}, "1397934": {"name": "Mycobacterium tuberculosis TKK_04_0045", "rank": "Strain"}, "1397937": {"name": "Mycobacterium tuberculosis TKK_04_0037", "rank": "Strain"}, "1397936": {"name": "Mycobacterium tuberculosis TKK_04_0042", "rank": "Strain"}, "1145170": {"name": "Neisseria meningitidis 2004264", "rank": "Strain"}, "1145171": {"name": "Neisseria meningitidis 2000175", "rank": "Strain"}, "1145172": {"name": "Neisseria meningitidis 2005079", "rank": "Strain"}, "1145173": {"name": "Neisseria meningitidis 2001068", "rank": "Strain"}, "1145174": {"name": "Neisseria meningitidis 2005040", "rank": "Strain"}, "1145175": {"name": "Neisseria meningitidis 2002004", "rank": "Strain"}, "1145176": {"name": "Neisseria meningitidis 2007461", "rank": "Strain"}, "1145177": {"name": "Neisseria meningitidis NM134", "rank": "Strain"}, "1403944": {"name": "Escherichia coli DORA_B_14", "rank": "Strain"}, "1403945": {"name": "Negativicoccus succinicivorans DORA_17_25", "rank": "Strain"}, "1403946": {"name": "Streptococcus anginosus DORA_7", "rank": "Strain"}, "1403940": {"name": "Intestinibacter bartlettii DORA_8_9", "rank": "Strain"}, "1458670": {"name": "Microbacterium phage vB_MoxS-ISF9", "rank": "Species"}, "1403942": {"name": "Enterococcus faecalis DORA_14", "rank": "Strain"}, "1100814": {"name": "Gordonia phage GTE7", "rank": "Species"}, "413404": {"name": "Candidatus Ruthia magnifica str. Cm (Calyptogena magnifica)", "rank": "Strain"}, "548908": {"name": "Fig fleck-associated virus", "rank": "Species"}, "1398776": {"name": "Pseudomonas chlororaphis YL-1", "rank": "Strain"}, "68199": {"name": "Streptomyces flavochromogenes", "rank": "Species"}, "1448841": {"name": "Staphylococcus aureus Lyso 1 2010", "rank": "Strain"}, "68194": {"name": "Streptomyces durhamensis", "rank": "Species"}, "477695": {"name": "Thermogladius", "rank": "Genus"}, "1448843": {"name": "Staphylococcus aureus LysK 1 2010", "rank": "Strain"}, "477693": {"name": "Desulfurococcus kamchatkensis", "rank": "Species"}, "1448844": {"name": "Staphylococcus aureus LysK 2 2010", "rank": "Strain"}, "83867": {"name": "Palaeococcus", "rank": "Genus"}, "159728": {"name": "Desulfovibrio cuneatus", "rank": "Species"}, "1448847": {"name": "Staphylococcus aureus 1801-1 2010", "rank": "Strain"}, "1511857": {"name": "Ligamenvirales", "rank": "Order"}, "1511854": {"name": "Betanudivirus", "rank": "No rank"}, "1511852": {"name": "Nudiviridae", "rank": "Family"}, "1511853": {"name": "Alphanudivirus", "rank": "No rank"}, "1388308": {"name": "Staphylococcus aureus M0462", "rank": "Strain"}, "1388309": {"name": "Staphylococcus aureus M0463", "rank": "Strain"}, "1388306": {"name": "Staphylococcus aureus M0458", "rank": "Strain"}, "1388307": {"name": "Staphylococcus aureus M0459", "rank": "Strain"}, "1388304": {"name": "Staphylococcus aureus M0454", "rank": "Strain"}, "1388305": {"name": "Staphylococcus aureus M0457", "rank": "Strain"}, "1388302": {"name": "Staphylococcus aureus M0452", "rank": "Strain"}, "1388303": {"name": "Staphylococcus aureus M0453", "rank": "Strain"}, "1511858": {"name": "Turriviridae", "rank": "Family"}, "1511859": {"name": "Alphaturrivirus", "rank": "Genus"}, "1151409": {"name": "Peptoclostridium difficile P25", "rank": "Strain"}, "1151408": {"name": "Peptoclostridium difficile P24", "rank": "Strain"}, "1151401": {"name": "Peptoclostridium difficile P11", "rank": "Strain"}, "1151400": {"name": "Peptoclostridium difficile P9", "rank": "Strain"}, "1151403": {"name": "Peptoclostridium difficile P15", "rank": "Strain"}, "1151402": {"name": "Peptoclostridium difficile P13", "rank": "Strain"}, "1151405": {"name": "Peptoclostridium difficile P20", "rank": "Strain"}, "1151404": {"name": "Peptoclostridium difficile P19", "rank": "Strain"}, "1151407": {"name": "Peptoclostridium difficile P23", "rank": "Strain"}, "1151406": {"name": "Peptoclostridium difficile P21", "rank": "Strain"}, "194326": {"name": "Lactobacillus versmoldensis", "rank": "Species"}, "1294269": {"name": "Klebsiella pneumoniae HSL4", "rank": "Strain"}, "92521": {"name": "Oryctes rhinoceros nudivirus", "rank": "Species"}, "1294263": {"name": "Clostridium straminisolvens JCM 21531", "rank": "Strain"}, "984129": {"name": "Francisella cf. novicida Fx1", "rank": "Strain"}, "197783": {"name": "Pseudomonad phage gh-1", "rank": "Species"}, "1294265": {"name": "Bacillus boroniphilus JCM 21738", "rank": "Strain"}, "1294264": {"name": "Lysinibacillus boronitolerans JCM 21713 = 10a = NBRC 103108", "rank": "Strain"}, "135858": {"name": "Catenibacterium", "rank": "Genus"}, "70863": {"name": "Shewanella oneidensis", "rank": "Species"}, "70864": {"name": "Shewanella pealeana", "rank": "Species"}, "942513": {"name": "Neisseria meningitidis WUE 2594", "rank": "Strain"}, "1442594": {"name": "Haloarcula hispanica pleomorphic virus 2", "rank": "Species"}, "1442598": {"name": "Arcobacter cibarius LMG 21996", "rank": "Strain"}, "1442599": {"name": "Luteimonas huabeiensis HB2", "rank": "Strain"}, "327386": {"name": "Unclassified Tobamovirus", "rank": "No rank"}, "348386": {"name": "Unclassified Lentivirus", "rank": "No rank"}, "103722": {"name": "Grapevine fleck virus", "rank": "Species"}, "707235": {"name": "Mycobacterium tuberculosis CTRI-2", "rank": "Strain"}, "707237": {"name": "Mycobacterium tuberculosis CTRI-4", "rank": "Strain"}, "707232": {"name": "Acinetobacter haemolyticus ATCC 19194", "rank": "Strain"}, "1214155": {"name": "Streptococcus suis 4417", "rank": "Strain"}, "1214154": {"name": "Streptococcus suis 2651", "rank": "Strain"}, "1214157": {"name": "Streptococcus suis 8830", "rank": "Strain"}, "1214156": {"name": "Streptococcus suis 12814", "rank": "Strain"}, "1214151": {"name": "Streptococcus suis 89-1591", "rank": "Strain"}, "1214150": {"name": "Streptococcus suis 161_00P5", "rank": "Strain"}, "1214153": {"name": "Streptococcus suis 5428", "rank": "Strain"}, "1214152": {"name": "Streptococcus suis RC1", "rank": "Strain"}, "686597": {"name": "Martelella sp. AD-3", "rank": "Species"}, "1214159": {"name": "Streptococcus suis 13730", "rank": "Strain"}, "1214158": {"name": "Streptococcus suis 10581", "rank": "Strain"}, "1317124": {"name": "Thioclava sp. 13D2W-2", "rank": "Species"}, "1317122": {"name": "Aquimarina sp. 22II-S11-z7", "rank": "Species"}, "1093787": {"name": "Pseudomonas aeruginosa DK2", "rank": "Strain"}, "85632": {"name": "16SrXII (Stolbur group)", "rank": "Species group"}, "413811": {"name": "Haloterrigena jeotgali", "rank": "Species"}, "1093789": {"name": "Campylobacter jejuni subsp. jejuni D2600", "rank": "Strain"}, "1093788": {"name": "Campylobacter jejuni subsp. jejuni NW", "rank": "Strain"}, "413810": {"name": "Halalkalicoccus jeotgali", "rank": "Species"}, "1437605": {"name": "Bifidobacterium actinocoloniiforme DSM 22766", "rank": "Strain"}, "1437606": {"name": "Bifidobacterium bohemicum DSM 22767", "rank": "Strain"}, "1437607": {"name": "Bifidobacterium saguini DSM 23967", "rank": "Strain"}, "1437600": {"name": "Bifidobacterium pullorum DSM 20433", "rank": "Strain"}, "1437601": {"name": "Bifidobacterium cuniculi DSM 20435", "rank": "Strain"}, "1437602": {"name": "Bifidobacterium gallinarum DSM 20670", "rank": "Strain"}, "1437603": {"name": "Bifidobacterium mongoliense DSM 21395", "rank": "Strain"}, "125627": {"name": "Thiothrix flexilis", "rank": "Species"}, "1437608": {"name": "Bifidobacterium biavatii DSM 23969", "rank": "Strain"}, "1437609": {"name": "Bifidobacterium callitrichos DSM 23973", "rank": "Strain"}, "346045": {"name": "Amycolatopsis benzoatilytica", "rank": "Species"}, "1158144": {"name": "Thioalkalivibrio sp. ALJ1", "rank": "Species"}, "1046974": {"name": "Cloacimonetes bacterium SCGC AAA255-B16", "rank": "Species"}, "82806": {"name": "Streptococcus ovis", "rank": "Species"}, "981405": {"name": "Frankia sp. Allo2", "rank": "Species"}, "1321783": {"name": "Peptostreptococcaceae bacterium oral taxon 113", "rank": "Species"}, "1321782": {"name": "Oribacterium sp. oral taxon 078 str. F0263", "rank": "Strain"}, "1321781": {"name": "Mitsuokella sp. oral taxon 131 str. W9106", "rank": "Strain"}, "1321780": {"name": "Mitsuokella sp. oral taxon 131", "rank": "Species"}, "1321786": {"name": "Selenomonas sp. oral taxon 892 str. F0426", "rank": "Strain"}, "1321785": {"name": "Selenomonas sp. oral taxon 892", "rank": "Species"}, "1321784": {"name": "Peptostreptococcaceae bacterium oral taxon 113 str. W5053", "rank": "Strain"}, "997830": {"name": "Streptococcus infantis X", "rank": "Strain"}, "1565": {"name": "Desulfotomaculum nigrificans", "rank": "Species"}, "1561": {"name": "Clostridium baratii", "rank": "Species"}, "1562": {"name": "Desulfotomaculum", "rank": "Genus"}, "1563": {"name": "Desulfosporosinus orientis", "rank": "Species"}, "1569": {"name": "Sporosarcina", "rank": "Genus"}, "12110": {"name": "Foot-and-mouth disease virus", "rank": "Species"}, "1441800": {"name": "Faba bean necrotic stunt alphasatellite 2", "rank": "Species"}, "539813": {"name": "Enterobacter mori", "rank": "Species"}, "12118": {"name": "Foot-and-mouth disease virus - type O", "rank": "Strain"}, "638617": {"name": "Bifidobacterium bohemicum", "rank": "Species"}, "491003": {"name": "Enterobacteria phage EPS7", "rank": "Species"}, "5027": {"name": "Pyrenophora", "rank": "Genus"}, "5020": {"name": "Phaeosphaeriaceae", "rank": "Family"}, "638619": {"name": "Bifidobacterium actinocoloniiforme", "rank": "Species"}, "1422325": {"name": "Staphylococcus aureus DAR5851", "rank": "Strain"}, "1422324": {"name": "Staphylococcus aureus DAR5852", "rank": "Strain"}, "1422327": {"name": "Staphylococcus aureus DAR5849", "rank": "Strain"}, "1422326": {"name": "Staphylococcus aureus DAR5850", "rank": "Strain"}, "1422321": {"name": "Staphylococcus aureus DAR5855", "rank": "Strain"}, "1422320": {"name": "Staphylococcus aureus DAR5856", "rank": "Strain"}, "1422323": {"name": "Staphylococcus aureus DAR5853", "rank": "Strain"}, "1422322": {"name": "Staphylococcus aureus DAR5854", "rank": "Strain"}, "454128": {"name": "Okra leaf curl Mali virus satellite DNA beta", "rank": "Species"}, "1422329": {"name": "Staphylococcus aureus DAR5847", "rank": "Strain"}, "1422328": {"name": "Staphylococcus aureus DAR5848", "rank": "Strain"}, "77775": {"name": "Salmonella phage FelixO1", "rank": "Species"}, "1243618": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20110353", "rank": "Strain"}, "1243619": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20110354", "rank": "Strain"}, "881953": {"name": "Lactococcus phage 949", "rank": "Species"}, "1284404": {"name": "Pseudomonas fluorescens FH5", "rank": "Strain"}, "904771": {"name": "Staphylococcus aureus subsp. aureus 21340", "rank": "Strain"}, "1161914": {"name": "Ureaplasma urealyticum 2033", "rank": "Strain"}, "1016881": {"name": "Ascocoryne sarcoides NRRL 50072", "rank": "Strain"}, "1124928": {"name": "Salmonella enterica subsp. enterica serovar Cerro str. 818", "rank": "Strain"}, "1124929": {"name": "Salmonella enterica subsp. enterica serovar Derby str. 626", "rank": "Strain"}, "1124926": {"name": "Salmonella enterica subsp. enterica serovar Berta str. ATCC 8392", "rank": "Strain"}, "1119528": {"name": "Methyloversatilis sp. FAM1", "rank": "Species"}, "1119529": {"name": "Carboxydothermus ferrireducens DSM 11255", "rank": "Strain"}, "691437": {"name": "Geobacillus sp. C56-T3", "rank": "Species"}, "1124923": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 648586-1", "rank": "Strain"}, "1124920": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 311387-1", "rank": "Strain"}, "1124921": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 419639 2-1", "rank": "Strain"}, "1402483": {"name": "Mycobacterium tuberculosis UG-D", "rank": "Strain"}, "1402480": {"name": "Mycobacterium tuberculosis UG-C", "rank": "Strain"}, "1402486": {"name": "Pseudomonas aeruginosa MSH3", "rank": "Strain"}, "1402487": {"name": "Pseudomonas aeruginosa MSH10", "rank": "Strain"}, "1402485": {"name": "Pseudomonas aeruginosa 62", "rank": "Strain"}, "1402488": {"name": "Pseudomonas aeruginosa CF127", "rank": "Strain"}, "1402489": {"name": "Pseudomonas aeruginosa CF18", "rank": "Strain"}, "278961": {"name": "Terriglobus sp. TAA 43", "rank": "Species"}, "278963": {"name": "Acidobacteriaceae bacterium TAA166", "rank": "Species"}, "1244155": {"name": "Enterococcus faecium SD3B-2", "rank": "Strain"}, "458197": {"name": "Serratia nematodiphila", "rank": "Species"}, "56698": {"name": "Sulfurospirillum arsenophilum", "rank": "Species"}, "40269": {"name": "Aliivibrio salmonicida", "rank": "Species"}, "228599": {"name": "Nocardia higoensis", "rank": "Species"}, "374844": {"name": "Enterobacteria phage G4 sensu lato", "rank": "Species"}, "766224": {"name": "Vibrio jasicida", "rank": "Species"}, "568247": {"name": "Ophioviridae", "rank": "Family"}, "1409584": {"name": "Staphylococcus aureus WMCS6055", "rank": "Strain"}, "1409585": {"name": "Staphylococcus aureus HOAG6104", "rank": "Strain"}, "1409582": {"name": "Staphylococcus aureus COAS6060", "rank": "Strain"}, "371833": {"name": "Unclassified Sapovirus", "rank": "No rank"}, "333922": {"name": "Betapapillomavirus", "rank": "Genus"}, "333923": {"name": "Human papillomavirus type 5", "rank": "Strain"}, "333920": {"name": "Equus caballus papillomavirus 1", "rank": "Strain"}, "333921": {"name": "Xipapillomavirus", "rank": "Genus"}, "333926": {"name": "Gammapapillomavirus 1", "rank": "Species"}, "374842": {"name": "Enterobacteria phage G4 clade", "rank": "No rank"}, "333924": {"name": "Betapapillomavirus 2", "rank": "Species"}, "333928": {"name": "Gammapapillomavirus 2", "rank": "Species"}, "333929": {"name": "Gammapapillomavirus 3", "rank": "Species"}, "1409568": {"name": "Staphylococcus aureus SJOS6125", "rank": "Strain"}, "1409569": {"name": "Staphylococcus aureus COAS6053", "rank": "Strain"}, "1409564": {"name": "Staphylococcus aureus SMMC6087", "rank": "Strain"}, "1409565": {"name": "Staphylococcus aureus SJOS6123", "rank": "Strain"}, "1409566": {"name": "Staphylococcus aureus COAS6052", "rank": "Strain"}, "1409567": {"name": "Staphylococcus aureus SJOS6118", "rank": "Strain"}, "1409560": {"name": "Staphylococcus aureus SCOA6048", "rank": "Strain"}, "1409561": {"name": "Staphylococcus aureus SJOS6105", "rank": "Strain"}, "1409562": {"name": "Staphylococcus aureus SJOS6106", "rank": "Strain"}, "1409563": {"name": "Staphylococcus aureus SJOS6124", "rank": "Strain"}, "641112": {"name": "Ruminococcus flavefaciens FD-1", "rank": "Strain"}, "641118": {"name": "Ochrobactrum intermedium LMG 3301", "rank": "Strain"}, "374849": {"name": "Enterobacteria phage alpha3 clade", "rank": "No rank"}, "205879": {"name": "Mycobacterium phage Omega", "rank": "Species"}, "136492": {"name": "Atopobacter phocae", "rank": "Species"}, "136491": {"name": "Atopobacter", "rank": "Genus"}, "63737": {"name": "Nostoc punctiforme PCC 73102", "rank": "Strain"}, "1175313": {"name": "Rickettsia honei RB", "rank": "Strain"}, "1420013": {"name": "Klebsiella pneumoniae 30684/NJST258_2", "rank": "Strain"}, "1420012": {"name": "Klebsiella pneumoniae 30660/NJST258_1", "rank": "Strain"}, "1071769": {"name": "Chlamydia trachomatis L1/440/LN", "rank": "Strain"}, "1071768": {"name": "Chlamydia trachomatis K/SotonK1", "rank": "Strain"}, "1122149": {"name": "Lactobacillus malefermentans DSM 5705 = KCTC 3548", "rank": "Strain"}, "1071761": {"name": "Chlamydia trachomatis E/SotonE8", "rank": "Strain"}, "1071760": {"name": "Chlamydia trachomatis E/SotonE4", "rank": "Strain"}, "1071763": {"name": "Chlamydia trachomatis F/SW5", "rank": "Strain"}, "1071762": {"name": "Chlamydia trachomatis F/SW4", "rank": "Strain"}, "1071765": {"name": "Chlamydia trachomatis G/SotonG1", "rank": "Strain"}, "336407": {"name": "Rickettsia bellii RML369-C", "rank": "Strain"}, "1071767": {"name": "Chlamydia trachomatis Ia/SotonIa3", "rank": "Strain"}, "1071766": {"name": "Chlamydia trachomatis Ia/SotonIa1", "rank": "Strain"}, "1244532": {"name": "Brucella melitensis F15/06-7", "rank": "Strain"}, "1240692": {"name": "Leptospira interrogans serovar Pomona str. CSL10083", "rank": "Strain"}, "1240691": {"name": "Leptospira interrogans serovar Pomona str. CSL4002", "rank": "Strain"}, "1244531": {"name": "Campylobacter sp. 1485E", "rank": "Species"}, "79328": {"name": "Chitinophaga", "rank": "Genus"}, "79329": {"name": "Chitinophaga pinensis", "rank": "Species"}, "1230531": {"name": "Flaviramulus ichthyoenteri", "rank": "Species"}, "289377": {"name": "Thermodesulfobacterium commune DSM 2178", "rank": "Strain"}, "289376": {"name": "Thermodesulfovibrio yellowstonii DSM 11347", "rank": "Strain"}, "1542963": {"name": "Halapricum", "rank": "Genus"}, "1477431": {"name": "Streptomyces albidoflavus group", "rank": "No rank"}, "1160711": {"name": "Mycobacterium avium subsp. hominissuis A5", "rank": "Strain"}, "748658": {"name": "Thioalkalivibrio sp. ALSr1", "rank": "Species"}, "1160712": {"name": "Mycobacterium avium subsp. hominissuis 3388", "rank": "Strain"}, "1160715": {"name": "Mycobacterium tuberculosis WX1", "rank": "Strain"}, "1160714": {"name": "Mycobacterium tuberculosis XDR1221", "rank": "Strain"}, "1160717": {"name": "Salmonella enterica subsp. enterica serovar Heidelberg str. B182", "rank": "Strain"}, "1160716": {"name": "Mycobacterium tuberculosis WX3", "rank": "Strain"}, "748652": {"name": "Thioalkalivibrio sp. ALJ15", "rank": "Species"}, "748653": {"name": "Thioalkalivibrio sp. ALJ17", "rank": "Species"}, "748651": {"name": "Thioalkalivibrio sp. ALE10", "rank": "Species"}, "1276919": {"name": "Vibrio parahaemolyticus PCV08-7", "rank": "Strain"}, "748654": {"name": "Thioalkalivibrio sp. ALJ6", "rank": "Species"}, "748655": {"name": "Thioalkalivibrio sp. ALgr1", "rank": "Species"}, "1240349": {"name": "Rhodococcus ruber Chol-4", "rank": "Strain"}, "1240348": {"name": "Salmonella enterica subsp. houtenae serovar 16:z4,z32:-- str. RKS3027", "rank": "Strain"}, "390877": {"name": "Nisaea denitrificans", "rank": "Species"}, "390876": {"name": "Nisaea", "rank": "Genus"}, "509923": {"name": "Beet cryptic virus 1", "rank": "Species"}, "390874": {"name": "Thermotoga petrophila RKU-1", "rank": "Strain"}, "192452": {"name": "Cocksfoot streak virus", "rank": "Species"}, "129138": {"name": "Pseudomonas syringae pv. morsprunorum", "rank": "Strain"}, "523850": {"name": "Thermococcus onnurineus NA1", "rank": "Strain"}, "904777": {"name": "Staphylococcus aureus subsp. aureus IS-55", "rank": "Strain"}, "904776": {"name": "Staphylococcus aureus subsp. aureus IS-24", "rank": "Strain"}, "904775": {"name": "Staphylococcus aureus subsp. aureus IS-3", "rank": "Strain"}, "904774": {"name": "Staphylococcus aureus subsp. aureus 21345", "rank": "Strain"}, "904773": {"name": "Staphylococcus aureus subsp. aureus 21343", "rank": "Strain"}, "904772": {"name": "Staphylococcus aureus subsp. aureus 21342", "rank": "Strain"}, "1287298": {"name": "Mesorhizobium sp. LSHC426A00", "rank": "Species"}, "904770": {"name": "Staphylococcus aureus subsp. aureus 21338", "rank": "Strain"}, "1121411": {"name": "Desulfomicrobium escambiense DSM 10707", "rank": "Strain"}, "1121413": {"name": "Desulfonatronovibrio hydrogenovorans DSM 9292", "rank": "Strain"}, "645170": {"name": "Brucella suis bv. 2", "rank": "Strain"}, "1287292": {"name": "Mesorhizobium sp. LSHC420B00", "rank": "Species"}, "904779": {"name": "Staphylococcus aureus subsp. aureus IS-91", "rank": "Strain"}, "1041938": {"name": "Prochlorococcus marinus bv. HNLC1", "rank": "Strain"}, "382": {"name": "Sinorhizobium meliloti", "rank": "Species"}, "380": {"name": "Sinorhizobium fredii", "rank": "Species"}, "381": {"name": "Mesorhizobium loti", "rank": "Species"}, "266808": {"name": "Thalassobacter", "rank": "Genus"}, "266809": {"name": "Thalassobacter stenotrophicus", "rank": "Species"}, "384": {"name": "Rhizobium leguminosarum", "rank": "Species"}, "385": {"name": "Rhizobium leguminosarum bv. phaseoli", "rank": "Strain"}, "266805": {"name": "Microbulbifer variabilis", "rank": "Species"}, "1345697": {"name": "Geobacillus sp. JF8", "rank": "Species"}, "1345695": {"name": "Clostridium saccharobutylicum DSM 13864", "rank": "Strain"}, "124285": {"name": "Nocardiopsis xinjiangensis", "rank": "Species"}, "1433288": {"name": "Streptococcus thermophilus MTH17CL396", "rank": "Strain"}, "1434206": {"name": "Burkholderia pseudomallei MSHR4503", "rank": "Strain"}, "1412516": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. SA20094383", "rank": "Strain"}, "1095955": {"name": "Treponema pallidum subsp. pallidum str. Sea 81-4", "rank": "Strain"}, "447325": {"name": "Tomato leaf curl Philippine betasatellite", "rank": "Species"}, "411361": {"name": "Halosarcina pallida", "rank": "Species"}, "411360": {"name": "Halosarcina", "rank": "Genus"}, "526968": {"name": "Bacillus cereus R309803", "rank": "Strain"}, "526969": {"name": "Bacillus cereus m1550", "rank": "Strain"}, "536444": {"name": "Cyanophage P-RSM1", "rank": "Species"}, "526967": {"name": "Bacillus cereus 172560W", "rank": "Strain"}, "1559373": {"name": "Jatropha leaf crumple India virus", "rank": "Species"}, "767892": {"name": "Candidatus Puniceispirillum marinum", "rank": "Species"}, "767891": {"name": "Candidatus Puniceispirillum", "rank": "Genus"}, "93224": {"name": "Spiroplasma phage SVTS2", "rank": "Species"}, "93222": {"name": "Pandoraea sputorum", "rank": "Species"}, "93221": {"name": "Pandoraea pulmonicola", "rank": "Species"}, "93220": {"name": "Pandoraea pnomenusa", "rank": "Species"}, "1173780": {"name": "Salmonella enterica subsp. diarizonae serovar 60:r:e,n,x,z15 str. 01-0170", "rank": "Strain"}, "57678": {"name": "Leptospira interrogans serovar Lai", "rank": "Strain"}, "1279384": {"name": "Eggerthia", "rank": "Genus"}, "1279388": {"name": "Kandleria", "rank": "Genus"}, "592977": {"name": "Bifidobacterium stercoris", "rank": "Species"}, "57676": {"name": "Rhizobium mongolense", "rank": "Species"}, "1124597": {"name": "Magnetococcus marinus", "rank": "Species"}, "696868": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. PT23", "rank": "Strain"}, "1306407": {"name": "Treponema phagedenis 4A", "rank": "Strain"}, "696863": {"name": "Spring viraemia of carp virus", "rank": "Species"}, "696865": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. SE10", "rank": "Strain"}, "696864": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. 20037", "rank": "Strain"}, "696867": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. 18569", "rank": "Strain"}, "696866": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. 13-1", "rank": "Strain"}, "11591": {"name": "Uukuniemi virus", "rank": "Species"}, "107465": {"name": "Teloschistales", "rank": "Order"}, "574093": {"name": "Streptococcus pneumoniae AP200", "rank": "Strain"}, "33889": {"name": "Brevibacterium casei", "rank": "Species"}, "196089": {"name": "Tomato black ring virus satellite RNA", "rank": "Species"}, "33882": {"name": "Microbacterium", "rank": "Genus"}, "33886": {"name": "Rathayibacter", "rank": "Genus"}, "1417141": {"name": "Staphylococcus aureus F85184", "rank": "Strain"}, "1276648": {"name": "Propionibacterium acnes hdn-1", "rank": "Strain"}, "104270": {"name": "Tenacibaculum ovolyticum", "rank": "Species"}, "444861": {"name": "Prochlorococcus phage Syn1", "rank": "Species"}, "1181765": {"name": "Escherichia coli KTE219", "rank": "Strain"}, "1181764": {"name": "Escherichia coli KTE218", "rank": "Strain"}, "1181767": {"name": "Escherichia coli KTE221", "rank": "Strain"}, "1181766": {"name": "Escherichia coli KTE220", "rank": "Strain"}, "1181761": {"name": "Escherichia coli KTE215", "rank": "Strain"}, "1181760": {"name": "Escherichia coli KTE214", "rank": "Strain"}, "1181763": {"name": "Escherichia coli KTE217", "rank": "Strain"}, "1181762": {"name": "Escherichia coli KTE216", "rank": "Strain"}, "1379": {"name": "Gemella haemolysans", "rank": "Species"}, "1181769": {"name": "Escherichia coli KTE223", "rank": "Strain"}, "1181768": {"name": "Escherichia coli KTE222", "rank": "Strain"}, "1378": {"name": "Gemella", "rank": "Genus"}, "11709": {"name": "Human immunodeficiency virus 2", "rank": "Species"}, "1306399": {"name": "Escherichia coli ONT:H33", "rank": "Strain"}, "29549": {"name": "Rhodothermus marinus", "rank": "Species"}, "29548": {"name": "Rhodothermus", "rank": "Genus"}, "29547": {"name": "Epsilonproteobacteria", "rank": "Class"}, "29546": {"name": "Lawsonia intracellularis", "rank": "Species"}, "29543": {"name": "Pelobacter propionicus", "rank": "Species"}, "29540": {"name": "Natrialba asiatica DSM 12278", "rank": "Strain"}, "478547": {"name": "Campylobacter jejuni subsp. jejuni CG8421", "rank": "Strain"}, "1274401": {"name": "Candidatus Hepatobacter", "rank": "Genus"}, "1274400": {"name": "Enterobacter sp. Bisph2", "rank": "Species"}, "1274403": {"name": "Legionella oakridgensis RV-2-2007", "rank": "Strain"}, "1274402": {"name": "Candidatus Hepatobacter penaei", "rank": "Species"}, "1306398": {"name": "Escherichia coli O127:H27", "rank": "Strain"}, "658089": {"name": "Lachnospiraceae bacterium 5_1_63FAA", "rank": "Species"}, "658088": {"name": "Lachnospiraceae bacterium 9_1_43BFAA", "rank": "Species"}, "658085": {"name": "Lachnospiraceae bacterium 5_1_57FAA", "rank": "Species"}, "658087": {"name": "Lachnospiraceae bacterium 7_1_58FAA", "rank": "Species"}, "658086": {"name": "Lachnospiraceae bacterium 3_1_57FAA_CT1", "rank": "Species"}, "658081": {"name": "Lachnospiraceae bacterium 1_1_57FAA", "rank": "Species"}, "658080": {"name": "Ralstonia sp. 5_2_56FAA", "rank": "Species"}, "658083": {"name": "Lachnospiraceae bacterium 6_1_63FAA", "rank": "Species"}, "658082": {"name": "Lachnospiraceae bacterium 2_1_58FAA", "rank": "Species"}, "437444": {"name": "Acidianus bottle-shaped virus", "rank": "Species"}, "2020": {"name": "Thermomonospora curvata", "rank": "Species"}, "2021": {"name": "Thermobifida fusca", "rank": "Species"}, "2023": {"name": "Thermoactinomyces", "rank": "Genus"}, "715225": {"name": "Paenibacillus vortex V453", "rank": "Strain"}, "364410": {"name": "Granulibacter bethesdensis", "rank": "Species"}, "1147044": {"name": "Staphylococcus phage StB27", "rank": "Species"}, "715226": {"name": "Asticcacaulis biprosthecum C19", "rank": "Strain"}, "1147042": {"name": "Staphylococcus phage StB12", "rank": "Species"}, "1147043": {"name": "Staphylococcus phage StB20", "rank": "Species"}, "715223": {"name": "California sea lion polyomavirus 1", "rank": "Species"}, "715222": {"name": "Caldicoprobacter", "rank": "Genus"}, "644524": {"name": "Burkholderia phage BcepIL02", "rank": "Species"}, "1109721": {"name": "Shigella phage EP23", "rank": "Species"}, "558170": {"name": "Salinicoccus carnicancri", "rank": "Species"}, "558173": {"name": "Corynebacterium doosanense CAU 212 = DSM 45436", "rank": "Strain"}, "65393": {"name": "Cyanothece sp. PCC 7424", "rank": "Species"}, "1439074": {"name": "Streptococcus pyogenes ABC020032535", "rank": "Strain"}, "658661": {"name": "Parabacteroides sp. D25", "rank": "Species"}, "658663": {"name": "Porphyromonas sp. 31_2", "rank": "Species"}, "658664": {"name": "Ralstonia sp. 5_7_47FAA", "rank": "Species"}, "66284": {"name": "Shigella phage SfII", "rank": "Species"}, "1439070": {"name": "Streptococcus pyogenes ABC020032182", "rank": "Strain"}, "187452": {"name": "Pediococcus claussenii", "rank": "Species"}, "192222": {"name": "Campylobacter jejuni subsp. jejuni NCTC 11168 = ATCC 700819", "rank": "Strain"}, "143393": {"name": "Eubacterium sulci", "rank": "Species"}, "553217": {"name": "Enhydrobacter aerosaccus SK60", "rank": "Strain"}, "1406134": {"name": "Murrumbidgee virus", "rank": "Species"}, "871738": {"name": "Dehalobacter restrictus DSM 9455", "rank": "Strain"}, "1766": {"name": "Mycobacterium fortuitum", "rank": "Species"}, "1767": {"name": "Mycobacterium intracellulare", "rank": "Species"}, "1764": {"name": "Mycobacterium avium", "rank": "Species"}, "1765": {"name": "Mycobacterium bovis", "rank": "Species"}, "1762": {"name": "Mycobacteriaceae", "rank": "Family"}, "1763": {"name": "Mycobacterium", "rank": "Genus"}, "1760": {"name": "Actinobacteria", "rank": "Class"}, "38767": {"name": "Duvenhage virus", "rank": "Species"}, "38766": {"name": "Lagos bat virus", "rank": "Species"}, "1768": {"name": "Mycobacterium kansasii", "rank": "Species"}, "1769": {"name": "Mycobacterium leprae", "rank": "Species"}, "991946": {"name": "Vibrio cholerae HE-45", "rank": "Strain"}, "991947": {"name": "Vibrio cholerae HE48", "rank": "Strain"}, "1463809": {"name": "Mycobacterium phage 39HC", "rank": "Species"}, "991945": {"name": "Vibrio cholerae HE39", "rank": "Strain"}, "991942": {"name": "Vibrio cholerae HC-61A1", "rank": "Strain"}, "991943": {"name": "Vibrio cholerae HC-61A2", "rank": "Strain"}, "991940": {"name": "Vibrio cholerae HC-46A1", "rank": "Strain"}, "991941": {"name": "Vibrio cholerae HC-46B1", "rank": "Strain"}, "52018": {"name": "Unclassified Actinobacteria", "rank": "No rank"}, "991948": {"name": "Vibrio cholerae HC-02A1", "rank": "Strain"}, "991949": {"name": "Vibrio cholerae HC-02C1", "rank": "Strain"}, "866628": {"name": "Legionella pneumophila 130b", "rank": "Strain"}, "866629": {"name": "Mycoplasma leachii 99/014/6", "rank": "Strain"}, "1171378": {"name": "Brucella suis 019", "rank": "Strain"}, "1171375": {"name": "Burkholderia terrae BS001", "rank": "Strain"}, "1171377": {"name": "Bibersteinia trehalosi USDA-ARS-USMARC-192", "rank": "Strain"}, "1171376": {"name": "Salmonella enterica subsp. enterica serovar Typhimurium str. U288", "rank": "Strain"}, "1171373": {"name": "Propionibacterium acidipropionici ATCC 4875", "rank": "Strain"}, "53946": {"name": "Octadecabacter arcticus", "rank": "Species"}, "1408453": {"name": "Mycoplasma alvi ATCC 29626", "rank": "Strain"}, "53945": {"name": "Octadecabacter", "rank": "Genus"}, "868597": {"name": "Stenotrophomonas maltophilia JV3", "rank": "Strain"}, "868595": {"name": "Desulfotomaculum carboxydivorans CO-1-SRB", "rank": "Strain"}, "760775": {"name": "Streptococcus pneumoniae GA13856", "rank": "Strain"}, "1292030": {"name": "Pseudomonas taiwanensis DSM 21245", "rank": "Strain"}, "1292031": {"name": "Pseudomonas vranovensis DSM 16006", "rank": "Strain"}, "1292032": {"name": "Salinibacillus aidingensis MSP4", "rank": "Strain"}, "1292033": {"name": "Mycoplasma putrefaciens Mput9231", "rank": "Strain"}, "1292034": {"name": "Caulobacter crescentus OR37", "rank": "Strain"}, "552810": {"name": "Dehalogenimonas lykanthroporepellens", "rank": "Species"}, "1292036": {"name": "Clostridium sordellii ATCC 9714", "rank": "Strain"}, "1292038": {"name": "Propionibacterium acnes PA2", "rank": "Strain"}, "1292039": {"name": "Propionibacterium acnes P6", "rank": "Strain"}, "397948": {"name": "Caldivirga maquilingensis IC-167", "rank": "Strain"}, "397945": {"name": "Acidovorax citrulli AAC00-1", "rank": "Strain"}, "872331": {"name": "Mycoplasma hyorhinis HUB-1", "rank": "Strain"}, "1460083": {"name": "Serratia liquefaciens FK01", "rank": "Strain"}, "993047": {"name": "Rhizobium etli CNPAF512", "rank": "Strain"}, "217161": {"name": "Chamaesiphon", "rank": "Genus"}, "1307799": {"name": "Pegivirus", "rank": "Genus"}, "523742": {"name": "Marinobacter santoriniensis", "rank": "Species"}, "51453": {"name": "Trichoderma reesei", "rank": "Species"}, "764544": {"name": "Staphylococcus epidermidis FRI909", "rank": "Strain"}, "178469": {"name": "Arenibacter", "rank": "Genus"}, "583346": {"name": "Clostridium kluyveri NBRC 12016", "rank": "Strain"}, "583345": {"name": "Methylotenera mobilis JLW8", "rank": "Strain"}, "46014": {"name": "Acholeplasma phage L2", "rank": "Species"}, "46015": {"name": "Autographa californica nucleopolyhedrovirus", "rank": "Strain"}, "160699": {"name": "Agrobacterium larrymoorei", "rank": "Species"}, "1513241": {"name": "Dyonupapillomavirus", "rank": "Genus"}, "1513240": {"name": "Dyomupapillomavirus", "rank": "Genus"}, "1513243": {"name": "Dyopipapillomavirus", "rank": "Genus"}, "1513242": {"name": "Dyoomikronpapillomavirus", "rank": "Genus"}, "1513245": {"name": "Dyosigmapapillomavirus", "rank": "Genus"}, "1513244": {"name": "Dyorhopapillomavirus", "rank": "Genus"}, "1513246": {"name": "Dyoxipapillomavirus", "rank": "Genus"}, "1513249": {"name": "Dyomupapillomavirus 1", "rank": "Species"}, "1513248": {"name": "Dyolambdapapillomavirus 1", "rank": "Species"}, "888817": {"name": "Streptococcus sanguinis SK405", "rank": "Strain"}, "888816": {"name": "Streptococcus sanguinis SK355", "rank": "Strain"}, "874272": {"name": "Lizard adenovirus 2", "rank": "Species"}, "888810": {"name": "Streptococcus sanguinis SK115", "rank": "Strain"}, "888813": {"name": "Streptococcus sanguinis SK330", "rank": "Strain"}, "888812": {"name": "Streptococcus sanguinis SK160", "rank": "Strain"}, "150829": {"name": "Treponema azotonutricium", "rank": "Species"}, "389230": {"name": "Bat coronavirus (BtCoV/133/2005)", "rank": "Species"}, "47839": {"name": "Mycobacterium triplex", "rank": "Species"}, "47838": {"name": "Chino del tomate virus", "rank": "Species"}, "999429": {"name": "Treponema denticola ATCC 33521", "rank": "Strain"}, "999428": {"name": "Treponema denticola ATCC 33520", "rank": "Strain"}, "310539": {"name": "Listonella phage phiHSIC", "rank": "Species"}, "999421": {"name": "Parabacteroides merdae CL09T00C40", "rank": "Strain"}, "999420": {"name": "Parabacteroides merdae CL03T12C32", "rank": "Strain"}, "999423": {"name": "Selenomonas sp. F0473", "rank": "Species"}, "999422": {"name": "Prevotella maculosa OT 289", "rank": "Strain"}, "999425": {"name": "Streptococcus sp. F0442", "rank": "Species"}, "999424": {"name": "Streptococcus sp. F0441", "rank": "Species"}, "999427": {"name": "Treponema denticola ASLM", "rank": "Strain"}, "999426": {"name": "Treponema denticola AL-2", "rank": "Strain"}, "1240761": {"name": "Escherichia coli O104:H4 str. Ec11-4984", "rank": "Strain"}, "409304": {"name": "Candidatus Ishikawaella", "rank": "Genus"}, "78259": {"name": "Scardovia inopinata", "rank": "Species"}, "78258": {"name": "Parascardovia denticolens", "rank": "Species"}, "117573": {"name": "Mitosporic Ophiostomataceae", "rank": "No rank"}, "1243181": {"name": "Yersinia enterocolitica IP 10393", "rank": "Strain"}, "117574": {"name": "Unclassified Microviridae", "rank": "No rank"}, "2378": {"name": "Sporomusa ovata", "rank": "Species"}, "367806": {"name": "Blattabacterium sp. (Blatta orientalis)", "rank": "Species"}, "1034836": {"name": "Bacillus amyloliquefaciens XH7", "rank": "Strain"}, "216614": {"name": "Daphne virus S", "rank": "Species"}, "710685": {"name": "Mycobacterium rhodesiae NBB3", "rank": "Strain"}, "941770": {"name": "Lactobacillus fructivorans KCTC 3543 = DSM 20203", "rank": "Strain"}, "470735": {"name": "Brucella inopinata BO1", "rank": "Strain"}, "1291315": {"name": "Leptospira interrogans serovar Copenhageni str. 2006006972", "rank": "Strain"}, "1291316": {"name": "Leptospira interrogans serovar Copenhageni str. 2006006982", "rank": "Strain"}, "1291317": {"name": "Leptospira interrogans serovar Copenhageni str. 2002000634", "rank": "Strain"}, "1291318": {"name": "Leptospira interrogans serovar Copenhageni str. 2002009669", "rank": "Strain"}, "1291319": {"name": "Leptospira interrogans serovar Copenhageni str. 2007005490", "rank": "Strain"}, "749520": {"name": "Enterococcus faecium TX0082", "rank": "Strain"}, "1104671": {"name": "Marinimicrobia bacterium JGI 0000090-C20", "rank": "Species"}, "1104679": {"name": "Pseudomonas syringae pv. actinidiae ICMP 18708", "rank": "Strain"}, "749529": {"name": "Escherichia coli MS 57-2", "rank": "Strain"}, "749528": {"name": "Escherichia coli MS 45-1", "rank": "Strain"}, "433357": {"name": "Bidens mottle virus", "rank": "Species"}, "142877": {"name": "Desulfitobacterium metallireducens", "rank": "Species"}, "95342": {"name": "Sapporo virus", "rank": "Species"}, "1590370": {"name": "Betacoronavirus HKU24", "rank": "Species"}, "512769": {"name": "Streptococcus pneumoniae BS458", "rank": "Strain"}, "1318598": {"name": "Unclassified Dehalococcoidia", "rank": "No rank"}, "512768": {"name": "Streptococcus pneumoniae BS457", "rank": "Strain"}, "504728": {"name": "Meiothermus ruber DSM 1279", "rank": "Strain"}, "1286140": {"name": "Hana virus", "rank": "Species"}, "1223802": {"name": "Sulfuritalea hydrogenivorans sk43H", "rank": "Strain"}, "1115829": {"name": "Streptococcus pyogenes GA19702", "rank": "Strain"}, "1115828": {"name": "Streptococcus pyogenes GA03747", "rank": "Strain"}, "1115827": {"name": "Streptococcus pyogenes GA40884", "rank": "Strain"}, "1115826": {"name": "Streptococcus pyogenes GA03799", "rank": "Strain"}, "1115825": {"name": "Streptococcus pyogenes GA03455", "rank": "Strain"}, "1115824": {"name": "Streptococcus pyogenes GA03805", "rank": "Strain"}, "1115823": {"name": "Streptococcus pyogenes GA40377", "rank": "Strain"}, "1115822": {"name": "Streptococcus pyogenes GA41394", "rank": "Strain"}, "1115821": {"name": "Streptococcus pyogenes GA40056", "rank": "Strain"}, "1115820": {"name": "Streptococcus pyogenes GA41208", "rank": "Strain"}, "909208": {"name": "Malpais Spring virus", "rank": "Species"}, "909209": {"name": "Escherichia albertii TW08933", "rank": "Strain"}, "1295076": {"name": "Pseudomonas aeruginosa PA45", "rank": "Strain"}, "1130299": {"name": "Crenarchaeote SCGC AAA261-C22", "rank": "Species"}, "512562": {"name": "Helicobacter pylori Shi470", "rank": "Strain"}, "1431825": {"name": "Candidatus Omnitrophus fodinae", "rank": "Species"}, "1431823": {"name": "Candidatus Omnitrophus", "rank": "Genus"}, "1388579": {"name": "Staphylococcus aureus M0788", "rank": "Strain"}, "1388578": {"name": "Staphylococcus aureus M0786", "rank": "Strain"}, "1388575": {"name": "Staphylococcus aureus M0783", "rank": "Strain"}, "1388574": {"name": "Staphylococcus aureus M0782", "rank": "Strain"}, "1388577": {"name": "Staphylococcus aureus M0785", "rank": "Strain"}, "1388576": {"name": "Staphylococcus aureus M0784", "rank": "Strain"}, "1388571": {"name": "Staphylococcus aureus M0777", "rank": "Strain"}, "1388570": {"name": "Staphylococcus aureus M0775", "rank": "Strain"}, "1388573": {"name": "Staphylococcus aureus M0779", "rank": "Strain"}, "1409465": {"name": "Staphylococcus aureus AMMC6008", "rank": "Strain"}, "1379159": {"name": "Dyella jiangningensis", "rank": "Species"}, "670307": {"name": "Hyphomicrobium denitrificans 1NES1", "rank": "Strain"}, "703613": {"name": "Bifidobacterium animalis subsp. animalis ATCC 25527", "rank": "Strain"}, "703612": {"name": "Bacillus subtilis subsp. spizizenii ATCC 6633", "rank": "Strain"}, "712215": {"name": "Capnocytophaga sp. oral taxon 335", "rank": "Species"}, "712217": {"name": "Capnocytophaga sp. oral taxon 380", "rank": "Species"}, "712216": {"name": "Capnocytophaga sp. oral taxon 336", "rank": "Species"}, "712211": {"name": "Capnocytophaga sp. oral taxon 324", "rank": "Species"}, "96491": {"name": "Gill-associated virus", "rank": "Species"}, "712212": {"name": "Capnocytophaga sp. oral taxon 326", "rank": "Species"}, "141693": {"name": "Nocardiopsis kunsanensis", "rank": "Species"}, "712218": {"name": "Capnocytophaga sp. oral taxon 412", "rank": "Species"}, "1409467": {"name": "Staphylococcus aureus LAMC0001", "rank": "Strain"}, "68525": {"name": "Delta/epsilon subdivisions", "rank": "Subphylum"}, "1197130": {"name": "Halococcus sp. 197A", "rank": "Species"}, "1394664": {"name": "Vibrio parahaemolyticus S130", "rank": "Strain"}, "1394665": {"name": "Vibrio parahaemolyticus S131", "rank": "Strain"}, "1394666": {"name": "Vibrio parahaemolyticus S132", "rank": "Strain"}, "1394660": {"name": "Vibrio parahaemolyticus S125", "rank": "Strain"}, "1394661": {"name": "Vibrio parahaemolyticus S126", "rank": "Strain"}, "1394662": {"name": "Vibrio parahaemolyticus S128", "rank": "Strain"}, "1185660": {"name": "Xanthomonas axonopodis pv. manihotis str. CIO151", "rank": "Strain"}, "1394668": {"name": "Vibrio parahaemolyticus S134", "rank": "Strain"}, "1394669": {"name": "Vibrio parahaemolyticus S135", "rank": "Strain"}, "564421": {"name": "Pseudomonas fluorescens NZ052", "rank": "Strain"}, "1409622": {"name": "Staphylococcus aureus MISS6131", "rank": "Strain"}, "10639": {"name": "Caulimovirus", "rank": "Genus"}, "911092": {"name": "Caldanaerobacter subterraneus", "rank": "Species"}, "10634": {"name": "Murine polyomavirus", "rank": "Species"}, "10633": {"name": "Simian virus 40", "rank": "Species"}, "10632": {"name": "JC polyomavirus", "rank": "Species"}, "1427331": {"name": "Bartonella bacilliformis Peru-18", "rank": "Strain"}, "518829": {"name": "Okra leaf curl alphasatellite", "rank": "Species"}, "47000": {"name": "Equine rhinitis A virus", "rank": "Species"}, "1422746": {"name": "Staphylococcus aureus VET1910R", "rank": "Strain"}, "938763": {"name": "Beta proteobacterium SCGC AAA024-K11", "rank": "Species"}, "223967": {"name": "Methylobacterium populi", "rank": "Species"}, "106841": {"name": "Cryptococcus", "rank": "Genus"}, "1388060": {"name": "Staphylococcus aureus M0101", "rank": "Strain"}, "930170": {"name": "Bacillus thuringiensis serovar finitimus YBT-020", "rank": "Strain"}, "930171": {"name": "Arthrobacter phenanthrenivorans Sphe3", "rank": "Strain"}, "1169862": {"name": "Escherichia coli NCCP15658", "rank": "Strain"}, "1169863": {"name": "Escherichia coli NCCP15657", "rank": "Strain"}, "1446560": {"name": "Escherichia coli O121:H19 str. 2010C-3609", "rank": "Strain"}, "80869": {"name": "Acidovorax citrulli", "rank": "Species"}, "186768": {"name": "Mitovirus", "rank": "Genus"}, "186769": {"name": "Cryphonectria parasitica mitovirus 1-NB631", "rank": "Species"}, "186766": {"name": "Narnaviridae", "rank": "Family"}, "186767": {"name": "Narnavirus", "rank": "Genus"}, "748247": {"name": "Azoarcus sp. KH32C", "rank": "Species"}, "186765": {"name": "Lambdalikevirus", "rank": "Genus"}, "80865": {"name": "Delftia", "rank": "Genus"}, "80864": {"name": "Comamonadaceae", "rank": "Family"}, "80867": {"name": "Acidovorax avenae", "rank": "Species"}, "80866": {"name": "Delftia acidovorans", "rank": "Species"}, "1446668": {"name": "Escherichia coli O157:H7 str. K1845", "rank": "Strain"}, "1446669": {"name": "Escherichia coli O157:H7 str. K1921", "rank": "Strain"}, "1446662": {"name": "Escherichia coli O157:H7 str. H2498", "rank": "Strain"}, "1287055": {"name": "Brachyspira hampsonii", "rank": "Species"}, "1446660": {"name": "Escherichia coli O157:H7 str. G5303", "rank": "Strain"}, "1446661": {"name": "Escherichia coli O157:H7 str. H2495", "rank": "Strain"}, "1446666": {"name": "Escherichia coli O157:H7 str. K1795", "rank": "Strain"}, "1446667": {"name": "Escherichia coli O157:H7 str. K1796", "rank": "Strain"}, "1446664": {"name": "Escherichia coli O157:H7 str. K1792", "rank": "Strain"}, "1446665": {"name": "Escherichia coli O157:H7 str. K1793", "rank": "Strain"}, "1124468": {"name": "Vibrio cholerae O1 str. 2010EL-1749", "rank": "Strain"}, "868209": {"name": "Escherichia coli DEC15D", "rank": "Strain"}, "1261072": {"name": "Bifidobacterium breve JCP7499", "rank": "Strain"}, "1422749": {"name": "Staphylococcus aureus VET1913R", "rank": "Strain"}, "1261070": {"name": "Gardnerella vaginalis JCP8481B", "rank": "Strain"}, "1261071": {"name": "Gardnerella vaginalis JCP8522", "rank": "Strain"}, "315730": {"name": "Bacillus weihenstephanensis KBAB4", "rank": "Strain"}, "1411697": {"name": "Escherichia coli 1365", "rank": "Strain"}, "34348": {"name": "Mixia", "rank": "Genus"}, "519849": {"name": "Ureaplasma urealyticum serovar 7 str. ATCC 27819", "rank": "Strain"}, "34346": {"name": "Schizosaccharomycetales", "rank": "Order"}, "904346": {"name": "Staphylococcus lugdunensis VCU139", "rank": "Strain"}, "904347": {"name": "Staphylococcus epidermidis VCU144", "rank": "Strain"}, "904344": {"name": "Staphylococcus epidermidis VCU128", "rank": "Strain"}, "904345": {"name": "Staphylococcus epidermidis VCU129", "rank": "Strain"}, "904342": {"name": "Staphylococcus epidermidis VCU126", "rank": "Strain"}, "904343": {"name": "Staphylococcus epidermidis VCU127", "rank": "Strain"}, "904340": {"name": "Staphylococcus epidermidis VCU123", "rank": "Strain"}, "904341": {"name": "Staphylococcus epidermidis VCU125", "rank": "Strain"}, "1411696": {"name": "Escherichia coli 1350", "rank": "Strain"}, "46351": {"name": "Mycobacterium hassiacum", "rank": "Species"}, "46350": {"name": "Adeno-associated virus - 3", "rank": "Strain"}, "46352": {"name": "Agrococcus", "rank": "Genus"}, "46355": {"name": "Spirochaeta africana", "rank": "Species"}, "46354": {"name": "Thermoanaerobacter wiegelii", "rank": "Species"}, "46356": {"name": "Spirochaeta alkalica", "rank": "Species"}, "1327037": {"name": "Croceibacter phage P2559Y", "rank": "Species"}, "1327036": {"name": "Mycobacterium phage WIVsmall", "rank": "Species"}, "1327035": {"name": "Mycobacterium phage CASbig", "rank": "Species"}, "339965": {"name": "Malvastrum leaf curl betasatellite", "rank": "Species"}, "1434164": {"name": "Shigella flexneri 2002091", "rank": "Strain"}, "1434165": {"name": "Shigella flexneri 2002106", "rank": "Strain"}, "1391746": {"name": "Tomato yellow leaf curl Saudi virus", "rank": "Species"}, "1434167": {"name": "Shigella flexneri 2002140", "rank": "Strain"}, "1434160": {"name": "Shigella flexneri 2001044", "rank": "Strain"}, "1434161": {"name": "Shigella flexneri 2002021", "rank": "Strain"}, "1434162": {"name": "Shigella flexneri 2002028", "rank": "Strain"}, "1434163": {"name": "Shigella flexneri 2002069", "rank": "Strain"}, "1434168": {"name": "Shigella flexneri 2003035", "rank": "Strain"}, "1434169": {"name": "Shigella flexneri 2005002", "rank": "Strain"}, "908339": {"name": "Lactobacillus oris PB013-T2-3", "rank": "Strain"}, "1229276": {"name": "Sphingobacterium sp. ACCC 05744", "rank": "Species"}, "1283331": {"name": "Azotobacter vinelandii CA6", "rank": "Strain"}, "1283330": {"name": "Azotobacter vinelandii CA", "rank": "Strain"}, "1170229": {"name": "Penicillium digitatum PHI26", "rank": "Strain"}, "1170227": {"name": "Candidatus Methylomirabilis", "rank": "Genus"}, "513052": {"name": "Burkholderia multivorans CGD2", "rank": "Strain"}, "513053": {"name": "Burkholderia multivorans CGD2M", "rank": "Strain"}, "513050": {"name": "Dictyoglomus turgidum", "rank": "Species"}, "513051": {"name": "Burkholderia multivorans CGD1", "rank": "Strain"}, "1408208": {"name": "Pseudomonas aeruginosa PFK10", "rank": "Strain"}, "258052": {"name": "Kitasatospora arboriphila", "rank": "Species"}, "246875": {"name": "Algoriphagus", "rank": "Genus"}, "246874": {"name": "Cryomorphaceae", "rank": "Family"}, "246873": {"name": "Crocinitomix", "rank": "Genus"}, "458032": {"name": "Candidatus Chloracidobacterium", "rank": "Genus"}, "458033": {"name": "Candidatus Chloracidobacterium thermophilum", "rank": "Species"}, "458031": {"name": "Unclassified Acidobacteria", "rank": "No rank"}, "12092": {"name": "Hepatitis A virus", "rank": "Species"}, "12091": {"name": "Hepatovirus", "rank": "Genus"}, "1090320": {"name": "Sphingomonas melonis DAPP-PG 224", "rank": "Strain"}, "1281184": {"name": "Escherichia coli UMEA 3113-1", "rank": "Strain"}, "1090322": {"name": "Methanolobus tindarius DSM 2278", "rank": "Strain"}, "147448": {"name": "Staphylococcus carnosus subsp. carnosus", "rank": "Subspecies"}, "1246445": {"name": "Nocardiopsis kunsanensis DSM 44524", "rank": "Strain"}, "5197": {"name": "Lecanorales", "rank": "Order"}, "500485": {"name": "Penicillium rubens Wisconsin 54-1255", "rank": "Strain"}, "927677": {"name": "Synechocystis sp. PCC 7509", "rank": "Species"}, "1192759": {"name": "Sphingobium xenophagum QYY", "rank": "Strain"}, "419942": {"name": "Sulfolobus islandicus Y.N.15.51", "rank": "Strain"}, "419947": {"name": "Mycobacterium tuberculosis H37Ra", "rank": "Strain"}, "1281134": {"name": "Escherichia coli HVH 207 (4-3113221)", "rank": "Strain"}, "1203226": {"name": "Brachyspira hampsonii bv. II", "rank": "Strain"}, "1409751": {"name": "Staphylococcus aureus DAR3165", "rank": "Strain"}, "1154820": {"name": "Streptococcus agalactiae LMG 15091", "rank": "Strain"}, "1281136": {"name": "Escherichia coli HVH 209 (4-3062651)", "rank": "Strain"}, "519014": {"name": "Aquareovirus G", "rank": "Species"}, "519015": {"name": "Pepper leaf curl Yunnan virus-YN323", "rank": "Strain"}, "519016": {"name": "Pepper leaf curl Yunnan virus satellite DNA beta", "rank": "Species"}, "1154821": {"name": "Streptococcus agalactiae LMG 15092", "rank": "Strain"}, "221066": {"name": "Kordia algicida", "rank": "Species"}, "221065": {"name": "Kordia", "rank": "Genus"}, "1116476": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. 58-6482", "rank": "Strain"}, "1116471": {"name": "Escherichia coli BCE008_MS-13", "rank": "Strain"}, "1154822": {"name": "Streptococcus agalactiae LMG 15093", "rank": "Strain"}, "1281130": {"name": "Escherichia coli HVH 203 (4-3126218)", "rank": "Strain"}, "1413585": {"name": "Staphylococcus aureus ZTA11/00189-8HSA", "rank": "Strain"}, "1413584": {"name": "Staphylococcus aureus ZTA09/03745-9HSA", "rank": "Strain"}, "1413587": {"name": "Staphylococcus aureus 11P4", "rank": "Strain"}, "1603259": {"name": "Escherichia coli O139:H28", "rank": "Strain"}, "1413581": {"name": "Staphylococcus aureus ZTA10/02412-8HSA", "rank": "Strain"}, "1311759": {"name": "Mannheimia haemolytica D171", "rank": "Strain"}, "766733": {"name": "Scheffersomyces", "rank": "Genus"}, "1413582": {"name": "Staphylococcus aureus ZTA09/03734-9HSA", "rank": "Strain"}, "768": {"name": "Anaplasma", "rank": "Genus"}, "41524": {"name": "Salmonella enterica subsp. houtenae serovar 16:z4,z32:--", "rank": "Strain"}, "1413589": {"name": "Staphylococcus aureus 36P1", "rank": "Strain"}, "1413588": {"name": "Staphylococcus aureus 11P8", "rank": "Strain"}, "769": {"name": "Anaplasma centrale", "rank": "Species"}, "1409393": {"name": "Staphylococcus aureus SJOS6076", "rank": "Strain"}, "1409392": {"name": "Staphylococcus aureus HOAG6057", "rank": "Strain"}, "1409391": {"name": "Staphylococcus aureus HOAG6054", "rank": "Strain"}, "1409390": {"name": "Staphylococcus aureus MISS6012", "rank": "Strain"}, "1409397": {"name": "Staphylococcus aureus SCOA6011", "rank": "Strain"}, "1409396": {"name": "Staphylococcus aureus OCMM6037", "rank": "Strain"}, "1409395": {"name": "Staphylococcus aureus OCMM6035", "rank": "Strain"}, "1409394": {"name": "Staphylococcus aureus LAMC0037", "rank": "Strain"}, "1409399": {"name": "Staphylococcus aureus SMMC6051", "rank": "Strain"}, "1409398": {"name": "Staphylococcus aureus SCOA6012", "rank": "Strain"}, "1154893": {"name": "Streptococcus agalactiae GB00012", "rank": "Strain"}, "348780": {"name": "Natronomonas pharaonis DSM 2160", "rank": "Strain"}, "1074157": {"name": "Streptococcus mutans TCI-212", "rank": "Strain"}, "1154892": {"name": "Streptococcus agalactiae GB00003", "rank": "Strain"}, "936350": {"name": "Rhizobium leguminosarum bv. phaseoli 4292", "rank": "Strain"}, "936351": {"name": "Bifidobacterium breve S27", "rank": "Strain"}, "1281138": {"name": "Escherichia coli HVH 211 (4-3041891)", "rank": "Strain"}, "536079": {"name": "Human mastadenovirus G", "rank": "Species"}, "336306": {"name": "Enterobacter cloacae subsp. cloacae", "rank": "Subspecies"}, "1154897": {"name": "Streptococcus agalactiae GB00082", "rank": "Strain"}, "1154896": {"name": "Streptococcus agalactiae GB00020", "rank": "Strain"}, "413970": {"name": "Anulavirus", "rank": "Genus"}, "2226": {"name": "Methanococcoides methylutens", "rank": "Species"}, "1182672": {"name": "Escherichia coli KTE65", "rank": "Strain"}, "2224": {"name": "Methanosaeta thermophila", "rank": "Species"}, "2225": {"name": "Methanococcoides", "rank": "Genus"}, "2222": {"name": "Methanosaeta", "rank": "Genus"}, "2223": {"name": "Methanosaeta concilii", "rank": "Species"}, "2220": {"name": "Methanolobus", "rank": "Genus"}, "2221": {"name": "Methanolobus tindarius", "rank": "Species"}, "1298906": {"name": "Planctomycetes bacterium SCGC AAA282-C19", "rank": "Species"}, "126385": {"name": "Providencia alcalifaciens", "rank": "Species"}, "1182670": {"name": "Escherichia coli KTE63", "rank": "Strain"}, "1080343": {"name": "Fusarium oxysporum f. sp. lycopersici MN25", "rank": "Strain"}, "273164": {"name": "Pontibacillus marinus", "rank": "Species"}, "1281061": {"name": "Escherichia coli HVH 126 (4-6034225)", "rank": "Strain"}, "1182671": {"name": "Escherichia coli KTE64", "rank": "Strain"}, "1281067": {"name": "Escherichia coli HVH 134 (4-6073441)", "rank": "Strain"}, "1281066": {"name": "Escherichia coli HVH 133 (4-4466519)", "rank": "Strain"}, "1281065": {"name": "Escherichia coli HVH 132 (4-6876862)", "rank": "Strain"}, "1281064": {"name": "Escherichia coli HVH 130 (4-7036876)", "rank": "Strain"}, "1182676": {"name": "Escherichia coli KTE69", "rank": "Strain"}, "1281069": {"name": "Escherichia coli HVH 136 (4-5970458)", "rank": "Strain"}, "1281068": {"name": "Escherichia coli HVH 135 (4-4449320)", "rank": "Strain"}, "1182677": {"name": "Escherichia coli KTE70", "rank": "Strain"}, "1444259": {"name": "Escherichia coli 2-011-08_S4_C3", "rank": "Strain"}, "1444258": {"name": "Escherichia coli 2-005-03_S4_C3", "rank": "Strain"}, "1182674": {"name": "Escherichia coli KTE67", "rank": "Strain"}, "1409641": {"name": "Staphylococcus aureus FVRH6052", "rank": "Strain"}, "1409640": {"name": "Staphylococcus aureus OCMM6085", "rank": "Strain"}, "1409643": {"name": "Staphylococcus aureus OCMM6090", "rank": "Strain"}, "1444252": {"name": "Escherichia coli 3-373-03_S4_C2", "rank": "Strain"}, "1444255": {"name": "Escherichia coli 6-175-07_S4_C2", "rank": "Strain"}, "1409644": {"name": "Staphylococcus aureus MISS6057", "rank": "Strain"}, "1409647": {"name": "Staphylococcus aureus WMCS6079", "rank": "Strain"}, "1409646": {"name": "Staphylococcus aureus SCLE6029", "rank": "Strain"}, "1127699": {"name": "Prevotella saccharolytica F0055", "rank": "Strain"}, "1127691": {"name": "Capnocytophaga sp. oral taxon 324 str. F0483", "rank": "Strain"}, "1127690": {"name": "Actinomyces sp. oral taxon 181 str. F0379", "rank": "Strain"}, "1127693": {"name": "Capnocytophaga sp. oral taxon 380 str. F0488", "rank": "Strain"}, "1127692": {"name": "Capnocytophaga sp. oral taxon 332 str. F0381", "rank": "Strain"}, "1127695": {"name": "Selenomonas sp. oral taxon 138 str. F0429", "rank": "Strain"}, "1127694": {"name": "Neisseria sp. oral taxon 020 str. F0370", "rank": "Strain"}, "488545": {"name": "Campylobacter lari subsp. concheus", "rank": "Subspecies"}, "1127696": {"name": "Porphyromonas catoniae F0037", "rank": "Strain"}, "1179773": {"name": "Saccharothrix espanaensis DSM 44229", "rank": "Strain"}, "1179777": {"name": "Mycoplasma sp. G5847", "rank": "Species"}, "1179778": {"name": "Pseudomonas sp. M47T1", "rank": "Species"}, "53328": {"name": "Desulfospira", "rank": "Genus"}, "111781": {"name": "Leptolyngbya sp. PCC 7376", "rank": "Species"}, "227873": {"name": "Pannonibacter", "rank": "Genus"}, "617121": {"name": "Streptococcus dysgalactiae subsp. equisimilis RE378", "rank": "Strain"}, "160233": {"name": "Ignicoccus hospitalis", "rank": "Species"}, "857114": {"name": "Streptococcus mutans NLML1", "rank": "Strain"}, "857115": {"name": "Streptococcus mutans NLML8", "rank": "Strain"}, "857116": {"name": "Streptococcus mutans U2A", "rank": "Strain"}, "857117": {"name": "Streptococcus mutans ST6", "rank": "Strain"}, "857110": {"name": "Streptococcus mutans B", "rank": "Strain"}, "857111": {"name": "Streptococcus mutans 66-2A", "rank": "Strain"}, "857112": {"name": "Streptococcus mutans 21", "rank": "Strain"}, "857113": {"name": "Streptococcus mutans 14D", "rank": "Strain"}, "1347791": {"name": "Bacillus cereus LCT-BC25", "rank": "Strain"}, "857118": {"name": "Streptococcus mutans ST1", "rank": "Strain"}, "857119": {"name": "Streptococcus mutans SM6", "rank": "Strain"}, "1230476": {"name": "Bradyrhizobium sp. DFCI-1", "rank": "Species"}, "1230477": {"name": "Bacillus subtilis S1-4", "rank": "Strain"}, "1133570": {"name": "Cesiribacter", "rank": "Genus"}, "551947": {"name": "Bradyrhizobium sp. STM 3843", "rank": "Species"}, "645464": {"name": "Campylobacter jejuni subsp. jejuni M1", "rank": "Strain"}, "1156917": {"name": "Salmonella enterica subsp. enterica serovar Typhi str. BL196", "rank": "Strain"}, "1156914": {"name": "Helicobacter pylori NAB47", "rank": "Strain"}, "1156915": {"name": "Helicobacter pylori NAD1", "rank": "Strain"}, "1156913": {"name": "Amycolatopsis orientalis HCCB10007", "rank": "Strain"}, "314292": {"name": "Photobacterium angustum S14", "rank": "Strain"}, "1150399": {"name": "Leifsonia sp. 109", "rank": "Species"}, "1549812": {"name": "Massilia sp. BSC265", "rank": "Species"}, "1156918": {"name": "Alcaligenes faecalis subsp. faecalis NCIB 8687", "rank": "Strain"}, "1549810": {"name": "Microvirga sp. BSC39", "rank": "Species"}, "438045": {"name": "XMRV", "rank": "Strain"}, "1468454": {"name": "Lagenaria siceraria endornavirus-California", "rank": "Species"}, "1150395": {"name": "Variovorax paradoxus 4MFCol3.1", "rank": "Strain"}, "1108810": {"name": "Feline picornavirus", "rank": "Species"}, "1469502": {"name": "Burkholderiales bacterium GJ-E10", "rank": "Species"}, "203124": {"name": "Trichodesmium erythraeum IMS101", "rank": "Strain"}, "203122": {"name": "Saccharophagus degradans 2-40", "rank": "Strain"}, "203123": {"name": "Oenococcus oeni PSU-1", "rank": "Strain"}, "203120": {"name": "Leuconostoc mesenteroides subsp. mesenteroides ATCC 8293", "rank": "Strain"}, "1085623": {"name": "Glaciecola nitratireducens FR1064", "rank": "Strain"}, "1009418": {"name": "Verrucomicrobia bacterium SCGC AAA164-M04", "rank": "Species"}, "1009419": {"name": "Verrucomicrobia bacterium SCGC AAA164-N20", "rank": "Species"}, "1009412": {"name": "Flavobacterium sp. SCGC AAA160-P02", "rank": "Species"}, "1009413": {"name": "Verrucomicrobia bacterium SCGC AAA164-A08", "rank": "Species"}, "1009414": {"name": "Verrucomicrobia bacterium SCGC AAA164-B23", "rank": "Species"}, "1009415": {"name": "Verrucomicrobia bacterium SCGC AAA164-E04", "rank": "Species"}, "1009416": {"name": "Verrucomicrobia bacterium SCGC AAA164-I21", "rank": "Species"}, "980514": {"name": "Acinetobacter baumannii TCDC-AB0715", "rank": "Strain"}, "1273739": {"name": "Bacillus phage Andromeda", "rank": "Species"}, "42422": {"name": "Halobacteroides halobius", "rank": "Species"}, "1530454": {"name": "Feline cyclovirus", "rank": "Species"}, "743730": {"name": "Candidatus Aenigmarchaeum subterraneum SCGC AAA011-O16", "rank": "Strain"}, "743731": {"name": "Diapherotrites archaeon SCGC AAA011-N19", "rank": "Species"}, "109807": {"name": "Caldanaerobacter subterraneus subsp. pacificus", "rank": "Subspecies"}, "1435411": {"name": "Oenococcus phage phi9805", "rank": "Species"}, "563798": {"name": "Cyclobacteriaceae", "rank": "Family"}, "1248401": {"name": "Campylobacter jejuni subsp. jejuni BIGS0014", "rank": "Strain"}, "568814": {"name": "Streptococcus suis BM407", "rank": "Strain"}, "568815": {"name": "Brucella microti CCM 4915", "rank": "Strain"}, "568816": {"name": "Acidaminococcus intestini RyC-MR95", "rank": "Strain"}, "568817": {"name": "Serratia symbiotica str. 'Cinara cedri'", "rank": "Strain"}, "568819": {"name": "Listeria monocytogenes serotype 4b str. CLIP 80459", "rank": "Strain"}, "576927": {"name": "Brevibacterium massiliense", "rank": "Species"}, "157691": {"name": "Leptotrichia shahii", "rank": "Species"}, "157692": {"name": "Leptotrichia goodfellowii", "rank": "Species"}, "1232192": {"name": "Peptoclostridium difficile F200", "rank": "Strain"}, "257468": {"name": "Muscovy duck circovirus", "rank": "Strain"}, "257464": {"name": "Potato black ringspot virus", "rank": "Species"}, "257463": {"name": "Arracacha virus B", "rank": "Species"}, "11191": {"name": "Sendai virus", "rank": "Species"}, "29371": {"name": "Clostridium termitidis", "rank": "Species"}, "29378": {"name": "Staphylococcus arlettae", "rank": "Species"}, "155077": {"name": "Cellvibrio japonicus", "rank": "Species"}, "1159075": {"name": "Helicobacter pylori HP250BSi", "rank": "Strain"}, "10759": {"name": "Enterobacteria phage T3", "rank": "Species"}, "1159076": {"name": "Helicobacter pylori HP260AFi", "rank": "Strain"}, "558964": {"name": "Aeromonas sp. AE235", "rank": "Species"}, "1331972": {"name": "Saccharomyces cerevisiae NY1308", "rank": "Strain"}, "1348238": {"name": "Kingella kingae KK93", "rank": "Strain"}, "1232640": {"name": "Solendovirus", "rank": "Genus"}, "721885": {"name": "Stereum hirsutum FP-91666 SS1", "rank": "Strain"}, "467210": {"name": "Lachnoanaerobaculum saburreum", "rank": "Species"}, "10570": {"name": "Alphapapillomavirus 12", "rank": "Species"}, "1198232": {"name": "Cycloclasticus zancles 7-ME", "rank": "Strain"}, "93506": {"name": "Unclassified Archaea (miscellaneous)", "rank": "No rank"}, "713586": {"name": "Thioalkalivibrio thiocyanodenitrificans ARhD 1", "rank": "Strain"}, "713587": {"name": "Thioalkalivibrio thiocyanoxidans ARh 4", "rank": "Strain"}, "650341": {"name": "Leeia", "rank": "Genus"}, "1421999": {"name": "Mycobacterium tuberculosis TB_RSA83", "rank": "Strain"}, "10911": {"name": "Coltivirus", "rank": "Genus"}, "1421997": {"name": "Mycobacterium tuberculosis TB_RSA81", "rank": "Strain"}, "370885": {"name": "Syntrophomonas wolfei subsp. wolfei", "rank": "Subspecies"}, "1421995": {"name": "Mycobacterium tuberculosis TB_RSA79", "rank": "Strain"}, "1421994": {"name": "Mycobacterium tuberculosis TB_RSA78", "rank": "Strain"}, "1421993": {"name": "Mycobacterium tuberculosis TB_RSA77", "rank": "Strain"}, "1421992": {"name": "Mycobacterium tuberculosis TB_RSA76", "rank": "Strain"}, "1421991": {"name": "Mycobacterium tuberculosis TB_RSA75", "rank": "Strain"}, "1421990": {"name": "Mycobacterium tuberculosis TB_RSA74", "rank": "Strain"}, "1308984": {"name": "Escherichia coli HM69", "rank": "Strain"}, "1308980": {"name": "Klebsiella oxytoca HKOPL1", "rank": "Strain"}, "1308981": {"name": "Escherichia coli HM27", "rank": "Strain"}, "698968": {"name": "Corynebacterium diphtheriae HC02", "rank": "Strain"}, "698969": {"name": "Corynebacterium diphtheriae HC03", "rank": "Strain"}, "698966": {"name": "Corynebacterium diphtheriae 241", "rank": "Strain"}, "1471479": {"name": "Prochlorococcus sp. scB243_496E10", "rank": "Species"}, "698964": {"name": "Corynebacterium diphtheriae PW8", "rank": "Strain"}, "698965": {"name": "Corynebacterium diphtheriae CDCE 8392", "rank": "Strain"}, "698962": {"name": "Corynebacterium diphtheriae 31A", "rank": "Strain"}, "698963": {"name": "Corynebacterium diphtheriae C7 (beta)", "rank": "Strain"}, "698960": {"name": "Gardnerella vaginalis 00703Dmash", "rank": "Strain"}, "1471478": {"name": "Prochlorococcus sp. scB243_496A2", "rank": "Species"}, "809": {"name": "Chlamydiaceae", "rank": "Family"}, "645161": {"name": "Human bocavirus 4", "rank": "Species"}, "1438878": {"name": "Mycobacterium tuberculosis UT0117", "rank": "Strain"}, "1438879": {"name": "Mycobacterium tuberculosis UT0098", "rank": "Strain"}, "173082": {"name": "Chum salmon reovirus CS", "rank": "Strain"}, "1438872": {"name": "Mycobacterium tuberculosis 3067CJ", "rank": "Strain"}, "1438873": {"name": "Mycobacterium tuberculosis 3280CJ", "rank": "Strain"}, "803": {"name": "Bartonella quintana", "rank": "Species"}, "1438871": {"name": "Mycobacterium tuberculosis 2995AB", "rank": "Strain"}, "1438877": {"name": "Mycobacterium tuberculosis UT0103", "rank": "Strain"}, "807": {"name": "Bartonella elizabethae", "rank": "Species"}, "1471474": {"name": "Prochlorococcus sp. scB243_495N16", "rank": "Species"}, "89154": {"name": "Corynebacterium terpenotabidum", "rank": "Species"}, "89152": {"name": "Clostridium hiranonis", "rank": "Species"}, "89153": {"name": "Clostridium hylemonae", "rank": "Species"}, "33765": {"name": "Tobacco vein banding mosaic virus", "rank": "Species"}, "33760": {"name": "Prune dwarf virus", "rank": "Species"}, "33763": {"name": "Peanut mottle virus", "rank": "Species"}, "150203": {"name": "Blastomonas", "rank": "Genus"}, "147554": {"name": "Schizosaccharomycetes", "rank": "Class"}, "174709": {"name": "Allobaculum stercoricanis", "rank": "Species"}, "174708": {"name": "Allobaculum", "rank": "Genus"}, "147555": {"name": "Taphrinomycetes", "rank": "Class"}, "1471473": {"name": "Prochlorococcus sp. scB243_495L20", "rank": "Species"}, "1471472": {"name": "Prochlorococcus sp. scB243_495K23", "rank": "Species"}, "113287": {"name": "Pseudoramibacter alactolyticus", "rank": "Species"}, "1484479": {"name": "Exiguobacterium sp. AB2", "rank": "Species"}, "11629": {"name": "Mopeia virus", "rank": "Species"}, "11628": {"name": "Machupo virus", "rank": "Species"}, "207921": {"name": "Lyngbya confervoides", "rank": "Species"}, "11620": {"name": "Lassa virus", "rank": "Species"}, "11623": {"name": "Lymphocytic choriomeningitis virus", "rank": "Species"}, "285892": {"name": "Unclassified Rhodobacterales", "rank": "No rank"}, "1274722": {"name": "Erwinia toletana DAPP-PG 735", "rank": "Strain"}, "1301100": {"name": "Clostridium sp. 01", "rank": "Species"}, "413435": {"name": "Solimonas", "rank": "Genus"}, "1402584": {"name": "Mycobacterium tuberculosis OFXR-6", "rank": "Strain"}, "1147129": {"name": "Dehalobacter sp. DCA", "rank": "Species"}, "1147128": {"name": "Bifidobacterium asteroides PRL2011", "rank": "Strain"}, "2342": {"name": "Candidatus Sodalis pierantonius str. SOPE", "rank": "Strain"}, "2349": {"name": "Haliscomenobacter", "rank": "Genus"}, "593750": {"name": "Methanoregula formicica SMSP", "rank": "Strain"}, "1147127": {"name": "Vibrio cholerae 2011EL-301", "rank": "Strain"}, "1401258": {"name": "Thalassobacillus devorans MSP14", "rank": "Strain"}, "1494913": {"name": "Anditalea", "rank": "Genus"}, "1412820": {"name": "Escherichia coli 53A", "rank": "Strain"}, "868203": {"name": "Escherichia coli DEC14C", "rank": "Strain"}, "1401257": {"name": "Xanthomonas axonopodis pv. glycines str. 8ra", "rank": "Strain"}, "1204719": {"name": "Phocaeicola abscessus CCUG 55929", "rank": "Strain"}, "693661": {"name": "Archaeoglobus veneficus SNP6", "rank": "Strain"}, "585503": {"name": "Selenomonas noxia ATCC 43541", "rank": "Strain"}, "585502": {"name": "Prevotella bergensis DSM 17361", "rank": "Strain"}, "585501": {"name": "Oribacterium sinus F0268", "rank": "Strain"}, "585506": {"name": "Weissella paramesenteroides ATCC 33313", "rank": "Strain"}, "449439": {"name": "Microcystis aeruginosa NIES-44", "rank": "Strain"}, "196136": {"name": "Methanosalsum", "rank": "Genus"}, "196137": {"name": "Methanospirillaceae", "rank": "Family"}, "149385": {"name": "Salmonella enterica subsp. enterica serovar Hadar", "rank": "Strain"}, "1438764": {"name": "Klebsiella pneumoniae CHS 58", "rank": "Strain"}, "149386": {"name": "Salmonella enterica subsp. enterica serovar Chester", "rank": "Strain"}, "979200": {"name": "Staphylococcus epidermidis NIHLM088", "rank": "Strain"}, "292029": {"name": "Staphylococcus phage G1", "rank": "Species"}, "979207": {"name": "Staphylococcus epidermidis NIHLM049", "rank": "Strain"}, "510955": {"name": "Chryseobacterium solincola", "rank": "Species"}, "510952": {"name": "Neurospora tetrasperma FGSC 2509", "rank": "Strain"}, "1438763": {"name": "Klebsiella pneumoniae CHS 57", "rank": "Strain"}, "1438760": {"name": "Klebsiella pneumoniae CHS 54", "rank": "Strain"}, "979204": {"name": "Staphylococcus epidermidis NIHLM061", "rank": "Strain"}, "1421863": {"name": "Staphylococcus aureus H75430", "rank": "Strain"}, "39687": {"name": "Mycobacterium austroafricanum", "rank": "Species"}, "39686": {"name": "Unclassified Flavivirus", "rank": "No rank"}, "212717": {"name": "Clostridium tetani E88", "rank": "Strain"}, "255431": {"name": "Klebsiella phage phiKO2", "rank": "Species"}, "293084": {"name": "Leptospira inadai serovar Lyme", "rank": "Strain"}, "293085": {"name": "Leptospira vanthielii", "rank": "Species"}, "293086": {"name": "Leptospira vanthielii serovar Holland", "rank": "Strain"}, "293080": {"name": "Leptospira meyeri serovar Semaranga", "rank": "Strain"}, "1438768": {"name": "Klebsiella pneumoniae CHS 62", "rank": "Strain"}, "293083": {"name": "Leptospira kirschneri serovar Cynopteri", "rank": "Strain"}, "293088": {"name": "Martelella", "rank": "Genus"}, "293089": {"name": "Martelella mediterranea", "rank": "Species"}, "1387998": {"name": "Staphylococcus aureus M0018", "rank": "Strain"}, "1387999": {"name": "Staphylococcus aureus M0021", "rank": "Strain"}, "1387996": {"name": "Staphylococcus aureus M0016", "rank": "Strain"}, "1387997": {"name": "Staphylococcus aureus M0017", "rank": "Strain"}, "1387994": {"name": "Staphylococcus aureus M0013", "rank": "Strain"}, "1387995": {"name": "Staphylococcus aureus M0014", "rank": "Strain"}, "1387992": {"name": "Staphylococcus aureus M0011", "rank": "Strain"}, "1387993": {"name": "Staphylococcus aureus M0012", "rank": "Strain"}, "1387990": {"name": "Staphylococcus aureus M0009", "rank": "Strain"}, "1387991": {"name": "Staphylococcus aureus M0010", "rank": "Strain"}, "1398028": {"name": "Staphylococcus aureus M1410", "rank": "Strain"}, "1423504": {"name": "Mycobacterium tuberculosis BTB09-184", "rank": "Strain"}, "1423505": {"name": "Mycobacterium tuberculosis BTB09-230", "rank": "Strain"}, "61305": {"name": "Nocardiopsis synnemataformans", "rank": "Species"}, "1227812": {"name": "Piscirickettsia salmonis LF-89 = ATCC VR-1361", "rank": "Strain"}, "1227813": {"name": "Escherichia coli S17", "rank": "Strain"}, "1439002": {"name": "Streptococcus pyogenes ABC020013256", "rank": "Strain"}, "1227811": {"name": "Bacillus pumilus BA06", "rank": "Strain"}, "1439004": {"name": "Streptococcus pyogenes ABC020013551", "rank": "Strain"}, "117999": {"name": "Denitrovibrio", "rank": "Genus"}, "111105": {"name": "Porphyromonas gulae", "rank": "Species"}, "1439008": {"name": "Streptococcus pyogenes ABC020014529", "rank": "Strain"}, "1137281": {"name": "Formosa sp. AK20", "rank": "Species"}, "1137280": {"name": "Marinobacter sp. AK21", "rank": "Species"}, "1263831": {"name": "Bibersteinia trehalosi USDA-ARS-USMARC-189", "rank": "Strain"}, "1263832": {"name": "Bibersteinia trehalosi USDA-ARS-USMARC-190", "rank": "Strain"}, "1263833": {"name": "Serratia marcescens VGH107", "rank": "Strain"}, "1223302": {"name": "Bluegill picornavirus", "rank": "Species"}, "411901": {"name": "Bacteroides caccae ATCC 43185", "rank": "Strain"}, "1223307": {"name": "Streptomyces sp. PVA 94-07", "rank": "Species"}, "411903": {"name": "Collinsella aerofaciens ATCC 25986", "rank": "Strain"}, "411902": {"name": "Clostridium bolteae ATCC BAA-613", "rank": "Strain"}, "1411594": {"name": "Staphylococcus aureus W55446", "rank": "Strain"}, "1425883": {"name": "Verticillium tricorpus MUCL 9792", "rank": "Strain"}, "1411595": {"name": "Staphylococcus aureus W55451", "rank": "Strain"}, "1411596": {"name": "Staphylococcus aureus W58473", "rank": "Strain"}, "191410": {"name": "Chlorobia", "rank": "Class"}, "191411": {"name": "Chlorobiales", "rank": "Order"}, "191412": {"name": "Chlorobiaceae", "rank": "Family"}, "1551504": {"name": "Candidatus Babela", "rank": "Genus"}, "1448615": {"name": "Mycobacterium tuberculosis M992", "rank": "Strain"}, "519496": {"name": "Unclassified Fijivirus", "rank": "No rank"}, "519497": {"name": "Southern rice black-streaked dwarf virus", "rank": "Species"}, "148813": {"name": "Sulfuricurvum kujiense", "rank": "Species"}, "1034944": {"name": "Legionella tunisiensis", "rank": "Species"}, "148814": {"name": "Lactobacillus kunkeei", "rank": "Species"}, "1105279": {"name": "Streptococcus agalactiae BSU248", "rank": "Strain"}, "1448611": {"name": "Mycobacterium tuberculosis M987", "rank": "Strain"}, "1448610": {"name": "Mycobacterium tuberculosis M984", "rank": "Strain"}, "218849": {"name": "Kamiti River virus", "rank": "Species"}, "1448613": {"name": "Mycobacterium tuberculosis M991", "rank": "Strain"}, "218845": {"name": "Tobacco leaf curl Yunnan virus satellite DNA beta", "rank": "Species"}, "160791": {"name": "Sphingomonas wittichii", "rank": "Species"}, "76745": {"name": "Sinorhizobium arboris", "rank": "Species"}, "164037": {"name": "Thermus phage IN93", "rank": "Species"}, "160795": {"name": "Ureibacillus", "rank": "Genus"}, "160799": {"name": "Paenibacillus borealis", "rank": "Species"}, "160798": {"name": "Marinitoga", "rank": "Genus"}, "1297645": {"name": "Corchorus yellow vein mosaic virus", "rank": "Species"}, "129956": {"name": "Murine mastadenovirus A", "rank": "Species"}, "129957": {"name": "Carboxydothermus", "rank": "Genus"}, "399587": {"name": "Salmonella enterica subsp. enterica serovar Rissen", "rank": "Strain"}, "1553907": {"name": "Streptomyces sp. CT34", "rank": "Species"}, "129950": {"name": "Bovine mastadenovirus B", "rank": "Species"}, "129951": {"name": "Human mastadenovirus C", "rank": "Species"}, "1545442": {"name": "Nitrincola sp. A-D6", "rank": "Species"}, "129958": {"name": "Carboxydothermus hydrogenoformans", "rank": "Species"}, "1422448": {"name": "Staphylococcus aureus VET0123R", "rank": "Strain"}, "206037": {"name": "Human endogenous retroviruses", "rank": "No rank"}, "206036": {"name": "Avian retroviruses", "rank": "No rank"}, "498848": {"name": "Thermus aquaticus Y51MC23", "rank": "Strain"}, "1392870": {"name": "Escherichia coli K2", "rank": "Strain"}, "1458469": {"name": "Pseudobutyrivibrio ruminis HUN009", "rank": "Strain"}, "1049939": {"name": "Leptospira interrogans str. UI 13372", "rank": "Strain"}, "1049938": {"name": "Leptospira interrogans str. UI 12758", "rank": "Strain"}, "1049937": {"name": "Leptospira interrogans str. UI 12621", "rank": "Strain"}, "1196034": {"name": "Klebsiella sp. 10982", "rank": "Species"}, "1049935": {"name": "Leptospira interrogans str. UI 08452", "rank": "Strain"}, "1049934": {"name": "Leptospira interrogans str. MMD3731", "rank": "Strain"}, "1196031": {"name": "Bacillus oceanisediminis 2691", "rank": "Strain"}, "1049932": {"name": "Leptospira interrogans str. L0996", "rank": "Strain"}, "1196033": {"name": "Escherichia coli SEPT362", "rank": "Strain"}, "1049930": {"name": "Leptospira interrogans str. 2002000623", "rank": "Strain"}, "1413497": {"name": "Staphylococcus aureus MRSA-136", "rank": "Strain"}, "1413496": {"name": "Staphylococcus aureus MSSA-123", "rank": "Strain"}, "78355": {"name": "Streptomyces somaliensis", "rank": "Species"}, "1087444": {"name": "Klebsiella pneumoniae subsp. pneumoniae KPNIH5", "rank": "Strain"}, "1413494": {"name": "Staphylococcus aureus MSSA-47", "rank": "Strain"}, "1413493": {"name": "Staphylococcus aureus MSSA-37", "rank": "Strain"}, "515320": {"name": "Lamium leaf distortion virus", "rank": "Species"}, "1413492": {"name": "Staphylococcus aureus MSSA-93", "rank": "Strain"}, "1413491": {"name": "Staphylococcus aureus 122", "rank": "Strain"}, "498846": {"name": "Candidatus Korarchaeum cryptofilum", "rank": "Species"}, "399320": {"name": "Sphaerochaeta", "rank": "Genus"}, "1053205": {"name": "Bacillus cereus HuA3-9", "rank": "Strain"}, "45224": {"name": "Leek white stripe virus", "rank": "Species"}, "45220": {"name": "Flexal virus", "rank": "Species"}, "45221": {"name": "Latino virus", "rank": "Species"}, "45222": {"name": "Parana virus", "rank": "Species"}, "45223": {"name": "Tamiami virus", "rank": "Species"}, "1236483": {"name": "Mycobacterium simiae ATCC 25275 = DSM 44165", "rank": "Strain"}, "1236482": {"name": "Staphylococcus aureus subsp. anaerobius ST1464", "rank": "Strain"}, "1236481": {"name": "Bacillus stratosphericus LAMA 585", "rank": "Strain"}, "197700": {"name": "Aeromonas salmonicida subsp. masoucida", "rank": "Subspecies"}, "145360": {"name": "Sanguibacteraceae", "rank": "Family"}, "1193128": {"name": "Parascardovia denticolens IPLA 20019", "rank": "Strain"}, "44158": {"name": "Aura virus", "rank": "Species"}, "1439853": {"name": "Burkholderia sp. TSV202", "rank": "Species"}, "1281284": {"name": "Xanthomonas campestris pv. campestris str. CN16", "rank": "Strain"}, "154621": {"name": "Enterococcus phoeniculicola", "rank": "Species"}, "1281282": {"name": "Xanthomonas campestris pv. campestris str. CN14", "rank": "Strain"}, "1046947": {"name": "Unclassified Gracilibacteria", "rank": "No rank"}, "1046946": {"name": "Nanoarchaeota archaeon SCGC AAA011-L22", "rank": "Species"}, "1046942": {"name": "Unclassified Diapherotrites", "rank": "No rank"}, "942033": {"name": "Cyclovirus PKgoat21/PAK/2009", "rank": "Species"}, "935599": {"name": "Neisseria meningitidis G2136", "rank": "Strain"}, "935598": {"name": "Neisseria meningitidis 961-5945", "rank": "Strain"}, "942037": {"name": "Cyclovirus NGchicken15/NGA/2009", "rank": "Species"}, "942034": {"name": "Cyclovirus PKgoat11/PAK/2009", "rank": "Species"}, "942035": {"name": "Cyclovirus bat/USA/2009", "rank": "Species"}, "935593": {"name": "Neisseria meningitidis M04-240196", "rank": "Strain"}, "935592": {"name": "Neisseria meningitidis OX99.30304", "rank": "Strain"}, "935591": {"name": "Neisseria meningitidis M01-240149", "rank": "Strain"}, "935590": {"name": "Neisseria meningitidis M0579", "rank": "Strain"}, "935597": {"name": "Neisseria meningitidis CU385", "rank": "Strain"}, "935595": {"name": "Neisseria meningitidis M01-240013", "rank": "Strain"}, "935594": {"name": "Neisseria meningitidis M13399", "rank": "Strain"}, "1422794": {"name": "Staphylococcus aureus VET1518S", "rank": "Strain"}, "444463": {"name": "Sporolactobacillus vineae", "rank": "Species"}, "945021": {"name": "Tetragenococcus halophilus NBRC 12172", "rank": "Strain"}, "257309": {"name": "Corynebacterium diphtheriae NCTC 13129", "rank": "Strain"}, "1247529": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. 10-34587", "rank": "Strain"}, "1422797": {"name": "Staphylococcus aureus VET1646S", "rank": "Strain"}, "252965": {"name": "Mahella", "rank": "Genus"}, "1378093": {"name": "Pantoea ananatis LMG 2665", "rank": "Strain"}, "1378092": {"name": "Pantoea ananatis BD442", "rank": "Strain"}, "284016": {"name": "Phenylobacterium zucineum", "rank": "Species"}, "662596": {"name": "Radish leaf curl betasatellite", "rank": "Species"}, "1235829": {"name": "Streptococcus pyogenes A20", "rank": "Strain"}, "1235824": {"name": "Acinetobacter phage Abp1", "rank": "Species"}, "662598": {"name": "Neisseria meningitidis alpha14", "rank": "Strain"}, "1235827": {"name": "Herbaspirillum rubrisubalbicans Os34", "rank": "Strain"}, "1427369": {"name": "Chlamydia pecorum MC/MarsBar", "rank": "Strain"}, "1388438": {"name": "Staphylococcus aureus M0657", "rank": "Strain"}, "1388439": {"name": "Staphylococcus aureus M0658", "rank": "Strain"}, "186153": {"name": "Staphylococcus phage phi13", "rank": "Species"}, "186152": {"name": "Staphylococcus phage phi 12", "rank": "Species"}, "186156": {"name": "Aedes aegypti densovirus", "rank": "Strain"}, "1388430": {"name": "Staphylococcus aureus M0647", "rank": "Strain"}, "1388431": {"name": "Staphylococcus aureus M0649", "rank": "Strain"}, "1388432": {"name": "Staphylococcus aureus M0651", "rank": "Strain"}, "1388433": {"name": "Staphylococcus aureus M0652", "rank": "Strain"}, "1388434": {"name": "Staphylococcus aureus M0653", "rank": "Strain"}, "981223": {"name": "Acinetobacter sp. NCTC 7422", "rank": "Species"}, "1388436": {"name": "Staphylococcus aureus M0655", "rank": "Strain"}, "1388437": {"name": "Staphylococcus aureus M0656", "rank": "Strain"}, "265072": {"name": "Methylobacillus flagellatus KT", "rank": "Strain"}, "188937": {"name": "Methanosarcina acetivorans C2A", "rank": "Strain"}, "1511900": {"name": "Primate erythroparvovirus 1", "rank": "Species"}, "188938": {"name": "Pronghorn antelope pestivirus", "rank": "Species"}, "664731": {"name": "Unclassified Pipapillomavirus", "rank": "No rank"}, "1422806": {"name": "Staphylococcus aureus VET1918S", "rank": "Strain"}, "234601": {"name": "Sapovirus Mc10", "rank": "Strain"}, "1388386": {"name": "Staphylococcus aureus M0585", "rank": "Strain"}, "1388387": {"name": "Staphylococcus aureus M0587", "rank": "Strain"}, "1388384": {"name": "Staphylococcus aureus M0582", "rank": "Strain"}, "1388385": {"name": "Staphylococcus aureus M0583", "rank": "Strain"}, "1388382": {"name": "Staphylococcus aureus M0579", "rank": "Strain"}, "1388383": {"name": "Staphylococcus aureus M0581", "rank": "Strain"}, "1388380": {"name": "Staphylococcus aureus M0573", "rank": "Strain"}, "1457173": {"name": "Comamonas aquatica DA1877", "rank": "Strain"}, "314723": {"name": "Borrelia hermsii HS1", "rank": "Strain"}, "1388388": {"name": "Staphylococcus aureus M0588", "rank": "Strain"}, "1388389": {"name": "Staphylococcus aureus M0589", "rank": "Strain"}, "392174": {"name": "Malva mosaic virus", "rank": "Species"}, "1511908": {"name": "Rodent protoparvovirus 1", "rank": "Species"}, "1240558": {"name": "Thioalkalivibrio sp. ALJ4", "rank": "Species"}, "1240557": {"name": "Thioalkalivibrio sp. ALJ3", "rank": "Species"}, "10778": {"name": "Bacillus phage B103", "rank": "Species"}, "1532031": {"name": "Alternaria longipes dsRNA virus 1", "rank": "Species"}, "579113": {"name": "Sunn hemp leaf distortion virus", "rank": "Species"}, "86304": {"name": "Saccharophagus degradans", "rank": "Species"}, "252970": {"name": "Burkholderia phenoliruptrix", "rank": "Species"}, "1295141": {"name": "Pseudomonas veronii 1YdBTEX2", "rank": "Strain"}, "938641": {"name": "Alpha proteobacterium SCGC AAA028-D10", "rank": "Species"}, "1295140": {"name": "Haemophilus influenzae CGSHiCZ412602", "rank": "Strain"}, "579112": {"name": "Vibrio cholerae M66-2", "rank": "Strain"}, "986075": {"name": "Caldalkalibacillus thermarum TA2.A1", "rank": "Strain"}, "1437818": {"name": "Campylobacter coli IPSID-1", "rank": "Strain"}, "649688": {"name": "Mycobacterium phage Angel", "rank": "Species"}, "114652": {"name": "Streptococcus orisratti", "rank": "Species"}, "400567": {"name": "Phormidium phage Pf-WMP4", "rank": "Species"}, "1239452": {"name": "Brugmansia mosaic virus", "rank": "Species"}, "1402657": {"name": "Staphylococcus aureus M1145", "rank": "Strain"}, "1402656": {"name": "Staphylococcus aureus M1144", "rank": "Strain"}, "1402655": {"name": "Staphylococcus aureus M1143", "rank": "Strain"}, "1402654": {"name": "Staphylococcus aureus M1141", "rank": "Strain"}, "1402653": {"name": "Staphylococcus aureus M1140", "rank": "Strain"}, "1402652": {"name": "Staphylococcus aureus M1139", "rank": "Strain"}, "1402651": {"name": "Staphylococcus aureus M1138", "rank": "Strain"}, "1328398": {"name": "Klebsiella pneumoniae BIDMC 1", "rank": "Strain"}, "1328397": {"name": "Klebsiella pneumoniae UCICRE 14", "rank": "Strain"}, "1328396": {"name": "Klebsiella pneumoniae UCICRE 13", "rank": "Strain"}, "1328395": {"name": "Klebsiella pneumoniae UCICRE 10", "rank": "Strain"}, "1328394": {"name": "Klebsiella pneumoniae UCICRE 8", "rank": "Strain"}, "1328393": {"name": "Klebsiella pneumoniae UCICRE 7", "rank": "Strain"}, "1328392": {"name": "Klebsiella pneumoniae UCICRE 6", "rank": "Strain"}, "1402659": {"name": "Staphylococcus aureus M1147", "rank": "Strain"}, "1402658": {"name": "Staphylococcus aureus M1146", "rank": "Strain"}, "1446745": {"name": "Escherichia coli O55:H7 str. 06-3555", "rank": "Strain"}, "1446744": {"name": "Escherichia coli O45:H2 str. 2010C-4211", "rank": "Strain"}, "1446747": {"name": "Escherichia coli O6:H16 str. 99-3165", "rank": "Strain"}, "1446746": {"name": "Escherichia coli O6:H16", "rank": "Strain"}, "1446741": {"name": "Escherichia coli O45:H2 str. 2009C-3686", "rank": "Strain"}, "1446740": {"name": "Escherichia coli O45:H2 str. 01-3147", "rank": "Strain"}, "1446743": {"name": "Escherichia coli O45:H2 str. 2010C-3876", "rank": "Strain"}, "1446742": {"name": "Escherichia coli O45:H2 str. 2009C-4780", "rank": "Strain"}, "1446749": {"name": "Escherichia coli O69:H11", "rank": "Strain"}, "1446748": {"name": "Escherichia coli O6:H16 str. F5656C1", "rank": "Strain"}, "131083": {"name": "Turnip yellows virus", "rank": "Species"}, "131082": {"name": "Beet chlorosis virus", "rank": "Species"}, "1450694": {"name": "Bacillus sp. TS-2", "rank": "Species"}, "1310556": {"name": "Acinetobacter baumannii 17534", "rank": "Strain"}, "307124": {"name": "Meiothermus timidus", "rank": "Species"}, "307126": {"name": "Lactobacillus apodemi", "rank": "Species"}, "430796": {"name": "Staphylococcus phage phi2958PVL", "rank": "Species"}, "1121860": {"name": "Edaphobacter aggregans DSM 19364", "rank": "Strain"}, "1121861": {"name": "Elioraea tepidiphila DSM 17972", "rank": "Strain"}, "1121862": {"name": "Endozoicomonas elysicola DSM 22380", "rank": "Strain"}, "1121863": {"name": "Cronobacter pulveris DSM 19144", "rank": "Strain"}, "1121864": {"name": "Enterococcus cecorum DSM 20682 = ATCC 43198", "rank": "Strain"}, "1121865": {"name": "Enterococcus columbae DSM 7374 = ATCC 51263", "rank": "Strain"}, "1121866": {"name": "Enterorhabdus mucosicola DSM 19490", "rank": "Strain"}, "1121867": {"name": "Enterovibrio calviensis DSM 14347", "rank": "Strain"}, "765117": {"name": "Propionibacterium acnes HL002PA3", "rank": "Strain"}, "367061": {"name": "Vernonia yellow vein virus", "rank": "Species"}, "46254": {"name": "Oenococcus", "rank": "Genus"}, "46255": {"name": "Weissella", "rank": "Genus"}, "46256": {"name": "Weissella hellenica", "rank": "Species"}, "46257": {"name": "Pseudomonas avellanae", "rank": "Species"}, "41202": {"name": "Ewingella americana", "rank": "Species"}, "41201": {"name": "Ewingella", "rank": "Genus"}, "12730": {"name": "Human parainfluenza virus 1", "rank": "Species"}, "403833": {"name": "Petrotoga mobilis SJ95", "rank": "Strain"}, "312026": {"name": "Burkholderia mimosarum", "rank": "Species"}, "1217718": {"name": "Cupriavidus sp. BIS7", "rank": "Species"}, "161156": {"name": "Thermodesulfobacterium hydrogeniphilum", "rank": "Species"}, "1391667": {"name": "Bufavirus-3", "rank": "Species"}, "1283278": {"name": "Staphylococcus aureus KLT6", "rank": "Strain"}, "1217712": {"name": "Acinetobacter sp. NIPH 758", "rank": "Species"}, "936155": {"name": "Helicobacter felis ATCC 49179", "rank": "Strain"}, "632348": {"name": "Caldicellulosiruptor kronotskyensis 2002", "rank": "Strain"}, "463794": {"name": "Pseudomonas fluorescens BBc6R8", "rank": "Strain"}, "1329904": {"name": "Mannheimia haemolytica D193", "rank": "Strain"}, "186938": {"name": "Respirovirus", "rank": "Genus"}, "332032": {"name": "Burkholderia phage phi52237", "rank": "Species"}, "640862": {"name": "Bombyx mandarina nucleopolyhedrovirus", "rank": "Strain"}, "1329906": {"name": "Mannheimia haemolytica D38", "rank": "Strain"}, "1230458": {"name": "Natrialba taiwanensis DSM 12281", "rank": "Strain"}, "1237149": {"name": "Fulvivirga imtechensis AK7", "rank": "Strain"}, "1196028": {"name": "Virgibacillus halodenitrificans 1806", "rank": "Strain"}, "566": {"name": "Escherichia vulneris", "rank": "Species"}, "1384067": {"name": "Pediococcus acidilactici AGR20", "rank": "Strain"}, "12198": {"name": "Clover yellow vein virus", "rank": "Species"}, "1196029": {"name": "Bacillus endophyticus 2102", "rank": "Strain"}, "562": {"name": "Escherichia coli", "rank": "Species"}, "563": {"name": "Shimwellia blattae", "rank": "Species"}, "561": {"name": "Escherichia", "rank": "Genus"}, "12196": {"name": "Bean common mosaic virus", "rank": "Species"}, "12197": {"name": "Bean yellow mosaic virus", "rank": "Species"}, "568": {"name": "Hafnia", "rank": "Genus"}, "12195": {"name": "Potyvirus", "rank": "Genus"}, "1131814": {"name": "Xanthobacter sp. 126", "rank": "Species"}, "1240770": {"name": "Escherichia coli O104:H4 str. 11-02092", "rank": "Strain"}, "1131816": {"name": "Bacillus sp. 72", "rank": "Species"}, "455360": {"name": "Thalassobaculum salexigens", "rank": "Species"}, "1131812": {"name": "Flavobacterium sp. 83", "rank": "Species"}, "1310975": {"name": "Acinetobacter baumannii 44467_1", "rank": "Strain"}, "40559": {"name": "Botrytis cinerea", "rank": "Species"}, "659019": {"name": "Mycobacterium tuberculosis W-148", "rank": "Strain"}, "1384061": {"name": "Pseudomonas putida S13.1.2", "rank": "Strain"}, "90062": {"name": "Leptospira interrogans serovar Icterohaemorrhagiae", "rank": "Strain"}, "1240773": {"name": "Escherichia coli O104:H4 str. 11-02318", "rank": "Strain"}, "1443665": {"name": "Aquimarina macrocephali JAMB N27", "rank": "Strain"}, "1282361": {"name": "Asticcacaulis sp. AC402", "rank": "Species"}, "1443666": {"name": "Aquimarina megaterium", "rank": "Species"}, "1282360": {"name": "Asticcacaulis sp. AC460", "rank": "Species"}, "1289591": {"name": "Rhodococcus erythropolis R138", "rank": "Strain"}, "1289590": {"name": "Clostridium botulinum CB11/1-1", "rank": "Strain"}, "134813": {"name": "Natronorubrum", "rank": "Genus"}, "91914": {"name": "Asaia", "rank": "Genus"}, "333348": {"name": "Nerine virus X", "rank": "Species"}, "333347": {"name": "Unclassified Potexvirus", "rank": "No rank"}, "1423546": {"name": "Mycobacterium tuberculosis BTB11-250", "rank": "Strain"}, "1227467": {"name": "Halorubrum distributum JCM 9100", "rank": "Strain"}, "1423544": {"name": "Mycobacterium tuberculosis BTB11-214", "rank": "Strain"}, "1423545": {"name": "Mycobacterium tuberculosis BTB11-236", "rank": "Strain"}, "1423542": {"name": "Mycobacterium tuberculosis BTB11-207", "rank": "Strain"}, "1423543": {"name": "Mycobacterium tuberculosis BTB11-210", "rank": "Strain"}, "433334": {"name": "Unclassified Erysipelotrichaceae", "rank": "No rank"}, "1458697": {"name": "Rhizobium phage vB_RglS_P106B", "rank": "Species"}, "1538295": {"name": "Aquabacterium sp. NJ1", "rank": "Species"}, "373384": {"name": "Shigella flexneri 5 str. 8401", "rank": "Strain"}, "373383": {"name": "Shigella flexneri 5", "rank": "Strain"}, "1423548": {"name": "Mycobacterium tuberculosis BTB11-299", "rank": "Strain"}, "1423549": {"name": "Mycobacterium tuberculosis BTB11-300", "rank": "Strain"}, "1123233": {"name": "Salinicoccus luteus DSM 17002", "rank": "Strain"}, "1123230": {"name": "Salinicoccus albus DSM 19776", "rank": "Strain"}, "1123237": {"name": "Salipiger mucosus DSM 16094", "rank": "Strain"}, "1123236": {"name": "Salinimonas chungwhensis DSM 16280", "rank": "Strain"}, "1123235": {"name": "Salinimicrobium xinjiangense DSM 19287", "rank": "Strain"}, "1123234": {"name": "Salinimicrobium terrae DSM 17865", "rank": "Strain"}, "1080798": {"name": "Soybean yellow common mosaic virus", "rank": "Species"}, "1080799": {"name": "Keunjorong mosaic virus", "rank": "Species"}, "1123239": {"name": "Salsuginibacillus kocurii DSM 18087", "rank": "Strain"}, "1227462": {"name": "Haloferax sp. ATCC BAA-644", "rank": "Species"}, "1227461": {"name": "Haloferax prahovense DSM 18310", "rank": "Strain"}, "1227460": {"name": "Haloferax larsenii JCM 13917", "rank": "Strain"}, "452637": {"name": "Opitutus terrae PB90-1", "rank": "Strain"}, "393305": {"name": "Yersinia enterocolitica subsp. enterocolitica 8081", "rank": "Strain"}, "452638": {"name": "Polynucleobacter necessarius subsp. necessarius STIR1", "rank": "Strain"}, "349519": {"name": "Leuconostoc citreum KM20", "rank": "Strain"}, "191547": {"name": "Beet ringspot virus", "rank": "Species"}, "1121937": {"name": "Haliea salexigens DSM 19537", "rank": "Strain"}, "1227468": {"name": "Halorubrum distributum JCM 10118", "rank": "Strain"}, "5313": {"name": "Ganodermataceae", "rank": "Family"}, "1249471": {"name": "Burkholderia pseudomallei MSHR146", "rank": "Strain"}, "1249474": {"name": "Burkholderia pseudomallei MSHR511", "rank": "Strain"}, "1249476": {"name": "Burkholderia pseudomallei NAU20B-16", "rank": "Strain"}, "5314": {"name": "Ganoderma", "rank": "Genus"}, "1422637": {"name": "Staphylococcus aureus VET0410R", "rank": "Strain"}, "1422636": {"name": "Staphylococcus aureus VET0407R", "rank": "Strain"}, "1422635": {"name": "Staphylococcus aureus VET0406R", "rank": "Strain"}, "1422634": {"name": "Staphylococcus aureus VET0403R", "rank": "Strain"}, "1422633": {"name": "Staphylococcus aureus VET0402R", "rank": "Strain"}, "1422632": {"name": "Staphylococcus aureus VET0401R", "rank": "Strain"}, "1422631": {"name": "Staphylococcus aureus VET0400R", "rank": "Strain"}, "1422630": {"name": "Staphylococcus aureus VET0399R", "rank": "Strain"}, "1422639": {"name": "Staphylococcus aureus VET0412R", "rank": "Strain"}, "1422638": {"name": "Staphylococcus aureus VET0411R", "rank": "Strain"}, "1415781": {"name": "Mycoplasma cricetuli ATCC 35279", "rank": "Strain"}, "1412577": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20122022", "rank": "Strain"}, "1412576": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20122026", "rank": "Strain"}, "1412575": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20122031", "rank": "Strain"}, "1412574": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20122033", "rank": "Strain"}, "1412573": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20122045", "rank": "Strain"}, "1412572": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20111561", "rank": "Strain"}, "1412571": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20121812", "rank": "Strain"}, "1412570": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20120916", "rank": "Strain"}, "693272": {"name": "Cafeteria roenbergensis virus BV-PW1", "rank": "Strain"}, "1412579": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20121989", "rank": "Strain"}, "1412578": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20121990", "rank": "Strain"}, "1121932": {"name": "Gramella portivictoriae DSM 23547", "rank": "Strain"}, "1417129": {"name": "Staphylococcus aureus F12917", "rank": "Strain"}, "1417128": {"name": "Staphylococcus aureus F12915", "rank": "Strain"}, "1417127": {"name": "Staphylococcus aureus H49917", "rank": "Strain"}, "1417126": {"name": "Staphylococcus aureus H49922", "rank": "Strain"}, "1417125": {"name": "Staphylococcus aureus T12849", "rank": "Strain"}, "1417124": {"name": "Staphylococcus aureus W73592", "rank": "Strain"}, "1417123": {"name": "Staphylococcus aureus W73676", "rank": "Strain"}, "1417122": {"name": "Staphylococcus aureus M49474", "rank": "Strain"}, "1417121": {"name": "Staphylococcus aureus H81433", "rank": "Strain"}, "1417120": {"name": "Staphylococcus aureus M49455", "rank": "Strain"}, "1380408": {"name": "Anoxybacillus flavithermus subsp. yunnanensis str. E13", "rank": "Strain"}, "272624": {"name": "Legionella pneumophila subsp. pneumophila str. Philadelphia 1", "rank": "Strain"}, "1438669": {"name": "Escherichia coli BIDMC 59", "rank": "Strain"}, "1129742": {"name": "Belli group", "rank": "Species group"}, "74660": {"name": "Choristoneura fumiferana DEF multiple nucleopolyhedrovirus", "rank": "Species"}, "1457189": {"name": "Brucella melitensis 548", "rank": "Strain"}, "383372": {"name": "Roseiflexus castenholzii DSM 13941", "rank": "Strain"}, "272623": {"name": "Lactococcus lactis subsp. lactis Il1403", "rank": "Strain"}, "272622": {"name": "Lactococcus lactis subsp. cremoris SK11", "rank": "Strain"}, "158822": {"name": "Cedecea neteri", "rank": "Species"}, "693897": {"name": "Tomato yellow leaf curl Thailand betasatellite", "rank": "Species"}, "693894": {"name": "Tomato leaf curl Cameroon virus", "rank": "Species"}, "693892": {"name": "Sweet potato leaf curl Bengal virus", "rank": "Species"}, "1345561": {"name": "Helicobacter pylori SA160C", "rank": "Strain"}, "749544": {"name": "Escherichia coli MS 175-1", "rank": "Strain"}, "1345563": {"name": "Helicobacter pylori SA161C", "rank": "Strain"}, "1345562": {"name": "Helicobacter pylori SA161A", "rank": "Strain"}, "749541": {"name": "Escherichia coli MS 153-1", "rank": "Strain"}, "1345564": {"name": "Helicobacter pylori SA162A", "rank": "Strain"}, "1345567": {"name": "Helicobacter pylori SA163C", "rank": "Strain"}, "1345566": {"name": "Helicobacter pylori SA163A", "rank": "Strain"}, "1345569": {"name": "Helicobacter pylori SA164C", "rank": "Strain"}, "1345568": {"name": "Helicobacter pylori SA164A", "rank": "Strain"}, "1388697": {"name": "Staphylococcus aureus M0929", "rank": "Strain"}, "749549": {"name": "Escherichia coli MS 198-1", "rank": "Strain"}, "749548": {"name": "Escherichia coli MS 196-1", "rank": "Strain"}, "1225203": {"name": "Streptococcus mutans B111SM-A", "rank": "Strain"}, "1225202": {"name": "Streptococcus mutans B23Sm1", "rank": "Strain"}, "1001240": {"name": "Cryobacterium roopkundense", "rank": "Species"}, "1128327": {"name": "Bradyrhizobium yuanmingense CCBAU 25021", "rank": "Strain"}, "1128328": {"name": "Bradyrhizobium yuanmingense CCBAU 35157", "rank": "Strain"}, "1128329": {"name": "Sinorhizobium fredii CCBAU 05557", "rank": "Strain"}, "491079": {"name": "Treponema pallidum subsp. pertenue str. CDC2", "rank": "Strain"}, "491078": {"name": "Treponema pallidum subsp. pertenue str. SamoaD", "rank": "Strain"}, "320933": {"name": "Salinibacillus", "rank": "Genus"}, "506534": {"name": "Rheinheimera sp. A13L", "rank": "Species"}, "1418415": {"name": "Staphylococcus aureus M79654", "rank": "Strain"}, "491075": {"name": "Enterococcus faecalis EnGen0297", "rank": "Strain"}, "491074": {"name": "Enterococcus faecalis TX0104", "rank": "Strain"}, "491077": {"name": "Lactobacillus reuteri SD2112", "rank": "Strain"}, "491076": {"name": "Lactobacillus crispatus JV-V01", "rank": "Strain"}, "330702": {"name": "Leptospira kirschneri serovar Bim", "rank": "Strain"}, "1005542": {"name": "Escherichia coli EC1847", "rank": "Strain"}, "1005543": {"name": "Escherichia coli EC1848", "rank": "Strain"}, "1005540": {"name": "Escherichia coli EC1845", "rank": "Strain"}, "1402566": {"name": "Pseudomonas aeruginosa BL25", "rank": "Strain"}, "1005546": {"name": "Escherichia coli EC1856", "rank": "Strain"}, "135735": {"name": "Bacillus endophyticus", "rank": "Species"}, "1005545": {"name": "Escherichia coli EC1850", "rank": "Strain"}, "1005548": {"name": "Escherichia coli EC1863", "rank": "Strain"}, "1005549": {"name": "Escherichia coli EC1864", "rank": "Strain"}, "1513458": {"name": "Marseillevirus", "rank": "Genus"}, "43141": {"name": "Watermelon silver mottle virus", "rank": "Species"}, "1051072": {"name": "Streptococcus equi subsp. zooepidemicus ATCC 35246", "rank": "Strain"}, "410826": {"name": "Potato apical leaf curl disease-associated satellite DNA beta", "rank": "Species"}, "394221": {"name": "Maricaulis maris MCS10", "rank": "Strain"}, "1182690": {"name": "Escherichia coli KTE84", "rank": "Strain"}, "1182691": {"name": "Escherichia coli KTE86", "rank": "Strain"}, "1182692": {"name": "Escherichia coli KTE87", "rank": "Strain"}, "1182693": {"name": "Escherichia coli KTE89", "rank": "Strain"}, "1182694": {"name": "Escherichia coli KTE91", "rank": "Strain"}, "1182695": {"name": "Klebsiella sp. KTE92", "rank": "Species"}, "1182696": {"name": "Escherichia coli KTE93", "rank": "Strain"}, "1182697": {"name": "Escherichia sp. KTE96", "rank": "Species"}, "1182698": {"name": "Escherichia coli KTE98", "rank": "Strain"}, "1182699": {"name": "Escherichia coli KTE100", "rank": "Strain"}, "1173748": {"name": "Listeria phage LP-110", "rank": "Species"}, "1173749": {"name": "Salmonella phage FSL SP-031", "rank": "Species"}, "1225188": {"name": "Streptococcus mutans B13Sm1", "rank": "Strain"}, "1225189": {"name": "Streptococcus mutans B12Sm1", "rank": "Strain"}, "1281172": {"name": "Escherichia coli KOEGE 131 (358a)", "rank": "Strain"}, "1225186": {"name": "Streptococcus mutans str. B16 P Sm1", "rank": "Strain"}, "1388707": {"name": "Staphylococcus aureus M0941", "rank": "Strain"}, "1225187": {"name": "Streptococcus mutans B05Sm11", "rank": "Strain"}, "653386": {"name": "Actinomyces sp. oral taxon 849 str. F0330", "rank": "Strain"}, "653385": {"name": "Actinomyces sp. oral taxon 849", "rank": "Species"}, "329553": {"name": "Planktothrix agardhii NIVA-CYA 15", "rank": "Strain"}, "84159": {"name": "Magnetospirillum magneticum", "rank": "Species"}, "1348253": {"name": "Microbacterium mangrovi", "rank": "Species"}, "84156": {"name": "Archaeoglobus profundus", "rank": "Species"}, "10437": {"name": "Avihepadnavirus", "rank": "Genus"}, "1415784": {"name": "Bacillus toyonensis BCT-7112", "rank": "Strain"}, "1382230": {"name": "Asaia platycodi SF2.1", "rank": "Strain"}, "1415780": {"name": "Algiphilus aromaticivorans DG1253", "rank": "Strain"}, "326811": {"name": "Clerodendron yellow mosaic virus", "rank": "Species"}, "1500289": {"name": "Chryseobacterium sp. OV705", "rank": "Species"}, "1459641": {"name": "Unclassified Bacilladnavirus", "rank": "No rank"}, "1173703": {"name": "Yug Bogdanovac virus", "rank": "Species"}, "1074179": {"name": "Streptococcus mutans TCI-268", "rank": "Strain"}, "1074178": {"name": "Streptococcus mutans TCI-267", "rank": "Strain"}, "1074177": {"name": "Streptococcus mutans TCI-264", "rank": "Strain"}, "1074176": {"name": "Streptococcus mutans TCI-260", "rank": "Strain"}, "1074175": {"name": "Streptococcus mutans TCI-256", "rank": "Strain"}, "1500282": {"name": "Chryseobacterium sp. CF365", "rank": "Species"}, "1074173": {"name": "Streptococcus mutans TCI-249", "rank": "Strain"}, "1189311": {"name": "Staphylococcus capitis QN1", "rank": "Strain"}, "1074171": {"name": "Streptococcus mutans TCI-244", "rank": "Strain"}, "1074170": {"name": "Streptococcus mutans TCI-243", "rank": "Strain"}, "1413369": {"name": "Staphylococcus aureus 12S01399", "rank": "Strain"}, "1413368": {"name": "Staphylococcus aureus 12S01153", "rank": "Strain"}, "1413365": {"name": "Staphylococcus aureus 12S00579", "rank": "Strain"}, "1413364": {"name": "Staphylococcus aureus 12S00040", "rank": "Strain"}, "1413367": {"name": "Staphylococcus aureus 12S00972", "rank": "Strain"}, "1413366": {"name": "Staphylococcus aureus 12S00881", "rank": "Strain"}, "1413361": {"name": "Staphylococcus aureus 11S01415", "rank": "Strain"}, "1413360": {"name": "Staphylococcus aureus 11S00627", "rank": "Strain"}, "1413363": {"name": "Staphylococcus aureus 11S01586", "rank": "Strain"}, "1121324": {"name": "Clostridium litorale DSM 5388", "rank": "Strain"}, "1400001": {"name": "Pasteurella sp. FF6", "rank": "Species"}, "762948": {"name": "Rothia dentocariosa ATCC 17931", "rank": "Strain"}, "1341876": {"name": "Maize yellow dwarf virus-RMV", "rank": "Species"}, "89059": {"name": "Lactobacillus acidipiscis", "rank": "Species"}, "211968": {"name": "Salmonella enterica subsp. enterica serovar Albany", "rank": "Strain"}, "89053": {"name": "Gordonia amicalis", "rank": "Species"}, "89050": {"name": "Streptomyces yeochonensis", "rank": "Species"}, "239934": {"name": "Akkermansia", "rank": "Genus"}, "1394141": {"name": "Ferret papillomavirus", "rank": "Species"}, "1489836": {"name": "Atlantic salmon calicivirus", "rank": "Species"}, "415849": {"name": "Solimonas flava", "rank": "Species"}, "392736": {"name": "Uliginosibacterium gangwonense", "rank": "Species"}, "113608": {"name": "Tetrapisispora phaffii", "rank": "Species"}, "65123": {"name": "Mycoplasma wenyonii", "rank": "Species"}, "411490": {"name": "Anaerostipes caccae DSM 14662", "rank": "Strain"}, "32604": {"name": "Human herpesvirus 6B", "rank": "Species"}, "663": {"name": "Vibrio alginolyticus", "rank": "Species"}, "662": {"name": "Vibrio", "rank": "Genus"}, "666": {"name": "Vibrio cholerae", "rank": "Species"}, "669": {"name": "Vibrio harveyi", "rank": "Species"}, "668": {"name": "Aliivibrio fischeri", "rank": "Species"}, "1130804": {"name": "Streptococcus pneumoniae ST556", "rank": "Strain"}, "870465": {"name": "Melon chlorotic mosaic virus-associated alphasatellite", "rank": "Species"}, "674036": {"name": "Methylobacter marinus A45", "rank": "Strain"}, "167642": {"name": "Ilyobacter polytropus", "rank": "Species"}, "1388638": {"name": "Staphylococcus aureus M0849", "rank": "Strain"}, "1388639": {"name": "Staphylococcus aureus M0860", "rank": "Strain"}, "1388636": {"name": "Staphylococcus aureus M0816", "rank": "Strain"}, "1388637": {"name": "Staphylococcus aureus M0827", "rank": "Strain"}, "1388634": {"name": "Staphylococcus aureus M0787", "rank": "Strain"}, "1388635": {"name": "Staphylococcus aureus M0803", "rank": "Strain"}, "1388632": {"name": "Staphylococcus aureus M0745", "rank": "Strain"}, "1388633": {"name": "Staphylococcus aureus M0776", "rank": "Strain"}, "1388630": {"name": "Staphylococcus aureus M0861", "rank": "Strain"}, "1388631": {"name": "Staphylococcus aureus M0862", "rank": "Strain"}, "246201": {"name": "Streptococcus mitis NCTC 12261", "rank": "Strain"}, "431596": {"name": "Paenibacillus ginsengihumi", "rank": "Species"}, "218493": {"name": "Salmonella bongori NCTC 12419", "rank": "Strain"}, "218491": {"name": "Pectobacterium atrosepticum SCRI1043", "rank": "Strain"}, "218496": {"name": "Tropheryma whipplei TW08/27", "rank": "Strain"}, "218497": {"name": "Chlamydophila abortus S26/3", "rank": "Strain"}, "218494": {"name": "Streptococcus suis P1/7", "rank": "Strain"}, "218495": {"name": "Streptococcus uberis 0140J", "rank": "Strain"}, "1291534": {"name": "Gluconobacter thailandicus NBRC 3255", "rank": "Strain"}, "1391465": {"name": "Enterococcus faecium 10/96A", "rank": "Strain"}, "1391464": {"name": "Listeria monocytogenes serotype 4bV str. LS542", "rank": "Strain"}, "1391467": {"name": "Enterococcus faecium BM4538", "rank": "Strain"}, "1391466": {"name": "Enterococcus faecium NEF1", "rank": "Strain"}, "1391469": {"name": "Enterococcus faecalis BM4654", "rank": "Strain"}, "1391468": {"name": "Enterococcus faecalis BM4539", "rank": "Strain"}, "1259812": {"name": "Vibrio mimicus CAIM 602", "rank": "Strain"}, "1283078": {"name": "Pelagibacter phage HTVC011P", "rank": "Species"}, "1283079": {"name": "Pelagibacter phage HTVC019P", "rank": "Species"}, "1283076": {"name": "Pelagibacter phage HTVC008M", "rank": "Species"}, "1283077": {"name": "Pelagibacter phage HTVC010P", "rank": "Species"}, "340097": {"name": "Tuberibacillus calidus", "rank": "Species"}, "1283071": {"name": "Vibrio phage JA-1", "rank": "Species"}, "1499504": {"name": "Prochlorococcus sp. MIT 0703", "rank": "Species"}, "1352578": {"name": "Mycobacterium tuberculosis PanR0606", "rank": "Strain"}, "37727": {"name": "Talaromyces marneffei", "rank": "Species"}, "499228": {"name": "Tepidanaerobacter", "rank": "Genus"}, "499229": {"name": "Tepidanaerobacter acetatoxydans", "rank": "Species"}, "68933": {"name": "Thermales", "rank": "Order"}, "1352572": {"name": "Mycobacterium tuberculosis PanR0505", "rank": "Strain"}, "1352573": {"name": "Mycobacterium tuberculosis PanR0601", "rank": "Strain"}, "1352570": {"name": "Mycobacterium tuberculosis PanR0501", "rank": "Strain"}, "1352571": {"name": "Mycobacterium tuberculosis PanR0503", "rank": "Strain"}, "1352576": {"name": "Mycobacterium tuberculosis PanR0604", "rank": "Strain"}, "1352577": {"name": "Mycobacterium tuberculosis PanR0605", "rank": "Strain"}, "1352574": {"name": "Mycobacterium tuberculosis PanR0602", "rank": "Strain"}, "631267": {"name": "Chaoyang virus", "rank": "Species"}, "1263979": {"name": "Candidatus Endolissoclinum faulkneri", "rank": "Species"}, "1263978": {"name": "Candidatus Endolissoclinum", "rank": "Genus"}, "218140": {"name": "Bifidobacterium psychraerophilum", "rank": "Species"}, "381852": {"name": "Haloferax prahovense", "rank": "Species"}, "1400860": {"name": "Candidatus Contendobacter odensis", "rank": "Species"}, "1400861": {"name": "Candidatus Contendobacter odensis Run_B_J11", "rank": "Strain"}, "1400867": {"name": "Acinetobacter baumannii ZW85-1", "rank": "Strain"}, "1400868": {"name": "Pseudomonas aeruginosa VRFPA04", "rank": "Strain"}, "1400869": {"name": "Lysinibacillus sphaericus CBAM5", "rank": "Strain"}, "476212": {"name": "Borrelia burgdorferi 94a", "rank": "Strain"}, "476213": {"name": "Salmonella enterica subsp. enterica serovar Paratyphi C str. RKS4594", "rank": "Strain"}, "476210": {"name": "Borrelia burgdorferi 118a", "rank": "Strain"}, "476211": {"name": "Borrelia burgdorferi 72a", "rank": "Strain"}, "264730": {"name": "Pseudomonas syringae pv. phaseolicola 1448A", "rank": "Strain"}, "1116130": {"name": "Escherichia coli 199900.1", "rank": "Strain"}, "264732": {"name": "Moorella thermoacetica ATCC 39073", "rank": "Strain"}, "1508594": {"name": "Chloroflexineae", "rank": "Suborder"}, "1105097": {"name": "Rickettsia prowazekii str. Dachau", "rank": "Strain"}, "1105096": {"name": "Rickettsia prowazekii str. BuV67-CWPP", "rank": "Strain"}, "1105095": {"name": "Rickettsia prowazekii str. Katsinyian", "rank": "Strain"}, "1105094": {"name": "Rickettsia prowazekii str. Chernikova", "rank": "Strain"}, "1105099": {"name": "Rickettsia prowazekii str. RpGvF24", "rank": "Strain"}, "1105098": {"name": "Rickettsia prowazekii str. GvV257", "rank": "Strain"}, "11631": {"name": "Tacaribe virus", "rank": "Species"}, "622454": {"name": "Cryptosporangiaceae", "rank": "Family"}, "622452": {"name": "Kineosporiineae", "rank": "Suborder"}, "622451": {"name": "Actinopolysporaceae", "rank": "Family"}, "622450": {"name": "Actinopolysporineae", "rank": "Suborder"}, "674962": {"name": "Bacillarnavirus", "rank": "Genus"}, "674963": {"name": "Succinatimonas", "rank": "Genus"}, "1134914": {"name": "Staphylococcus haemolyticus R1P1", "rank": "Strain"}, "1134912": {"name": "Methylocystis parvus OBBP", "rank": "Strain"}, "1003201": {"name": "Rickettsia typhi str. TH1527", "rank": "Strain"}, "1256204": {"name": "Lactobacillus paracasei subsp. paracasei Lpp14", "rank": "Strain"}, "97253": {"name": "Eubacterium plexicaudatum", "rank": "Species"}, "357240": {"name": "Cronobacter helveticus", "rank": "Species"}, "1394889": {"name": "Thermosynechococcus sp. NK55a", "rank": "Species"}, "944546": {"name": "Arcobacter butzleri ED-1", "rank": "Strain"}, "944547": {"name": "Arcobacter sp. L", "rank": "Species"}, "1537158": {"name": "Lactobacillus delbrueckii subsp. jakobsenii", "rank": "Subspecies"}, "1346792": {"name": "Acinetobacter baumannii AB-HKU3-08", "rank": "Strain"}, "1402648": {"name": "Staphylococcus aureus M1135", "rank": "Strain"}, "1402649": {"name": "Staphylococcus aureus M1136", "rank": "Strain"}, "1481663": {"name": "Vibrio metoecus", "rank": "Species"}, "1346790": {"name": "Sphingobium chinhatense IP26", "rank": "Strain"}, "444859": {"name": "Synechococcus phage S-SM1", "rank": "Species"}, "267285": {"name": "Chalara elegans RNA Virus 1", "rank": "Species"}, "487821": {"name": "Xanthomonas arboricola pv. corylina", "rank": "Strain"}, "741733": {"name": "Malvastrum yellow mosaic Cameroon alphasatellite", "rank": "Species"}, "1181729": {"name": "Escherichia coli KTE183", "rank": "Strain"}, "1311138": {"name": "Acinetobacter baumannii 42057_6", "rank": "Strain"}, "1311131": {"name": "Acinetobacter baumannii 45057_4", "rank": "Strain"}, "1311137": {"name": "Acinetobacter baumannii 42057_5", "rank": "Strain"}, "1311136": {"name": "Acinetobacter baumannii 42057_4", "rank": "Strain"}, "1311135": {"name": "Acinetobacter baumannii 42057_3", "rank": "Strain"}, "1311134": {"name": "Acinetobacter baumannii 42057_2", "rank": "Strain"}, "279916": {"name": "Mobiluncus/Falcivibrio group", "rank": "No rank"}, "596318": {"name": "Acinetobacter radioresistens SK82", "rank": "Strain"}, "707241": {"name": "Sinorhizobium meliloti SM11", "rank": "Strain"}, "1174530": {"name": "Feline bocavirus", "rank": "Strain"}, "176290": {"name": "Halomonas halocynthiae", "rank": "Species"}, "176292": {"name": "Lactobacillus malefermentans", "rank": "Species"}, "351160": {"name": "Methanocella arvoryzae MRE50", "rank": "Strain"}, "331678": {"name": "Chlorobium phaeobacteroides BS1", "rank": "Strain"}, "758796": {"name": "Burkholderia sp. RPE67", "rank": "Species"}, "1225205": {"name": "Streptococcus mutans B115SM-A", "rank": "Strain"}, "758793": {"name": "Burkholderia sp. RPE64", "rank": "Species"}, "257440": {"name": "Pleomorphomonas koreensis", "rank": "Species"}, "1310721": {"name": "Acinetobacter baumannii 1533268", "rank": "Strain"}, "1310720": {"name": "Acinetobacter baumannii 478810", "rank": "Strain"}, "1310723": {"name": "Acinetobacter baumannii 1564232", "rank": "Strain"}, "1310722": {"name": "Acinetobacter baumannii 825610", "rank": "Strain"}, "1310725": {"name": "Acinetobacter baumannii 1062314", "rank": "Strain"}, "1310724": {"name": "Acinetobacter baumannii 1245249", "rank": "Strain"}, "1310727": {"name": "Acinetobacter baumannii 836190", "rank": "Strain"}, "1169359": {"name": "Escherichia coli KTE42", "rank": "Strain"}, "1169356": {"name": "Escherichia coli KTE39", "rank": "Strain"}, "1310728": {"name": "Acinetobacter baumannii 1245593", "rank": "Strain"}, "1169354": {"name": "Escherichia coli KTE37", "rank": "Strain"}, "1169355": {"name": "Escherichia coli KTE38", "rank": "Strain"}, "1169352": {"name": "Escherichia coli KTE34", "rank": "Strain"}, "1169353": {"name": "Escherichia coli KTE36", "rank": "Strain"}, "1169350": {"name": "Citrobacter sp. KTE32", "rank": "Species"}, "1169351": {"name": "Escherichia coli KTE33", "rank": "Strain"}, "1408909": {"name": "Mycobacterium tuberculosis UT0009", "rank": "Strain"}, "1339314": {"name": "Bacteroides fragilis str. 3976T8", "rank": "Strain"}, "1339317": {"name": "Bacteroides fragilis str. S6L3", "rank": "Strain"}, "260742": {"name": "Streptomyces sp. SS", "rank": "Species"}, "1339311": {"name": "Bacteroides fragilis str. 3783N1-8", "rank": "Strain"}, "1339310": {"name": "Bacteroides fragilis str. 3783N1-6", "rank": "Strain"}, "1339313": {"name": "Bacteroides fragilis str. 3976T7", "rank": "Strain"}, "1339312": {"name": "Bacteroides fragilis str. 3783N2-1", "rank": "Strain"}, "1329380": {"name": "Ageratum Yellow vein China virus - OX1", "rank": "Species"}, "1408905": {"name": "Mycobacterium tuberculosis UT0002", "rank": "Strain"}, "1339318": {"name": "Bacteroides fragilis str. S6L5", "rank": "Strain"}, "1408907": {"name": "Mycobacterium tuberculosis UT0004", "rank": "Strain"}, "1408906": {"name": "Mycobacterium tuberculosis UT0003", "rank": "Strain"}, "1398059": {"name": "Staphylococcus aureus M1447", "rank": "Strain"}, "1398058": {"name": "Staphylococcus aureus M1446", "rank": "Strain"}, "572418": {"name": "Mycobacterium africanum GM041182", "rank": "Strain"}, "1398053": {"name": "Staphylococcus aureus M1438", "rank": "Strain"}, "1398052": {"name": "Staphylococcus aureus M1437", "rank": "Strain"}, "1398051": {"name": "Staphylococcus aureus M1436", "rank": "Strain"}, "1398050": {"name": "Staphylococcus aureus M1435", "rank": "Strain"}, "1398057": {"name": "Staphylococcus aureus M1445", "rank": "Strain"}, "1398056": {"name": "Staphylococcus aureus M1444", "rank": "Strain"}, "1398055": {"name": "Staphylococcus aureus M1443", "rank": "Strain"}, "1398054": {"name": "Staphylococcus aureus M1441", "rank": "Strain"}, "1111728": {"name": "Budvicia aquatica DSM 5075 = ATCC 35567", "rank": "Strain"}, "1111729": {"name": "Corynebacterium sputi DSM 45148", "rank": "Strain"}, "992060": {"name": "Helicobacter pylori Hp H-4", "rank": "Strain"}, "1077442": {"name": "Talaromyces marneffei PM1", "rank": "Strain"}, "992062": {"name": "Helicobacter pylori Hp H-9", "rank": "Strain"}, "992063": {"name": "Helicobacter pylori Hp H-10", "rank": "Strain"}, "992064": {"name": "Helicobacter pylori Hp H-11", "rank": "Strain"}, "992065": {"name": "Helicobacter pylori Hp H-18", "rank": "Strain"}, "992066": {"name": "Helicobacter pylori Hp H-19", "rank": "Strain"}, "992067": {"name": "Helicobacter pylori Hp H-21", "rank": "Strain"}, "992068": {"name": "Helicobacter pylori Hp H-23", "rank": "Strain"}, "992069": {"name": "Helicobacter pylori Hp H-34", "rank": "Strain"}, "1449061": {"name": "Ochrobactrum sp. UNC390CL2Tsu3S39", "rank": "Species"}, "1449060": {"name": "Mycobacterium sp. UNCCL9", "rank": "Species"}, "1449063": {"name": "Paenibacillus sp. UNC451MF", "rank": "Species"}, "1449062": {"name": "Paenibacillus sp. UNC217MF", "rank": "Species"}, "1449065": {"name": "Phyllobacterium sp. UNC302MFCol5.2", "rank": "Species"}, "1449064": {"name": "Paenibacillus sp. UNCCL52", "rank": "Species"}, "1449069": {"name": "Rhodococcus sp. UNC363MFTsu5.1", "rank": "Species"}, "1126906": {"name": "Escherichia coli C527_94", "rank": "Strain"}, "686659": {"name": "Propionibacterium acnes SK187", "rank": "Strain"}, "1126907": {"name": "Escherichia coli C581_05", "rank": "Strain"}, "1052585": {"name": "Bacillus subtilis subsp. spizizenii TU-B-10", "rank": "Strain"}, "1126905": {"name": "Escherichia coli C497_10", "rank": "Strain"}, "1052588": {"name": "Bacillus subtilis subsp. subtilis str. RO-NN-1", "rank": "Strain"}, "1527771": {"name": "Mesorhizobium phagevB_MloP_Lo5R7ANS", "rank": "Species"}, "981384": {"name": "Ruegeria conchae", "rank": "Species"}, "43305": {"name": "Butyrivibrio proteoclasticus", "rank": "Species"}, "981383": {"name": "Ornithinibacillus scapharcae TW25", "rank": "Strain"}, "43306": {"name": "Pseudomonas denitrificans", "rank": "Species"}, "100474": {"name": "Batrachochytrium", "rank": "Genus"}, "189691": {"name": "Paenibacillus elgii", "rank": "Species"}, "931223": {"name": "Rhodococcus sp. BCP1", "rank": "Species"}, "931222": {"name": "Lebetimonas sp. JS085", "rank": "Species"}, "392320": {"name": "Burkholderia nodosa", "rank": "Species"}, "1417303": {"name": "Dehalococcoidia bacterium Dsc1", "rank": "Species"}, "742816": {"name": "Megamonas funiformis YIT 11815", "rank": "Strain"}, "742817": {"name": "Odoribacter laneus YIT 12061", "rank": "Strain"}, "742814": {"name": "Fusobacterium necrophorum subsp. funduliforme 1_1_36S", "rank": "Strain"}, "1316445": {"name": "Streptomyces albulus CCRC 11814", "rank": "Strain"}, "1224318": {"name": "Mangrovibacter sp. MFB070", "rank": "Species"}, "742813": {"name": "Enterococcus saccharolyticus 30_1", "rank": "Strain"}, "1053181": {"name": "Bacillus cereus BAG2X1-3", "rank": "Strain"}, "1053180": {"name": "Bacillus cereus BAG2X1-2", "rank": "Strain"}, "1053183": {"name": "Bacillus cereus BAG3X2-1", "rank": "Strain"}, "1053182": {"name": "Bacillus cereus BAG3O-2", "rank": "Strain"}, "1053185": {"name": "Bacillus cereus BAG4O-1", "rank": "Strain"}, "1053184": {"name": "Bacillus cereus BAG3X2-2", "rank": "Strain"}, "1053187": {"name": "Bacillus cereus BAG4X2-1", "rank": "Strain"}, "1053186": {"name": "Bacillus cereus BAG4X12-1", "rank": "Strain"}, "889221": {"name": "Campylobacter jejuni subsp. jejuni 1997-1", "rank": "Strain"}, "889220": {"name": "Campylobacter jejuni subsp. jejuni 53161", "rank": "Strain"}, "889223": {"name": "Campylobacter jejuni subsp. jejuni 1997-7", "rank": "Strain"}, "889222": {"name": "Campylobacter jejuni subsp. jejuni 1997-4", "rank": "Strain"}, "889225": {"name": "Campylobacter jejuni subsp. jejuni 1997-11", "rank": "Strain"}, "889224": {"name": "Campylobacter jejuni subsp. jejuni 1997-10", "rank": "Strain"}, "889227": {"name": "Campylobacter jejuni subsp. jejuni 51037", "rank": "Strain"}, "889226": {"name": "Campylobacter jejuni subsp. jejuni 1997-14", "rank": "Strain"}, "889229": {"name": "Campylobacter jejuni subsp. jejuni 87459", "rank": "Strain"}, "889228": {"name": "Campylobacter jejuni subsp. jejuni 87330", "rank": "Strain"}, "257708": {"name": "Roseomonas gilardii", "rank": "Species"}, "1286363": {"name": "Bacillus sp. 171095_106", "rank": "Species"}, "1110702": {"name": "Campylobacter phage CPX", "rank": "Strain"}, "310540": {"name": "Simian adenovirus 1", "rank": "Strain"}, "1353795": {"name": "Leptopilina boulardi RNA virus", "rank": "Species"}, "441771": {"name": "Clostridium botulinum A str. Hall", "rank": "Strain"}, "441770": {"name": "Clostridium botulinum A str. ATCC 19397", "rank": "Strain"}, "671126": {"name": "Pelargonium vein banding virus", "rank": "Species"}, "400396": {"name": "Wild tomato mosaic virus", "rank": "Species"}, "400394": {"name": "Telosma mosaic virus", "rank": "Species"}, "563038": {"name": "Streptococcus sp. M334", "rank": "Species"}, "563037": {"name": "Streptococcus sp. M143", "rank": "Species"}, "563036": {"name": "Streptococcus sp. C300", "rank": "Species"}, "563033": {"name": "Rothia mucilaginosa M508", "rank": "Strain"}, "563032": {"name": "Rothia dentocariosa M567", "rank": "Strain"}, "563031": {"name": "Prevotella sp. C561", "rank": "Species"}, "943083": {"name": "California sea lion adenovirus 1", "rank": "Species"}, "1429044": {"name": "Vibrio parahaemolyticus UCM-V493", "rank": "Strain"}, "1429046": {"name": "Rhodococcus rhodochrous ATCC 21198", "rank": "Strain"}, "1157358": {"name": "Enterococcus faecalis EnGen0097", "rank": "Strain"}, "1242992": {"name": "Leptospira sp. B5-022", "rank": "Species"}, "1242993": {"name": "Ehrlichia mineirensis", "rank": "Species"}, "1242990": {"name": "Leptospira sp. serovar Kenya", "rank": "Species"}, "1242991": {"name": "Leptospira sp. serovar Kenya str. Sh9", "rank": "Strain"}, "1446554": {"name": "Escherichia coli O121:H19 str. 06-3822", "rank": "Strain"}, "1446555": {"name": "Escherichia coli O121:H19 str. 2009C-4050", "rank": "Strain"}, "1446556": {"name": "Escherichia coli O121:H19 str. 2009C-4659", "rank": "Strain"}, "1446557": {"name": "Escherichia coli O121:H19 str. 2009C-4750", "rank": "Strain"}, "1446550": {"name": "Escherichia coli O119:H4", "rank": "Strain"}, "1446551": {"name": "Escherichia coli O119:H4 str. 03-3458", "rank": "Strain"}, "1446552": {"name": "Escherichia coli O121:H19 str. 03-3227", "rank": "Strain"}, "1446553": {"name": "Escherichia coli O121:H19 str. 06-3003", "rank": "Strain"}, "1121121": {"name": "Brevibacillus laterosporus DSM 25", "rank": "Strain"}, "1121123": {"name": "Brevundimonas aveniformis DSM 17977", "rank": "Strain"}, "1121122": {"name": "Brevibacterium album DSM 18261", "rank": "Strain"}, "1121125": {"name": "Brevundimonas naejangsanensis DSM 23858", "rank": "Strain"}, "1121124": {"name": "Brevundimonas bacteroides DSM 4726", "rank": "Strain"}, "1121127": {"name": "Burkholderia nodosa DSM 21604", "rank": "Strain"}, "1121126": {"name": "Brochothrix thermosphacta DSM 20171 = FSL F6-1036", "rank": "Strain"}, "1413556": {"name": "Staphylococcus aureus Tur-15", "rank": "Strain"}, "1413557": {"name": "Staphylococcus aureus 28(18S1K13-24-05)", "rank": "Strain"}, "525280": {"name": "Erysipelothrix rhusiopathiae ATCC 19414", "rank": "Strain"}, "222079": {"name": "Ageratum yellow vein Sri Lanka virus", "rank": "Species"}, "1413555": {"name": "Staphylococcus aureus Tur-12", "rank": "Strain"}, "1321372": {"name": "Streptococcus suis EA1832.92", "rank": "Strain"}, "1534548": {"name": "Chicken picornavirus 5", "rank": "Species"}, "1321370": {"name": "Idiomarina loihiensis GSL 199", "rank": "Strain"}, "1321371": {"name": "Holospora undulata HU1", "rank": "Strain"}, "1534545": {"name": "Chicken picornavirus 2", "rank": "Species"}, "1534544": {"name": "Chicken picornavirus 1", "rank": "Species"}, "1534547": {"name": "Chicken picornavirus 4", "rank": "Species"}, "1534546": {"name": "Chicken picornavirus 3", "rank": "Species"}, "1158648": {"name": "Enterococcus faecium EnGen0318", "rank": "Strain"}, "1158649": {"name": "Enterococcus faecium EnGen0319", "rank": "Strain"}, "1413550": {"name": "Staphylococcus aureus Chi-8", "rank": "Strain"}, "1158640": {"name": "Enterococcus faecalis EnGen0301", "rank": "Strain"}, "1158641": {"name": "Enterococcus faecium EnGen0305", "rank": "Strain"}, "1158642": {"name": "Enterococcus faecium EnGen0308", "rank": "Strain"}, "1158644": {"name": "Enterococcus faecium EnGen0320", "rank": "Strain"}, "1158645": {"name": "Enterococcus faecium EnGen0322", "rank": "Strain"}, "1158646": {"name": "Enterococcus faecium EnGen0314", "rank": "Strain"}, "1158647": {"name": "Enterococcus faecium EnGen0316", "rank": "Strain"}, "482628": {"name": "Campylobacter jejuni subsp. jejuni BH-01-0142", "rank": "Strain"}, "482629": {"name": "Hassallia", "rank": "Genus"}, "1177712": {"name": "Komagataeibacter medellinensis", "rank": "Species"}, "162387": {"name": "Metapneumovirus", "rank": "Genus"}, "1161942": {"name": "Ruminococcus champanellensis", "rank": "Species"}, "51123": {"name": "Eubacterium saphenum", "rank": "Species"}, "1232672": {"name": "Bacillus licheniformis CGMCC 3963", "rank": "Strain"}, "1232673": {"name": "Aeromonas hydrophila SNUFPC-A8", "rank": "Strain"}, "1232675": {"name": "Micrococcus luteus str. modasa", "rank": "Strain"}, "1471444": {"name": "Prochlorococcus sp. scB241_527E14", "rank": "Species"}, "1471445": {"name": "Prochlorococcus sp. scB241_527E15", "rank": "Species"}, "1471446": {"name": "Prochlorococcus sp. scB241_527G5", "rank": "Species"}, "1471447": {"name": "Prochlorococcus sp. scB241_527I9", "rank": "Species"}, "1471440": {"name": "Prochlorococcus sp. scB241_526D20", "rank": "Species"}, "33938": {"name": "Geobacillus thermocatenulatus", "rank": "Species"}, "1471442": {"name": "Prochlorococcus sp. scB241_526N5", "rank": "Species"}, "1471443": {"name": "Prochlorococcus sp. scB241_526N9", "rank": "Species"}, "1159027": {"name": "Helicobacter pylori GAM118Bi", "rank": "Strain"}, "33934": {"name": "Anoxybacillus flavithermus", "rank": "Species"}, "28256": {"name": "Halomonadaceae", "rank": "Family"}, "1159024": {"name": "Helicobacter pylori GAM114Ai", "rank": "Strain"}, "28250": {"name": "Ornithobacterium", "rank": "Genus"}, "28251": {"name": "Ornithobacterium rhinotracheale", "rank": "Species"}, "28252": {"name": "Halomonas halodenitrificans", "rank": "Species"}, "28253": {"name": "Marinomonas", "rank": "Genus"}, "926543": {"name": "Ralstonia phage PE226", "rank": "Species"}, "926549": {"name": "Adhaeribacter aquaticus DSM 16391", "rank": "Strain"}, "93930": {"name": "Thermotoga naphthophila", "rank": "Species"}, "183967": {"name": "Thermoplasmata", "rank": "Class"}, "345341": {"name": "Kutzneria sp. 744", "rank": "Species"}, "183963": {"name": "Halobacteria", "rank": "Class"}, "94624": {"name": "Bordetella petrii", "rank": "Species"}, "94625": {"name": "Ochrobactrum intermedium", "rank": "Species"}, "1043003": {"name": "Aureobasidium melanogenum CBS 110374", "rank": "Strain"}, "1043002": {"name": "Aureobasidium pullulans EXF-150", "rank": "Strain"}, "1043005": {"name": "Aureobasidium subglaciale EXF-2481", "rank": "Strain"}, "393921": {"name": "Porphyromonas crevioricanis", "rank": "Species"}, "183968": {"name": "Thermococci", "rank": "Class"}, "938457": {"name": "Actinobacterium SCGC AAA028-I14", "rank": "Species"}, "127891": {"name": "Bacillus wakoensis", "rank": "Species"}, "11099": {"name": "Bovine viral diarrhea virus 1", "rank": "Species"}, "11096": {"name": "Classical swine fever virus", "rank": "Species"}, "538004": {"name": "Tomato leaf curl Pakistan alphasatellite", "rank": "Species"}, "388401": {"name": "Rhodobacteraceae bacterium HTCC2150", "rank": "Species"}, "388400": {"name": "Bacillus sp. B14905", "rank": "Species"}, "929704": {"name": "Myroides odoratus DSM 2801", "rank": "Strain"}, "929703": {"name": "Flectobacillus major DSM 103", "rank": "Strain"}, "158327": {"name": "Hahella chejuensis", "rank": "Species"}, "221359": {"name": "Synechococcus sp. RS9916", "rank": "Species"}, "337039": {"name": "Alphapapillomavirus 2", "rank": "Species"}, "1428434": {"name": "Oenococcus oeni IOEB_VF", "rank": "Strain"}, "44752": {"name": "Rhodococcus wratislaviensis", "rank": "Species"}, "1428439": {"name": "Oenococcus oeni S15", "rank": "Strain"}, "1218586": {"name": "Leptospira noguchii str. Bonito", "rank": "Strain"}, "1218584": {"name": "Leptospira kirschneri str. JB", "rank": "Strain"}, "1218585": {"name": "Leptospira meyeri serovar Semaranga str. Veldrot Semarang 173", "rank": "Strain"}, "1218582": {"name": "Leptospira interrogans serovar Valbuzzi str. Duyster", "rank": "Strain"}, "1218583": {"name": "Leptospira kirschneri str. MMD1493", "rank": "Strain"}, "342610": {"name": "Pseudoalteromonas atlantica T6c", "rank": "Strain"}, "342614": {"name": "Streptococcus agalactiae 515", "rank": "Strain"}, "342615": {"name": "Streptococcus agalactiae H36B", "rank": "Strain"}, "342616": {"name": "Streptococcus agalactiae COH1", "rank": "Strain"}, "342617": {"name": "Streptococcus agalactiae CJB111", "rank": "Strain"}, "251096": {"name": "Babuvirus", "rank": "Genus"}, "1163617": {"name": "Sulfuricella denitrificans skB26", "rank": "Strain"}, "244127": {"name": "Anaerotruncus", "rank": "Genus"}, "1388678": {"name": "Staphylococcus aureus M0906", "rank": "Strain"}, "1008297": {"name": "Salmonella enterica subsp. enterica serovar Typhimurium str. 798", "rank": "Strain"}, "117156": {"name": "Actinopolymorpha", "rank": "Genus"}, "2734": {"name": "Symbiobacterium thermophilum", "rank": "Species"}, "2735": {"name": "Verrucomicrobium", "rank": "Genus"}, "2736": {"name": "Verrucomicrobium spinosum", "rank": "Species"}, "2737": {"name": "Vagococcus", "rank": "Genus"}, "2733": {"name": "Symbiobacterium", "rank": "Genus"}, "283": {"name": "Comamonas", "rank": "Genus"}, "282682": {"name": "Citreicella", "rank": "Genus"}, "280": {"name": "Xanthobacter autotrophicus", "rank": "Species"}, "287": {"name": "Pseudomonas aeruginosa", "rank": "Species"}, "286": {"name": "Pseudomonas", "rank": "Genus"}, "285": {"name": "Comamonas testosteroni", "rank": "Species"}, "204669": {"name": "Candidatus Koribacter versatilis Ellin345", "rank": "Strain"}, "1383058": {"name": "Fervidibacteria", "rank": "Phylum"}, "1413509": {"name": "Staphylococcus aureus C0637", "rank": "Strain"}, "1413508": {"name": "Staphylococcus aureus C0630", "rank": "Strain"}, "698761": {"name": "Rhizobium tropici CIAT 899", "rank": "Strain"}, "1413505": {"name": "Staphylococcus aureus R0611", "rank": "Strain"}, "1458714": {"name": "Mycobacterium phage Seabiscuit", "rank": "Species"}, "1413507": {"name": "Staphylococcus aureus C0626", "rank": "Strain"}, "1458716": {"name": "Vibrio phage CHOED", "rank": "Species"}, "1458711": {"name": "Mycobacterium phage Hawkeye", "rank": "Species"}, "1413500": {"name": "Staphylococcus aureus R0294", "rank": "Strain"}, "1413503": {"name": "Staphylococcus aureus R0487", "rank": "Strain"}, "1413502": {"name": "Staphylococcus aureus R0357", "rank": "Strain"}, "1498228": {"name": "Rhizobium phage vB_RleM_PPF1", "rank": "Species"}, "1438689": {"name": "Escherichia coli UCI 51", "rank": "Strain"}, "1388677": {"name": "Staphylococcus aureus M0905", "rank": "Strain"}, "698948": {"name": "Thermoanaerobacterium thermosaccharolyticum M0795", "rank": "Strain"}, "61170": {"name": "Holdemania", "rank": "Genus"}, "61171": {"name": "Holdemania filiformis", "rank": "Species"}, "1502770": {"name": "Methylotenera sp. L2L1", "rank": "Species"}, "660470": {"name": "Mesotoga prima MesG1.Ag.4.2", "rank": "Strain"}, "653930": {"name": "Pseudomonas bauzanensis", "rank": "Species"}, "226010": {"name": "Aestuariibacter salexigens", "rank": "Species"}, "1281243": {"name": "Escherichia coli UMEA 3336-1", "rank": "Strain"}, "288021": {"name": "Kordiimonas", "rank": "Genus"}, "653938": {"name": "Listeria monocytogenes 08-5578", "rank": "Strain"}, "1333591": {"name": "Escherichia coli AB42602061-isolate1", "rank": "Strain"}, "1333590": {"name": "Escherichia coli AB42554418-isolate1", "rank": "Strain"}, "1333593": {"name": "Escherichia coli MC19", "rank": "Strain"}, "1333592": {"name": "Escherichia coli AB43739056-isolate1", "rank": "Strain"}, "1333595": {"name": "Escherichia coli MC23", "rank": "Strain"}, "1333594": {"name": "Escherichia coli MC21", "rank": "Strain"}, "1333597": {"name": "Escherichia coli MC6003", "rank": "Strain"}, "1333596": {"name": "Escherichia coli MC6002", "rank": "Strain"}, "747525": {"name": "Heterobasidion irregulare TC 32-1", "rank": "Strain"}, "515621": {"name": "Clostridium botulinum Ba4 str. 657", "rank": "Strain"}, "515620": {"name": "Eubacterium eligens ATCC 27750", "rank": "Strain"}, "1417084": {"name": "Staphylococcus aureus M39274", "rank": "Strain"}, "1417085": {"name": "Staphylococcus aureus H38215", "rank": "Strain"}, "1417086": {"name": "Staphylococcus aureus M39265", "rank": "Strain"}, "1262528": {"name": "Halovirus HVTV-1", "rank": "Species"}, "1417080": {"name": "Staphylococcus aureus H38239", "rank": "Strain"}, "1417081": {"name": "Staphylococcus aureus F73187", "rank": "Strain"}, "568706": {"name": "Bordetella pertussis 18323", "rank": "Strain"}, "1417083": {"name": "Staphylococcus aureus M39260", "rank": "Strain"}, "568708": {"name": "Salmonella enterica subsp. enterica serovar Typhimurium str. D23580", "rank": "Strain"}, "568709": {"name": "Salmonella enterica subsp. enterica serovar Typhimurium str. DT2", "rank": "Strain"}, "1417088": {"name": "Staphylococcus aureus T83715", "rank": "Strain"}, "1417089": {"name": "Staphylococcus aureus W65910", "rank": "Strain"}, "1506581": {"name": "Crohivirus", "rank": "Species"}, "1506582": {"name": "Pseudomonas sp. 11/12A", "rank": "Species"}, "1506583": {"name": "Flavobacterium sp. Fl", "rank": "Species"}, "1506585": {"name": "Methylotenera sp. G11", "rank": "Species"}, "1506586": {"name": "Methylophilus sp. Q8", "rank": "Species"}, "1506587": {"name": "Burkholderia sp. MSh1", "rank": "Species"}, "1506588": {"name": "Burkholderia sp. MSh2", "rank": "Species"}, "306281": {"name": "Fischerella muscicola PCC 7414", "rank": "Strain"}, "1410858": {"name": "Staphylococcus aureus T81559", "rank": "Strain"}, "1410859": {"name": "Staphylococcus aureus F86379", "rank": "Strain"}, "340102": {"name": "Pyrobaculum arsenaticum DSM 13514", "rank": "Strain"}, "1410852": {"name": "Staphylococcus aureus F83269", "rank": "Strain"}, "1410853": {"name": "Staphylococcus aureus F83272", "rank": "Strain"}, "1410850": {"name": "Staphylococcus aureus H45760", "rank": "Strain"}, "1410851": {"name": "Staphylococcus aureus F83251", "rank": "Strain"}, "1410856": {"name": "Staphylococcus aureus H48649", "rank": "Strain"}, "1410857": {"name": "Staphylococcus aureus H48646", "rank": "Strain"}, "1410854": {"name": "Staphylococcus aureus T87526", "rank": "Strain"}, "700015": {"name": "Coriobacterium glomerans PW2", "rank": "Strain"}, "53436": {"name": "Treponema pallidum subsp. endemicum", "rank": "Subspecies"}, "53437": {"name": "Nocardiopsis alba", "rank": "Species"}, "53434": {"name": "Halobacteroidaceae", "rank": "Family"}, "53435": {"name": "Treponema paraluiscuniculi", "rank": "Species"}, "53433": {"name": "Halanaerobiales", "rank": "Order"}, "1125701": {"name": "Treponema socranskii subsp. paredis ATCC 35535", "rank": "Strain"}, "1125700": {"name": "Treponema medium ATCC 700293", "rank": "Strain"}, "1125702": {"name": "Treponema vincentii F0403", "rank": "Strain"}, "205910": {"name": "Cypovirus 15", "rank": "Species"}, "205913": {"name": "Bifidobacterium longum DJO10A", "rank": "Strain"}, "11819": {"name": "Spleen focus-forming virus", "rank": "Species"}, "205919": {"name": "Bacillus anthracis str. Kruger B", "rank": "Strain"}, "205918": {"name": "Pseudomonas syringae pv. syringae B728a", "rank": "Strain"}, "1416028": {"name": "Escherichia phage bV_EcoS_AHP42", "rank": "Species"}, "284689": {"name": "Amasya cherry disease-associated mycovirus", "rank": "Species"}, "284687": {"name": "Amasya cherry disease associated chrysovirus", "rank": "Species"}, "1452718": {"name": "Pseudomonas sp. RL", "rank": "Species"}, "1416021": {"name": "Feline sakobuvirus A", "rank": "Species"}, "1303386": {"name": "Bat hepatitis virus", "rank": "Species"}, "658904": {"name": "Rosellinia necatrix megabirnavirus 1/W779", "rank": "Strain"}, "871325": {"name": "Bacteroides faecichinchillae", "rank": "Species"}, "871324": {"name": "Bacteroides stercorirosoris", "rank": "Species"}, "1351754": {"name": "Avibacterium paragallinarum JF4211", "rank": "Strain"}, "156205": {"name": "Halobacillus trueperi", "rank": "Species"}, "10747": {"name": "Streptococcus phage Cp-1", "rank": "Species"}, "1027880": {"name": "Asclepias asymptomatic virus", "rank": "Species"}, "113395": {"name": "Bradyrhizobium sp. Tv2a-2", "rank": "Species"}, "1349409": {"name": "Pandoravirus dulcis", "rank": "Species"}, "1281245": {"name": "Escherichia coli UMEA 3341-1", "rank": "Strain"}, "1341657": {"name": "Francisella tularensis subsp. tularensis str. SCHU S4 substr. NR-10492", "rank": "Strain"}, "1341656": {"name": "Francisella tularensis subsp. tularensis str. SCHU S4 substr. NR-28534", "rank": "Strain"}, "1383028": {"name": "Candidatus Aminicenans sakinawicola JGI OTU-1", "rank": "Strain"}, "447171": {"name": "Lettuce virus X", "rank": "Species"}, "562020": {"name": "Neisseria meningitidis N1568", "rank": "Strain"}, "1383026": {"name": "Atribacteria bacterium JGI OTU-1", "rank": "Species"}, "1341659": {"name": "Francisella tularensis subsp. tularensis str. SCHU S4 substr. SL", "rank": "Strain"}, "1341658": {"name": "Francisella tularensis subsp. tularensis str. SCHU S4 substr. NR-643", "rank": "Strain"}, "1075106": {"name": "Bifidobacterium animalis subsp. lactis BLC1", "rank": "Strain"}, "1305741": {"name": "Bacteroidetes bacterium JGI 0000119-L22", "rank": "Species"}, "1305740": {"name": "Marinobacter nanhaiticus", "rank": "Species"}, "481722": {"name": "Lactobacillus kisonensis", "rank": "Species"}, "1281244": {"name": "Escherichia coli UMEA 3337-1", "rank": "Strain"}, "999809": {"name": "Sporisorium reilianum SRZ2", "rank": "Strain"}, "341673": {"name": "Duck parvovirus", "rank": "Strain"}, "341671": {"name": "Avian adeno-associated virus", "rank": "Strain"}, "341670": {"name": "Unclassified Dependovirus", "rank": "No rank"}, "1134687": {"name": "Klebsiella michiganensis", "rank": "Species"}, "931456": {"name": "Staphylococcus aureus subsp. aureus CIGC341D", "rank": "Strain"}, "1151238": {"name": "Escherichia coli B17", "rank": "Strain"}, "1151239": {"name": "Escherichia coli B83", "rank": "Strain"}, "246194": {"name": "Carboxydothermus hydrogenoformans Z-2901", "rank": "Strain"}, "246195": {"name": "Dichelobacter nodosus VCS1703A", "rank": "Strain"}, "246196": {"name": "Mycobacterium smegmatis str. MC2 155", "rank": "Strain"}, "246197": {"name": "Myxococcus xanthus DK 1622", "rank": "Strain"}, "1151232": {"name": "Escherichia coli B94", "rank": "Strain"}, "1151233": {"name": "Escherichia coli B95", "rank": "Strain"}, "1072572": {"name": "Salmonella enterica subsp. enterica serovar Paratyphi A str. ZJ98-53", "rank": "Strain"}, "1072575": {"name": "Ralstonia solanacearum Y45", "rank": "Strain"}, "1151237": {"name": "Escherichia coli B15", "rank": "Strain"}, "1151234": {"name": "Escherichia coli B103", "rank": "Strain"}, "1151235": {"name": "Escherichia coli B89", "rank": "Strain"}, "1311038": {"name": "Acinetobacter baumannii 44362_4", "rank": "Strain"}, "1311039": {"name": "Acinetobacter baumannii 44362_5", "rank": "Strain"}, "1311032": {"name": "Acinetobacter baumannii 44437_8", "rank": "Strain"}, "1311033": {"name": "Acinetobacter baumannii 44437_9", "rank": "Strain"}, "1311031": {"name": "Acinetobacter baumannii 44437_7", "rank": "Strain"}, "1311036": {"name": "Acinetobacter baumannii 44362_2", "rank": "Strain"}, "1311037": {"name": "Acinetobacter baumannii 44362_3", "rank": "Strain"}, "1311035": {"name": "Acinetobacter baumannii 44362_1", "rank": "Strain"}, "756828": {"name": "Bacillus sp. WP8", "rank": "Species"}, "1182719": {"name": "Escherichia coli KTE136", "rank": "Strain"}, "1182718": {"name": "Escherichia coli KTE135", "rank": "Strain"}, "1182715": {"name": "Escherichia coli KTE130", "rank": "Strain"}, "1182714": {"name": "Escherichia coli KTE127", "rank": "Strain"}, "1182717": {"name": "Escherichia coli KTE134", "rank": "Strain"}, "1182716": {"name": "Escherichia coli KTE132", "rank": "Strain"}, "400095": {"name": "Pseudomonas tuomuerensis", "rank": "Species"}, "1182710": {"name": "Escherichia coli KTE119", "rank": "Strain"}, "1182713": {"name": "Escherichia coli KTE126", "rank": "Strain"}, "1182712": {"name": "Escherichia coli KTE123", "rank": "Strain"}, "1421869": {"name": "Staphylococcus aureus M17074", "rank": "Strain"}, "1421868": {"name": "Staphylococcus aureus H88188", "rank": "Strain"}, "1397878": {"name": "Mycobacterium tuberculosis TKK_02_0052", "rank": "Strain"}, "1397879": {"name": "Mycobacterium tuberculosis TKK_02_0061", "rank": "Strain"}, "1397874": {"name": "Mycobacterium tuberculosis TKK_02_0038", "rank": "Strain"}, "1397875": {"name": "Mycobacterium tuberculosis TKK_02_0039", "rank": "Strain"}, "1421861": {"name": "Staphylococcus aureus H72152", "rank": "Strain"}, "1397877": {"name": "Mycobacterium tuberculosis TKK_02_0046", "rank": "Strain"}, "1421867": {"name": "Staphylococcus aureus H88185", "rank": "Strain"}, "1397871": {"name": "Mycobacterium tuberculosis TKK_02_0033", "rank": "Strain"}, "1397872": {"name": "Mycobacterium tuberculosis TKK_02_0034", "rank": "Strain"}, "1421864": {"name": "Staphylococcus aureus H84956", "rank": "Strain"}, "256821": {"name": "Gulosibacter molinativorax", "rank": "Species"}, "907239": {"name": "Helicobacter pylori SouthAfrica7", "rank": "Strain"}, "907238": {"name": "Helicobacter pylori India7", "rank": "Strain"}, "1413435": {"name": "Staphylococcus aureus 1111203374", "rank": "Strain"}, "1286341": {"name": "Escherichia coli TOP550-3", "rank": "Strain"}, "368445": {"name": "Crocodilepox virus", "rank": "Species"}, "580372": {"name": "Mariprofundaceae", "rank": "Family"}, "580371": {"name": "Mariprofundales", "rank": "Order"}, "580370": {"name": "Zetaproteobacteria", "rank": "Class"}, "1250316": {"name": "Olive viral satellite RNA", "rank": "Species"}, "1250315": {"name": "RNA satellites", "rank": "No rank"}, "1485186": {"name": "Nhumirim virus", "rank": "Species"}, "1156769": {"name": "Porcine kobuvirus", "rank": "Strain"}, "1196347": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN001088", "rank": "Strain"}, "945962": {"name": "Mosquito densovirus BR/07", "rank": "Species"}, "1196349": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN001090", "rank": "Strain"}, "1196348": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN001089", "rank": "Strain"}, "994695": {"name": "Candidatus Kinetoplastibacterium galatii", "rank": "Species"}, "994696": {"name": "Candidatus Kinetoplastibacterium oncopeltii", "rank": "Species"}, "941058": {"name": "Bacillus phage SP10", "rank": "Species"}, "994692": {"name": "Candidatus Kinetoplastibacterium desouzaii", "rank": "Species"}, "310300": {"name": "Bacteroides pyogenes", "rank": "Species"}, "1336245": {"name": "Carnimonas nigrificans ATCC BAA-78", "rank": "Strain"}, "196627": {"name": "Corynebacterium glutamicum ATCC 13032", "rank": "Strain"}, "196620": {"name": "Staphylococcus aureus subsp. aureus MW2", "rank": "Strain"}, "1418247": {"name": "Pseudomonas aeruginosa PS75", "rank": "Strain"}, "1418246": {"name": "Pseudomonas aeruginosa BWH060", "rank": "Strain"}, "1418245": {"name": "Pseudomonas aeruginosa BWH059", "rank": "Strain"}, "1418244": {"name": "Pseudomonas aeruginosa BWH058", "rank": "Strain"}, "1418243": {"name": "Pseudomonas aeruginosa BWH057", "rank": "Strain"}, "1418242": {"name": "Pseudomonas aeruginosa BWH056", "rank": "Strain"}, "1418241": {"name": "Pseudomonas aeruginosa BWH055", "rank": "Strain"}, "1418240": {"name": "Pseudomonas aeruginosa BWH054", "rank": "Strain"}, "1418248": {"name": "Pseudomonas aeruginosa PAO1-GFP", "rank": "Strain"}, "1413431": {"name": "Staphylococcus aureus 1111100370", "rank": "Strain"}, "359159": {"name": "Nonomuraea candida", "rank": "Species"}, "1454383": {"name": "Escherichia coli 4541-1", "rank": "Strain"}, "1388119": {"name": "Staphylococcus aureus M0182", "rank": "Strain"}, "1388118": {"name": "Staphylococcus aureus M0181", "rank": "Strain"}, "1388117": {"name": "Staphylococcus aureus M0180", "rank": "Strain"}, "1388116": {"name": "Staphylococcus aureus M0179", "rank": "Strain"}, "1388115": {"name": "Staphylococcus aureus M0178", "rank": "Strain"}, "1388114": {"name": "Staphylococcus aureus M0175", "rank": "Strain"}, "1388113": {"name": "Staphylococcus aureus M0174", "rank": "Strain"}, "1388112": {"name": "Staphylococcus aureus M0172", "rank": "Strain"}, "1388111": {"name": "Staphylococcus aureus M0170", "rank": "Strain"}, "1388110": {"name": "Staphylococcus aureus M0169", "rank": "Strain"}, "1321778": {"name": "Clostridiales bacterium oral taxon 876 str. F0540", "rank": "Strain"}, "1321779": {"name": "Leptotrichia sp. oral taxon 215 str. W9775", "rank": "Strain"}, "222475": {"name": "Malvastrum yellow vein virus", "rank": "Species"}, "222474": {"name": "Squash leaf curl Yunnan virus", "rank": "Species"}, "543734": {"name": "Lactobacillus casei BL23", "rank": "Strain"}, "1321777": {"name": "Clostridiales bacterium oral taxon 876", "rank": "Species"}, "1321774": {"name": "Leptotrichia sp. oral taxon 225 str. F0581", "rank": "Strain"}, "1321775": {"name": "Actinomyces sp. oral taxon 172 str. F0311", "rank": "Strain"}, "997881": {"name": "Bacteroides fragilis CL05T12C13", "rank": "Strain"}, "997880": {"name": "Bacteroides fragilis CL05T00C42", "rank": "Strain"}, "997883": {"name": "Bacteroides fragilis CL07T12C05", "rank": "Strain"}, "997882": {"name": "Bacteroides fragilis CL07T00C01", "rank": "Strain"}, "997885": {"name": "Bacteroides ovatus CL02T12C04", "rank": "Strain"}, "997884": {"name": "Bacteroides nordii CL02T12C05", "rank": "Strain"}, "997887": {"name": "Bacteroides salyersiae CL02T12C01", "rank": "Strain"}, "997886": {"name": "Bacteroides ovatus CL03T12C18", "rank": "Strain"}, "997889": {"name": "Bacteroides uniformis CL03T00C23", "rank": "Strain"}, "997888": {"name": "Bacteroides finegoldii CL09T03C10", "rank": "Strain"}, "112987": {"name": "Neochlamydia", "rank": "Genus"}, "1183377": {"name": "Pyrococcus sp. ST04", "rank": "Species"}, "1183378": {"name": "Campylobacter coli RM1875", "rank": "Strain"}, "1183379": {"name": "Campylobacter coli RM4661", "rank": "Strain"}, "186490": {"name": "Candidatus Baumannia cicadellinicola", "rank": "Species"}, "1269": {"name": "Micrococcus", "rank": "Genus"}, "1268": {"name": "Micrococcaceae", "rank": "Family"}, "158080": {"name": "Chromohalobacter salexigens", "rank": "Species"}, "1265": {"name": "Ruminococcus flavefaciens", "rank": "Species"}, "1264": {"name": "Ruminococcus albus", "rank": "Species"}, "1263": {"name": "Ruminococcus", "rank": "Genus"}, "1261": {"name": "Peptostreptococcus anaerobius", "rank": "Species"}, "1260": {"name": "Finegoldia magna", "rank": "Species"}, "272626": {"name": "Listeria innocua Clip11262", "rank": "Strain"}, "49319": {"name": "Rubrobacter xylanophilus", "rank": "Species"}, "515849": {"name": "Podospora anserina S mat+", "rank": "Strain"}, "1324331": {"name": "Staphylococcus aureus JS046", "rank": "Strain"}, "1324330": {"name": "Staphylococcus aureus HST-105", "rank": "Strain"}, "1324332": {"name": "Pseudomonas fluorescens LMG 5329", "rank": "Strain"}, "61653": {"name": "Methylopila", "rank": "Genus"}, "1406885": {"name": "Aliiglaciecola", "rank": "Genus"}, "152475": {"name": "Thioalkalivibrio thiocyanoxidans", "rank": "Species"}, "314865": {"name": "Vibrio ordalii 12B09", "rank": "Strain"}, "1112268": {"name": "Chlamydia psittaci 09DC77", "rank": "Strain"}, "1112269": {"name": "Chlamydia psittaci 09DC78", "rank": "Strain"}, "1849": {"name": "Actinopolyspora", "rank": "Genus"}, "200414": {"name": "Caldisphaera", "rank": "Genus"}, "68876": {"name": "Kashmir bee virus", "rank": "Species"}, "1379257": {"name": "Mycobacterium tuberculosis OSDD493", "rank": "Strain"}, "1112260": {"name": "Chlamydia psittaci 02DC24", "rank": "Strain"}, "68879": {"name": "Penicillium paneum", "rank": "Species"}, "1112262": {"name": "Chlamydia psittaci 03DC29", "rank": "Strain"}, "1847": {"name": "Pseudonocardia", "rank": "Genus"}, "316385": {"name": "Escherichia coli str. K-12 substr. DH10B", "rank": "Strain"}, "1112267": {"name": "Chlamydia psittaci 08DC60", "rank": "Strain"}, "1267754": {"name": "Corynebacterium urealyticum DSM 7111", "rank": "Strain"}, "345219": {"name": "Bacillus coagulans 36D1", "rank": "Strain"}, "1267753": {"name": "Salmonella enterica subsp. enterica serovar Javiana str. CFSAN001992", "rank": "Strain"}, "1027253": {"name": "Stenotrophomonas phage phiSHP2", "rank": "Species"}, "651183": {"name": "Aurantimonas manganoxydans", "rank": "Species"}, "651182": {"name": "Desulfobacula toluolica Tol2", "rank": "Strain"}, "1439080": {"name": "Streptococcus pyogenes ABC020033919", "rank": "Strain"}, "887061": {"name": "Methylovorus sp. MP688", "rank": "Species"}, "754059": {"name": "Synechococcus phage S-CBP4", "rank": "Species"}, "754058": {"name": "Vibrio phage PWH3a-P1", "rank": "Species"}, "85043": {"name": "Williamsia", "rank": "Genus"}, "754051": {"name": "Vibrio phage pYD38-A", "rank": "Species"}, "754053": {"name": "Paenibacillus phage PG1", "rank": "Species"}, "754052": {"name": "Pseudoalteromonas phage pYD6-A", "rank": "Species"}, "754055": {"name": "Rhodobacter phage RC1", "rank": "Species"}, "754056": {"name": "Rhodovulum phage RS1", "rank": "Species"}, "1400941": {"name": "Mycobacterium tuberculosis KT-0110", "rank": "Strain"}, "1400940": {"name": "Mycobacterium tuberculosis KT-0109", "rank": "Strain"}, "1167640": {"name": "Campylobacter fetus subsp. venerealis 642-21", "rank": "Strain"}, "1167641": {"name": "Pseudomonas geniculata N1", "rank": "Strain"}, "1432047": {"name": "Salmonella enterica subsp. enterica serovar Bovismorbificans str. Sal683", "rank": "Strain"}, "1432046": {"name": "Salmonella enterica subsp. enterica serovar Bovismorbificans str. Sal644", "rank": "Strain"}, "1432049": {"name": "Rhizobium etli bv. phaseoli str. IE4803", "rank": "Strain"}, "1432048": {"name": "Salmonella enterica subsp. enterica serovar Bovismorbificans str. Sal682", "rank": "Strain"}, "454194": {"name": "Pyrinomonas methylaliphatogenes", "rank": "Species"}, "60714": {"name": "Galinsoga mosaic virus", "rank": "Species"}, "38170": {"name": "Avian orthoreovirus", "rank": "Species"}, "1287476": {"name": "Prevotella bivia DNF00188", "rank": "Strain"}, "279538": {"name": "Gremmeniella abietina mitochondrial RNA virus S2", "rank": "Species"}, "279539": {"name": "Gremmeniella abietina RNA virus L2", "rank": "Species"}, "279530": {"name": "Burkholderia phage BcepB1A", "rank": "Species"}, "38173": {"name": "Unclassified ssRNA positive-strand viruses", "rank": "No rank"}, "64290": {"name": "Bagaza virus", "rank": "Species"}, "1016879": {"name": "Cutthroat trout virus", "rank": "Species"}, "798300": {"name": "Streptococcus pyogenes MGAS15252", "rank": "Strain"}, "368408": {"name": "Thermofilum pendens Hrk 5", "rank": "Strain"}, "1409635": {"name": "Staphylococcus aureus KINW6033", "rank": "Strain"}, "1409756": {"name": "Staphylococcus aureus DAR5894", "rank": "Strain"}, "1348908": {"name": "Bacillus megaterium MSP20.1", "rank": "Strain"}, "64293": {"name": "Tembusu virus", "rank": "Species"}, "1505907": {"name": "Thermococcus eurythermalis", "rank": "Species"}, "1240775": {"name": "Escherichia coli O104:H4 str. 11-03439", "rank": "Strain"}, "673515": {"name": "Mosquito flavivirus", "rank": "Species"}, "459349": {"name": "Candidatus Cloacimonas acidaminovorans str. Evry", "rank": "Strain"}, "673518": {"name": "Bacillus anthracis str. A16R", "rank": "Strain"}, "673519": {"name": "Vibrio harveyi 1DA3", "rank": "Strain"}, "39845": {"name": "Actinokineospora", "rank": "Genus"}, "2323": {"name": "Unclassified Bacteria", "rank": "No rank"}, "445227": {"name": "Maize white line mosaic virus", "rank": "Species"}, "445226": {"name": "Francisella tularensis subsp. holarctica URFT1", "rank": "Strain"}, "445220": {"name": "Reyranella massiliensis", "rank": "Species"}, "2322": {"name": "Methanohalobium evestigatum", "rank": "Species"}, "869690": {"name": "Escherichia coli 2.4168", "rank": "Strain"}, "572289": {"name": "Munia coronavirus HKU13-3514", "rank": "Strain"}, "869691": {"name": "Escherichia coli 3.2303", "rank": "Strain"}, "62098": {"name": "Alphaentomopoxvirus", "rank": "Genus"}, "62099": {"name": "Anomala cuprea entomopoxvirus", "rank": "Species"}, "311400": {"name": "Thermococcus kodakarensis", "rank": "Species"}, "311403": {"name": "Agrobacterium radiobacter K84", "rank": "Strain"}, "311402": {"name": "Agrobacterium vitis S4", "rank": "Strain"}, "233055": {"name": "Desulfitobacterium dichloroeliminans", "rank": "Species"}, "233051": {"name": "Hibiscus latent Fort Pierce virus", "rank": "Species"}, "102115": {"name": "Stanieria", "rank": "Genus"}, "1282994": {"name": "Burkholderia phage ST79", "rank": "Species"}, "102116": {"name": "Stanieria cyanosphaera", "rank": "Species"}, "1127743": {"name": "Bacillus sp. 5B6", "rank": "Species"}, "1127744": {"name": "Bacillus sp. JS", "rank": "Species"}, "1175295": {"name": "Pseudoalteromonas sp. PAMC 22718", "rank": "Species"}, "1314835": {"name": "Escherichia coli MP1", "rank": "Strain"}, "391573": {"name": "Unclassified Vibrionales", "rank": "No rank"}, "1448479": {"name": "Mycobacterium tuberculosis TKK_04_0079", "rank": "Strain"}, "1448478": {"name": "Mycobacterium tuberculosis TKK_04_0078", "rank": "Strain"}, "439488": {"name": "SsRNA viruses", "rank": "No rank"}, "506480": {"name": "Exiguobacterium alkaliphilum 12/1", "rank": "Strain"}, "1448475": {"name": "Mycobacterium tuberculosis TKK_04_0071", "rank": "Strain"}, "1448474": {"name": "Mycobacterium tuberculosis TKK_04_0070", "rank": "Strain"}, "1448477": {"name": "Mycobacterium tuberculosis TKK_04_0075", "rank": "Strain"}, "1448476": {"name": "Mycobacterium tuberculosis TKK_04_0072", "rank": "Strain"}, "1448471": {"name": "Mycobacterium tuberculosis TKK_04_0067", "rank": "Strain"}, "1448470": {"name": "Mycobacterium tuberculosis TKK_04_0066", "rank": "Strain"}, "1448473": {"name": "Mycobacterium tuberculosis TKK_04_0069", "rank": "Strain"}, "1448472": {"name": "Mycobacterium tuberculosis TKK_04_0068", "rank": "Strain"}, "882090": {"name": "Methanolinea tarda NOBI-1", "rank": "Strain"}, "182403": {"name": "Rubritepida flocculans", "rank": "Species"}, "182402": {"name": "Rubritepida", "rank": "Genus"}, "882097": {"name": "Listeria monocytogenes SLCC2376", "rank": "Strain"}, "1249634": {"name": "Serratia marcescens FGI94", "rank": "Strain"}, "74501": {"name": "Bovine torovirus", "rank": "Species"}, "444178": {"name": "Brucella ovis ATCC 25840", "rank": "Strain"}, "444179": {"name": "Candidatus Sulcia muelleri GWSS", "rank": "Strain"}, "393595": {"name": "Alcanivorax borkumensis SK2", "rank": "Strain"}, "1111075": {"name": "Campylobacter jejuni subsp. jejuni 04197", "rank": "Strain"}, "393599": {"name": "East African cassava mosaic Kenya virus", "rank": "Species"}, "393598": {"name": "Aeromonas phage phiO18P", "rank": "Species"}, "1236401": {"name": "Pan troglodytes verus polyomavirus 3", "rank": "Species"}, "882094": {"name": "Listeria monocytogenes L312", "rank": "Strain"}, "1236407": {"name": "Piliocolobus rufomitratus polyomavirus 1", "rank": "Species"}, "444177": {"name": "Lysinibacillus sphaericus C3-41", "rank": "Strain"}, "910964": {"name": "Ewingella americana ATCC 33852", "rank": "Strain"}, "909656": {"name": "Phocaeicola", "rank": "Genus"}, "505682": {"name": "Ureaplasma parvum serovar 3 str. ATCC 27815", "rank": "Strain"}, "322104": {"name": "Scheffersomyces stipitis CBS 6054", "rank": "Strain"}, "1151377": {"name": "Peptoclostridium difficile Y165", "rank": "Strain"}, "1151376": {"name": "Peptoclostridium difficile Y155", "rank": "Strain"}, "1151375": {"name": "Peptoclostridium difficile Y41", "rank": "Strain"}, "1151374": {"name": "Peptoclostridium difficile Y21", "rank": "Strain"}, "1151373": {"name": "Peptoclostridium difficile Y10", "rank": "Strain"}, "1151372": {"name": "Peptoclostridium difficile F501", "rank": "Strain"}, "310750": {"name": "Phytophthora endornavirus 1", "rank": "Species"}, "1230587": {"name": "Sinorhizobium meliloti Rm41", "rank": "Strain"}, "1151378": {"name": "Peptoclostridium difficile Y171", "rank": "Strain"}, "1154938": {"name": "Streptococcus agalactiae GB00891", "rank": "Strain"}, "1154939": {"name": "Streptococcus agalactiae GB00893", "rank": "Strain"}, "1048332": {"name": "Streptococcus salivarius CCHSS3", "rank": "Strain"}, "1154932": {"name": "Streptococcus agalactiae GB00865", "rank": "Strain"}, "1154933": {"name": "Streptococcus agalactiae GB00867", "rank": "Strain"}, "1154930": {"name": "Streptococcus agalactiae GB00679", "rank": "Strain"}, "1154931": {"name": "Streptococcus agalactiae GB00864", "rank": "Strain"}, "1154936": {"name": "Streptococcus agalactiae GB00887", "rank": "Strain"}, "1154937": {"name": "Streptococcus agalactiae GB00888", "rank": "Strain"}, "1154934": {"name": "Streptococcus agalactiae GB00874", "rank": "Strain"}, "1154935": {"name": "Streptococcus agalactiae GB00884", "rank": "Strain"}, "1450449": {"name": "Mannheimia haemolytica serotype A1/A6 str. PKL10", "rank": "Strain"}, "1327994": {"name": "Enterococcus faecalis 10244", "rank": "Strain"}, "69714": {"name": "Treponema socranskii subsp. paredis", "rank": "Subspecies"}, "69715": {"name": "Treponema socranskii subsp. socranskii", "rank": "Subspecies"}, "1327990": {"name": "Cellulophaga phage phi14:2", "rank": "Species"}, "1327991": {"name": "Staphylococcus epidermidis UC7032", "rank": "Strain"}, "69710": {"name": "Treponema vincentii", "rank": "Species"}, "1327993": {"name": "Cellulophaga phage phi39:1", "rank": "Species"}, "475963": {"name": "Caldilineales", "rank": "Order"}, "475962": {"name": "Caldilineae", "rank": "Class"}, "1327998": {"name": "Streptococcus pneumoniae BHN191", "rank": "Strain"}, "475964": {"name": "Caldilineaceae", "rank": "Family"}, "1454753": {"name": "Candidatus Caldatribacterium saccharofermentans", "rank": "Species"}, "1298858": {"name": "Mesorhizobium sp. URHA0056", "rank": "Species"}, "1298859": {"name": "Burkholderia sp. URHA0054", "rank": "Species"}, "1298855": {"name": "Novosphingobium sp. B-7", "rank": "Species"}, "1298857": {"name": "Solirubrobacter sp. URHD0082", "rank": "Species"}, "196117": {"name": "Methanocaldococcaceae", "rank": "Family"}, "1175504": {"name": "Mycobacterium phage SWU1", "rank": "Species"}, "1175505": {"name": "Ageratum leaf curl betasatellite", "rank": "Species"}, "104628": {"name": "Helicobacter suis", "rank": "Species"}, "1160199": {"name": "Brucella abortus 64/108", "rank": "Strain"}, "1160198": {"name": "Brucella abortus 80/108", "rank": "Strain"}, "1160193": {"name": "Brucella abortus 863/67", "rank": "Strain"}, "1160192": {"name": "Brucella abortus F2/06-8", "rank": "Strain"}, "1160191": {"name": "Brucella abortus F1/06 B1", "rank": "Strain"}, "1160190": {"name": "Brucella abortus I103_(UK3/01)", "rank": "Strain"}, "1160197": {"name": "Brucella abortus 93/1", "rank": "Strain"}, "1160196": {"name": "Brucella abortus 90/50", "rank": "Strain"}, "1160194": {"name": "Brucella abortus 88/226", "rank": "Strain"}, "305976": {"name": "Pusillimonas", "rank": "Genus"}, "305977": {"name": "Pusillimonas noertemannii", "rank": "Species"}, "401650": {"name": "Listeria monocytogenes HPB2262", "rank": "Strain"}, "1070409": {"name": "Human papillomavirus type 136", "rank": "Species"}, "742914": {"name": "Suggested genus Cyclovirus", "rank": "No rank"}, "351": {"name": "Azotobacter group", "rank": "Subfamily"}, "353": {"name": "Azotobacter chroococcum", "rank": "Species"}, "352": {"name": "Azotobacter", "rank": "Genus"}, "354": {"name": "Azotobacter vinelandii", "rank": "Species"}, "357": {"name": "Agrobacterium", "rank": "Genus"}, "356": {"name": "Rhizobiales", "rank": "Order"}, "359": {"name": "Agrobacterium rhizogenes", "rank": "Species"}, "358": {"name": "Agrobacterium tumefaciens", "rank": "Species"}, "1428189": {"name": "Hedyotis uncinella yellow mosaic betasatellite", "rank": "Species"}, "1010840": {"name": "Streptococcus pyogenes MGAS1882", "rank": "Strain"}, "384765": {"name": "Labrenzia aggregata IAM 12614", "rank": "Strain"}, "1479485": {"name": "Tolypothrix bouteillei VB521301", "rank": "Strain"}, "337828": {"name": "Enterobacteria phage JK06", "rank": "Species"}, "688269": {"name": "Thermotoga thermarum DSM 5069", "rank": "Strain"}, "337823": {"name": "Sida leaf curl virus", "rank": "Species"}, "337826": {"name": "Alternanthera yellow vein virus", "rank": "Species"}, "337825": {"name": "Sida leaf curl virus-associated DNA 1", "rank": "Species"}, "337824": {"name": "Sida leaf curl virus-associated DNA beta", "rank": "Species"}, "186537": {"name": "Marburgvirus", "rank": "Genus"}, "497974": {"name": "Salmonella enterica subsp. enterica serovar Typhi str. E02-1180", "rank": "Strain"}, "186536": {"name": "Ebolavirus", "rank": "Genus"}, "497978": {"name": "Acinetobacter baumannii MDR-ZJ06", "rank": "Strain"}, "11207": {"name": "Parainfluenza virus 5", "rank": "Species"}, "11203": {"name": "Human parainfluenza virus 4", "rank": "Species"}, "243261": {"name": "Burkholderia sp. Ch1-1", "rank": "Species"}, "186532": {"name": "C2likevirus", "rank": "Genus"}, "520848": {"name": "Urochloa streak virus", "rank": "Species"}, "1225722": {"name": "Peptoclostridium difficile E1", "rank": "Strain"}, "1328315": {"name": "Pseudomonas aeruginosa PGPR2", "rank": "Strain"}, "1328314": {"name": "Azotobacter chroococcum NCIMB 8003", "rank": "Strain"}, "1328313": {"name": "Catenovulum agarivorans DS-2", "rank": "Strain"}, "227979": {"name": "Jeotgalicoccus", "rank": "Genus"}, "1158763": {"name": "Thioalkalivibrio sp. ALJ20", "rank": "Species"}, "1158762": {"name": "Thioalkalivibrio sp. ALJ16", "rank": "Species"}, "1158761": {"name": "Thioalkalivibrio sp. ALJ12", "rank": "Species"}, "1158760": {"name": "Thioalkalivibrio sp. ALJ11", "rank": "Species"}, "1158764": {"name": "Thioalkalivibrio sp. ALJ21", "rank": "Species"}, "1107311": {"name": "Flavobacterium enshiense DK69", "rank": "Strain"}, "694018": {"name": "Bafinivirus", "rank": "Genus"}, "694017": {"name": "Torovirinae", "rank": "Subfamily"}, "228897": {"name": "Sida micrantha mosaic virus", "rank": "Species"}, "694015": {"name": "Beluga Whale coronavirus SW1", "rank": "Species"}, "694013": {"name": "Gammacoronavirus", "rank": "Genus"}, "764298": {"name": "Streptococcus macacae NCTC 11558", "rank": "Strain"}, "764299": {"name": "Streptococcus ictaluri 707-05", "rank": "Strain"}, "5535": {"name": "Rhodotorula glutinis", "rank": "Species"}, "5533": {"name": "Rhodotorula", "rank": "Genus"}, "5530": {"name": "Metarhizium anisopliae", "rank": "Species"}, "764291": {"name": "Streptococcus urinalis 2285-97", "rank": "Strain"}, "387631": {"name": "Archaeoglobus sulfaticallidus PM70-1", "rank": "Strain"}, "1221264": {"name": "Acinetobacter baumannii AB_2009-04-02-7", "rank": "Strain"}, "880074": {"name": "Barnesiella viscericola DSM 18177", "rank": "Strain"}, "51047": {"name": "Actinobacillus minor", "rank": "Species"}, "1294177": {"name": "Sebokele virus 1", "rank": "Species"}, "28118": {"name": "Odoribacter splanchnicus", "rank": "Species"}, "33870": {"name": "Coriobacterium", "rank": "Genus"}, "33871": {"name": "Coriobacterium glomerans", "rank": "Species"}, "28111": {"name": "Bacteroides eggerthii", "rank": "Species"}, "28110": {"name": "Francisella philomiragia", "rank": "Species"}, "33874": {"name": "Catenuloplanes", "rank": "Genus"}, "28116": {"name": "Bacteroides ovatus", "rank": "Species"}, "33876": {"name": "Catenuloplanes japonicus", "rank": "Species"}, "33877": {"name": "Agromyces", "rank": "Genus"}, "1444189": {"name": "Escherichia coli 8-415-05_S3_C3", "rank": "Strain"}, "1444188": {"name": "Escherichia coli 7-233-03_S3_C3", "rank": "Strain"}, "1306948": {"name": "Xanthomonas arboricola pv. corylina str. NCCB 100457", "rank": "Strain"}, "1444181": {"name": "Escherichia coli 2-222-05_S3_C3", "rank": "Strain"}, "1444180": {"name": "Escherichia coli 2-210-07_S3_C3", "rank": "Strain"}, "1444183": {"name": "Escherichia coli 2-427-07_S3_C3", "rank": "Strain"}, "1444182": {"name": "Escherichia coli 2-316-03_S3_C3", "rank": "Strain"}, "1444185": {"name": "Escherichia coli 2-474-04_S3_C3", "rank": "Strain"}, "1444184": {"name": "Escherichia coli 2-460-02_S3_C3", "rank": "Strain"}, "1444187": {"name": "Escherichia coli 5-366-08_S3_C3", "rank": "Strain"}, "862719": {"name": "Azospirillum lipoferum 4B", "rank": "Strain"}, "106284": {"name": "Staphylococcus phage phiETA", "rank": "Species"}, "161544": {"name": "Bacillus sp. SG-1", "rank": "Species"}, "391296": {"name": "Streptococcus suis 98HAH33", "rank": "Strain"}, "1353260": {"name": "Thaumarchaeota archaeon MY3", "rank": "Species"}, "1005056": {"name": "Salmonella phage iEPS5", "rank": "Species"}, "32003": {"name": "Nitrosomonadales", "rank": "Order"}, "32001": {"name": "Alcaligenes faecalis subsp. faecalis", "rank": "Subspecies"}, "765121": {"name": "Propionibacterium acnes HL082PA2", "rank": "Strain"}, "765120": {"name": "Propionibacterium acnes HL082PA1", "rank": "Strain"}, "32008": {"name": "Burkholderia", "rank": "Genus"}, "765122": {"name": "Propionibacterium acnes HL037PA1", "rank": "Strain"}, "765124": {"name": "Propionibacterium humerusii HL037PA3", "rank": "Strain"}, "1408166": {"name": "Vibrio Parahaemolyticus VIP4-0439", "rank": "Strain"}, "1408165": {"name": "Vibrio Parahaemolyticus VIP4-0395", "rank": "Strain"}, "1408164": {"name": "Betaproteobacteria bacterium MOLA814", "rank": "Species"}, "1408160": {"name": "Thermotoga profunda AZM34c06", "rank": "Strain"}, "1408169": {"name": "Vibrio parahaemolyticus VIP4-0434", "rank": "Strain"}, "1408168": {"name": "Vibrio parahaemolyticus VIP4-0407", "rank": "Strain"}, "1422627": {"name": "Staphylococcus aureus VET0394R", "rank": "Strain"}, "1203670": {"name": "Streptococcus agalactiae GD201008-001", "rank": "Strain"}, "127441": {"name": "Groundnut rosette virus satellite RNA", "rank": "Species"}, "1120979": {"name": "Alloscardovia omnicolens DSM 21503", "rank": "Strain"}, "693750": {"name": "Brucella sp. BO2", "rank": "Species"}, "1447505": {"name": "Mycobacterium tuberculosis MD13744", "rank": "Strain"}, "1005058": {"name": "Gallibacterium anatis UMN179", "rank": "Strain"}, "80744": {"name": "Serpula", "rank": "Genus"}, "1447506": {"name": "Mycobacterium tuberculosis MD14839", "rank": "Strain"}, "330379": {"name": "Unclassified Betanodavirus", "rank": "No rank"}, "11938": {"name": "Rauscher murine leukemia virus", "rank": "Strain"}, "732242": {"name": "Bacteroides paurosaccharolyticus", "rank": "Species"}, "1094559": {"name": "Bartonella tamiae Th307", "rank": "Strain"}, "1094558": {"name": "Bartonella tamiae Th239", "rank": "Strain"}, "445961": {"name": "Chryseobacterium soli", "rank": "Species"}, "1094553": {"name": "Bartonella doshiae NCTC 12862", "rank": "Strain"}, "1094552": {"name": "Bartonella birtlesii LL-WM9", "rank": "Strain"}, "1094551": {"name": "Bartonella alsatica IBS 382", "rank": "Strain"}, "1094557": {"name": "Bartonella melophagi K-2C", "rank": "Strain"}, "1094556": {"name": "Bartonella rattimassiliensis 15908", "rank": "Strain"}, "1094555": {"name": "Bartonella elizabethae F9251", "rank": "Strain"}, "1094554": {"name": "Bartonella elizabethae Re6043vi", "rank": "Strain"}, "132249": {"name": "Nocardia veterana", "rank": "Species"}, "663932": {"name": "Acetobacter aceti ATCC 23746", "rank": "Strain"}, "440482": {"name": "Promicromonospora kroppenstedtii", "rank": "Species"}, "416348": {"name": "Halorubrum lacusprofundi ATCC 49239", "rank": "Strain"}, "912033": {"name": "Ageratum leaf curl Cameroon virus", "rank": "Species"}, "1347342": {"name": "Formosa agariphila KMM 3901", "rank": "Strain"}, "416344": {"name": "Burkholderia sp. KJ006", "rank": "Species"}, "1347340": {"name": "Campylobacter jejuni 4031", "rank": "Strain"}, "912035": {"name": "Ageratum leaf curl Buea betasatellite", "rank": "Species"}, "912034": {"name": "Okra leaf curl Cameroon virus", "rank": "Species"}, "1151244": {"name": "Escherichia coli B109", "rank": "Strain"}, "1080712": {"name": "Methanomassiliicoccus luminyensis", "rank": "Species"}, "1151249": {"name": "Escherichia coli B112", "rank": "Strain"}, "1151248": {"name": "Escherichia coli B106", "rank": "Strain"}, "1088544": {"name": "Leptospira weilii str. UI 14631", "rank": "Strain"}, "1088541": {"name": "Leptospira weilii str. LNT 1234", "rank": "Strain"}, "1088540": {"name": "Leptospira weilii serovar Topaz str. LT2116", "rank": "Strain"}, "1200325": {"name": "Helicobacter pylori CCHI 33", "rank": "Strain"}, "1200324": {"name": "Helicobacter pylori UMB_G1", "rank": "Strain"}, "1047012": {"name": "Caldiserica bacterium JGI 0000059-M03", "rank": "Species"}, "1047013": {"name": "Aminicenantes bacterium SCGC AAA252-A02", "rank": "Species"}, "173824": {"name": "Methanothermobacter phage psiM100", "rank": "Species"}, "10243": {"name": "Cowpox virus", "rank": "Species"}, "10244": {"name": "Monkeypox virus", "rank": "Species"}, "286729": {"name": "Alkaliflexus", "rank": "Genus"}, "1047017": {"name": "Aminicenantes bacterium SCGC AAA252-D18", "rank": "Species"}, "617140": {"name": "Vibrio splendidus ZS-139", "rank": "Strain"}, "617145": {"name": "Vibrio splendidus 1F-157", "rank": "Strain"}, "617147": {"name": "Vibrio splendidus ZF-90", "rank": "Strain"}, "617146": {"name": "Vibrio splendidus FF-6", "rank": "Strain"}, "617148": {"name": "Vibrio splendidus 5S-101", "rank": "Strain"}, "1047015": {"name": "Aminicenantes bacterium SCGC AAA252-C08", "rank": "Species"}, "997355": {"name": "Propionibacterium avidum ATCC 25577", "rank": "Strain"}, "997356": {"name": "Streptococcus sanguinis ATCC 29667", "rank": "Strain"}, "291331": {"name": "Xanthomonas oryzae pv. oryzae KACC 10331", "rank": "Strain"}, "997353": {"name": "Prevotella pallens ATCC 700821", "rank": "Strain"}, "997352": {"name": "Prevotella nigrescens ATCC 33563", "rank": "Strain"}, "1224154": {"name": "Vibrio cholerae O1 str. Inaba G4222", "rank": "Strain"}, "1224152": {"name": "Dickeya solani MK16", "rank": "Strain"}, "1224153": {"name": "Dickeya zeae MK19", "rank": "Strain"}, "1224150": {"name": "Dickeya paradisiaca NCPPB 2511", "rank": "Strain"}, "1224151": {"name": "Dickeya solani MK10", "rank": "Strain"}, "551759": {"name": "Aromatoleum", "rank": "Genus"}, "1047068": {"name": "Unclassified Cloacimonetes", "rank": "No rank"}, "795797": {"name": "Halalkalicoccus jeotgali B3", "rank": "Strain"}, "1311048": {"name": "Acinetobacter baumannii 43557_1", "rank": "Strain"}, "1134413": {"name": "Bacillus sp. L1(2012)", "rank": "Species"}, "399742": {"name": "Enterobacter sp. 638", "rank": "Species"}, "399741": {"name": "Serratia proteamaculans 568", "rank": "Strain"}, "35841": {"name": "Bacillus thermoamylovorans", "rank": "Species"}, "1303783": {"name": "Staphylococcus aureus M1078", "rank": "Strain"}, "1009370": {"name": "Acetonema longum DSM 6540", "rank": "Strain"}, "1303781": {"name": "Staphylococcus aureus M0294", "rank": "Strain"}, "1303780": {"name": "Staphylococcus aureus M0075", "rank": "Strain"}, "1303787": {"name": "Staphylococcus aureus M1466", "rank": "Strain"}, "1303786": {"name": "Staphylococcus aureus M1407", "rank": "Strain"}, "1303785": {"name": "Staphylococcus aureus M1228", "rank": "Strain"}, "1303784": {"name": "Staphylococcus aureus M1193", "rank": "Strain"}, "1273092": {"name": "Pteronotus polyomavirus", "rank": "Species"}, "1273090": {"name": "Miniopterus polyomavirus", "rank": "Species"}, "1268239": {"name": "Pseudoalteromonas luteoviolacea B = ATCC 29581", "rank": "Strain"}, "374463": {"name": "Baumannia cicadellinicola str. Hc (Homalodisca coagulata)", "rank": "Strain"}, "37665": {"name": "Ectocarpus siliculosus virus 1", "rank": "Species"}, "360398": {"name": "Staphylococcus phage phiPVL108", "rank": "Species"}, "589437": {"name": "Prevotella scopos", "rank": "Species"}, "360397": {"name": "Canine papillomavirus 3", "rank": "Strain"}, "1268237": {"name": "Aeromonas diversa 2478-85", "rank": "Strain"}, "871203": {"name": "Burkholderia zhejiangensis", "rank": "Species"}, "1307441": {"name": "Fusobacterium hwasookii ChDC F145", "rank": "Strain"}, "1307442": {"name": "Fusobacterium hwasookii ChDC F174", "rank": "Strain"}, "1307443": {"name": "Fusobacterium hwasookii ChDC F206", "rank": "Strain"}, "1307444": {"name": "Fusobacterium hwasookii ChDC F300", "rank": "Strain"}, "81583": {"name": "Himetobi P virus", "rank": "Species"}, "656449": {"name": "Escherichia coli TW10509", "rank": "Strain"}, "469371": {"name": "Thermobispora bispora DSM 43833", "rank": "Strain"}, "469378": {"name": "Cryptobacterium curtum DSM 15641", "rank": "Strain"}, "206389": {"name": "Rhodocyclales", "rank": "Order"}, "1289387": {"name": "Streptomyces sp. TAA204", "rank": "Species"}, "204928": {"name": "Calibrachoa mottle virus", "rank": "Species"}, "1410628": {"name": "Lachnospiraceae bacterium ND2006", "rank": "Species"}, "1410625": {"name": "Lachnospiraceae bacterium MD2004", "rank": "Species"}, "1410624": {"name": "Lachnospiraceae bacterium FE2018", "rank": "Species"}, "1410627": {"name": "Lachnospiraceae bacterium NC2008", "rank": "Species"}, "1410626": {"name": "Lachnospiraceae bacterium NC2004", "rank": "Species"}, "1069615": {"name": "Neisseria meningitidis NM576", "rank": "Strain"}, "1410620": {"name": "Shinella sp. DD12", "rank": "Species"}, "1410623": {"name": "Lachnospiraceae bacterium FD2005", "rank": "Species"}, "1410622": {"name": "Lachnospiraceae bacterium C6A11", "rank": "Species"}, "1265634": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 66.F.99", "rank": "Strain"}, "1265635": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 71.E.05", "rank": "Strain"}, "1265636": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 03.O.05", "rank": "Strain"}, "1265637": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 08.A.05", "rank": "Strain"}, "1265630": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 61.O.08", "rank": "Strain"}, "1265631": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 59.F.08", "rank": "Strain"}, "1265632": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 64.H.00", "rank": "Strain"}, "1265633": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 69.H.06", "rank": "Strain"}, "311176": {"name": "Blotched snakehead virus", "rank": "Species"}, "1265638": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 13.E.05", "rank": "Strain"}, "1265639": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 23.F.01", "rank": "Strain"}, "322067": {"name": "J-virus", "rank": "Species"}, "662758": {"name": "Candidatus Parvarchaeum", "rank": "Genus"}, "662759": {"name": "Candidatus Parvarchaeum acidiphilum", "rank": "Species"}, "1562038": {"name": "Norway rat hepacivirus 1", "rank": "Species"}, "1562039": {"name": "Norway rat hepacivirus 2", "rank": "Species"}, "662755": {"name": "Corynebacterium resistens DSM 45100", "rank": "Strain"}, "1439028": {"name": "Streptococcus pyogenes ABC020017526", "rank": "Strain"}, "999386": {"name": "Acidovorax radicis N35", "rank": "Strain"}, "50052": {"name": "Mycoplasma crocodyli", "rank": "Species"}, "1439029": {"name": "Streptococcus pyogenes ABC020017774", "rank": "Strain"}, "1001719": {"name": "Mycobacterium abscessus 3A-0930-S", "rank": "Strain"}, "1001718": {"name": "Mycobacterium abscessus 3A-0731", "rank": "Strain"}, "1001713": {"name": "Mycobacterium abscessus subsp. bolletii 2B-0307", "rank": "Strain"}, "1001712": {"name": "Mycobacterium abscessus subsp. bolletii 2B-0912-S", "rank": "Strain"}, "1001711": {"name": "Mycobacterium abscessus subsp. bolletii 2B-0912-R", "rank": "Strain"}, "1001710": {"name": "Mycobacterium abscessus subsp. bolletii 2B-0107", "rank": "Strain"}, "1001717": {"name": "Mycobacterium abscessus 3A-0810-R", "rank": "Strain"}, "1001716": {"name": "Mycobacterium abscessus 3A-0122-S", "rank": "Strain"}, "1001715": {"name": "Mycobacterium abscessus 3A-0122-R", "rank": "Strain"}, "1001714": {"name": "Mycobacterium abscessus subsp. bolletii CCUG 48898 = JCM 15300", "rank": "Strain"}, "456327": {"name": "Xanthomonas euvesicatoria", "rank": "Species"}, "456320": {"name": "Methanococcus voltae A3", "rank": "Strain"}, "71235": {"name": "Stappia stellulata", "rank": "Species"}, "362534": {"name": "Kordiimonadales", "rank": "Order"}, "1504822": {"name": "Bacterium OL-1", "rank": "Species"}, "1078775": {"name": "Salmonella enterica subsp. salamae str. 3588/07", "rank": "Strain"}, "1569284": {"name": "Bdellovibrio sp. ArHS", "rank": "Species"}, "1196420": {"name": "Italian clover phyllody phytoplasma", "rank": "Species"}, "1196421": {"name": "Italian clover phyllody phytoplasma str. MA1", "rank": "Strain"}, "1448673": {"name": "Mycobacterium tuberculosis M1402", "rank": "Strain"}, "1448672": {"name": "Mycobacterium tuberculosis M1400", "rank": "Strain"}, "1448671": {"name": "Mycobacterium tuberculosis M1397", "rank": "Strain"}, "1448670": {"name": "Mycobacterium tuberculosis M1393", "rank": "Strain"}, "1448677": {"name": "Mycobacterium tuberculosis M1416", "rank": "Strain"}, "1448676": {"name": "Mycobacterium tuberculosis M1415", "rank": "Strain"}, "1448675": {"name": "Mycobacterium tuberculosis M1410", "rank": "Strain"}, "1297661": {"name": "Munia coronavirus HKU13", "rank": "Species"}, "1448679": {"name": "Mycobacterium tuberculosis M1418", "rank": "Strain"}, "1448678": {"name": "Mycobacterium tuberculosis M1417", "rank": "Strain"}, "585158": {"name": "Staphylococcus aureus subsp. aureus M876", "rank": "Strain"}, "585159": {"name": "Staphylococcus aureus subsp. aureus M899", "rank": "Strain"}, "665115": {"name": "Shiraia sp. slf14", "rank": "Species"}, "585155": {"name": "Staphylococcus aureus subsp. aureus H19", "rank": "Strain"}, "585156": {"name": "Staphylococcus aureus subsp. aureus M1015", "rank": "Strain"}, "585157": {"name": "Staphylococcus aureus subsp. aureus M809", "rank": "Strain"}, "1365484": {"name": "Penicillium roqueforti FM164", "rank": "Strain"}, "585151": {"name": "Staphylococcus aureus subsp. aureus C427", "rank": "Strain"}, "585152": {"name": "Staphylococcus aureus subsp. aureus D139", "rank": "Strain"}, "585153": {"name": "Staphylococcus aureus subsp. aureus E1410", "rank": "Strain"}, "1324959": {"name": "Burdock mottle virus", "rank": "Species"}, "154": {"name": "Spirochaeta thermophila", "rank": "Species"}, "683179": {"name": "Saccharum streak virus", "rank": "Species"}, "683174": {"name": "Astrovirus VA3", "rank": "Species"}, "683176": {"name": "Senegalese sole Iberian betanodavirus", "rank": "Species"}, "119065": {"name": "Unclassified Burkholderiales", "rank": "No rank"}, "1169668": {"name": "Enterococcus sp. GMD4E", "rank": "Species"}, "1324957": {"name": "Candidatus Halobonum tyrrellensis G22", "rank": "Strain"}, "683172": {"name": "Astrovirus MLB2", "rank": "Species"}, "538398": {"name": "Pseudomonas phage PB1", "rank": "Species"}, "1169669": {"name": "Enterococcus sp. GMD5E", "rank": "Species"}, "1427308": {"name": "Mycobacterium tuberculosis XTB13-238", "rank": "Strain"}, "1427309": {"name": "Mycobacterium tuberculosis XTB13-239", "rank": "Strain"}, "1388018": {"name": "Staphylococcus aureus M0046", "rank": "Strain"}, "1388019": {"name": "Staphylococcus aureus M0048", "rank": "Strain"}, "415703": {"name": "Tremellales incertae sedis", "rank": "No rank"}, "344005": {"name": "Unclassified Polyomavirus", "rank": "No rank"}, "1427300": {"name": "Mycobacterium tuberculosis XTB13-229", "rank": "Strain"}, "1388013": {"name": "Staphylococcus aureus M0040", "rank": "Strain"}, "1388010": {"name": "Staphylococcus aureus M0037", "rank": "Strain"}, "1388011": {"name": "Staphylococcus aureus M0038", "rank": "Strain"}, "1388016": {"name": "Staphylococcus aureus M0043", "rank": "Strain"}, "1388017": {"name": "Staphylococcus aureus M0044", "rank": "Strain"}, "1427306": {"name": "Mycobacterium tuberculosis XTB13-235", "rank": "Strain"}, "1388015": {"name": "Staphylococcus aureus M0042", "rank": "Strain"}, "222534": {"name": "Frankia sp. BMG5.12", "rank": "Species"}, "1262514": {"name": "Pseudomonas phage MPK6", "rank": "Species"}, "1262515": {"name": "Leuconostoc phage phiLN03", "rank": "Species"}, "1262516": {"name": "Leuconostoc phage phiLN04", "rank": "Species"}, "1262517": {"name": "Leuconostoc phage phiLN12", "rank": "Species"}, "104394": {"name": "Picobirnavirus", "rank": "Genus"}, "1496": {"name": "Peptoclostridium difficile", "rank": "Species"}, "1262513": {"name": "Serratia phage phiMAM1", "rank": "Species"}, "1157393": {"name": "Enterococcus faecalis EnGen0374", "rank": "Strain"}, "1499": {"name": "Clostridium josui", "rank": "Species"}, "1157391": {"name": "Enterococcus faecalis EnGen0228", "rank": "Strain"}, "1157390": {"name": "Enterococcus faecalis EnGen0205", "rank": "Strain"}, "1157397": {"name": "Enterococcus faecalis EnGen0211", "rank": "Strain"}, "1262519": {"name": "Leuconostoc phage phiLN34", "rank": "Species"}, "1157395": {"name": "Enterococcus faecalis EnGen0209", "rank": "Strain"}, "1157394": {"name": "Enterococcus faecalis EnGen0208", "rank": "Strain"}, "149539": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis", "rank": "Strain"}, "670516": {"name": "Mycobacterium chelonae group", "rank": "Species group"}, "1320322": {"name": "Enterococcus faecalis JH2-2", "rank": "Strain"}, "1406792": {"name": "Bacillus phage Staley", "rank": "Species"}, "1406793": {"name": "Clavibacter phage CN1A", "rank": "Species"}, "1406790": {"name": "Bacillus phage Slash", "rank": "Species"}, "1406791": {"name": "Bacillus phage Spock", "rank": "Species"}, "1384049": {"name": "Lysinibacillus manganicus DSM 26584", "rank": "Strain"}, "1406794": {"name": "Salmonella phage Marshall", "rank": "Species"}, "1406795": {"name": "Salmonella phage Maynard", "rank": "Species"}, "1310956": {"name": "Acinetobacter baumannii 25561_2", "rank": "Strain"}, "192843": {"name": "Rhodoferax ferrireducens", "rank": "Species"}, "1310954": {"name": "Acinetobacter baumannii 24975_10", "rank": "Strain"}, "1310955": {"name": "Acinetobacter baumannii 25561_1", "rank": "Strain"}, "1310953": {"name": "Acinetobacter baumannii 24975_9", "rank": "Strain"}, "1310951": {"name": "Acinetobacter baumannii 24975_7", "rank": "Strain"}, "10867": {"name": "Enterobacteria phage Ike", "rank": "Species"}, "1486662": {"name": "Bacillus phage Riley", "rank": "Species"}, "1486660": {"name": "Bacillus phage Hoody T", "rank": "Species"}, "1486661": {"name": "Bacillus phage Megatron", "rank": "Species"}, "1183239": {"name": "Salisaeta icosahedral phage 1", "rank": "Species"}, "10860": {"name": "Inoviridae", "rank": "Family"}, "1266367": {"name": "Brucella melitensis 043", "rank": "Strain"}, "1148": {"name": "Synechocystis sp. PCC 6803", "rank": "Species"}, "1142": {"name": "Synechocystis", "rank": "Genus"}, "1140": {"name": "Synechococcus elongatus PCC 7942", "rank": "Strain"}, "1147": {"name": "Synechocystis sp. PCC 6714", "rank": "Species"}, "675071": {"name": "Virgaviridae", "rank": "Family"}, "675070": {"name": "Cilevirus", "rank": "Genus"}, "675073": {"name": "Torradovirus", "rank": "Genus"}, "675072": {"name": "Secoviridae", "rank": "Family"}, "675075": {"name": "Comovirinae", "rank": "Subfamily"}, "675074": {"name": "Unclassified Picornavirales", "rank": "No rank"}, "675077": {"name": "Plum bark necrosis stem pitting-associated virus", "rank": "Species"}, "675076": {"name": "Lolavirus", "rank": "Genus"}, "717959": {"name": "Alistipes shahii WAL 8301", "rank": "Strain"}, "373398": {"name": "Basella rugose mosaic virus", "rank": "Species"}, "915099": {"name": "Pseudomonas sp. 2-92(2010)", "rank": "Species"}, "1297570": {"name": "Mesorhizobium sp. STM 4661", "rank": "Species"}, "1150615": {"name": "Xanthomonas axonopodis pv. glycines str. 12-2", "rank": "Strain"}, "39766": {"name": "Sulfurimonas denitrificans", "rank": "Species"}, "39765": {"name": "Thiomicrospira crunogena", "rank": "Species"}, "1113547": {"name": "Salmonella phage 9NA", "rank": "Species"}, "39760": {"name": "Idaeovirus", "rank": "Genus"}, "39768": {"name": "Blattabacterium sp. (Mastotermes darwiniensis)", "rank": "Species"}, "471824": {"name": "Haloplasma", "rank": "Genus"}, "471825": {"name": "Haloplasma contractile", "rank": "Species"}, "471826": {"name": "Candidatus Desulforudis", "rank": "Genus"}, "471827": {"name": "Candidatus Desulforudis audaxviator", "rank": "Species"}, "471822": {"name": "Haloplasmatales", "rank": "Order"}, "471823": {"name": "Haloplasmataceae", "rank": "Family"}, "1116118": {"name": "Escherichia coli BCE034_MS-14", "rank": "Strain"}, "1116119": {"name": "Escherichia coli 2719100", "rank": "Strain"}, "1064539": {"name": "Azospirillum brasilense Sp245", "rank": "Strain"}, "1116112": {"name": "Escherichia coli BCE002_MS12", "rank": "Strain"}, "1064537": {"name": "Brachybacterium paraconglomeratum LC44", "rank": "Strain"}, "1064535": {"name": "Megasphaera elsdenii DSM 20460", "rank": "Strain"}, "1116116": {"name": "Escherichia coli BCE030_MS-09", "rank": "Strain"}, "1116117": {"name": "Escherichia coli BCE032_MS-12", "rank": "Strain"}, "1116114": {"name": "Escherichia coli BCE011_MS-01", "rank": "Strain"}, "1116115": {"name": "Escherichia coli BCE019_MS-13", "rank": "Strain"}, "267989": {"name": "Lebetimonas", "rank": "Genus"}, "180816": {"name": "Stx2 converting phage I", "rank": "Strain"}, "267986": {"name": "Owenweeksia", "rank": "Genus"}, "1525218": {"name": "Sulfitobacter sp. CB2047", "rank": "Species"}, "1401027": {"name": "Flavobacterium limnosediminis", "rank": "Species"}, "1123226": {"name": "Saccharibacillus kuerlensis DSM 22868", "rank": "Strain"}, "1123227": {"name": "Saccharibacter floricola DSM 15669", "rank": "Strain"}, "491916": {"name": "Rhizobium etli CIAT 652", "rank": "Strain"}, "535026": {"name": "Bacillus subtilis subsp. subtilis str. NCIB 3610", "rank": "Strain"}, "1429793": {"name": "Mycobacterium phage Donovan", "rank": "Species"}, "535024": {"name": "Bacillus subtilis subsp. subtilis str. SMY", "rank": "Strain"}, "511680": {"name": "Butyrivibrio crossotus DSM 2876", "rank": "Strain"}, "1441931": {"name": "Pseudomonas aeruginosa VRFPA09", "rank": "Strain"}, "1441930": {"name": "Serratia fonticola RB-25", "rank": "Strain"}, "798130": {"name": "Pseudomonas aeruginosa 39016", "rank": "Strain"}, "46541": {"name": "Thermosipho melanesiensis", "rank": "Species"}, "10912": {"name": "Rotavirus", "rank": "Genus"}, "343865": {"name": "Unclassified Mitovirus", "rank": "No rank"}, "1429244": {"name": "Paenibacillus polymyxa CR1", "rank": "Strain"}, "1151350": {"name": "Peptoclostridium difficile DA00232", "rank": "Strain"}, "637730": {"name": "Shigella phage Ag3", "rank": "Species"}, "891398": {"name": "Candidatus Tremblaya princeps PCIT", "rank": "Strain"}, "1236525": {"name": "Asaia platycodi JCM 25414", "rank": "Strain"}, "1095774": {"name": "Pantoea ananatis PA13", "rank": "Strain"}, "63399": {"name": "Arthroderma", "rank": "Genus"}, "404330": {"name": "Streptococcus pyogenes serotype M2", "rank": "Strain"}, "404331": {"name": "Streptococcus pyogenes serotype M4", "rank": "Strain"}, "1095772": {"name": "Timonella senegalensis JC301", "rank": "Strain"}, "392016": {"name": "Alicyclobacillus contaminans", "rank": "Species"}, "1191324": {"name": "Vibrio tasmaniensis 1F-267", "rank": "Strain"}, "1191325": {"name": "Vibrio tasmaniensis 5F-79", "rank": "Strain"}, "1191326": {"name": "Vibrio tasmaniensis ZS-17", "rank": "Strain"}, "1191322": {"name": "Vibrio tasmaniensis 1F-187", "rank": "Strain"}, "1191323": {"name": "Vibrio tasmaniensis 1F-155", "rank": "Strain"}, "180822": {"name": "Chronic bee paralysis virus", "rank": "Species"}, "1049766": {"name": "Leptospira borgpetersenii serovar Javanica str. MK146", "rank": "Strain"}, "1049767": {"name": "Leptospira borgpetersenii serovar Javanica str. UI 09931", "rank": "Strain"}, "1049765": {"name": "Leptospira borgpetersenii serovar Javanica str. L0864", "rank": "Strain"}, "1049762": {"name": "Leptospira borgpetersenii serovar Castellonis str. 200801910", "rank": "Strain"}, "392015": {"name": "Alicyclobacillus macrosporangiidus", "rank": "Species"}, "78120": {"name": "Succinispira mobilis", "rank": "Species"}, "11830": {"name": "Murine osteosarcoma virus", "rank": "Species"}, "11834": {"name": "RD114 retrovirus", "rank": "Species"}, "1114263": {"name": "Methylosarcina lacus LW14", "rank": "Strain"}, "1446531": {"name": "Escherichia coli O111:NM str. 2011C-3632", "rank": "Strain"}, "452623": {"name": "Pseudoclavibacter soli", "rank": "Species"}, "1507006": {"name": "Mirabilis leaf curl India virus", "rank": "Species"}, "196400": {"name": "Grapevine rupestris stem pitting-associated virus", "rank": "Species"}, "452627": {"name": "Amphritea japonica", "rank": "Species"}, "1121346": {"name": "Cohnella laeviribosi DSM 21336", "rank": "Strain"}, "233150": {"name": "Mycoplasma gallisepticum str. R", "rank": "Strain"}, "272947": {"name": "Rickettsia prowazekii str. Madrid E", "rank": "Strain"}, "753670": {"name": "Pea necrotic yellow dwarf virus", "rank": "Species"}, "74201": {"name": "Verrucomicrobia", "rank": "Phylum"}, "1408360": {"name": "Campylobacter jejuni subsp. doylei ATCC 49349", "rank": "Strain"}, "224027": {"name": "Hydrogenothermaceae", "rank": "Family"}, "1412452": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. SA19992322", "rank": "Strain"}, "1169312": {"name": "Enterococcus faecalis ATCC 10100", "rank": "Strain"}, "1412453": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20090641", "rank": "Strain"}, "929835": {"name": "Vibrio phage pYD38-B", "rank": "Species"}, "1203471": {"name": "Geobacter daltonii", "rank": "Species"}, "1412455": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20110221", "rank": "Strain"}, "766146": {"name": "Shigella flexneri K-218", "rank": "Strain"}, "766147": {"name": "Shigella flexneri K-227", "rank": "Strain"}, "230311": {"name": "Herbaspirillum huttiense subsp. putei", "rank": "Subspecies"}, "230310": {"name": "Curvibacter gracilis", "rank": "Species"}, "766142": {"name": "Shigella dysenteriae 155-74", "rank": "Strain"}, "766143": {"name": "Shigella dysenteriae 225-75", "rank": "Strain"}, "766140": {"name": "Shigella boydii 4444-74", "rank": "Strain"}, "766141": {"name": "Shigella boydii 5216-82", "rank": "Strain"}, "574890": {"name": "Sweet potato leaf curl Lanzarote virus", "rank": "Species"}, "766148": {"name": "Shigella flexneri K-272", "rank": "Strain"}, "766149": {"name": "Shigella flexneri K-304", "rank": "Strain"}, "214092": {"name": "Yersinia pestis CO92", "rank": "Strain"}, "340467": {"name": "Desulfatirhabdium butyrativorans", "rank": "Species"}, "1435361": {"name": "Staphylococcus aureus CUHK_BJ2007", "rank": "Strain"}, "354356": {"name": "Niastella koreensis", "rank": "Species"}, "108007": {"name": "Thermanaerovibrio velox", "rank": "Species"}, "92444": {"name": "Acute bee paralysis virus", "rank": "Species"}, "354350": {"name": "Unclassified Aureusvirus", "rank": "No rank"}, "1241583": {"name": "Burkholderia pseudomallei NCTC 13179", "rank": "Strain"}, "1408941": {"name": "Mycobacterium tuberculosis UT0070", "rank": "Strain"}, "53179": {"name": "Porcine rubulavirus", "rank": "Species"}, "1310768": {"name": "Acinetobacter baumannii 1397513", "rank": "Strain"}, "1218078": {"name": "Burkholderia ginsengisoli NBRC 100965", "rank": "Strain"}, "1218079": {"name": "Burkholderia gladioli NBRC 13700", "rank": "Strain"}, "1040978": {"name": "Cupriavidus taiwanensis STM 6018", "rank": "Strain"}, "1040979": {"name": "Cupriavidus taiwanensis STM 6070", "rank": "Strain"}, "1235653": {"name": "Propionibacterium phage PHL111M01", "rank": "Species"}, "1235650": {"name": "Propionibacterium phage PHL071N05", "rank": "Species"}, "1218076": {"name": "Burkholderia ferrariae NBRC 106233", "rank": "Strain"}, "1235656": {"name": "Propionibacterium phage PHL114L00", "rank": "Species"}, "1218074": {"name": "Burkholderia acidipaludis NBRC 101816", "rank": "Strain"}, "1218075": {"name": "Burkholderia bannensis NBRC 103871", "rank": "Strain"}, "1436885": {"name": "Campylobacter jejuni subsp. jejuni 81-176-UMCW7", "rank": "Strain"}, "1321817": {"name": "Actinomyces graevenitzii F0530", "rank": "Strain"}, "661086": {"name": "Olsenella sp. oral taxon 809", "rank": "Species"}, "640081": {"name": "Dechlorosoma suillum PS", "rank": "Strain"}, "1321816": {"name": "Alloscardovia omnicolens F0580", "rank": "Strain"}, "1310761": {"name": "Acinetobacter baumannii 88816", "rank": "Strain"}, "1436889": {"name": "Escherichia phage KBNP1711", "rank": "Species"}, "258255": {"name": "Pseudovibrio", "rank": "Genus"}, "1408948": {"name": "Mycobacterium tuberculosis UT0083", "rank": "Strain"}, "1116043": {"name": "Escherichia coli P0299438.8", "rank": "Strain"}, "228912": {"name": "Xanthomonas axonopodis pv. malvacearum", "rank": "Strain"}, "1398015": {"name": "Staphylococcus aureus M1392", "rank": "Strain"}, "401040": {"name": "Okra yellow crinkle virus", "rank": "Species"}, "1163722": {"name": "Bacillus cereus LCT-BC244", "rank": "Strain"}, "562018": {"name": "Streptococcus pyogenes AA472", "rank": "Strain"}, "231447": {"name": "Desulfobulbus japonicus", "rank": "Species"}, "446529": {"name": "Microbacterium phage Min1", "rank": "Species"}, "186783": {"name": "Ourmiavirus", "rank": "Genus"}, "1276135": {"name": "Metarhizium anisopliae ARSEF 549", "rank": "Strain"}, "1122988": {"name": "Prevotella nanceiensis DSM 19126 = JCM 15639", "rank": "Strain"}, "1418303": {"name": "Staphylococcus aureus H19420", "rank": "Strain"}, "1445865": {"name": "Serratia marcescens BIDMC 81", "rank": "Strain"}, "1445864": {"name": "Serratia marcescens BIDMC 80", "rank": "Strain"}, "1445863": {"name": "Escherichia coli BIDMC 83", "rank": "Strain"}, "1445862": {"name": "Escherichia coli BIDMC 82", "rank": "Strain"}, "1122986": {"name": "Prevotella maculosa DSM 19339 = JCM 15638", "rank": "Strain"}, "186789": {"name": "Punalikevirus", "rank": "Genus"}, "359987": {"name": "Rhizosolenia setigera RNA virus 01", "rank": "Species"}, "91604": {"name": "Candidatus Paracaedibacter acanthamoebae", "rank": "Species"}, "439292": {"name": "Bacillus selenitireducens MLS10", "rank": "Strain"}, "1435367": {"name": "Burkholderia pseudomallei MSHR4012", "rank": "Strain"}, "1122985": {"name": "Prevotella loescheii DSM 19665 = JCM 12249 = ATCC 15930", "rank": "Strain"}, "1313265": {"name": "Thermocrinis sp. GBS", "rank": "Species"}, "347962": {"name": "Bacillus phage Gamma", "rank": "Species"}, "1122982": {"name": "Prevotella denticola DSM 20614 = JCM 13449", "rank": "Strain"}, "1122983": {"name": "Prevotella falsenii DSM 22864 = JCM 15124", "rank": "Strain"}, "1122981": {"name": "Prevotella corporis DSM 18810 = JCM 8529", "rank": "Strain"}, "11014": {"name": "Chrysovirus", "rank": "Genus"}, "386428": {"name": "Pseudoalteromonas sp. BSi20480", "rank": "Species"}, "11012": {"name": "Partitiviridae", "rank": "Family"}, "11011": {"name": "Giardiavirus", "rank": "Genus"}, "483179": {"name": "Brucella canis ATCC 23365", "rank": "Strain"}, "11019": {"name": "Alphavirus", "rank": "Genus"}, "498736": {"name": "Borrelia burgdorferi 80a", "rank": "Strain"}, "522373": {"name": "Stenotrophomonas maltophilia K279a", "rank": "Strain"}, "1365217": {"name": "Salmonella enterica subsp. enterica serovar Typhimurium str. ST78896", "rank": "Strain"}, "1172178": {"name": "Promicromonospora sukumoe 327MFSha3.1", "rank": "Strain"}, "1172179": {"name": "Streptomyces sp. 142MFCol3.1", "rank": "Species"}, "879243": {"name": "Porphyromonas asaccharolytica DSM 20707", "rank": "Strain"}, "1422127": {"name": "Staphylococcus aureus DAR3555", "rank": "Strain"}, "880": {"name": "Desulfovibrio salexigens", "rank": "Species"}, "167879": {"name": "Colwellia psychrerythraea 34H", "rank": "Strain"}, "1422124": {"name": "Staphylococcus aureus DAR3534", "rank": "Strain"}, "270146": {"name": "Tomato leaf curl Sudan virus", "rank": "Species"}, "318844": {"name": "Tibrogargan virus", "rank": "Species"}, "318843": {"name": "Almpiwar virus", "rank": "Species"}, "270140": {"name": "Tomato leaf curl Iran virus", "rank": "Species"}, "1412479": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. SA20094177", "rank": "Strain"}, "1412476": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. SA20094682", "rank": "Strain"}, "1412477": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. SA20084384", "rank": "Strain"}, "1412474": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. SA19970769", "rank": "Strain"}, "929814": {"name": "Salmonella phage RE-2010", "rank": "Species"}, "1412472": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. SA19980677", "rank": "Strain"}, "598550": {"name": "Pseudomonas sp. ICMP 17674", "rank": "Species"}, "1412470": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20120008", "rank": "Strain"}, "1412471": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20120009", "rank": "Strain"}, "1029979": {"name": "Salmonella enterica subsp. enterica serovar Pullorum str. ATCC 9120", "rank": "Strain"}, "1122967": {"name": "Pontibacter roseus DSM 17521", "rank": "Strain"}, "1122960": {"name": "Photorhabdus asymbiotica subsp. australis DSM 17609", "rank": "Strain"}, "1122962": {"name": "Pleomorphomonas koreensis DSM 23070", "rank": "Strain"}, "1122963": {"name": "Pleomorphomonas oryzae DSM 16300", "rank": "Strain"}, "1239792": {"name": "Streptococcus mitis 11/5", "rank": "Strain"}, "1239793": {"name": "Streptococcus mitis 13/39", "rank": "Strain"}, "1239790": {"name": "Streptococcus pneumoniae 845", "rank": "Strain"}, "1239791": {"name": "Streptococcus pneumoniae 2009", "rank": "Strain"}, "136849": {"name": "Pseudomonas syringae group", "rank": "Species group"}, "561965": {"name": "Aliagarivorans marinus", "rank": "Species"}, "136844": {"name": "Pseudomonas pertucinogena group", "rank": "Species group"}, "136845": {"name": "Pseudomonas putida group", "rank": "Species group"}, "136846": {"name": "Pseudomonas stutzeri group", "rank": "Species group"}, "136841": {"name": "Pseudomonas aeruginosa group", "rank": "Species group"}, "136842": {"name": "Pseudomonas chlororaphis group", "rank": "Species group"}, "136843": {"name": "Pseudomonas fluorescens group", "rank": "Species group"}, "1029978": {"name": "Salmonella enterica subsp. enterica serovar Typhimurium str. SARA13", "rank": "Strain"}, "1274399": {"name": "Enterobacter sp. Bisph1", "rank": "Species"}, "1422129": {"name": "Staphylococcus aureus DAR3565", "rank": "Strain"}, "5478": {"name": "Candida glabrata", "rank": "Species"}, "12542": {"name": "Omsk hemorrhagic fever virus", "rank": "Species"}, "423368": {"name": "Salmonella enterica subsp. enterica serovar Newport str. SL254", "rank": "Strain"}, "35276": {"name": "Unclassified Retroviridae", "rank": "No rank"}, "1131442": {"name": "Mycobacterium marinum E11", "rank": "Strain"}, "1202464": {"name": "Dehalococcoidaceae", "rank": "Family"}, "1202465": {"name": "Dehalococcoidales", "rank": "Order"}, "864596": {"name": "Bat coronavirus BM48-31/BGR/2008", "rank": "Species"}, "515982": {"name": "Mycobacterium phage BPs", "rank": "Species"}, "386793": {"name": "Pseudomonas phage LKA1", "rank": "Species"}, "386792": {"name": "Pseudomonas phage LKD16", "rank": "Species"}, "1418308": {"name": "Staphylococcus aureus H43694", "rank": "Strain"}, "1080179": {"name": "Burkholderia sp. UYPR1.413", "rank": "Species"}, "406817": {"name": "Xenorhabdus nematophila ATCC 19061", "rank": "Strain"}, "1422603": {"name": "Staphylococcus aureus VET0352R", "rank": "Strain"}, "406819": {"name": "Burkholderia sp. SJ98", "rank": "Species"}, "406818": {"name": "Xenorhabdus bovienii SS-2004", "rank": "Strain"}, "1382520": {"name": "Burkholderia mallei strain_6", "rank": "Strain"}, "1382521": {"name": "Burkholderia mallei strain_11", "rank": "Strain"}, "1382522": {"name": "Kuraishia capsulata CBS 1993", "rank": "Strain"}, "497727": {"name": "Candidatus Nitrososphaera gargensis", "rank": "Species"}, "497726": {"name": "Nitrososphaera", "rank": "Genus"}, "497724": {"name": "Campylobacter subantarcticus", "rank": "Species"}, "1233099": {"name": "Clostridium tunisiense TJ", "rank": "Strain"}, "1233098": {"name": "Aeromonas salmonicida subsp. achromogenes AS03", "rank": "Strain"}, "64178": {"name": "Coleofasciculus chthonoplastes", "rank": "Species"}, "67760": {"name": "Methanocaldococcus infernus", "rank": "Species"}, "172653": {"name": "Ictalurivirus", "rank": "Genus"}, "1144885": {"name": "Pseudomonas sp. R81", "rank": "Species"}, "1144884": {"name": "Pseudomonas sp. R62", "rank": "Species"}, "60847": {"name": "Halogeometricum borinquense", "rank": "Species"}, "60846": {"name": "Halogeometricum", "rank": "Genus"}, "1144888": {"name": "Rickettsia helvetica C9P9", "rank": "Strain"}, "1029977": {"name": "Salmonella enterica subsp. enterica serovar Paratyphi B str. SARA42", "rank": "Strain"}, "349967": {"name": "Yersinia mollaretii ATCC 43969", "rank": "Strain"}, "349966": {"name": "Yersinia frederiksenii ATCC 33641", "rank": "Strain"}, "349965": {"name": "Yersinia intermedia ATCC 29909", "rank": "Strain"}, "349968": {"name": "Yersinia bercovieri ATCC 43970", "rank": "Strain"}, "1422606": {"name": "Staphylococcus aureus VET0357R", "rank": "Strain"}, "1209355": {"name": "Acinetobacter sp. MDS7A", "rank": "Species"}, "1209359": {"name": "Staphylococcus sp. MDS7B", "rank": "Species"}, "489140": {"name": "Geminicoccus", "rank": "Genus"}, "1422242": {"name": "Staphylococcus aureus DAR1800", "rank": "Strain"}, "1422243": {"name": "Staphylococcus aureus DAR1810", "rank": "Strain"}, "1422240": {"name": "Staphylococcus aureus DAR1692", "rank": "Strain"}, "1422241": {"name": "Staphylococcus aureus DAR1698", "rank": "Strain"}, "1422246": {"name": "Staphylococcus aureus DAR1814", "rank": "Strain"}, "1422247": {"name": "Staphylococcus aureus DAR1815", "rank": "Strain"}, "1422244": {"name": "Staphylococcus aureus DAR1811", "rank": "Strain"}, "1422245": {"name": "Staphylococcus aureus DAR1813", "rank": "Strain"}, "1202448": {"name": "Enterobacter sp. Ag1", "rank": "Species"}, "1422248": {"name": "Staphylococcus aureus DAR1842", "rank": "Strain"}, "1422249": {"name": "Staphylococcus aureus DAR1859", "rank": "Strain"}, "408577": {"name": "Methanobacterium veterum", "rank": "Species"}, "31770": {"name": "Shallot virus X", "rank": "Species"}, "219305": {"name": "Micromonospora sp. ATCC 39149", "rank": "Species"}, "219301": {"name": "Brachybacterium muris", "rank": "Species"}, "203": {"name": "Campylobacter rectus", "rank": "Species"}, "202": {"name": "Campylobacter mucosalis", "rank": "Species"}, "201": {"name": "Campylobacter lari", "rank": "Species"}, "200": {"name": "Campylobacter curvus", "rank": "Species"}, "206": {"name": "Campylobacter sputorum", "rank": "Species"}, "204": {"name": "Campylobacter showae", "rank": "Species"}, "209": {"name": "Helicobacter", "rank": "Genus"}, "525271": {"name": "Enterococcus faecalis ATCC 29200", "rank": "Strain"}, "525279": {"name": "Enterococcus faecium TX1330", "rank": "Strain"}, "525278": {"name": "Enterococcus faecalis TX1322", "rank": "Strain"}, "887062": {"name": "Hylemonella gracilis ATCC 19624", "rank": "Strain"}, "1205676": {"name": "Mycobacterium canettii CIPT 140060008", "rank": "Strain"}, "1205677": {"name": "Mycobacterium canettii CIPT 140070017", "rank": "Strain"}, "1205674": {"name": "Mycobacterium canettii CIPT 140070010", "rank": "Strain"}, "1205675": {"name": "Mycobacterium canettii CIPT 140070008", "rank": "Strain"}, "167158": {"name": "Subgroup A", "rank": "No rank"}, "167159": {"name": "Subgroup B", "rank": "No rank"}, "1417131": {"name": "Staphylococcus aureus F16104", "rank": "Strain"}, "1463936": {"name": "Streptomyces sp. NRRL WC-3773", "rank": "Species"}, "1463935": {"name": "Streptomyces sp. NRRL WC-3744", "rank": "Species"}, "1463934": {"name": "Streptomyces sp. NRRL WC-3742", "rank": "Species"}, "1463931": {"name": "Streptomyces sp. NRRL WC-3704", "rank": "Species"}, "1463930": {"name": "Streptomyces sp. NRRL WC-3703", "rank": "Species"}, "1463938": {"name": "Streptomyces sp. NRRL WC-3795", "rank": "Species"}, "999883": {"name": "Lausannevirus", "rank": "Species"}, "755732": {"name": "Fluviicola taffensis DSM 16823", "rank": "Strain"}, "755731": {"name": "Clostridium sp. BNL1100", "rank": "Species"}, "1105259": {"name": "Streptococcus agalactiae CCUG 37739", "rank": "Strain"}, "1105258": {"name": "Streptococcus agalactiae CCUG 37736", "rank": "Strain"}, "1159040": {"name": "Helicobacter pylori GAM250T", "rank": "Strain"}, "610130": {"name": "Clostridium saccharolyticum WM1", "rank": "Strain"}, "1105253": {"name": "Streptococcus agalactiae CCUG 17336", "rank": "Strain"}, "1105252": {"name": "Streptococcus agalactiae CCUG 91", "rank": "Strain"}, "1105255": {"name": "Streptococcus agalactiae CCUG 29376", "rank": "Strain"}, "1159043": {"name": "Helicobacter pylori GAM254Ai", "rank": "Strain"}, "1105257": {"name": "Streptococcus agalactiae CCUG 30636", "rank": "Strain"}, "1105256": {"name": "Streptococcus agalactiae CCUG 29782", "rank": "Strain"}, "1611681": {"name": "Mucinivorans", "rank": "Genus"}, "1439006": {"name": "Streptococcus pyogenes ABC020013952", "rank": "Strain"}, "111804": {"name": "Actinomadura oligospora", "rank": "Species"}, "1387568": {"name": "Cronobacter helveticus LMG 23732", "rank": "Strain"}, "637388": {"name": "Escherichia coli O157:H7 str. FRIK2000", "rank": "Strain"}, "160454": {"name": "Enterococcus pallens", "rank": "Species"}, "160453": {"name": "Enterococcus gilvus", "rank": "Species"}, "1316409": {"name": "Streptococcus sp. HSISB1", "rank": "Species"}, "285268": {"name": "Acetobacter nitrogenifigens", "rank": "Species"}, "637381": {"name": "Listeria monocytogenes 08-5923", "rank": "Strain"}, "169683": {"name": "Pseudomonas phage phiKZ", "rank": "Species"}, "377609": {"name": "Tomato leaf curl Guangxi virus", "rank": "Species"}, "1527444": {"name": "Candidatus Atelocyanobacterium thalassa isolate SIO64986", "rank": "Strain"}, "637382": {"name": "Yersinia pestis D106004", "rank": "Strain"}, "945250": {"name": "Verbesina encelioides leaf curl alphasatellite", "rank": "Species"}, "992157": {"name": "Yersinia pestis PY-55", "rank": "Strain"}, "992150": {"name": "Yersinia pestis PY-45", "rank": "Strain"}, "992151": {"name": "Yersinia pestis PY-46", "rank": "Strain"}, "120652": {"name": "Methylocella", "rank": "Genus"}, "155194": {"name": "Bartonella bovis", "rank": "Species"}, "326544": {"name": "Glaciecola psychrophila", "rank": "Species"}, "873517": {"name": "Capnocytophaga ochracea F0287", "rank": "Strain"}, "873513": {"name": "Prevotella buccae ATCC 33574", "rank": "Strain"}, "1288082": {"name": "Streptomyces sp. CNH287", "rank": "Species"}, "1288083": {"name": "Streptomyces sp. TAA040", "rank": "Species"}, "1288080": {"name": "Streptomyces sp. CNT360", "rank": "Species"}, "1288081": {"name": "Streptomyces sp. CNQ865", "rank": "Species"}, "1288086": {"name": "Salinispora arenicola CNS299", "rank": "Strain"}, "1288087": {"name": "Salinispora arenicola CNS243", "rank": "Strain"}, "1288084": {"name": "Salinispora tropica CNT261", "rank": "Strain"}, "1288085": {"name": "Salinispora arenicola CNH963", "rank": "Strain"}, "1413376": {"name": "Staphylococcus aureus Sau 47", "rank": "Strain"}, "1288089": {"name": "Salinispora pacifica CNS237", "rank": "Strain"}, "715962": {"name": "Dothideomyceta", "rank": "No rank"}, "1413377": {"name": "Staphylococcus aureus Sau 74", "rank": "Strain"}, "1500298": {"name": "Chryseobacterium sp. YR561", "rank": "Species"}, "63402": {"name": "Microsporum gypseum", "rank": "Species"}, "1500299": {"name": "Rhizobium sp. CF048", "rank": "Species"}, "63405": {"name": "Arthroderma otae", "rank": "Species"}, "1273538": {"name": "Planomicrobium glaciei CHR43", "rank": "Strain"}, "1095662": {"name": "Vibrio cholerae O1 str. 116063", "rank": "Strain"}, "914129": {"name": "Streptococcus pneumoniae 2061376", "rank": "Strain"}, "1074165": {"name": "Streptococcus mutans TCI-227", "rank": "Strain"}, "1562064": {"name": "Norway rat hunnivirus", "rank": "Species"}, "1413378": {"name": "Staphylococcus aureus Sau 93", "rank": "Strain"}, "1388197": {"name": "Staphylococcus aureus M0300", "rank": "Strain"}, "1388196": {"name": "Staphylococcus aureus M0298", "rank": "Strain"}, "1388195": {"name": "Staphylococcus aureus M0297", "rank": "Strain"}, "69328": {"name": "Pseudomonas sp. VLB120", "rank": "Species"}, "1388193": {"name": "Staphylococcus aureus M0295", "rank": "Strain"}, "1388192": {"name": "Staphylococcus aureus M0293", "rank": "Strain"}, "1388191": {"name": "Staphylococcus aureus M0292", "rank": "Strain"}, "1388190": {"name": "Staphylococcus aureus M0291", "rank": "Strain"}, "1500292": {"name": "Chryseobacterium sp. YR459", "rank": "Species"}, "1388199": {"name": "Staphylococcus aureus M0302", "rank": "Strain"}, "1095667": {"name": "Neisseria meningitidis 77221", "rank": "Strain"}, "1074162": {"name": "Streptococcus mutans TCI-222", "rank": "Strain"}, "369791": {"name": "Mesonia mobilis", "rank": "Species"}, "56780": {"name": "Syntrophus aciditrophicus SB", "rank": "Strain"}, "351094": {"name": "Paucisalibacillus", "rank": "Genus"}, "351095": {"name": "Paucisalibacillus globulus", "rank": "Species"}, "662945": {"name": "Mycoplasma genitalium M6320", "rank": "Strain"}, "662947": {"name": "Mycoplasma genitalium M2288", "rank": "Strain"}, "351091": {"name": "Oscillibacter valericigenes", "rank": "Species"}, "215743": {"name": "Roseovarius mucosus", "rank": "Species"}, "197575": {"name": "Haemophilus aegyptius", "rank": "Species"}, "758678": {"name": "Clostridium botulinum F str. 230613", "rank": "Strain"}, "550540": {"name": "Ferrimonas balearica DSM 9799", "rank": "Strain"}, "550542": {"name": "Geobacillus sp. Y412MC52", "rank": "Species"}, "1310695": {"name": "Acinetobacter baumannii 259052", "rank": "Strain"}, "1310694": {"name": "Acinetobacter baumannii 232184", "rank": "Strain"}, "1310697": {"name": "Acinetobacter baumannii 21072", "rank": "Strain"}, "1310696": {"name": "Acinetobacter baumannii 1592897", "rank": "Strain"}, "1310691": {"name": "Acinetobacter baumannii 42887", "rank": "Strain"}, "1310693": {"name": "Acinetobacter baumannii 655378", "rank": "Strain"}, "1310692": {"name": "Acinetobacter baumannii 532279", "rank": "Strain"}, "1310699": {"name": "Acinetobacter baumannii 1575710", "rank": "Strain"}, "1310698": {"name": "Acinetobacter baumannii 1593273", "rank": "Strain"}, "1403869": {"name": "Staphylococcus aureus M1485", "rank": "Strain"}, "1403868": {"name": "Staphylococcus aureus M1484", "rank": "Strain"}, "144193": {"name": "Turicella", "rank": "Genus"}, "1403866": {"name": "Staphylococcus aureus M1482", "rank": "Strain"}, "112040": {"name": "Zobellia", "rank": "Genus"}, "1403864": {"name": "Staphylococcus aureus M1479", "rank": "Strain"}, "1403863": {"name": "Staphylococcus aureus M1478", "rank": "Strain"}, "1403862": {"name": "Staphylococcus aureus M1477", "rank": "Strain"}, "1403861": {"name": "Staphylococcus aureus M1476", "rank": "Strain"}, "1403860": {"name": "Staphylococcus aureus M1475", "rank": "Strain"}, "62352": {"name": "Eyach virus", "rank": "Species"}, "1245909": {"name": "Sulfolobales Mexican rudivirus 1", "rank": "Species"}, "1448822": {"name": "Mycobacterium tuberculosis H2754", "rank": "Strain"}, "1448823": {"name": "Mycobacterium tuberculosis H3094", "rank": "Strain"}, "1448821": {"name": "Mycobacterium tuberculosis H2463", "rank": "Strain"}, "1448826": {"name": "Mycobacterium tuberculosis H1996", "rank": "Strain"}, "1448827": {"name": "Mycobacterium tuberculosis H2375", "rank": "Strain"}, "1448824": {"name": "Mycobacterium tuberculosis H3986", "rank": "Strain"}, "1448825": {"name": "Mycobacterium tuberculosis H1249", "rank": "Strain"}, "1448828": {"name": "Mycobacterium tuberculosis H2581", "rank": "Strain"}, "1314667": {"name": "Clavispora lusitaniae MTCC 1001", "rank": "Strain"}, "1379399": {"name": "Cloacimonetes bacterium JGI OTU-1", "rank": "Species"}, "1379398": {"name": "Cloacimonetes bacterium JGI OTU-2", "rank": "Species"}, "977905": {"name": "Bacillus sp. 17376", "rank": "Species"}, "1379391": {"name": "Nanoarchaeota archaeon JGI OTU-2", "rank": "Species"}, "1379390": {"name": "Nanoarchaeota archaeon JGI OTU-1", "rank": "Species"}, "1379393": {"name": "Cloacimonetes bacterium JGI OTU-5", "rank": "Species"}, "1379392": {"name": "Cloacimonetes bacterium JGI OTU-4", "rank": "Species"}, "1379394": {"name": "Cloacimonetes bacterium JGI OTU-6", "rank": "Species"}, "1379397": {"name": "Cloacimonetes bacterium JGI OTU-3", "rank": "Species"}, "1194757": {"name": "Canine circovirus", "rank": "Species"}, "869675": {"name": "Escherichia coli 1.2264", "rank": "Strain"}, "359407": {"name": "Methylotenera", "rank": "Genus"}, "1144674": {"name": "Acinetobacter sp. CIP A162", "rank": "Species"}, "1144670": {"name": "Acinetobacter sp. CIP 51.11", "rank": "Species"}, "1144671": {"name": "Acinetobacter sp. CIP 53.82", "rank": "Species"}, "1144672": {"name": "Acinetobacter sp. CIP 56.2", "rank": "Species"}, "1144673": {"name": "Acinetobacter sp. CIP 64.7", "rank": "Species"}, "52225": {"name": "Mitsuokella", "rank": "Genus"}, "459845": {"name": "Streptococcus phage 858", "rank": "Species"}, "76886": {"name": "Caldivirga", "rank": "Genus"}, "76887": {"name": "Caldivirga maquilingensis", "rank": "Species"}, "52227": {"name": "Prevotella dentalis", "rank": "Species"}, "479936": {"name": "Commensalibacter intestini", "rank": "Species"}, "479935": {"name": "Gluconobacter morbifer", "rank": "Species"}, "241630": {"name": "Mossman virus", "rank": "Species"}, "1046596": {"name": "Lactobacillus mali KCTC 3596 = DSM 20444", "rank": "Strain"}, "1310719": {"name": "Acinetobacter baumannii 607805", "rank": "Strain"}, "1046599": {"name": "Lactobacillus acidipiscis KCTC 13900", "rank": "Strain"}, "188763": {"name": "Panine herpesvirus 2", "rank": "Species"}, "1156497": {"name": "Pichiaceae", "rank": "Family"}, "378548": {"name": "Novosphingobium nitrogenifigens", "rank": "Species"}, "544556": {"name": "Geobacillus sp. Y412MC61", "rank": "Species"}, "1345571": {"name": "Helicobacter pylori SA165C", "rank": "Strain"}, "1198108": {"name": "Acinetobacter baumannii AC12", "rank": "Strain"}, "1148786": {"name": "Diplosphaera colitermitum", "rank": "Species"}, "114196": {"name": "Selenomonas ruminantium subsp. ruminantium", "rank": "Subspecies"}, "114197": {"name": "Selenomonas ruminantium subsp. lactilytica", "rank": "Subspecies"}, "1148783": {"name": "Diplosphaera", "rank": "Genus"}, "37328": {"name": "Nocardia carnea", "rank": "Species"}, "680194": {"name": "Bicaudavirus", "rank": "Genus"}, "1367671": {"name": "Malvastrum leaf curl Philippines betasatellite", "rank": "Species"}, "38312": {"name": "Rhodococcus rhodnii", "rank": "Species"}, "1265612": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 12.A.06", "rank": "Strain"}, "1345578": {"name": "Helicobacter pylori SA170C", "rank": "Strain"}, "249058": {"name": "Gordonia otitidis", "rank": "Species"}, "1345579": {"name": "Helicobacter pylori SA171A", "rank": "Strain"}, "1359": {"name": "Lactococcus lactis subsp. cremoris", "rank": "Subspecies"}, "1358": {"name": "Lactococcus lactis", "rank": "Species"}, "1046963": {"name": "Cloacimonetes bacterium SCGC AAA252-M08", "rank": "Species"}, "1353": {"name": "Enterococcus gallinarum", "rank": "Species"}, "1352": {"name": "Enterococcus faecium", "rank": "Species"}, "1351": {"name": "Enterococcus faecalis", "rank": "Species"}, "1350": {"name": "Enterococcus", "rank": "Genus"}, "1357": {"name": "Lactococcus", "rank": "Genus"}, "1356": {"name": "Enterococcus sulfureus", "rank": "Species"}, "1355": {"name": "Enterococcus columbae", "rank": "Species"}, "1354": {"name": "Enterococcus hirae", "rank": "Species"}, "1448141": {"name": "Trueperella pyogenes MS249", "rank": "Strain"}, "1257079": {"name": "Bacillus thuringiensis DAR 81934", "rank": "Strain"}, "759938": {"name": "Barbel circovirus", "rank": "Species"}, "682382": {"name": "HMO Astrovirus A", "rank": "Species"}, "1321245": {"name": "Burkholderia pseudomallei 4900CFPatient1", "rank": "Strain"}, "42857": {"name": "Moorella group", "rank": "No rank"}, "649187": {"name": "Lammi virus", "rank": "Species"}, "649188": {"name": "Lujo virus", "rank": "Species"}, "649189": {"name": "Streptomyces griseus XylebKG-1", "rank": "Strain"}, "42858": {"name": "Staphylococcus lentus", "rank": "Species"}, "1417796": {"name": "Escherichia coli LAU-EC10", "rank": "Strain"}, "231053": {"name": "Saccharibacter floricola", "rank": "Species"}, "231052": {"name": "Saccharibacter", "rank": "Genus"}, "1392507": {"name": "Anaplasma phagocytophilum str. Norway variant2", "rank": "Strain"}, "1392505": {"name": "Anaplasma phagocytophilum str. MRK", "rank": "Strain"}, "1392502": {"name": "Selenomonas ruminantium AB3002", "rank": "Strain"}, "1392501": {"name": "Selenomonas ruminantium AC2024", "rank": "Strain"}, "1392500": {"name": "Klebsiella pneumoniae HK787", "rank": "Strain"}, "1392508": {"name": "Anaplasma phagocytophilum str. CRT35", "rank": "Strain"}, "1280998": {"name": "Escherichia coli HVH 50 (4-2593475)", "rank": "Strain"}, "1280999": {"name": "Escherichia coli HVH 51 (4-2172526)", "rank": "Strain"}, "1238201": {"name": "Vibrio parahaemolyticus 861", "rank": "Strain"}, "1238200": {"name": "Vibrio parahaemolyticus 605", "rank": "Strain"}, "185639": {"name": "Acheta domestica densovirus", "rank": "Strain"}, "185638": {"name": "Culex pipiens densovirus", "rank": "Strain"}, "1238205": {"name": "Vibrio parahaemolyticus V14/01", "rank": "Strain"}, "1238204": {"name": "Vibrio parahaemolyticus VP-48", "rank": "Strain"}, "1280990": {"name": "Escherichia coli HVH 40 (4-1219782)", "rank": "Strain"}, "1280991": {"name": "Escherichia coli HVH 41 (4-2677849)", "rank": "Strain"}, "1280992": {"name": "Escherichia coli HVH 42 (4-2100061)", "rank": "Strain"}, "1280993": {"name": "Escherichia coli HVH 43 (4-2173468)", "rank": "Strain"}, "1280994": {"name": "Escherichia coli HVH 44 (4-2298570)", "rank": "Strain"}, "1280995": {"name": "Escherichia coli HVH 45 (4-3129918)", "rank": "Strain"}, "1280996": {"name": "Escherichia coli HVH 46 (4-2758776)", "rank": "Strain"}, "1280997": {"name": "Escherichia coli HVH 48 (4-2658593)", "rank": "Strain"}, "39443": {"name": "Carnation Italian ringspot virus", "rank": "Species"}, "39441": {"name": "Methanobrevibacter arboriphilus", "rank": "Species"}, "39444": {"name": "Cotia virus", "rank": "Species"}, "1445714": {"name": "Mycobacterium phage Nyxis", "rank": "Species"}, "345585": {"name": "Invertebrate iridescent virus 30", "rank": "Species"}, "202751": {"name": "Listeria ivanovii subsp. ivanovii", "rank": "Subspecies"}, "1304919": {"name": "Klebsiella pneumoniae 280_1220", "rank": "Strain"}, "118964": {"name": "Deinococcales", "rank": "Order"}, "118969": {"name": "Legionellales", "rank": "Order"}, "118968": {"name": "Coxiellaceae", "rank": "Family"}, "1116097": {"name": "Escherichia coli p0305293.9", "rank": "Strain"}, "1116096": {"name": "Escherichia coli p0305293.8", "rank": "Strain"}, "1116095": {"name": "Escherichia coli p0305293.7", "rank": "Strain"}, "1116094": {"name": "Escherichia coli p0305293.6", "rank": "Strain"}, "1116093": {"name": "Escherichia coli p0305293.5", "rank": "Strain"}, "223926": {"name": "Vibrio parahaemolyticus RIMD 2210633", "rank": "Strain"}, "1116091": {"name": "Escherichia coli p0305293.3", "rank": "Strain"}, "1116090": {"name": "Escherichia coli p0305293.2", "rank": "Strain"}, "261939": {"name": "Ostreid herpesvirus 1", "rank": "Species"}, "1116099": {"name": "Escherichia coli p0305293.11", "rank": "Strain"}, "1116098": {"name": "Escherichia coli p0305293.10", "rank": "Strain"}, "302484": {"name": "Haloferax larsenii", "rank": "Species"}, "1094188": {"name": "Ruminiclostridium thermocellum YS", "rank": "Strain"}, "263793": {"name": "Horsegram yellow mosaic virus", "rank": "Species"}, "1094180": {"name": "Xanthomonas vasicola pv. vasculorum NCPPB 1381", "rank": "Strain"}, "1094181": {"name": "Xanthomonas vasicola pv. vasculorum NCPPB 206", "rank": "Strain"}, "1094183": {"name": "Xanthomonas campestris pv. musacearum NCPPB 2005", "rank": "Strain"}, "1094184": {"name": "Xanthomonas campestris pv. musacearum NCPPB 4379", "rank": "Strain"}, "1094185": {"name": "Xanthomonas campestris pv. musacearum NCPPB 4380", "rank": "Strain"}, "1094186": {"name": "Xanthomonas campestris pv. musacearum NCPPB 4384", "rank": "Strain"}, "1094187": {"name": "Xanthomonas campestris pv. musacearum NCPPB 4394", "rank": "Strain"}, "1409735": {"name": "Staphylococcus aureus KINW6061", "rank": "Strain"}, "1409734": {"name": "Staphylococcus aureus KINW6058", "rank": "Strain"}, "1158181": {"name": "Thioalkalivibrio sp. ALE30", "rank": "Species"}, "1409736": {"name": "Staphylococcus aureus KINW6062", "rank": "Strain"}, "1409731": {"name": "Staphylococcus aureus WAMC6071", "rank": "Strain"}, "1409730": {"name": "Staphylococcus aureus HBHO6022", "rank": "Strain"}, "1409733": {"name": "Staphylococcus aureus KINW6056", "rank": "Strain"}, "1409732": {"name": "Staphylococcus aureus HBHO6024", "rank": "Strain"}, "1281117": {"name": "Escherichia coli HVH 190 (4-3255514)", "rank": "Strain"}, "1281116": {"name": "Escherichia coli HVH 189 (4-3220125)", "rank": "Strain"}, "1281115": {"name": "Escherichia coli HVH 188 (4-2356988)", "rank": "Strain"}, "1281114": {"name": "Escherichia coli HVH 187 (4-4471660)", "rank": "Strain"}, "1409739": {"name": "Staphylococcus aureus KINW6066", "rank": "Strain"}, "1409738": {"name": "Staphylococcus aureus UCIM6144", "rank": "Strain"}, "1281111": {"name": "Escherichia coli HVH 184 (4-3343286)", "rank": "Strain"}, "1281110": {"name": "Escherichia coli HVH 183 (4-3205932)", "rank": "Strain"}, "1422400": {"name": "Staphylococcus aureus VET0061R", "rank": "Strain"}, "1422401": {"name": "Staphylococcus aureus VET0062R", "rank": "Strain"}, "1422402": {"name": "Staphylococcus aureus VET0063R", "rank": "Strain"}, "1422403": {"name": "Staphylococcus aureus VET0065R", "rank": "Strain"}, "1422404": {"name": "Staphylococcus aureus VET0066R", "rank": "Strain"}, "1422405": {"name": "Staphylococcus aureus VET0067R", "rank": "Strain"}, "1422406": {"name": "Staphylococcus aureus VET0069R", "rank": "Strain"}, "1422407": {"name": "Staphylococcus aureus VET0070R", "rank": "Strain"}, "1422408": {"name": "Staphylococcus aureus VET0072R", "rank": "Strain"}, "1422409": {"name": "Staphylococcus aureus VET0073R", "rank": "Strain"}, "130478": {"name": "Staphylococcus phage phiSLT", "rank": "Species"}, "1192196": {"name": "Bacillus subtilis subsp. subtilis str. BSP1", "rank": "Strain"}, "1192197": {"name": "Pelosinus fermentans JBW45", "rank": "Strain"}, "91892": {"name": "Legionella pneumophila subsp. fraseri", "rank": "Subspecies"}, "91890": {"name": "Legionella pneumophila subsp. pascullei", "rank": "Subspecies"}, "91891": {"name": "Legionella pneumophila subsp. pneumophila", "rank": "Subspecies"}, "49082": {"name": "Candidatus Arthromitus", "rank": "Genus"}, "54247": {"name": "Hyperthermus", "rank": "Genus"}, "133789": {"name": "Budgerigar fledgling disease virus - 1", "rank": "Strain"}, "221262": {"name": "Pennisetum mosaic virus", "rank": "Species"}, "1095639": {"name": "Vibrio cholerae O1 str. PCS-023", "rank": "Strain"}, "1095638": {"name": "Vibrio cholerae O1 str. PCS-022", "rank": "Strain"}, "573063": {"name": "Methanocaldococcus infernus ME", "rank": "Strain"}, "573062": {"name": "Thermoanaerobacter sp. X513", "rank": "Species"}, "573065": {"name": "Asticcacaulis excentricus CB 48", "rank": "Strain"}, "573064": {"name": "Methanocaldococcus fervens AG86", "rank": "Strain"}, "1202667": {"name": "Staphylococcus sp. OJ82", "rank": "Species"}, "1202668": {"name": "Lactobacillus oryzae", "rank": "Species"}, "281714": {"name": "Nocardioides alkalitolerans", "rank": "Species"}, "74030": {"name": "Roseovarius", "rank": "Genus"}, "953739": {"name": "Streptomyces venezuelae ATCC 10712", "rank": "Strain"}, "438596": {"name": "Salinimicrobium xinjiangense", "rank": "Species"}, "44281": {"name": "Pneumocystidaceae", "rank": "Family"}, "44283": {"name": "Pasteurella multocida subsp. multocida", "rank": "Subspecies"}, "560178": {"name": "Listeria phage P40", "rank": "Species"}, "765099": {"name": "Propionibacterium acnes HL005PA4", "rank": "Strain"}, "935863": {"name": "Luteimonas sp. J29", "rank": "Species"}, "935861": {"name": "Bordetella petrii J51", "rank": "Strain"}, "935860": {"name": "Bordetella petrii J49", "rank": "Strain"}, "935867": {"name": "Pseudomonas thermotolerans J53", "rank": "Strain"}, "935866": {"name": "Nocardioides sp. J54", "rank": "Species"}, "644356": {"name": "Xylella fastidiosa subsp. fastidiosa", "rank": "Subspecies"}, "644357": {"name": "Xylella fastidiosa subsp. multiplex", "rank": "Subspecies"}, "1123008": {"name": "Proteiniphilum acetatigenes DSM 18083", "rank": "Strain"}, "1123009": {"name": "Proteocatella sphenisci DSM 23131", "rank": "Strain"}, "1409489": {"name": "Staphylococcus aureus COAS6004", "rank": "Strain"}, "1409488": {"name": "Staphylococcus aureus WMCS6001", "rank": "Strain"}, "1409487": {"name": "Staphylococcus aureus COAS6001", "rank": "Strain"}, "1409486": {"name": "Staphylococcus aureus AMMC6013", "rank": "Strain"}, "1409485": {"name": "Staphylococcus aureus AMMC6014", "rank": "Strain"}, "1409484": {"name": "Staphylococcus aureus AMMC6015", "rank": "Strain"}, "1409483": {"name": "Staphylococcus aureus SMMC6030", "rank": "Strain"}, "1409482": {"name": "Staphylococcus aureus LAMC0016", "rank": "Strain"}, "1409481": {"name": "Staphylococcus aureus LAMC0013", "rank": "Strain"}, "1409480": {"name": "Staphylococcus aureus LAMC0011", "rank": "Strain"}, "244310": {"name": "Burkholderia phage Bcep1", "rank": "Species"}, "48782": {"name": "Leptospira fainei", "rank": "Species"}, "1266995": {"name": "Sida mottle Alagoas virus", "rank": "Species"}, "54526": {"name": "SAR11 cluster", "rank": "No rank"}, "1408282": {"name": "Geobacillus sp. MAS1", "rank": "Species"}, "1408283": {"name": "Clostridium botulinum CDC_1436", "rank": "Strain"}, "1408286": {"name": "Parvimonas micra A293", "rank": "Strain"}, "1408287": {"name": "Fusobacterium nucleatum W1481", "rank": "Strain"}, "1408284": {"name": "Clostridium botulinum Prevot_594", "rank": "Strain"}, "1408285": {"name": "Clostridium botulinum CDC_297", "rank": "Strain"}, "1408279": {"name": "Canine pneumovirus", "rank": "Species"}, "709484": {"name": "Enterobacteria phage CC31", "rank": "Species"}, "254358": {"name": "Streptococcus equi subsp. ruminatorum", "rank": "Subspecies"}, "1365659": {"name": "Campylobacter jejuni Cj2", "rank": "Strain"}, "364298": {"name": "Janibacter hoylei", "rank": "Species"}, "1266993": {"name": "Sida yellow blotch virus", "rank": "Species"}, "1157629": {"name": "Streptomyces sp. KhCrAH-340", "rank": "Species"}, "186778": {"name": "Novirhabdovirus", "rank": "Genus"}, "80870": {"name": "Acidovorax avenae subsp. avenae", "rank": "Subspecies"}, "80871": {"name": "Cryptosporangium arvum", "rank": "Species"}, "186772": {"name": "Saccharomyces 20S RNA narnavirus", "rank": "Species"}, "1441609": {"name": "Vibrio parahaemolyticus TUMSAT_D06_S3", "rank": "Strain"}, "1441608": {"name": "Vibrio parahaemolyticus TUMSAT_DE2_S2", "rank": "Strain"}, "1446659": {"name": "Escherichia coli O157:H7 str. F7410", "rank": "Strain"}, "1446658": {"name": "Escherichia coli O157:H7 str. F7384", "rank": "Strain"}, "1446657": {"name": "Escherichia coli O157:H7 str. F7377", "rank": "Strain"}, "1446656": {"name": "Escherichia coli O157:H7 str. F7350", "rank": "Strain"}, "1446655": {"name": "Escherichia coli O157:H7 str. F6751", "rank": "Strain"}, "1446654": {"name": "Escherichia coli O157:H7 str. F6750", "rank": "Strain"}, "1446653": {"name": "Escherichia coli O157:H7 str. F6749", "rank": "Strain"}, "1446652": {"name": "Escherichia coli O157:H7 str. F6142", "rank": "Strain"}, "1446651": {"name": "Escherichia coli O157:H7 str. 2011EL-2313", "rank": "Strain"}, "1446650": {"name": "Escherichia coli O157:H7 str. 2011EL-2312", "rank": "Strain"}, "395962": {"name": "Cyanothece sp. PCC 8802", "rank": "Species"}, "395963": {"name": "Beijerinckia indica subsp. indica ATCC 9039", "rank": "Strain"}, "395960": {"name": "Rhodopseudomonas palustris TIE-1", "rank": "Strain"}, "395961": {"name": "Cyanothece sp. PCC 7425", "rank": "Species"}, "395964": {"name": "Methylocapsa acidiphila B2", "rank": "Strain"}, "395965": {"name": "Methylocella silvestris BL2", "rank": "Strain"}, "1455275": {"name": "Mycobacterium tuberculosis NRITLD56", "rank": "Strain"}, "118173": {"name": "Pseudanabaena sp. PCC 6802", "rank": "Species"}, "1388562": {"name": "Staphylococcus aureus M0743", "rank": "Strain"}, "1388563": {"name": "Staphylococcus aureus M0744", "rank": "Strain"}, "1388560": {"name": "Staphylococcus aureus M0105", "rank": "Strain"}, "1388561": {"name": "Staphylococcus aureus M0113", "rank": "Strain"}, "1388566": {"name": "Staphylococcus aureus M0752", "rank": "Strain"}, "1388567": {"name": "Staphylococcus aureus M0772", "rank": "Strain"}, "529507": {"name": "Proteus mirabilis HI4320", "rank": "Strain"}, "1388565": {"name": "Staphylococcus aureus M0750", "rank": "Strain"}, "296591": {"name": "Polaromonas sp. JS666", "rank": "Species"}, "1388568": {"name": "Staphylococcus aureus M0773", "rank": "Strain"}, "1395523": {"name": "Unassigned Hepeviridae", "rank": "No rank"}, "909929": {"name": "Selenomonadales", "rank": "Order"}, "1203568": {"name": "Dermabacter sp. HFH0086", "rank": "Species"}, "1345661": {"name": "Nilaparvata lugens honeydew virus-2", "rank": "Species"}, "1090945": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. 50-3079", "rank": "Strain"}, "75320": {"name": "Vibrio phage KVP40", "rank": "Species"}, "373413": {"name": "Mycobacterium phage Pipefish", "rank": "Species"}, "1304881": {"name": "Clostridium indolis DSM 755", "rank": "Strain"}, "1304880": {"name": "Caldicoprobacter oshimai DSM 21659", "rank": "Strain"}, "477967": {"name": "Phikmvlikevirus", "rank": "Genus"}, "1125965": {"name": "Brevundimonas abyssalis", "rank": "Species"}, "1125964": {"name": "Loktanella cinnabarina", "rank": "Species"}, "1434199": {"name": "Burkholderia pseudomallei MSHR4375", "rank": "Strain"}, "1434198": {"name": "Burkholderia pseudomallei MSHR4372", "rank": "Strain"}, "1304882": {"name": "Cupriavidus necator A5-1", "rank": "Strain"}, "1304885": {"name": "Desulforegula conservatrix Mb1Pa", "rank": "Strain"}, "1434193": {"name": "Burkholderia pseudomallei MSHR4032", "rank": "Strain"}, "1434192": {"name": "Burkholderia pseudomallei MSHR3951", "rank": "Strain"}, "1434195": {"name": "Burkholderia pseudomallei MSHR4303", "rank": "Strain"}, "1434194": {"name": "Burkholderia pseudomallei MSHR4300", "rank": "Strain"}, "1434197": {"name": "Burkholderia pseudomallei MSHR4308", "rank": "Strain"}, "1434196": {"name": "Burkholderia pseudomallei MSHR4304", "rank": "Strain"}, "5151": {"name": "Ophiostomatales", "rank": "Order"}, "1137133": {"name": "Staphylococcus aureus subsp. aureus MRGR3", "rank": "Strain"}, "82996": {"name": "Serratia plymuthica", "rank": "Species"}, "82995": {"name": "Serratia grimesii", "rank": "Species"}, "1304886": {"name": "Desulfotignum balticum DSM 7044", "rank": "Strain"}, "1432": {"name": "Bacillus thuringiensis serovar thuringiensis", "rank": "Strain"}, "1433": {"name": "Bacillus thuringiensis serovar aizawai", "rank": "Strain"}, "1430": {"name": "Bacillus thuringiensis serovar israelensis", "rank": "Strain"}, "5152": {"name": "Ophiostomataceae", "rank": "Family"}, "1212580": {"name": "Shigella sonnei 08-7761", "rank": "Strain"}, "1212581": {"name": "Shigella sonnei 08-7765", "rank": "Strain"}, "1434": {"name": "Bacillus thuringiensis serovar berliner", "rank": "Strain"}, "10629": {"name": "BK polyomavirus", "rank": "Species"}, "10626": {"name": "Hamster polyomavirus", "rank": "Species"}, "10627": {"name": "Bovine polyomavirus", "rank": "Species"}, "10624": {"name": "Polyomavirus", "rank": "Genus"}, "10625": {"name": "Budgerigar fledgling disease polyomavirus", "rank": "Species"}, "10623": {"name": "Kappapapillomavirus 2", "rank": "Species"}, "10620": {"name": "Human papillomavirus type 7", "rank": "Strain"}, "10621": {"name": "Human papillomavirus type 9", "rank": "Strain"}, "5157": {"name": "Ceratocystis", "rank": "Genus"}, "75984": {"name": "Mannheimia", "rank": "Genus"}, "75985": {"name": "Mannheimia haemolytica", "rank": "Species"}, "1078464": {"name": "Pseudomonas aeruginosa NCMG1179", "rank": "Strain"}, "1226740": {"name": "Staphylococcus aureus subsp. aureus VH60", "rank": "Strain"}, "171288": {"name": "Mycoplasma molare", "rank": "Species"}, "930169": {"name": "Alcanivorax dieselolei B5", "rank": "Strain"}, "930168": {"name": "Sweet potato caulimo-like virus", "rank": "Species"}, "1329516": {"name": "Thermoactinomyces daqus", "rank": "Species"}, "171282": {"name": "Mycoplasma columborale", "rank": "Species"}, "930167": {"name": "Unclassified Cavemovirus", "rank": "No rank"}, "930166": {"name": "Pseudomonas brassicacearum", "rank": "Species"}, "171287": {"name": "Mycoplasma moatsii", "rank": "Species"}, "1213182": {"name": "Bacillus anthracis str. BF1", "rank": "Strain"}, "171285": {"name": "Mycoplasma glycophilum", "rank": "Species"}, "171284": {"name": "Mycoplasma cynos", "rank": "Species"}, "260963": {"name": "Avulavirus", "rank": "Genus"}, "260964": {"name": "Henipavirus", "rank": "Genus"}, "180281": {"name": "Cyanobium sp. PCC 7001", "rank": "Species"}, "258591": {"name": "Halomonas anticariensis", "rank": "Species"}, "1505652": {"name": "Terrisporobacter", "rank": "Genus"}, "258594": {"name": "Rhodopseudomonas palustris CGA009", "rank": "Strain"}, "238854": {"name": "Synechococcus phage S-PM2", "rank": "Species"}, "987059": {"name": "Rubrivivax benzoatilyticus JA2 = ATCC BAA-35", "rank": "Strain"}, "138074": {"name": "Serratia symbiotica", "rank": "Species"}, "138073": {"name": "Candidatus Regiella insecticola", "rank": "Species"}, "138072": {"name": "Candidatus Hamiltonella defensa", "rank": "Species"}, "221054": {"name": "Eupatorium yellow vein betasatellite", "rank": "Species"}, "1316941": {"name": "Archaeoglobus sulfaticallidus", "rank": "Species"}, "1316940": {"name": "Mycobacterium tuberculosis EAI", "rank": "Strain"}, "1280671": {"name": "Butyrivibrio sp. FC2001", "rank": "Species"}, "1280670": {"name": "Butyrivibrio sp. AD3002", "rank": "Species"}, "1280673": {"name": "Butyrivibrio sp. AE3006", "rank": "Species"}, "1280672": {"name": "Butyrivibrio sp. AC2005", "rank": "Species"}, "1280675": {"name": "Bifidobacterium sp. AGR2158", "rank": "Species"}, "1280674": {"name": "Prevotella sp. AGR2160", "rank": "Species"}, "1280676": {"name": "Butyrivibrio sp. WCD3002", "rank": "Species"}, "1280679": {"name": "Butyrivibrio sp. VCB2006", "rank": "Species"}, "1280678": {"name": "Butyrivibrio sp. MB2005", "rank": "Species"}, "1437425": {"name": "Criblamydia sequanensis CRIB-18", "rank": "Strain"}, "85963": {"name": "Helicobacter pylori J99", "rank": "Strain"}, "85962": {"name": "Helicobacter pylori 26695", "rank": "Strain"}, "11572": {"name": "Orthobunyavirus", "rank": "Genus"}, "11577": {"name": "La Crosse virus", "rank": "Strain"}, "63132": {"name": "Geitlerinema", "rank": "Genus"}, "904354": {"name": "Staphylococcus lugdunensis VCU150", "rank": "Strain"}, "904352": {"name": "Staphylococcus lugdunensis VCU148", "rank": "Strain"}, "428711": {"name": "Jonquetella", "rank": "Genus"}, "428712": {"name": "Jonquetella anthropi", "rank": "Species"}, "11584": {"name": "Phlebovirus", "rank": "Genus"}, "1296573": {"name": "Gastropod associated circular ssDNA virus", "rank": "Species"}, "140100": {"name": "Vibrio albensis", "rank": "Species"}, "2238": {"name": "Haloarcula marismortui", "rank": "Species"}, "1126888": {"name": "Escherichia coli C2139_99", "rank": "Strain"}, "1458256": {"name": "Bordetella bronchiseptica 980", "rank": "Strain"}, "2231": {"name": "Archaeoglobales", "rank": "Order"}, "1458259": {"name": "Bordetella bronchiseptica D989", "rank": "Strain"}, "2233": {"name": "Archaeoglobus", "rank": "Genus"}, "2232": {"name": "Archaeoglobaceae", "rank": "Family"}, "2235": {"name": "Halobacteriales", "rank": "Order"}, "2234": {"name": "Archaeoglobus fulgidus", "rank": "Species"}, "2237": {"name": "Haloarcula", "rank": "Genus"}, "2236": {"name": "Halobacteriaceae", "rank": "Family"}, "1281070": {"name": "Escherichia coli HVH 137 (4-2124971)", "rank": "Strain"}, "1281071": {"name": "Escherichia coli HVH 138 (4-6066704)", "rank": "Strain"}, "1281072": {"name": "Escherichia coli HVH 139 (4-3192644)", "rank": "Strain"}, "1281073": {"name": "Escherichia coli HVH 140 (4-5894387)", "rank": "Strain"}, "1249526": {"name": "Mannheimia haemolytica USDA-ARS-USMARC-185", "rank": "Strain"}, "5204": {"name": "Basidiomycota", "rank": "Phylum"}, "5207": {"name": "Cryptococcus neoformans", "rank": "Species"}, "1249525": {"name": "Salmonella enterica subsp. enterica serovar Virchow str. SVQ1", "rank": "Strain"}, "1281078": {"name": "Escherichia coli HVH 145 (4-5672112)", "rank": "Strain"}, "1281079": {"name": "Escherichia coli HVH 146 (4-3189767)", "rank": "Strain"}, "28997": {"name": "Dacrymycetales", "rank": "Order"}, "1071755": {"name": "Chlamydia trachomatis A/7249", "rank": "Strain"}, "1157445": {"name": "Enterococcus faecium EnGen0150", "rank": "Strain"}, "1444248": {"name": "Escherichia coli 3-020-07_S4_C2", "rank": "Strain"}, "1444249": {"name": "Escherichia coli 3-073-06_S4_C2", "rank": "Strain"}, "1444246": {"name": "Escherichia coli 1-250-04_S4_C2", "rank": "Strain"}, "1444247": {"name": "Escherichia coli 1-392-07_S4_C2", "rank": "Strain"}, "1444244": {"name": "Escherichia coli 1-176-05_S4_C2", "rank": "Strain"}, "1444245": {"name": "Escherichia coli 1-182-04_S4_C2", "rank": "Strain"}, "1444242": {"name": "Escherichia coli 8-415-05_S4_C2", "rank": "Strain"}, "1444243": {"name": "Escherichia coli 1-110-08_S4_C2", "rank": "Strain"}, "1444240": {"name": "Escherichia coli 5-366-08_S4_C2", "rank": "Strain"}, "1444241": {"name": "Escherichia coli 7-233-03_S4_C2", "rank": "Strain"}, "1529886": {"name": "Bacillus atrophaeus subsp. globigii", "rank": "Subspecies"}, "1422508": {"name": "Staphylococcus aureus VET0212R", "rank": "Strain"}, "332163": {"name": "Candidatus Solibacter usitatus", "rank": "Species"}, "332162": {"name": "Candidatus Solibacter", "rank": "Genus"}, "90244": {"name": "Oligella ureolytica", "rank": "Species"}, "90245": {"name": "Oligella urethralis", "rank": "Species"}, "1042878": {"name": "Cupriavidus necator N-1", "rank": "Strain"}, "1042877": {"name": "Thermococcus sp. 4557", "rank": "Species"}, "332168": {"name": "Halococcus hamelinensis", "rank": "Species"}, "1422503": {"name": "Staphylococcus aureus VET0203R", "rank": "Strain"}, "513049": {"name": "Arthrospira maxima CS-328", "rank": "Strain"}, "57477": {"name": "Bacillus phage Bastille", "rank": "Species"}, "229533": {"name": "Fusarium graminearum PH-1", "rank": "Strain"}, "1154961": {"name": "Streptococcus agalactiae GB00957", "rank": "Strain"}, "147452": {"name": "Staphylococcus saprophyticus subsp. saprophyticus", "rank": "Subspecies"}, "1236908": {"name": "Wolbachia endosymbiont of Drosophila simulans wNo", "rank": "Strain"}, "1236909": {"name": "Wolbachia endosymbiont of Drosophila simulans wHa", "rank": "Strain"}, "1236904": {"name": "Mycoplasma pneumoniae PI 1428", "rank": "Strain"}, "1236905": {"name": "Bacillus coagulans H-1", "rank": "Strain"}, "1236902": {"name": "Nocardiopsis baichengensis YIM 90130", "rank": "Strain"}, "1236903": {"name": "Methanosarcina mazei Tuc01", "rank": "Strain"}, "585425": {"name": "Synechococcus sp. KORDI-52", "rank": "Species"}, "36446": {"name": "Unclassified Reoviridae", "rank": "No rank"}, "1154960": {"name": "Streptococcus agalactiae GB00955", "rank": "Strain"}, "340195": {"name": "Unclassified Cheravirus", "rank": "No rank"}, "340197": {"name": "Escherichia coli F11", "rank": "Strain"}, "340190": {"name": "Salmonella enterica subsp. enterica serovar Schwarzengrund", "rank": "Strain"}, "12637": {"name": "Dengue virus", "rank": "Species"}, "28219": {"name": "Brachymonas", "rank": "Genus"}, "1334046": {"name": "Kurthia huakuii LAM0618", "rank": "Strain"}, "1413598": {"name": "Staphylococcus aureus 08139-6", "rank": "Strain"}, "976": {"name": "Bacteroidetes", "rank": "Phylum"}, "971": {"name": "Selenomonas ruminantium", "rank": "Species"}, "970": {"name": "Selenomonas", "rank": "Genus"}, "972": {"name": "Halanaerobiaceae", "rank": "Family"}, "1413592": {"name": "Staphylococcus aureus 40P10", "rank": "Strain"}, "1413593": {"name": "Staphylococcus aureus 43P3", "rank": "Strain"}, "1413590": {"name": "Staphylococcus aureus 36P5", "rank": "Strain"}, "1413591": {"name": "Staphylococcus aureus 40P5 1_1", "rank": "Strain"}, "979": {"name": "Cellulophaga lytica", "rank": "Species"}, "978": {"name": "Cytophaga", "rank": "Genus"}, "1413594": {"name": "Staphylococcus aureus 43P8", "rank": "Strain"}, "1413595": {"name": "Staphylococcus aureus 47P5", "rank": "Strain"}, "1409380": {"name": "Staphylococcus aureus WMCA6041", "rank": "Strain"}, "1409381": {"name": "Staphylococcus aureus WAMC6010", "rank": "Strain"}, "1409382": {"name": "Staphylococcus aureus HBHO6042", "rank": "Strain"}, "1409383": {"name": "Staphylococcus aureus SJUD6063", "rank": "Strain"}, "1409384": {"name": "Staphylococcus aureus SJUD6064", "rank": "Strain"}, "1409385": {"name": "Staphylococcus aureus SJUD6053", "rank": "Strain"}, "1409386": {"name": "Staphylococcus aureus SJUD6056", "rank": "Strain"}, "1409387": {"name": "Staphylococcus aureus MISS6020", "rank": "Strain"}, "1409388": {"name": "Staphylococcus aureus MISS6017", "rank": "Strain"}, "1409389": {"name": "Staphylococcus aureus MISS6019", "rank": "Strain"}, "1111107": {"name": "Metallosphaera yellowstonensis", "rank": "Species"}, "1256205": {"name": "Lactobacillus paracasei subsp. paracasei Lpp228", "rank": "Strain"}, "12639": {"name": "Duck hepatitis B virus", "rank": "Species"}, "632569": {"name": "Saccharomonospora marina", "rank": "Species"}, "163869": {"name": "Algicola sagamiensis", "rank": "Species"}, "121428": {"name": "Sphingobium xenophagum", "rank": "Species"}, "1577898": {"name": "Leisingera sp. ANG-S", "rank": "Species"}, "1577899": {"name": "Leisingera sp. ANG-S3", "rank": "Species"}, "1577896": {"name": "Leisingera sp. ANG-Vp", "rank": "Species"}, "1577897": {"name": "Leisingera sp. ANG-DT", "rank": "Species"}, "1577895": {"name": "Leisingera sp. ANG-M1", "rank": "Species"}, "53260": {"name": "Papaya leaf curl virus", "rank": "Species"}, "926067": {"name": "Aeromonas phage PX29", "rank": "Species"}, "416870": {"name": "Lactococcus lactis subsp. cremoris MG1363", "rank": "Strain"}, "1430429": {"name": "Salmonella enterica subsp. enterica serovar Bovismorbificans str. Sal677", "rank": "Strain"}, "1384065": {"name": "Ruminococcus albus AD2013", "rank": "Strain"}, "592028": {"name": "Dialister invisus DSM 15470", "rank": "Strain"}, "34063": {"name": "Actinobacillus pleuropneumoniae serovar 2", "rank": "Strain"}, "34067": {"name": "Cycloclasticus", "rank": "Genus"}, "34064": {"name": "Francisellaceae", "rank": "Family"}, "592021": {"name": "Bacillus anthracis str. A0248", "rank": "Strain"}, "592022": {"name": "Bacillus megaterium DSM 319", "rank": "Strain"}, "153948": {"name": "Nitrosomonas sp. AL212", "rank": "Species"}, "592026": {"name": "Catonella morbi ATCC 51271", "rank": "Strain"}, "592027": {"name": "Clostridium botulinum D str. 1873", "rank": "Strain"}, "575610": {"name": "Staphylococcus phage phiSauS-IPLA35", "rank": "Species"}, "575611": {"name": "Prevotella buccae D17", "rank": "Strain"}, "575612": {"name": "Prevotella melaninogenica D18", "rank": "Strain"}, "575614": {"name": "Prevotella sp. oral taxon 299 str. F0039", "rank": "Strain"}, "575615": {"name": "Prevotella sp. oral taxon 317 str. F0108", "rank": "Strain"}, "1333508": {"name": "Pseudoalteromonas haloplanktis TB13", "rank": "Strain"}, "1333509": {"name": "Pseudoalteromonas haloplanktis TB25", "rank": "Strain"}, "1333507": {"name": "Pseudoalteromonas haloplanktis TB64", "rank": "Strain"}, "1229520": {"name": "Alkalibacterium sp. AK22", "rank": "Species"}, "1229521": {"name": "Nitrincola sp. AK23", "rank": "Species"}, "10345": {"name": "Suid herpesvirus 1", "rank": "Species"}, "1173478": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN000232", "rank": "Strain"}, "117743": {"name": "Flavobacteriia", "rank": "Class"}, "117747": {"name": "Sphingobacteriia", "rank": "Class"}, "117744": {"name": "Unclassified Flavobacteriia", "rank": "No rank"}, "1173471": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN000235", "rank": "Strain"}, "1173472": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN000236", "rank": "Strain"}, "1173473": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN000184", "rank": "Strain"}, "1173474": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN000186", "rank": "Strain"}, "1173475": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN000187", "rank": "Strain"}, "1173476": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN000195", "rank": "Strain"}, "1173477": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN000202", "rank": "Strain"}, "412597": {"name": "Paracoccus sp. TRP", "rank": "Species"}, "1121278": {"name": "Chitinimonas koreensis DSM 17726", "rank": "Strain"}, "42323": {"name": "Listonella anguillarum serovar O1", "rank": "Strain"}, "1121275": {"name": "Chitinilyticum aquatile DSM 21506", "rank": "Strain"}, "1121274": {"name": "Chitinibacter tainanensis DSM 15459", "rank": "Strain"}, "1121276": {"name": "Chitinilyticum litopenaei", "rank": "Species"}, "1121271": {"name": "Gemmobacter nectariphilus DSM 15620", "rank": "Strain"}, "1121272": {"name": "Catelliglobosispora koreensis DSM 44566", "rank": "Strain"}, "693988": {"name": "Bilophila sp. 4_1_30", "rank": "Species"}, "693982": {"name": "Sinorhizobium meliloti AK83", "rank": "Strain"}, "693985": {"name": "Pseudomonas savastanoi pv. savastanoi NCPPB 3335", "rank": "Strain"}, "693986": {"name": "Methylobacterium oryzae CBMB20", "rank": "Strain"}, "1384060": {"name": "Rhodococcus sp. P27", "rank": "Species"}, "1287308": {"name": "Mesorhizobium sp. LSHC440B00", "rank": "Species"}, "301375": {"name": "Methanosaeta harundinacea", "rank": "Species"}, "1416349": {"name": "Equine hepacivirus JPN3/JAPAN/2013", "rank": "Species"}, "1287303": {"name": "Mesorhizobium sp. LSHC432A00", "rank": "Species"}, "135193": {"name": "Paenibacillus daejeonensis", "rank": "Species"}, "1287307": {"name": "Mesorhizobium sp. LSHC440A00", "rank": "Species"}, "333759": {"name": "Human papillomavirus type 10", "rank": "Strain"}, "176280": {"name": "Staphylococcus epidermidis ATCC 12228", "rank": "Strain"}, "333750": {"name": "Alphapapillomavirus", "rank": "Genus"}, "333754": {"name": "Alphapapillomavirus 10", "rank": "Species"}, "333757": {"name": "Alphapapillomavirus 8", "rank": "Species"}, "1033740": {"name": "Kurthia sp. JC8E", "rank": "Species"}, "1033743": {"name": "Paenibacillus senegalensis JC66", "rank": "Strain"}, "1033744": {"name": "Peptoniphilus senegalensis JC140", "rank": "Strain"}, "489": {"name": "Neisseria polysaccharea", "rank": "Species"}, "488": {"name": "Neisseria mucosa", "rank": "Species"}, "914144": {"name": "Streptococcus pneumoniae 2080076", "rank": "Strain"}, "485": {"name": "Neisseria gonorrhoeae", "rank": "Species"}, "484": {"name": "Neisseria flavescens", "rank": "Species"}, "487": {"name": "Neisseria meningitidis", "rank": "Species"}, "486": {"name": "Neisseria lactamica", "rank": "Species"}, "481": {"name": "Neisseriaceae", "rank": "Family"}, "480": {"name": "Moraxella catarrhalis", "rank": "Species"}, "483": {"name": "Neisseria cinerea", "rank": "Species"}, "482": {"name": "Neisseria", "rank": "Genus"}, "160800": {"name": "Methylosarcina", "rank": "Genus"}, "1410779": {"name": "Staphylococcus aureus H15665", "rank": "Strain"}, "1410778": {"name": "Staphylococcus aureus W39902", "rank": "Strain"}, "1410777": {"name": "Staphylococcus aureus F46632", "rank": "Strain"}, "1410776": {"name": "Staphylococcus aureus F46600", "rank": "Strain"}, "1410775": {"name": "Staphylococcus aureus W33796", "rank": "Strain"}, "160808": {"name": "Acidithiobacillus ferrivorans", "rank": "Species"}, "1410773": {"name": "Staphylococcus aureus F43676", "rank": "Strain"}, "1410772": {"name": "Staphylococcus aureus M80333", "rank": "Strain"}, "1410771": {"name": "Staphylococcus aureus M80329", "rank": "Strain"}, "1410770": {"name": "Staphylococcus aureus T28854", "rank": "Strain"}, "257277": {"name": "Nocardia aobensis", "rank": "Species"}, "1182783": {"name": "Xanthomonas campestris JX", "rank": "Strain"}, "257275": {"name": "Nocardia thailandica", "rank": "Species"}, "914146": {"name": "Streptococcus pneumoniae 2082170", "rank": "Strain"}, "798073": {"name": "Tuhoko virus 2", "rank": "Species"}, "1388760": {"name": "Pseudomonas putida SJ3", "rank": "Strain"}, "1388761": {"name": "Caldanaerobacter subterraneus subsp. yonseiensis KB-1", "rank": "Strain"}, "1388763": {"name": "Pseudomonas mosselii SJ10", "rank": "Strain"}, "1388764": {"name": "Pseudogulbenkiania ferrooxidans EGD-HP2", "rank": "Strain"}, "1411565": {"name": "Staphylococcus aureus T39363", "rank": "Strain"}, "1411564": {"name": "Staphylococcus aureus T39328", "rank": "Strain"}, "1411567": {"name": "Staphylococcus aureus T62346", "rank": "Strain"}, "1411566": {"name": "Staphylococcus aureus T42722", "rank": "Strain"}, "1411561": {"name": "Staphylococcus aureus T30033", "rank": "Strain"}, "1411560": {"name": "Staphylococcus aureus T26751", "rank": "Strain"}, "1411563": {"name": "Staphylococcus aureus T33147", "rank": "Strain"}, "1411562": {"name": "Staphylococcus aureus T33139", "rank": "Strain"}, "521098": {"name": "Alicyclobacillus acidocaldarius subsp. acidocaldarius DSM 446", "rank": "Strain"}, "1411569": {"name": "Staphylococcus aureus T69703", "rank": "Strain"}, "1411568": {"name": "Staphylococcus aureus T69686", "rank": "Strain"}, "327108": {"name": "Unclassified Chrysovirus", "rank": "No rank"}, "327107": {"name": "Unclassified Maculavirus", "rank": "No rank"}, "327106": {"name": "Unclassified Marafivirus", "rank": "No rank"}, "1522059": {"name": "Bovine astrovirus CH13", "rank": "Species"}, "1155096": {"name": "Borrelia crocidurae str. Achema", "rank": "Strain"}, "749952": {"name": "Salmonella enterica subsp. enterica serovar Montevideo str. SARB31", "rank": "Strain"}, "749953": {"name": "Salmonella enterica subsp. enterica serovar Montevideo str. ATCC BAA710", "rank": "Strain"}, "749950": {"name": "Salmonella enterica subsp. enterica serovar Montevideo str. OH_2009072675", "rank": "Strain"}, "749951": {"name": "Salmonella enterica subsp. enterica serovar Montevideo str. CASC_09SCPH15965", "rank": "Strain"}, "914143": {"name": "Streptococcus pneumoniae 2071247", "rank": "Strain"}, "1305849": {"name": "Enterococcus faecium Aus0085", "rank": "Strain"}, "1305843": {"name": "Salinispora pacifica CNY202", "rank": "Strain"}, "1305841": {"name": "Shewanella putrefaciens HRCR-6", "rank": "Strain"}, "1045855": {"name": "Pseudoxanthomonas spadix BD-a59", "rank": "Strain"}, "979725": {"name": "Unclassified Sp6likevirus", "rank": "No rank"}, "979726": {"name": "Enterobacteria phage UAB_Phi78", "rank": "Species"}, "1045856": {"name": "Enterobacter cloacae EcWSU1", "rank": "Strain"}, "1549126": {"name": "Desulfatiglans", "rank": "Genus"}, "416585": {"name": "Halorubrum californiense", "rank": "Species"}, "416586": {"name": "Selenomonas bovis", "rank": "Species"}, "211165": {"name": "Chlorogloeopsis fritschii PCC 6912", "rank": "Strain"}, "1266458": {"name": "Tomato mottle wrinkle virus", "rank": "Species"}, "1292256": {"name": "Penicillium paxilli ATCC 26601", "rank": "Strain"}, "267818": {"name": "Lactobacillus kefiranofaciens", "rank": "Species"}, "152682": {"name": "Sphingomonas melonis", "rank": "Species"}, "1185359": {"name": "Bat sapovirus TLC58/HK", "rank": "Species"}, "1349820": {"name": "Arthrobacter sp. AK-YN10", "rank": "Species"}, "1349822": {"name": "Coprobacter fastidiosus NSB1", "rank": "Strain"}, "225752": {"name": "Sweet potato leaf curl Georgia virus", "rank": "Species"}, "1349824": {"name": "Acinetobacter baumannii str. Perm", "rank": "Strain"}, "421052": {"name": "Acinetobacter rudis CIP 110305", "rank": "Strain"}, "78257": {"name": "Bifidobacterium saeculare", "rank": "Species"}, "421058": {"name": "Chryseobacterium oranimense", "rank": "Species"}, "935897": {"name": "Haemophilus influenzae F3047", "rank": "Strain"}, "1157425": {"name": "Enterococcus faecium EnGen0130", "rank": "Strain"}, "1157424": {"name": "Enterococcus faecium EnGen0134", "rank": "Strain"}, "196013": {"name": "Caldimonas", "rank": "Genus"}, "1157421": {"name": "Enterococcus faecium EnGen0126", "rank": "Strain"}, "1157420": {"name": "Enterococcus faecium EnGen0133", "rank": "Strain"}, "1157423": {"name": "Enterococcus faecium EnGen0129", "rank": "Strain"}, "1157422": {"name": "Enterococcus faecium EnGen0135", "rank": "Strain"}, "1157429": {"name": "Enterococcus faecium EnGen0128", "rank": "Strain"}, "1498170": {"name": "Escherichia phage PE3-1", "rank": "Species"}, "2172": {"name": "Methanobrevibacter", "rank": "Genus"}, "2173": {"name": "Methanobrevibacter smithii", "rank": "Species"}, "2176": {"name": "Methanohalophilus mahii", "rank": "Species"}, "2175": {"name": "Methanohalophilus", "rank": "Genus"}, "2178": {"name": "Methanothermaceae", "rank": "Family"}, "2179": {"name": "Methanothermus", "rank": "Genus"}, "661101": {"name": "Tomato chocolate spot virus", "rank": "Species"}, "192954": {"name": "Salmonella enterica subsp. enterica serovar Mbandaka", "rank": "Strain"}, "192955": {"name": "Salmonella enterica subsp. enterica serovar Kentucky", "rank": "Strain"}, "192952": {"name": "Methanosarcina mazei Go1", "rank": "Strain"}, "192953": {"name": "Salmonella enterica subsp. enterica serovar Stanley", "rank": "Strain"}, "598660": {"name": "Corynebacterium pyruviciproducens", "rank": "Species"}, "35745": {"name": "Haloferax denitrificans", "rank": "Species"}, "35746": {"name": "Haloferax gibbonsii", "rank": "Species"}, "35742": {"name": "Haloarcula sinaiiensis", "rank": "Species"}, "195099": {"name": "Campylobacter jejuni RM1221", "rank": "Strain"}, "1324258": {"name": "Mycobacterium tuberculosis TKK-01-0048", "rank": "Strain"}, "1324259": {"name": "Mycobacterium tuberculosis TKK-01-0049", "rank": "Strain"}, "1324252": {"name": "Mycobacterium tuberculosis TKK-01-0042", "rank": "Strain"}, "1324253": {"name": "Mycobacterium tuberculosis TKK-01-0043", "rank": "Strain"}, "1324250": {"name": "Mycobacterium tuberculosis TKK-01-0040", "rank": "Strain"}, "1324251": {"name": "Mycobacterium tuberculosis TKK-01-0041", "rank": "Strain"}, "1324256": {"name": "Mycobacterium tuberculosis TKK-01-0046", "rank": "Strain"}, "1324257": {"name": "Mycobacterium tuberculosis TKK-01-0047", "rank": "Strain"}, "1324254": {"name": "Mycobacterium tuberculosis TKK-01-0044", "rank": "Strain"}, "1324255": {"name": "Mycobacterium tuberculosis TKK-01-0045", "rank": "Strain"}, "755176": {"name": "Rhizobium leguminosarum bv. viciae WSM1455", "rank": "Strain"}, "293387": {"name": "Bacillus altitudinis", "rank": "Species"}, "293386": {"name": "Bacillus stratosphericus", "rank": "Species"}, "1134808": {"name": "Enterococcus faecium 509", "rank": "Strain"}, "1134809": {"name": "Enterococcus faecium 510", "rank": "Strain"}, "1134800": {"name": "Enterococcus faecalis ERV93", "rank": "Strain"}, "1134801": {"name": "Enterococcus faecalis R508", "rank": "Strain"}, "1134802": {"name": "Enterococcus faecium TX1337RF", "rank": "Strain"}, "1134804": {"name": "Enterococcus faecium 503", "rank": "Strain"}, "1134805": {"name": "Enterococcus faecium 504", "rank": "Strain"}, "1134806": {"name": "Enterococcus faecium 505", "rank": "Strain"}, "1134807": {"name": "Enterococcus faecium 506", "rank": "Strain"}, "1035189": {"name": "Streptococcus infantis SK970", "rank": "Strain"}, "571254": {"name": "Ochrobactrum rhizosphaerae", "rank": "Species"}, "656388": {"name": "Escherichia coli H252", "rank": "Strain"}, "656380": {"name": "Escherichia coli FVEC1412", "rank": "Strain"}, "1035184": {"name": "Streptococcus constellatus subsp. pharyngis SK1060 = CCUG 46377", "rank": "Strain"}, "1035187": {"name": "Streptococcus mitis SK569", "rank": "Strain"}, "656383": {"name": "Escherichia coli H120", "rank": "Strain"}, "471857": {"name": "Saccharomonospora viridis DSM 43017", "rank": "Strain"}, "1198449": {"name": "Aeropyrum camini SY1 = JCM 12091", "rank": "Strain"}, "265317": {"name": "Poribacteria", "rank": "Phylum"}, "265311": {"name": "Mesoplasma florum L1", "rank": "Strain"}, "1439109": {"name": "Streptococcus pyogenes ABC020038558", "rank": "Strain"}, "942938": {"name": "Spirochaeta alkalica DSM 8900", "rank": "Strain"}, "114277": {"name": "Spotted fever group", "rank": "Species group"}, "1439107": {"name": "Streptococcus pyogenes ABC020038545", "rank": "Strain"}, "1439106": {"name": "Streptococcus pyogenes ABC020038544", "rank": "Strain"}, "796939": {"name": "Peptostreptococcaceae bacterium CM2", "rank": "Species"}, "796937": {"name": "Peptostreptococcaceae bacterium ACC19a", "rank": "Species"}, "1435973": {"name": "Alcanivorax sp. 97CO-5", "rank": "Species"}, "1167747": {"name": "Rhizobium sp. JGI 001012-K08", "rank": "Species"}, "460523": {"name": "Ogataea polymorpha", "rank": "Species"}, "1167741": {"name": "Pelomonas sp. JGI 001013-K11", "rank": "Species"}, "398555": {"name": "Lactobacillus composti", "rank": "Species"}, "1167748": {"name": "Rhizobium sp. JGI 001013-F22", "rank": "Species"}, "1438848": {"name": "Mycobacterium tuberculosis 2093HD", "rank": "Strain"}, "224462": {"name": "Nannocystineae", "rank": "Suborder"}, "224463": {"name": "Nannocystaceae", "rank": "Family"}, "224464": {"name": "Kofleriaceae", "rank": "Family"}, "224467": {"name": "Nautiliaceae", "rank": "Family"}, "67315": {"name": "Streptomyces lavenduligriseus", "rank": "Species"}, "46630": {"name": "Picrophilaceae", "rank": "Family"}, "46631": {"name": "Picrophilus", "rank": "Genus"}, "46634": {"name": "Aureobasidium melanogenum", "rank": "Species"}, "60552": {"name": "Burkholderia vietnamiensis", "rank": "Species"}, "1310559": {"name": "Acinetobacter baumannii 987421", "rank": "Strain"}, "1196844": {"name": "Hpunalikevirus", "rank": "Genus"}, "1392048": {"name": "Staphylococcus aureus M1035", "rank": "Strain"}, "1392049": {"name": "Staphylococcus aureus M1039", "rank": "Strain"}, "1392046": {"name": "Staphylococcus aureus M1031", "rank": "Strain"}, "1392047": {"name": "Staphylococcus aureus M1033", "rank": "Strain"}, "1392044": {"name": "Staphylococcus aureus M1029", "rank": "Strain"}, "1392045": {"name": "Staphylococcus aureus M1030", "rank": "Strain"}, "1392042": {"name": "Staphylococcus aureus M1027", "rank": "Strain"}, "1392043": {"name": "Staphylococcus aureus M1028", "rank": "Strain"}, "1392040": {"name": "Staphylococcus aureus M1025", "rank": "Strain"}, "1392041": {"name": "Staphylococcus aureus M1026", "rank": "Strain"}, "662475": {"name": "Haloarcula californiae ATCC 33799", "rank": "Strain"}, "144178": {"name": "Mobiluncus curtisii subsp. holmesii", "rank": "Subspecies"}, "1418443": {"name": "Staphylococcus aureus W89577", "rank": "Strain"}, "662476": {"name": "Haloarcula sinaiiensis ATCC 33800", "rank": "Strain"}, "702438": {"name": "Prevotella oulorum F0390", "rank": "Strain"}, "702439": {"name": "Prevotella nigrescens F0103", "rank": "Strain"}, "702434": {"name": "Escherichia coli O157:H7 str. EC4191", "rank": "Strain"}, "702437": {"name": "Selenomonas noxia F0398", "rank": "Strain"}, "662479": {"name": "Haloferax mucosum ATCC BAA-1512", "rank": "Strain"}, "662478": {"name": "Haloferax denitrificans ATCC 35960", "rank": "Strain"}, "144177": {"name": "Mobiluncus curtisii subsp. curtisii", "rank": "Subspecies"}, "434923": {"name": "Coxiella burnetii CbuG_Q212", "rank": "Strain"}, "1049815": {"name": "Leptospira interrogans serovar Bratislava str. Brem 137", "rank": "Strain"}, "56144": {"name": "Deltapapillomavirus 3", "rank": "Species"}, "1049819": {"name": "Leptospira interrogans serovar Copenhageni str. HAI0188", "rank": "Strain"}, "1310557": {"name": "Acinetobacter baumannii 959073", "rank": "Strain"}, "1310554": {"name": "Acinetobacter baumannii 1036938", "rank": "Strain"}, "1310555": {"name": "Acinetobacter baumannii 993520", "rank": "Strain"}, "1130317": {"name": "Euryarchaeote SCGC AAA261-E04", "rank": "Species"}, "434928": {"name": "Xanthomonas citri pv. citri", "rank": "Strain"}, "1403948": {"name": "Varibaculum cambriense DORA_20", "rank": "Strain"}, "216432": {"name": "Croceibacter atlanticus HTCC2559", "rank": "Strain"}, "216431": {"name": "Croceibacter", "rank": "Genus"}, "81440": {"name": "Unclassified Caulobacteraceae", "rank": "No rank"}, "1145178": {"name": "Neisseria meningitidis 98002", "rank": "Strain"}, "1269813": {"name": "Thioalkalivibrio sp. ALR17-21", "rank": "Species"}, "668618": {"name": "Staphylococcus phage P954", "rank": "Species"}, "742729": {"name": "Bifidobacterium animalis subsp. lactis Bi-07", "rank": "Strain"}, "1173747": {"name": "Listeria phage LP-037", "rank": "Species"}, "1130318": {"name": "Euryarchaeote SCGC AAA261-G15", "rank": "Species"}, "742722": {"name": "Collinsella sp. 4_8_47FAA", "rank": "Species"}, "742723": {"name": "Lachnospiraceae bacterium 2_1_46FAA", "rank": "Species"}, "188786": {"name": "Thermaceae", "rank": "Family"}, "742725": {"name": "Alistipes indistinctus YIT 12060", "rank": "Strain"}, "742726": {"name": "Barnesiella intestinihominis YIT 11860", "rank": "Strain"}, "742727": {"name": "Bacteroides oleiciplenus YIT 12058", "rank": "Strain"}, "1161745": {"name": "Bifidobacterium longum subsp. longum 2-2B", "rank": "Strain"}, "1161744": {"name": "Bifidobacterium longum subsp. longum 1-6B", "rank": "Strain"}, "444051": {"name": "Mesoflavibacter", "rank": "Genus"}, "1193060": {"name": "Leptospira interrogans str. HAI1594", "rank": "Strain"}, "1161743": {"name": "Bifidobacterium longum subsp. longum 44B", "rank": "Strain"}, "1245827": {"name": "Tomato leaf curl Peru virus", "rank": "Species"}, "1193069": {"name": "Leptospira wolffii serovar Khorat str. Khorat-H2", "rank": "Strain"}, "1156433": {"name": "Streptococcus sp. I-P16", "rank": "Species"}, "1169170": {"name": "Salinispora arenicola CNP193", "rank": "Strain"}, "1169171": {"name": "Salinispora arenicola CNX814", "rank": "Strain"}, "1097556": {"name": "Taphrina deformans PYCC 5710", "rank": "Strain"}, "441620": {"name": "Methylobacterium populi BJ001", "rank": "Strain"}, "1394556": {"name": "Vibrio parahaemolyticus S008", "rank": "Strain"}, "1394555": {"name": "Vibrio parahaemolyticus S005", "rank": "Strain"}, "1394553": {"name": "Vibrio parahaemolyticus S003", "rank": "Strain"}, "331109": {"name": "Burkholderia pseudomallei 1655", "rank": "Strain"}, "1250998": {"name": "Pseudomonas syringae pv. actinidiae ICMP 19439", "rank": "Strain"}, "331104": {"name": "Blattabacterium sp. (Blattella germanica) str. Bge", "rank": "Strain"}, "644966": {"name": "Thermaerobacter marianensis DSM 12885", "rank": "Strain"}, "1394558": {"name": "Vibrio parahaemolyticus S011", "rank": "Strain"}, "1212820": {"name": "Citrobacter sp. L17", "rank": "Species"}, "182639": {"name": "Kribbella", "rank": "Genus"}, "1169240": {"name": "Brucella suis F7/06-2", "rank": "Strain"}, "1169241": {"name": "Brucella suis F7/06-5", "rank": "Strain"}, "906669": {"name": "Escherichia phage HK639", "rank": "Species"}, "1169243": {"name": "Brucella suis F8/06-3", "rank": "Strain"}, "1169244": {"name": "Brucella suis F9/06-1", "rank": "Strain"}, "1169245": {"name": "Enterococcus faecalis EnGen0328", "rank": "Strain"}, "393768": {"name": "Bat coronavirus 1B", "rank": "Species"}, "1169247": {"name": "Enterococcus faecalis EnGen0334", "rank": "Strain"}, "1169248": {"name": "Enterococcus faecalis EnGen0329", "rank": "Strain"}, "393767": {"name": "Bat coronavirus 1A", "rank": "Species"}, "1408813": {"name": "Sphingobacterium sp. H1ai", "rank": "Species"}, "1310679": {"name": "Acinetobacter baumannii 1552865", "rank": "Strain"}, "1310678": {"name": "Acinetobacter baumannii 263903-1", "rank": "Strain"}, "1310673": {"name": "Acinetobacter baumannii 1499986", "rank": "Strain"}, "1310672": {"name": "Acinetobacter baumannii 554515", "rank": "Strain"}, "1408819": {"name": "Youngiibacter fragilis", "rank": "Species"}, "1408818": {"name": "Youngiibacter", "rank": "Genus"}, "1310677": {"name": "Acinetobacter baumannii 766875", "rank": "Strain"}, "1310676": {"name": "Acinetobacter baumannii 43926", "rank": "Strain"}, "1310675": {"name": "Acinetobacter baumannii 1526966", "rank": "Strain"}, "1310674": {"name": "Acinetobacter baumannii 1546444", "rank": "Strain"}, "1179100": {"name": "Bacillus cereus biovar anthracis", "rank": "Strain"}, "1256908": {"name": "Eubacterium ramulus ATCC 29099", "rank": "Strain"}, "529731": {"name": "Listeria marthii", "rank": "Species"}, "907287": {"name": "Mycoplasma hyopneumoniae 168", "rank": "Strain"}, "186637": {"name": "Eupatorium yellow vein virus", "rank": "Species"}, "545865": {"name": "Calditerrivibrio", "rank": "Genus"}, "1163671": {"name": "Clostridium sp. 12(A)", "rank": "Species"}, "1163670": {"name": "Bacteroides sp. 14(A)", "rank": "Species"}, "1443119": {"name": "Clostridium novyi A str. BKT29909", "rank": "Strain"}, "1443118": {"name": "Clostridium novyi A str. GD211209", "rank": "Strain"}, "1443117": {"name": "Clostridium botulinum D str. 16868", "rank": "Strain"}, "1443116": {"name": "Clostridium botulinum D str. CCUG 7971", "rank": "Strain"}, "1443115": {"name": "Clostridium haemolyticum NCTC 8350", "rank": "Strain"}, "1443114": {"name": "Clostridium haemolyticum NCTC 9693", "rank": "Strain"}, "1443113": {"name": "Yersinia enterocolitica LC20", "rank": "Strain"}, "1443112": {"name": "Sulfitobacter mediterraneus KCTC 32188", "rank": "Strain"}, "1443111": {"name": "Sulfitobacter guttiformis KCTC 32187", "rank": "Strain"}, "712438": {"name": "Porphyromonas sp. oral taxon 279", "rank": "Species"}, "712430": {"name": "Peptoniphilus sp. oral taxon 375", "rank": "Species"}, "712437": {"name": "Porphyromonas sp. oral taxon 278", "rank": "Species"}, "939324": {"name": "Alpha proteobacterium SCGC AAA288-G21", "rank": "Species"}, "43219": {"name": "Herpotrichiellaceae", "rank": "Family"}, "1050219": {"name": "Chlamydia psittaci CP3", "rank": "Strain"}, "1168595": {"name": "Mycobacterium phage Aeneas", "rank": "Species"}, "1005439": {"name": "Escherichia coli 99.1781", "rank": "Strain"}, "1448598": {"name": "Mycobacterium tuberculosis TKK_04_0141", "rank": "Strain"}, "1448599": {"name": "Mycobacterium tuberculosis TKK_04_0145", "rank": "Strain"}, "1448596": {"name": "Mycobacterium tuberculosis TKK_04_0139", "rank": "Strain"}, "1005433": {"name": "Escherichia coli 99.0815", "rank": "Strain"}, "1448594": {"name": "Mycobacterium tuberculosis TKK_04_0136", "rank": "Strain"}, "1005431": {"name": "Escherichia coli 99.0848", "rank": "Strain"}, "1448592": {"name": "Mycobacterium tuberculosis TKK_04_0132", "rank": "Strain"}, "1005437": {"name": "Escherichia coli 99.1793", "rank": "Strain"}, "1448590": {"name": "Mycobacterium tuberculosis TKK_04_0130", "rank": "Strain"}, "1448591": {"name": "Mycobacterium tuberculosis TKK_04_0131", "rank": "Strain"}, "203795": {"name": "Alteromonas marina", "rank": "Species"}, "1398775": {"name": "Bacillus subtilis PTS-394", "rank": "Strain"}, "406984": {"name": "Chlamydophila pneumoniae LPCoLN", "rank": "Strain"}, "936565": {"name": "Klebsiella sp. OBRC7", "rank": "Species"}, "862944": {"name": "Circulifer tenellus virus 1", "rank": "Species"}, "936563": {"name": "Fusobacterium sp. CM22", "rank": "Species"}, "936562": {"name": "Fusobacterium sp. CM21", "rank": "Species"}, "936561": {"name": "Fusobacterium sp. CM1", "rank": "Species"}, "350703": {"name": "Pseudomonas aeruginosa 2192", "rank": "Strain"}, "47229": {"name": "Massilia timonae", "rank": "Species"}, "99930": {"name": "Blackcurrant reversion virus satellite RNA", "rank": "Species"}, "882020": {"name": "Listeria monocytogenes SLCC2479", "rank": "Strain"}, "450380": {"name": "Microbacterium profundi", "rank": "Species"}, "1229324": {"name": "Baminivirus", "rank": "Species"}, "1229325": {"name": "Niminivirus", "rank": "Species"}, "1158464": {"name": "Staphylococcus aureus M1076", "rank": "Strain"}, "1158465": {"name": "Staphylococcus aureus M1064", "rank": "Strain"}, "1158466": {"name": "Staphylococcus aureus M1092", "rank": "Strain"}, "1158467": {"name": "Staphylococcus aureus M1093", "rank": "Strain"}, "1158461": {"name": "Staphylococcus aureus M0628", "rank": "Strain"}, "1158462": {"name": "Staphylococcus aureus M0529", "rank": "Strain"}, "1158463": {"name": "Staphylococcus aureus M1063", "rank": "Strain"}, "1029823": {"name": "Acinetobacter sp. P8-3-8", "rank": "Species"}, "1029822": {"name": "Lactobacillus salivarius NIAS840", "rank": "Strain"}, "1158468": {"name": "Staphylococcus aureus M1095", "rank": "Strain"}, "1158469": {"name": "Staphylococcus aureus M1103", "rank": "Strain"}, "278197": {"name": "Pediococcus pentosaceus ATCC 25745", "rank": "Strain"}, "1029824": {"name": "Kocuria rhizophila P7-4", "rank": "Strain"}, "1402738": {"name": "Staphylococcus aureus M1241", "rank": "Strain"}, "1402739": {"name": "Staphylococcus aureus M1242", "rank": "Strain"}, "1402730": {"name": "Staphylococcus aureus M1233", "rank": "Strain"}, "1402731": {"name": "Staphylococcus aureus M1234", "rank": "Strain"}, "1402732": {"name": "Staphylococcus aureus M1235", "rank": "Strain"}, "1402733": {"name": "Staphylococcus aureus M1236", "rank": "Strain"}, "1402734": {"name": "Staphylococcus aureus M1237", "rank": "Strain"}, "1402735": {"name": "Staphylococcus aureus M1238", "rank": "Strain"}, "1402736": {"name": "Staphylococcus aureus M1239", "rank": "Strain"}, "1402737": {"name": "Staphylococcus aureus M1240", "rank": "Strain"}, "105767": {"name": "Tremella", "rank": "Genus"}, "614083": {"name": "Rhodoferax saidenbachensis ED16", "rank": "Strain"}, "1121921": {"name": "Gilvimarinus chinensis DSM 19667", "rank": "Strain"}, "1121920": {"name": "Geothrix fermentans DSM 14018", "rank": "Strain"}, "1121923": {"name": "Glaciecola punicea DSM 14233 = ACAM 611", "rank": "Strain"}, "1121922": {"name": "Glaciecola pallidula DSM 14239 = ACAM 615", "rank": "Strain"}, "272123": {"name": "Anabaena cylindrica PCC 7122", "rank": "Strain"}, "1121927": {"name": "Gordonia hirsuta DSM 44140 = NBRC 16056", "rank": "Strain"}, "1121926": {"name": "Glycomyces arizonensis DSM 44726", "rank": "Strain"}, "1121929": {"name": "Gracilibacillus lacisalsi DSM 19029", "rank": "Strain"}, "1121928": {"name": "Gordonia shandongensis DSM 45094", "rank": "Strain"}, "62140": {"name": "Acidiphilium multivorum", "rank": "Species"}, "272129": {"name": "Oscillatoria sp. PCC 6506", "rank": "Species"}, "64895": {"name": "Borrelia burgdorferi group", "rank": "Species group"}, "12455": {"name": "Borna disease virus", "rank": "Species"}, "12451": {"name": "Raspberry bushy dwarf virus", "rank": "Species"}, "12450": {"name": "Saccharomyces cerevisiae killer virus M1", "rank": "Species"}, "95641": {"name": "Methylomicrobium buryatense", "rank": "Species"}, "342564": {"name": "Pasteurella phage F108", "rank": "Species"}, "12458": {"name": "Garlic latent virus", "rank": "Strain"}, "933263": {"name": "Acinetobacter baumannii UMB001", "rank": "Strain"}, "933262": {"name": "Desulfosarcina sp. BuS5", "rank": "Species"}, "1432559": {"name": "Escherichia coli ISC41", "rank": "Strain"}, "933267": {"name": "Neisseria sicca DS1", "rank": "Strain"}, "933266": {"name": "Neisseria sicca 4320", "rank": "Strain"}, "933265": {"name": "Acinetobacter baumannii UMB003", "rank": "Strain"}, "933264": {"name": "Acinetobacter baumannii UMB002", "rank": "Strain"}, "933269": {"name": "Neisseria polysaccharea NS342", "rank": "Strain"}, "1432550": {"name": "Klebsiella pneumoniae IS33", "rank": "Strain"}, "1432557": {"name": "Escherichia coli ISC11", "rank": "Strain"}, "1432556": {"name": "Enterobacter cloacae ISC8", "rank": "Strain"}, "1432555": {"name": "Escherichia coli ISC7", "rank": "Strain"}, "451435": {"name": "Chytridiomycetes", "rank": "Class"}, "1095383": {"name": "Geobacillus sp. A8", "rank": "Species"}, "1233498": {"name": "OM43 clade", "rank": "No rank"}, "187272": {"name": "Alkalilimnicola ehrlichii MLHE-1", "rank": "Strain"}, "338215": {"name": "Leptospira interrogans serovar Bratislava", "rank": "Strain"}, "338217": {"name": "Leptospira borgpetersenii serovar Hardjo-bovis", "rank": "Strain"}, "418453": {"name": "Desulfovirgula", "rank": "Genus"}, "573591": {"name": "Stenotrophomonas phage S1", "rank": "Species"}, "201862": {"name": "Wisteria vein mosaic virus", "rank": "Species"}, "28347": {"name": "Apple stem grooving virus", "rank": "Species"}, "28344": {"name": "Porcine reproductive and respiratory syndrome virus", "rank": "Species"}, "28348": {"name": "Sweet clover necrotic mosaic virus", "rank": "Species"}, "1232724": {"name": "Mycobacterium indicus pranii MTCC 9506", "rank": "Strain"}, "1422718": {"name": "Staphylococcus aureus VET1866R", "rank": "Strain"}, "1422719": {"name": "Staphylococcus aureus VET1867R", "rank": "Strain"}, "54736": {"name": "Salmonella bongori", "rank": "Species"}, "459786": {"name": "Oscillibacter", "rank": "Genus"}, "1422710": {"name": "Staphylococcus aureus VET1854R", "rank": "Strain"}, "1422711": {"name": "Staphylococcus aureus VET1855R", "rank": "Strain"}, "1422712": {"name": "Staphylococcus aureus VET1856R", "rank": "Strain"}, "1422713": {"name": "Staphylococcus aureus VET1858R", "rank": "Strain"}, "1422714": {"name": "Staphylococcus aureus VET1859R", "rank": "Strain"}, "1422715": {"name": "Staphylococcus aureus VET1860R", "rank": "Strain"}, "1422716": {"name": "Staphylococcus aureus VET1861R", "rank": "Strain"}, "1422717": {"name": "Staphylococcus aureus VET1865R", "rank": "Strain"}, "760848": {"name": "Streptococcus pneumoniae GA47794", "rank": "Strain"}, "760845": {"name": "Streptococcus pneumoniae GA47751", "rank": "Strain"}, "760844": {"name": "Streptococcus pneumoniae GA47688", "rank": "Strain"}, "760847": {"name": "Streptococcus pneumoniae GA47778", "rank": "Strain"}, "760846": {"name": "Streptococcus pneumoniae GA47760", "rank": "Strain"}, "760841": {"name": "Streptococcus pneumoniae GA47562", "rank": "Strain"}, "209446": {"name": "Candidatus Mycoplasma haemominutum", "rank": "Species"}, "760843": {"name": "Streptococcus pneumoniae GA47628", "rank": "Strain"}, "760842": {"name": "Streptococcus pneumoniae GA47597", "rank": "Strain"}, "1154811": {"name": "Streptococcus agalactiae CCUG 37737", "rank": "Strain"}, "1154810": {"name": "Streptococcus agalactiae CCUG 37430", "rank": "Strain"}, "1154813": {"name": "Streptococcus agalactiae CCUG 37741", "rank": "Strain"}, "1154812": {"name": "Streptococcus agalactiae CCUG 37738", "rank": "Strain"}, "1154815": {"name": "Streptococcus agalactiae CCUG 38383", "rank": "Strain"}, "1154814": {"name": "Streptococcus agalactiae CCUG 37742", "rank": "Strain"}, "1154817": {"name": "Streptococcus agalactiae CCUG 44077", "rank": "Strain"}, "1154816": {"name": "Streptococcus agalactiae CCUG 39096 A", "rank": "Strain"}, "1154819": {"name": "Streptococcus agalactiae LMG 15085", "rank": "Strain"}, "1154818": {"name": "Streptococcus agalactiae CCUG 49087", "rank": "Strain"}, "696281": {"name": "Desulfotomaculum ruminis DSM 2154", "rank": "Strain"}, "245160": {"name": "Fictibacillus macauensis", "rank": "Species"}, "758": {"name": "Pasteurella pneumotropica", "rank": "Species"}, "1246475": {"name": "Nocardiopsis chromatogenes YIM 90109", "rank": "Strain"}, "754": {"name": "Pasteurella dagmatis", "rank": "Species"}, "1246477": {"name": "Brevibacillus agri BAB-2500", "rank": "Strain"}, "1246476": {"name": "Arthrobacter crystallopoietes BAB-32", "rank": "Strain"}, "750": {"name": "Gallibacterium anatis", "rank": "Species"}, "752": {"name": "Pasteurella bettyae", "rank": "Species"}, "1388300": {"name": "Staphylococcus aureus M0449", "rank": "Strain"}, "1388301": {"name": "Staphylococcus aureus M0451", "rank": "Strain"}, "392838": {"name": "Bacteroides propionicifaciens", "rank": "Species"}, "492774": {"name": "Rhizobium alamii", "rank": "Species"}, "1048808": {"name": "Endosymbiont of Riftia pachyptila (vent Ph05)", "rank": "Strain"}, "2269": {"name": "Thermofilum pendens", "rank": "Species"}, "1124469": {"name": "Vibrio cholerae O1 str. 2009V-1085", "rank": "Strain"}, "1331209": {"name": "Bordetella holmesii CDC-H643-BH", "rank": "Strain"}, "1331208": {"name": "Bordetella holmesii CDC-H635-BH", "rank": "Strain"}, "1331203": {"name": "Bordetella bronchiseptica CA90 BB1334", "rank": "Strain"}, "1331202": {"name": "Bordetella bronchiseptica 99-R-0433", "rank": "Strain"}, "1331201": {"name": "Bordetella bronchiseptica 7E71", "rank": "Strain"}, "1331200": {"name": "Bordetella bronchiseptica 3E44", "rank": "Strain"}, "1331207": {"name": "Bordetella holmesii CDC-H629-BH", "rank": "Strain"}, "1331206": {"name": "Bordetella holmesii CDC-H585-BH", "rank": "Strain"}, "1331205": {"name": "Bordetella holmesii CDC-H572-BH", "rank": "Strain"}, "1331204": {"name": "Bordetella bronchiseptica CARE970018BB", "rank": "Strain"}, "204040": {"name": "Dickeya dadantii subsp. dieffenbachiae", "rank": "Subspecies"}, "204042": {"name": "Dickeya zeae", "rank": "Species"}, "634168": {"name": "Halorubrum pleomorphic virus 1", "rank": "Species"}, "1123314": {"name": "Streptococcus plurextorum DSM 22810", "rank": "Strain"}, "1123315": {"name": "Streptococcus porci DSM 23759", "rank": "Strain"}, "1123316": {"name": "Streptococcus pyogenes DSM 20565", "rank": "Strain"}, "1123317": {"name": "Streptococcus sobrinus DSM 20742 = ATCC 33478", "rank": "Strain"}, "1123310": {"name": "Streptococcus mutans DSM 20523", "rank": "Strain"}, "1123311": {"name": "Streptococcus orisratti DSM 15617", "rank": "Strain"}, "1123312": {"name": "Streptococcus ovis DSM 16829", "rank": "Strain"}, "1123313": {"name": "Faecalicoccus pleomorphus DSM 20574", "rank": "Strain"}, "1076592": {"name": "Acetobacter papayae", "rank": "Species"}, "1123318": {"name": "Streptococcus thoraltensis DSM 12221", "rank": "Strain"}, "1076596": {"name": "Acetobacter persici", "rank": "Species"}, "1076594": {"name": "Acetobacter okinawensis", "rank": "Species"}, "123899": {"name": "Bordetella trematum", "rank": "Species"}, "702453": {"name": "Listeria seeligeri FSL N1-067", "rank": "Strain"}, "1047067": {"name": "Latescibacteria bacterium JGI 0000059-A10", "rank": "Species"}, "702450": {"name": "Turicibacter sanguinis PC909", "rank": "Strain"}, "56774": {"name": "Eubacterium infirmum", "rank": "Species"}, "1047066": {"name": "Latescibacteria bacterium SCGC AAA257-K07", "rank": "Species"}, "794846": {"name": "Sinorhizobium sp. CCBAU 05631", "rank": "Species"}, "702457": {"name": "Listeria marthii FSL S4-120", "rank": "Strain"}, "1447535": {"name": "Pseudomonas aeruginosa 3580", "rank": "Strain"}, "1413415": {"name": "Staphylococcus aureus 2393-19", "rank": "Strain"}, "1413414": {"name": "Staphylococcus aureus 2393-15", "rank": "Strain"}, "1413413": {"name": "Staphylococcus aureus 56864-11", "rank": "Strain"}, "1413412": {"name": "Staphylococcus aureus 56824-21", "rank": "Strain"}, "1413411": {"name": "Staphylococcus aureus 56824-15", "rank": "Strain"}, "1413410": {"name": "Staphylococcus aureus 56824-10", "rank": "Strain"}, "702455": {"name": "Listeria innocua FSL J1-023", "rank": "Strain"}, "373153": {"name": "Streptococcus pneumoniae D39", "rank": "Strain"}, "1047069": {"name": "Cloacimonetes bacterium JGI 0000039-A21", "rank": "Species"}, "1413419": {"name": "Staphylococcus aureus 1110601896", "rank": "Strain"}, "1413418": {"name": "Staphylococcus aureus 1110601704", "rank": "Strain"}, "1281207": {"name": "Escherichia coli UMEA 3178-1", "rank": "Strain"}, "1281206": {"name": "Escherichia coli UMEA 3176-1", "rank": "Strain"}, "1281205": {"name": "Escherichia coli UMEA 3175-1", "rank": "Strain"}, "1281204": {"name": "Escherichia coli UMEA 3174-1", "rank": "Strain"}, "1281203": {"name": "Escherichia coli UMEA 3173-1", "rank": "Strain"}, "1281202": {"name": "Escherichia coli UMEA 3172-1", "rank": "Strain"}, "1281201": {"name": "Escherichia coli UMEA 3163-1", "rank": "Strain"}, "1281200": {"name": "Escherichia coli UMEA 3162-1", "rank": "Strain"}, "1281209": {"name": "Escherichia coli UMEA 3185-1", "rank": "Strain"}, "1281208": {"name": "Escherichia coli UMEA 3180-1", "rank": "Strain"}, "1409429": {"name": "Staphylococcus aureus SJOS6098", "rank": "Strain"}, "1409428": {"name": "Staphylococcus aureus COAS6039", "rank": "Strain"}, "1409425": {"name": "Staphylococcus aureus SJUD6074", "rank": "Strain"}, "262719": {"name": "Mycoplasma hyopneumoniae J", "rank": "Strain"}, "1409427": {"name": "Staphylococcus aureus WMCS6039", "rank": "Strain"}, "1409426": {"name": "Staphylococcus aureus SJUD6085", "rank": "Strain"}, "1409421": {"name": "Staphylococcus aureus SJOS6095", "rank": "Strain"}, "1409420": {"name": "Staphylococcus aureus COAS6044", "rank": "Strain"}, "1409423": {"name": "Staphylococcus aureus SMMC6067", "rank": "Strain"}, "1409422": {"name": "Staphylococcus aureus SJUD6087", "rank": "Strain"}, "1305793": {"name": "Kingella kingae BB016", "rank": "Strain"}, "157673": {"name": "Mannheimia succiniciproducens", "rank": "Species"}, "57372": {"name": "Mycoplasma suis", "rank": "Species"}, "376625": {"name": "Unclassified Oceanospirillales", "rank": "No rank"}, "656414": {"name": "Escherichia coli H736", "rank": "Strain"}, "1417221": {"name": "Staphylococcus aureus W86059", "rank": "Strain"}, "1417222": {"name": "Staphylococcus aureus W86063", "rank": "Strain"}, "656417": {"name": "Escherichia coli M605", "rank": "Strain"}, "656413": {"name": "Escherichia coli H730", "rank": "Strain"}, "1417229": {"name": "Borrelia hispanica CRI", "rank": "Strain"}, "656419": {"name": "Escherichia coli M718", "rank": "Strain"}, "79263": {"name": "Paenibacillus chitinolyticus", "rank": "Species"}, "79262": {"name": "Bifidobacterium thermacidophilum subsp. thermacidophilum", "rank": "Subspecies"}, "215578": {"name": "Entomoplasma somnilux", "rank": "Species"}, "1469613": {"name": "Rhodovulum sp. NI22", "rank": "Species"}, "420255": {"name": "Sida yellow vein Madurai virus", "rank": "Species"}, "1380708": {"name": "Listeria monocytogenes 36-25-1", "rank": "Strain"}, "66821": {"name": "Sulfurospirillum multivorans", "rank": "Species"}, "1293916": {"name": "Brucella ovis IntaBari-2002-82-58", "rank": "Strain"}, "41460": {"name": "Yam mosaic virus", "rank": "Species"}, "1273173": {"name": "Campylobacter coli CVM N29710", "rank": "Strain"}, "177872": {"name": "VEEV complex", "rank": "No rank"}, "1133592": {"name": "Candidatus Uzinura diaspidicola str. ASNER", "rank": "Strain"}, "1133596": {"name": "Pediococcus pentosaceus IE-3", "rank": "Strain"}, "1412766": {"name": "Staphylococcus aureus M77229", "rank": "Strain"}, "1412767": {"name": "Staphylococcus aureus M77238", "rank": "Strain"}, "1412764": {"name": "Staphylococcus aureus M77210", "rank": "Strain"}, "1412765": {"name": "Staphylococcus aureus M77225", "rank": "Strain"}, "1412762": {"name": "Staphylococcus aureus M20180", "rank": "Strain"}, "1412763": {"name": "Staphylococcus aureus M20198", "rank": "Strain"}, "1412760": {"name": "Staphylococcus aureus M16586", "rank": "Strain"}, "1412761": {"name": "Staphylococcus aureus M16597", "rank": "Strain"}, "171868": {"name": "Thermovibrio", "rank": "Genus"}, "59310": {"name": "Streptococcus macedonicus", "rank": "Species"}, "1412768": {"name": "Staphylococcus aureus M80979", "rank": "Strain"}, "1409680": {"name": "Staphylococcus aureus LAMC6106", "rank": "Strain"}, "177873": {"name": "EEEV complex", "rank": "No rank"}, "74724": {"name": "Canine calicivirus", "rank": "Species"}, "1421939": {"name": "Mycobacterium tuberculosis TB_RSA23", "rank": "Strain"}, "1421938": {"name": "Mycobacterium tuberculosis TB_RSA22", "rank": "Strain"}, "334380": {"name": "Orientia tsutsugamushi str. Ikeda", "rank": "Strain"}, "1421935": {"name": "Mycobacterium tuberculosis TB_RSA19", "rank": "Strain"}, "1421934": {"name": "Mycobacterium tuberculosis TB_RSA18", "rank": "Strain"}, "1421937": {"name": "Mycobacterium tuberculosis TB_RSA21", "rank": "Strain"}, "1421936": {"name": "Mycobacterium tuberculosis TB_RSA20", "rank": "Strain"}, "1421931": {"name": "Mycobacterium tuberculosis TB_RSA15", "rank": "Strain"}, "1421930": {"name": "Mycobacterium tuberculosis TB_RSA14", "rank": "Strain"}, "1421933": {"name": "Mycobacterium tuberculosis TB_RSA17", "rank": "Strain"}, "1421932": {"name": "Mycobacterium tuberculosis TB_RSA16", "rank": "Strain"}, "1465613": {"name": "Salmonella phage vB_SenS-Ent3", "rank": "Species"}, "1465618": {"name": "Salmonella phage vB_SenS-Ent2", "rank": "Species"}, "1222338": {"name": "Enterobacteria phage GEC-3S", "rank": "Species"}, "749447": {"name": "Pseudomonas phage JG024", "rank": "Species"}, "1354129": {"name": "Mycobacterium tuberculosis MAL020150", "rank": "Strain"}, "1354128": {"name": "Mycobacterium tuberculosis MAL020147", "rank": "Strain"}, "1354127": {"name": "Mycobacterium tuberculosis MAL020146", "rank": "Strain"}, "1354126": {"name": "Mycobacterium tuberculosis MAL020145", "rank": "Strain"}, "1354125": {"name": "Mycobacterium tuberculosis MAL020144", "rank": "Strain"}, "1354124": {"name": "Mycobacterium tuberculosis MAL020142", "rank": "Strain"}, "1354123": {"name": "Mycobacterium tuberculosis MAL020141", "rank": "Strain"}, "1354122": {"name": "Mycobacterium tuberculosis MAL020138", "rank": "Strain"}, "1354121": {"name": "Mycobacterium tuberculosis MAL020182", "rank": "Strain"}, "1354120": {"name": "Mycobacterium tuberculosis MAL020181", "rank": "Strain"}, "384933": {"name": "Bacillus aidingensis", "rank": "Species"}, "1055325": {"name": "Vibrio cholerae O1 str. Amazonia", "rank": "Strain"}, "1439225": {"name": "Streptococcus pyogenes ABC020053060", "rank": "Strain"}, "1055328": {"name": "Neisseria meningitidis NM233", "rank": "Strain"}, "1263406": {"name": "Chlamydia trachomatis L2/434/Bu(i)", "rank": "Strain"}, "1439221": {"name": "Streptococcus pyogenes ABC020052877", "rank": "Strain"}, "341053": {"name": "Beilong virus", "rank": "Species"}, "762551": {"name": "Jejuia", "rank": "Genus"}, "762550": {"name": "Leuconostoc gelidum subsp. gasicomitatum LMG 18811", "rank": "Strain"}, "1422057": {"name": "Mycobacterium tuberculosis TB_RSA141", "rank": "Strain"}, "1524267": {"name": "Pseudomonas sp. BRG-100", "rank": "Species"}, "1422056": {"name": "Mycobacterium tuberculosis TB_RSA140", "rank": "Strain"}, "1391472": {"name": "Enterococcus faecalis EnGen0402", "rank": "Strain"}, "1422055": {"name": "Mycobacterium tuberculosis TB_RSA139", "rank": "Strain"}, "1391473": {"name": "Enterococcus faecalis EnGen0403", "rank": "Strain"}, "1422054": {"name": "Mycobacterium tuberculosis TB_RSA138", "rank": "Strain"}, "328430": {"name": "Chickpea chlorotic stunt virus", "rank": "Species"}, "328432": {"name": "Unclassified Nucleopolyhedrovirus", "rank": "No rank"}, "1295769": {"name": "Mycobacterium tuberculosis TKK_02_0053", "rank": "Strain"}, "1453869": {"name": "Staphylococcus aureus subsp. aureus 301-188", "rank": "Strain"}, "1295765": {"name": "Mycobacterium tuberculosis TKK_02_0049", "rank": "Strain"}, "1295764": {"name": "Mycobacterium tuberculosis TKK_02_0048", "rank": "Strain"}, "1295767": {"name": "Mycobacterium tuberculosis TKK_02_0051", "rank": "Strain"}, "1295766": {"name": "Mycobacterium tuberculosis TKK_02_0050", "rank": "Strain"}, "1295760": {"name": "Mycobacterium tuberculosis TKK_02_0044", "rank": "Strain"}, "1295763": {"name": "Mycobacterium tuberculosis TKK_02_0047", "rank": "Strain"}, "1273742": {"name": "Bacillus phage Finn", "rank": "Species"}, "526119": {"name": "Unclassified Mamastrovirus", "rank": "No rank"}, "1273740": {"name": "Bacillus phage Curly", "rank": "Species"}, "992402": {"name": "Acinetobacter baumannii ABNIH1", "rank": "Strain"}, "992403": {"name": "Acinetobacter baumannii ABNIH2", "rank": "Strain"}, "992401": {"name": "Amycolicicoccus", "rank": "Genus"}, "992406": {"name": "Riemerella anatipestifer RA-GD", "rank": "Strain"}, "992404": {"name": "Acinetobacter baumannii ABNIH3", "rank": "Strain"}, "992405": {"name": "Acinetobacter baumannii ABNIH4", "rank": "Strain"}, "580880": {"name": "Amorphus", "rank": "Genus"}, "161360": {"name": "Planococcus antarcticus", "rank": "Species"}, "84030": {"name": "Clostridium saccharolyticum", "rank": "Species"}, "84031": {"name": "Clostridium sartagoforme", "rank": "Species"}, "1463847": {"name": "Streptomyces sp. NRRL F-3218", "rank": "Species"}, "125287": {"name": "Ornithinimicrobium", "rank": "Genus"}, "321961": {"name": "Wheat blue dwarf phytoplasma", "rank": "Species"}, "321967": {"name": "Lactobacillus casei ATCC 334", "rank": "Strain"}, "1412671": {"name": "Staphylococcus aureus M49691", "rank": "Strain"}, "319546": {"name": "Rickettsia conorii subsp. conorii", "rank": "Subspecies"}, "63959": {"name": "Demetria terragena", "rank": "Species"}, "28196": {"name": "Arcobacter", "rank": "Genus"}, "358396": {"name": "Halobiforma lacisalsi AJ5", "rank": "Strain"}, "1086751": {"name": "Mycobacterium phage Rumpelstiltskin", "rank": "Species"}, "867080": {"name": "Paenibacillus sp. IHB B 3415", "rank": "Species"}, "1132507": {"name": "Salmonella enterica subsp. enterica serovar Typhi str. P-stx-12", "rank": "Strain"}, "1132506": {"name": "Sulfolobus islandicus M.16.47", "rank": "Strain"}, "1132505": {"name": "Sulfolobus islandicus M.16.46", "rank": "Strain"}, "1132504": {"name": "Sulfolobus islandicus M.16.43", "rank": "Strain"}, "1132503": {"name": "Sulfolobus islandicus M.16.40", "rank": "Strain"}, "1132502": {"name": "Sulfolobus islandicus M.16.30", "rank": "Strain"}, "1132501": {"name": "Sulfolobus islandicus M.16.23", "rank": "Strain"}, "1132500": {"name": "Sulfolobus islandicus M.16.22", "rank": "Strain"}, "1438890": {"name": "Mycobacterium tuberculosis UT0049", "rank": "Strain"}, "1438892": {"name": "Mycobacterium tuberculosis UT0101", "rank": "Strain"}, "1417042": {"name": "Staphylococcus aureus F63787", "rank": "Strain"}, "1132509": {"name": "Halococcus hamelinensis 100A6", "rank": "Strain"}, "1489714": {"name": "Tanay virus", "rank": "Species"}, "1448758": {"name": "Mycobacterium tuberculosis M2132", "rank": "Strain"}, "1448759": {"name": "Mycobacterium tuberculosis M2134", "rank": "Strain"}, "1448754": {"name": "Mycobacterium tuberculosis M2128", "rank": "Strain"}, "1448755": {"name": "Mycobacterium tuberculosis M2129", "rank": "Strain"}, "1448756": {"name": "Mycobacterium tuberculosis M2131", "rank": "Strain"}, "1448757": {"name": "Mycobacterium tuberculosis M2130", "rank": "Strain"}, "1448750": {"name": "Mycobacterium tuberculosis M2085", "rank": "Strain"}, "1448751": {"name": "Mycobacterium tuberculosis M2086", "rank": "Strain"}, "1448752": {"name": "Mycobacterium tuberculosis M2113", "rank": "Strain"}, "1448753": {"name": "Mycobacterium tuberculosis M2116", "rank": "Strain"}, "1168590": {"name": "Acinetobacter baumannii Ab33333", "rank": "Strain"}, "723172": {"name": "Vibrio genomosp. F6", "rank": "Species"}, "1417046": {"name": "Staphylococcus aureus T74005", "rank": "Strain"}, "947969": {"name": "Cellulomonas carbonis T26", "rank": "Strain"}, "1040986": {"name": "Mesorhizobium sp. WSM3224", "rank": "Species"}, "1040989": {"name": "Bradyrhizobium sp. ARR65", "rank": "Species"}, "1417049": {"name": "Staphylococcus aureus T74091", "rank": "Strain"}, "1427289": {"name": "Mycobacterium tuberculosis XTB13-212", "rank": "Strain"}, "1427288": {"name": "Mycobacterium tuberculosis XTB13-211", "rank": "Strain"}, "73819": {"name": "Andean potato latent virus", "rank": "Species"}, "1427281": {"name": "Mycobacterium tuberculosis XTB13-204", "rank": "Strain"}, "1427280": {"name": "Mycobacterium tuberculosis XTB13-203", "rank": "Strain"}, "1427283": {"name": "Mycobacterium tuberculosis XTB13-206", "rank": "Strain"}, "1427282": {"name": "Mycobacterium tuberculosis XTB13-205", "rank": "Strain"}, "1427285": {"name": "Mycobacterium tuberculosis XTB13-208", "rank": "Strain"}, "1427287": {"name": "Mycobacterium tuberculosis XTB13-210", "rank": "Strain"}, "1427286": {"name": "Mycobacterium tuberculosis XTB13-209", "rank": "Strain"}, "664638": {"name": "Leucobacter salsicius", "rank": "Species"}, "27319": {"name": "Metschnikowiaceae", "rank": "Family"}, "1350366": {"name": "Thermoanaerobacter sp. A7A", "rank": "Species"}, "222459": {"name": "Cotton leaf curl Gezira virus", "rank": "Species"}, "72030": {"name": "Ceratocystis moniliformis", "rank": "Species"}, "222450": {"name": "Chayote yellow mosaic virus", "rank": "Species"}, "222456": {"name": "Cotton leaf curl Alabad virus", "rank": "Species"}, "11855": {"name": "Mason-Pfizer monkey virus", "rank": "Species"}, "1213734": {"name": "Staphylococcus aureus M0927", "rank": "Strain"}, "1142394": {"name": "Phycisphaera mikurensis NBRC 102666", "rank": "Strain"}, "101385": {"name": "Aequorivita sublithincola", "rank": "Species"}, "1486726": {"name": "Pseudobacteroides", "rank": "Genus"}, "1486721": {"name": "Methylothermaceae", "rank": "Family"}, "1122213": {"name": "Maritalea myrionectae DSM 19524", "rank": "Strain"}, "153721": {"name": "Sporocytophaga myxococcoides", "rank": "Species"}, "1249": {"name": "Weissella paramesenteroides", "rank": "Species"}, "1266068": {"name": "Streptococcus agalactiae SS1218", "rank": "Strain"}, "1266069": {"name": "Streptococcus agalactiae CF01173", "rank": "Strain"}, "38288": {"name": "Corynebacterium genitalium", "rank": "Species"}, "38289": {"name": "Corynebacterium jeikeium", "rank": "Species"}, "1266064": {"name": "Lysinibacillus manganicus", "rank": "Species"}, "1266066": {"name": "Streptococcus agalactiae LADL-90-503", "rank": "Strain"}, "1266067": {"name": "Streptococcus agalactiae LADL_05-108a", "rank": "Strain"}, "1245": {"name": "Leuconostoc mesenteroides", "rank": "Species"}, "1244": {"name": "Leuconostoc gelidum", "rank": "Species"}, "1247": {"name": "Oenococcus oeni", "rank": "Species"}, "1246": {"name": "Leuconostoc lactis", "rank": "Species"}, "59803": {"name": "Sphingomonas echinoides", "rank": "Species"}, "189201": {"name": "Salmonella enterica subsp. enterica serovar Cubana", "rank": "Strain"}, "265522": {"name": "Hyposoter fugitivus ichnovirus", "rank": "Species"}, "1562889": {"name": "Pantoea sp. MBLJ3", "rank": "Species"}, "667013": {"name": "Candidatus Carsonella ruddii DC", "rank": "Strain"}, "667014": {"name": "Thermodesulfatator indicus DSM 15286", "rank": "Strain"}, "667015": {"name": "Bacteroides salanitronis DSM 18170", "rank": "Strain"}, "1439318": {"name": "Citrobacter freundii MGH 56", "rank": "Strain"}, "1439319": {"name": "Citrobacter sp. MGH 55", "rank": "Species"}, "293069": {"name": "Leptospira yanagawae", "rank": "Species"}, "1439310": {"name": "Streptococcus pyogenes ABC020062601", "rank": "Strain"}, "293066": {"name": "Leptospira alexanderi serovar Manhao 3", "rank": "Strain"}, "1439316": {"name": "Acinetobacter baumanii BIDMC 56", "rank": "Strain"}, "293065": {"name": "Leptospira wolbachii serovar Codice", "rank": "Strain"}, "566461": {"name": "Streptomyces ghanaensis ATCC 14672", "rank": "Strain"}, "566466": {"name": "Gamma proteobacterium NOR5-3", "rank": "Species"}, "1865": {"name": "Actinoplanes", "rank": "Genus"}, "1112244": {"name": "Chlamydia psittaci 06-1683", "rank": "Strain"}, "1866": {"name": "Actinoplanes missouriensis", "rank": "Species"}, "1861": {"name": "Geodermatophilus obscurus", "rank": "Species"}, "1860": {"name": "Geodermatophilus", "rank": "Genus"}, "1863": {"name": "Dermatophilus congolensis", "rank": "Species"}, "1862": {"name": "Dermatophilus", "rank": "Genus"}, "686598": {"name": "Unassigned Myoviridae", "rank": "No rank"}, "1869": {"name": "Actinoplanes utahensis", "rank": "Species"}, "267608": {"name": "Ralstonia solanacearum GMI1000", "rank": "Strain"}, "1112248": {"name": "Chlamydia psittaci C1/97", "rank": "Strain"}, "1112249": {"name": "Chlamydia psittaci C6/98", "rank": "Strain"}, "693066": {"name": "Bovine rhinitis B virus", "rank": "Species"}, "1379274": {"name": "Lactococcus lactis subsp. lactis 1AA59", "rank": "Strain"}, "1379270": {"name": "Gemmatimonas sp. AP64", "rank": "Species"}, "1379271": {"name": "Salmonella enterica subsp. enterica serovar Typhimurium str. ST4848", "rank": "Strain"}, "47420": {"name": "Hydrogenophaga", "rank": "Genus"}, "1536611": {"name": "Yersinia phage vB_YenP_AP5", "rank": "Species"}, "754077": {"name": "Shigella sonnei str. Moseley", "rank": "Strain"}, "754075": {"name": "Vibrio phage 11895-B1", "rank": "Species"}, "754074": {"name": "Vibrio phage VBM1", "rank": "Species"}, "754073": {"name": "Vibrio phage VBP47", "rank": "Species"}, "754072": {"name": "Vibrio phage VBP32", "rank": "Species"}, "754071": {"name": "Tetraselmis viridis virus SI1", "rank": "Species"}, "754070": {"name": "Tetraselmis viridis virus S20", "rank": "Species"}, "259564": {"name": "Methanococcoides burtonii DSM 6242", "rank": "Strain"}, "180282": {"name": "Delftia tsuruhatensis", "rank": "Species"}, "1127767": {"name": "Espirito Santo virus", "rank": "Species"}, "754078": {"name": "Escherichia coli G58-1", "rank": "Strain"}, "1487922": {"name": "Pseudomonas sp. HMP271", "rank": "Species"}, "1487923": {"name": "Desulfosporosinus sp. HMP52", "rank": "Species"}, "85028": {"name": "Tsukamurellaceae", "rank": "Family"}, "85029": {"name": "Dietziaceae", "rank": "Family"}, "1104595": {"name": "Atribacteria bacterium SCGC AB-164-L03", "rank": "Species"}, "1104597": {"name": "Atribacteria bacterium SCGC AB-164-P05", "rank": "Species"}, "1400923": {"name": "Mycobacterium tuberculosis KT-0080", "rank": "Strain"}, "85023": {"name": "Microbacteriaceae", "rank": "Family"}, "1400921": {"name": "Mycobacterium tuberculosis KT-0078", "rank": "Strain"}, "85021": {"name": "Intrasporangiaceae", "rank": "Family"}, "85026": {"name": "Gordoniaceae", "rank": "Family"}, "1400926": {"name": "Mycobacterium tuberculosis KT-0085", "rank": "Strain"}, "1400925": {"name": "Mycobacterium tuberculosis KT-0084", "rank": "Strain"}, "1400924": {"name": "Mycobacterium tuberculosis KT-0083", "rank": "Strain"}, "84993": {"name": "Acidimicrobiales", "rank": "Order"}, "84992": {"name": "Acidimicrobidae", "rank": "Subclass"}, "84995": {"name": "Rubrobacteridae", "rank": "Subclass"}, "84994": {"name": "Acidimicrobiaceae", "rank": "Family"}, "84997": {"name": "Rubrobacteraceae", "rank": "Family"}, "84996": {"name": "Rubrobacterales", "rank": "Order"}, "84999": {"name": "Coriobacteriales", "rank": "Order"}, "1403347": {"name": "Halotalea alkalilenta DSM 17697", "rank": "Strain"}, "1403344": {"name": "Xylella fastidiosa Mul-MD", "rank": "Strain"}, "1403343": {"name": "Deinococcus xibeiensis R13", "rank": "Strain"}, "432329": {"name": "Deinococcus peraridilitoris", "rank": "Species"}, "46448": {"name": "Horseradish curly top virus", "rank": "Species"}, "1105171": {"name": "Bacteroides phage B124-14", "rank": "Species"}, "1329819": {"name": "Enterobacter sp. MGH 10", "rank": "Species"}, "1329818": {"name": "Enterobacter sp. MGH 9", "rank": "Species"}, "1329817": {"name": "Enterobacter sp. MGH 8", "rank": "Species"}, "1329816": {"name": "Enterobacter sp. MGH 7", "rank": "Species"}, "1329815": {"name": "Enterobacter sp. MGH 6", "rank": "Species"}, "1329814": {"name": "Enterobacter sp. MGH 5", "rank": "Species"}, "1329813": {"name": "Enterobacter sp. MGH 4", "rank": "Species"}, "1329812": {"name": "Enterobacter sp. MGH 3", "rank": "Species"}, "1329811": {"name": "Enterobacter sp. MGH 2", "rank": "Species"}, "1329810": {"name": "Enterobacter sp. MGH 1", "rank": "Species"}, "312309": {"name": "Vibrio fischeri ES114", "rank": "Strain"}, "755305": {"name": "Sida yellow vein disease associated DNA 1", "rank": "Species"}, "312306": {"name": "Pseudomonas entomophila", "rank": "Species"}, "1047027": {"name": "Aminicenantes bacterium SCGC AAA252-K18", "rank": "Species"}, "881290": {"name": "Nematocida parisii ERTm1", "rank": "Strain"}, "336722": {"name": "Zymoseptoria tritici IPO323", "rank": "Strain"}, "214684": {"name": "Cryptococcus neoformans var. neoformans JEC21", "rank": "Strain"}, "346884": {"name": "Acidianus filamentous virus 8", "rank": "Species"}, "1160784": {"name": "Candidatus Nasuia deltocephalinicola", "rank": "Species"}, "346881": {"name": "Acidianus filamentous virus 3", "rank": "Species"}, "346883": {"name": "Acidianus filamentous virus 7", "rank": "Species"}, "346882": {"name": "Acidianus filamentous virus 6", "rank": "Species"}, "1246981": {"name": "Tolypothrix bouteillei", "rank": "Species"}, "432587": {"name": "Gryllus bimaculatus nudivirus", "rank": "Species"}, "62079": {"name": "East African cassava mosaic virus", "rank": "Species"}, "311424": {"name": "Dehalococcoides mccartyi VS", "rank": "Strain"}, "40324": {"name": "Stenotrophomonas maltophilia", "rank": "Species"}, "40325": {"name": "Actinobacillus pleuropneumoniae serovar 1", "rank": "Strain"}, "45130": {"name": "Bipolaris sorokiniana", "rank": "Species"}, "40323": {"name": "Stenotrophomonas", "rank": "Genus"}, "1093958": {"name": "Sida yellow mottle virus", "rank": "Species"}, "213481": {"name": "Bdellovibrionales", "rank": "Order"}, "213483": {"name": "Bdellovibrionaceae", "rank": "Family"}, "213485": {"name": "Micavibrio", "rank": "Genus"}, "229204": {"name": "Flavobacterium frigoris", "rank": "Species"}, "98443": {"name": "Richelia", "rank": "Genus"}, "1455061": {"name": "Candidatus Magnetobacterium casensis", "rank": "Species"}, "107324": {"name": "Tobacco vein clearing virus", "rank": "Species"}, "102134": {"name": "Desulfotomaculum gibsoniae", "rank": "Species"}, "195088": {"name": "Halobacillus karajensis", "rank": "Species"}, "1448412": {"name": "Mycobacterium tuberculosis TKK_03_0065", "rank": "Strain"}, "1448411": {"name": "Mycobacterium tuberculosis TKK_03_0064", "rank": "Strain"}, "1448410": {"name": "Mycobacterium tuberculosis TKK_03_0063", "rank": "Strain"}, "1448417": {"name": "Mycobacterium tuberculosis TKK_03_0075", "rank": "Strain"}, "1448414": {"name": "Mycobacterium tuberculosis TKK_03_0072", "rank": "Strain"}, "1249650": {"name": "Ehrlichia chaffeensis str. West Paces", "rank": "Strain"}, "1249651": {"name": "Ehrlichia chaffeensis str. Heartland", "rank": "Strain"}, "1249652": {"name": "Ehrlichia chaffeensis str. Jax", "rank": "Strain"}, "266762": {"name": "Porphyromonas gingivicanis", "rank": "Species"}, "1249654": {"name": "Ehrlichia chaffeensis str. Osceola", "rank": "Strain"}, "1249655": {"name": "Ehrlichia chaffeensis str. Saint Vincent", "rank": "Strain"}, "1249656": {"name": "Ehrlichia chaffeensis str. Wakulla", "rank": "Strain"}, "184246": {"name": "Streptococcus constellatus subsp. constellatus", "rank": "Subspecies"}, "1249658": {"name": "Burkholderia pseudomallei PB08298010", "rank": "Strain"}, "1249659": {"name": "Burkholderia pseudomallei MSHR520", "rank": "Strain"}, "103376": {"name": "Stereaceae", "rank": "Family"}, "1564515": {"name": "Phaeodactylibacter", "rank": "Genus"}, "1193181": {"name": "Tetrasphaera elongata Lp2", "rank": "Strain"}, "444157": {"name": "Pyrobaculum neutrophilum V24Sta", "rank": "Strain"}, "638300": {"name": "Cardiobacterium hominis ATCC 15826", "rank": "Strain"}, "638301": {"name": "Granulicatella adiacens ATCC 49175", "rank": "Strain"}, "638302": {"name": "Selenomonas flueggei ATCC 43531", "rank": "Strain"}, "638303": {"name": "Thermocrinis albus DSM 14484", "rank": "Strain"}, "351053": {"name": "Unclassified Brevidensovirus", "rank": "No rank"}, "1004152": {"name": "Mycoplasma flocculare ATCC 27716", "rank": "Strain"}, "1004153": {"name": "Escherichia coli AA86", "rank": "Strain"}, "1004150": {"name": "Photorhabdus temperata subsp. khanii", "rank": "Subspecies"}, "1492": {"name": "Clostridium butyricum", "rank": "Species"}, "687333": {"name": "Gammatorquevirus", "rank": "Genus"}, "687332": {"name": "Betatorquevirus", "rank": "Genus"}, "687331": {"name": "Alphatorquevirus", "rank": "Genus"}, "1494608": {"name": "Arthrobacter sp. PAMC25486", "rank": "Species"}, "687337": {"name": "Etatorquevirus", "rank": "Genus"}, "687336": {"name": "Zetatorquevirus", "rank": "Genus"}, "687335": {"name": "Epsilontorquevirus", "rank": "Genus"}, "687339": {"name": "Iotatorquevirus", "rank": "Genus"}, "687338": {"name": "Thetatorquevirus", "rank": "Genus"}, "1154950": {"name": "Streptococcus agalactiae GB00922", "rank": "Strain"}, "1154951": {"name": "Streptococcus agalactiae GB00923", "rank": "Strain"}, "1343738": {"name": "Vibrio cholerae 2012EL-1759", "rank": "Strain"}, "1343739": {"name": "Palaeococcus pacificus DY20341", "rank": "Strain"}, "1154954": {"name": "Streptococcus agalactiae GB00932", "rank": "Strain"}, "1151358": {"name": "Peptoclostridium difficile DA00275", "rank": "Strain"}, "1339238": {"name": "Staphylococcus sp. ZWU0021", "rank": "Species"}, "1154957": {"name": "Streptococcus agalactiae GB00947", "rank": "Strain"}, "1339236": {"name": "Ensifer sp. ZNC0028", "rank": "Species"}, "1339237": {"name": "Pseudomonas mendocina ZWU0006", "rank": "Strain"}, "1339234": {"name": "Kocuria sp. ZOR0020", "rank": "Species"}, "1151356": {"name": "Peptoclostridium difficile DA00261", "rank": "Strain"}, "1339232": {"name": "Enterobacter sp. ZOR0014", "rank": "Species"}, "1343737": {"name": "Xylella fastidiosa subsp. multiplex Griffin-1", "rank": "Strain"}, "1339230": {"name": "Plesiomonas sp. ZOR0011", "rank": "Species"}, "1339231": {"name": "Shewanella sp. ZOR0012", "rank": "Species"}, "1088888": {"name": "Vibrio campbellii DS40M4", "rank": "Strain"}, "59380": {"name": "Rice yellow stunt virus", "rank": "Species"}, "1298878": {"name": "Rhizobacter sp. JGI 0001007-A16", "rank": "Species"}, "1298879": {"name": "Streptomyces sp. CNQ329", "rank": "Species"}, "1031536": {"name": "Campylobacter lari subsp. concheus LMG 11760", "rank": "Strain"}, "1298872": {"name": "Pseudomonas sp. JGI 0001012-A11", "rank": "Species"}, "1298873": {"name": "Rhizobium sp. JGI 0001005-L20", "rank": "Species"}, "1298870": {"name": "Delftia sp. JGI 0001020-O15", "rank": "Species"}, "1168034": {"name": "Draconibacterium orientale", "rank": "Species"}, "1298877": {"name": "Rhizobacter sp. JGI 0001009-E21", "rank": "Species"}, "1298874": {"name": "Rhizobium sp. JGI 0001011-C22", "rank": "Species"}, "1298875": {"name": "Nocardioides sp. JGI 0001009-J09", "rank": "Species"}, "1284820": {"name": "Klebsiella pneumoniae UHKPC22", "rank": "Strain"}, "1284821": {"name": "Klebsiella pneumoniae UHKPC29", "rank": "Strain"}, "1284822": {"name": "Klebsiella pneumoniae UHKPC32", "rank": "Strain"}, "1284823": {"name": "Klebsiella pneumoniae UHKPC04", "rank": "Strain"}, "1284825": {"name": "Klebsiella pneumoniae VAKPC254", "rank": "Strain"}, "1284826": {"name": "Klebsiella pneumoniae VAKPC269", "rank": "Strain"}, "1284827": {"name": "Klebsiella pneumoniae VAKPC278", "rank": "Strain"}, "1284828": {"name": "Klebsiella pneumoniae VAKPC280", "rank": "Strain"}, "1284829": {"name": "Klebsiella pneumoniae VAKPC270", "rank": "Strain"}, "643132": {"name": "Quang Binh virus", "rank": "Species"}, "1126218": {"name": "Bacillus licheniformis WX-02", "rank": "Strain"}, "1042163": {"name": "Brevibacillus laterosporus LMG 15441", "rank": "Strain"}, "1408916": {"name": "Mycobacterium tuberculosis UT0026", "rank": "Strain"}, "104605": {"name": "Sphingomonas sp. Ant20", "rank": "Species"}, "1218933": {"name": "Pectobacterium carotovorum subsp. carotovorum PCC21", "rank": "Strain"}, "1126217": {"name": "Vibrio campbellii PEL22A", "rank": "Strain"}, "1206898": {"name": "Unclassified Twortlikevirus", "rank": "No rank"}, "1339300": {"name": "Bacteroides fragilis str. 3397 N2", "rank": "Strain"}, "706473": {"name": "Volvariella volvacea V23", "rank": "Strain"}, "551275": {"name": "Hirschia maritima DSM 19733", "rank": "Strain"}, "551276": {"name": "Pseudonocardia acaciae", "rank": "Species"}, "1339301": {"name": "Bacteroides fragilis str. 3397 N3", "rank": "Strain"}, "1339306": {"name": "Bacteroides fragilis str. 3719 T6", "rank": "Strain"}, "401638": {"name": "Paenibacillus taiwanensis", "rank": "Species"}, "75294": {"name": "Saccharomonospora xinjiangensis", "rank": "Species"}, "1408913": {"name": "Mycobacterium tuberculosis UT0020", "rank": "Strain"}, "337": {"name": "Burkholderia glumae", "rank": "Species"}, "333": {"name": "Pseudomonas chlororaphis subsp. chlororaphis", "rank": "Subspecies"}, "1432548": {"name": "Escherichia coli IS25", "rank": "Strain"}, "330": {"name": "Pseudomonas pseudoalcaligenes", "rank": "Species"}, "1408911": {"name": "Mycobacterium tuberculosis UT0015", "rank": "Strain"}, "339": {"name": "Xanthomonas campestris", "rank": "Species"}, "338": {"name": "Xanthomonas", "rank": "Genus"}, "1432549": {"name": "Escherichia coli IS29", "rank": "Strain"}, "1345600": {"name": "Helicobacter pylori SA220C", "rank": "Strain"}, "130371": {"name": "Porcine mastadenovirus C", "rank": "Species"}, "175696": {"name": "Thermaerobacter subterraneus", "rank": "Species"}, "1048260": {"name": "Leptospirillum ferriphilum ML-04", "rank": "Strain"}, "642260": {"name": "Circovirus-like genome BBC-A", "rank": "Species"}, "1048261": {"name": "Pseudomonas putida B001", "rank": "Strain"}, "306276": {"name": "Yunnan orbivirus", "rank": "Species"}, "10798": {"name": "Human parvovirus B19", "rank": "Strain"}, "10799": {"name": "H-1 parvovirus", "rank": "Strain"}, "301301": {"name": "Roseburia hominis", "rank": "Species"}, "1310650": {"name": "Acinetobacter baumannii 724909", "rank": "Strain"}, "1398044": {"name": "Staphylococcus aureus M1429", "rank": "Strain"}, "10796": {"name": "Porcine parvovirus", "rank": "Strain"}, "10794": {"name": "Minute virus of mice", "rank": "Strain"}, "1048265": {"name": "Escherichia coli O104:H4 str. 04-8351", "rank": "Strain"}, "11263": {"name": "Murine pneumonia virus", "rank": "Species"}, "1033979": {"name": "Mitosporic Plectosphaerellaceae", "rank": "No rank"}, "1048266": {"name": "Escherichia coli O104:H4 str. 09-7901", "rank": "Strain"}, "11266": {"name": "Filoviridae", "rank": "Family"}, "11269": {"name": "Marburg marburgvirus", "rank": "Species"}, "1033976": {"name": "Bean necrotic mosaic virus", "rank": "Species"}, "1310657": {"name": "Acinetobacter baumannii 1096934", "rank": "Strain"}, "1310656": {"name": "Acinetobacter baumannii 1146103", "rank": "Strain"}, "1310659": {"name": "Acinetobacter baumannii 1106579", "rank": "Strain"}, "13684": {"name": "Parastagonospora nodorum", "rank": "Species"}, "13687": {"name": "Sphingomonas", "rank": "Genus"}, "1169267": {"name": "Staphylococcus aureus M1142", "rank": "Strain"}, "13689": {"name": "Sphingomonas paucimobilis", "rank": "Species"}, "1095655": {"name": "Vibrio cholerae O1 str. NHCC-004A", "rank": "Strain"}, "383629": {"name": "Phaeobacter gallaeciensis 2.10", "rank": "Strain"}, "413071": {"name": "Trichoderma virens Gv29-8", "rank": "Strain"}, "888059": {"name": "Capnocytophaga sp. oral taxon 338 str. F0234", "rank": "Strain"}, "1160209": {"name": "Brucella abortus 65/110", "rank": "Strain"}, "1160208": {"name": "Brucella abortus F6/05-9", "rank": "Strain"}, "1328339": {"name": "Brucella abortus 68-3396P", "rank": "Strain"}, "1344956": {"name": "Microbacterium sp. TS-1", "rank": "Species"}, "225842": {"name": "Formosa", "rank": "Genus"}, "1160203": {"name": "Brucella abortus 80/102", "rank": "Strain"}, "1328334": {"name": "Salmonella enterica subsp. enterica serovar Muenchen str. 08-1125", "rank": "Strain"}, "1328337": {"name": "Klebsiella pneumoniae BIDMC 31", "rank": "Strain"}, "888052": {"name": "Actinomyces sp. oral taxon 180 str. F0310", "rank": "Strain"}, "1328331": {"name": "Salmonella enterica subsp. enterica serovar Poona str. 2010K-2244", "rank": "Strain"}, "1328330": {"name": "Salmonella enterica subsp. enterica serovar Mbandaka str. 2012K-0273", "rank": "Strain"}, "1328333": {"name": "Salmonella enterica subsp. enterica serovar Muenchen str. 2009K-0951", "rank": "Strain"}, "1328332": {"name": "Salmonella enterica subsp. enterica serovar Stanley str. 06-0538", "rank": "Strain"}, "412895": {"name": "Desulfotomaculum hydrothermale", "rank": "Species"}, "12242": {"name": "Tobacco mosaic virus", "rank": "Species"}, "12241": {"name": "Tobacco mild green mosaic virus", "rank": "Species"}, "5518": {"name": "Fusarium graminearum", "rank": "Species"}, "1126908": {"name": "Escherichia coli C58_11", "rank": "Strain"}, "936060": {"name": "Tursiops truncatus papillomavirus 2", "rank": "Strain"}, "303179": {"name": "Kokobera virus group", "rank": "Subgenus"}, "35554": {"name": "Geobacter sulfurreducens", "rank": "Species"}, "1177632": {"name": "Salmonella phage SSU5", "rank": "Species"}, "320832": {"name": "Staphylococcus phage 66", "rank": "Species"}, "1177630": {"name": "American hop latent virus", "rank": "Species"}, "505248": {"name": "Novosphingobium acidiphilum", "rank": "Species"}, "1344043": {"name": "Mycobacterium tuberculosis PanR0203", "rank": "Strain"}, "1344042": {"name": "Enterococcus faecium T110", "rank": "Strain"}, "1344045": {"name": "Mycobacterium tuberculosis PanR0206", "rank": "Strain"}, "1344044": {"name": "Mycobacterium tuberculosis PanR0205", "rank": "Strain"}, "1344047": {"name": "Mycobacterium tuberculosis PanR0208", "rank": "Strain"}, "66219": {"name": "Lachnoclostridium phytofermentans", "rank": "Species"}, "1344048": {"name": "Mycobacterium tuberculosis PanR0209", "rank": "Strain"}, "655844": {"name": "Metarhizium robertsii ARSEF 23", "rank": "Strain"}, "1095652": {"name": "Vibrio cholerae O1 str. EC-0012", "rank": "Strain"}, "418240": {"name": "Blautia wexlerae", "rank": "Species"}, "909297": {"name": "Synechococcus phage S-CBS1", "rank": "Species"}, "463191": {"name": "Streptomyces sviceus ATCC 29083", "rank": "Strain"}, "320837": {"name": "Staphylococcus phage 42E", "rank": "Species"}, "150396": {"name": "Pseudomonas sp. MT-1", "rank": "Species"}, "33811": {"name": "Unclassified Gammaproteobacteria (miscellaneous)", "rank": "No rank"}, "1159328": {"name": "Leptospirillum sp. Group II 'C75'", "rank": "Species"}, "1444167": {"name": "Escherichia coli 3-105-05_S3_C2", "rank": "Strain"}, "1444166": {"name": "Escherichia coli 3-073-06_S3_C2", "rank": "Strain"}, "1444165": {"name": "Escherichia coli 3-020-07_S3_C2", "rank": "Strain"}, "1444164": {"name": "Escherichia coli 1-392-07_S3_C2", "rank": "Strain"}, "1444163": {"name": "Escherichia coli 1-250-04_S3_C2", "rank": "Strain"}, "1444162": {"name": "Escherichia coli 1-182-04_S3_C2", "rank": "Strain"}, "1444161": {"name": "Escherichia coli 1-176-05_S3_C2", "rank": "Strain"}, "1444160": {"name": "Escherichia coli 1-110-08_S3_C2", "rank": "Strain"}, "1003835": {"name": "Severe fever with thrombocytopenia syndrome virus", "rank": "Species"}, "1003836": {"name": "Pepper leaf curl Yunnan virus", "rank": "Species"}, "1574475": {"name": "Aphanocapsa montana BDHKU210001", "rank": "Strain"}, "1444169": {"name": "Escherichia coli 3-373-03_S3_C2", "rank": "Strain"}, "1444168": {"name": "Escherichia coli 3-267-03_S3_C2", "rank": "Strain"}, "1226299": {"name": "Lactobacillus paracasei COM0101", "rank": "Strain"}, "1226298": {"name": "Lactobacillus paracasei subsp. paracasei JCM 8130", "rank": "Strain"}, "403897": {"name": "Corchorus yellow spot virus", "rank": "Species"}, "906968": {"name": "Treponema brennaborense DSM 12168", "rank": "Strain"}, "348842": {"name": "Desulfovirgula thermocuniculi", "rank": "Species"}, "1138902": {"name": "Enterococcus faecium EnGen0028", "rank": "Strain"}, "573413": {"name": "Spirochaeta smaragdinae DSM 11293", "rank": "Strain"}, "1330457": {"name": "Escherichia coli O157:H7 str. SS52", "rank": "Strain"}, "1330458": {"name": "Agrococcus pavilionensis RW1", "rank": "Strain"}, "765107": {"name": "Propionibacterium acnes HL036PA2", "rank": "Strain"}, "765106": {"name": "Propionibacterium acnes HL036PA1", "rank": "Strain"}, "1385985": {"name": "Sphingobacterium paucimobilis", "rank": "Species"}, "765104": {"name": "Propionibacterium acnes HL030PA2", "rank": "Strain"}, "36738": {"name": "Halococcus salifodinae", "rank": "Species"}, "36739": {"name": "Dermabacter", "rank": "Genus"}, "765101": {"name": "Propionibacterium acnes HL050PA2", "rank": "Strain"}, "765100": {"name": "Propionibacterium acnes HL050PA1", "rank": "Strain"}, "36734": {"name": "Unikaryonidae", "rank": "Family"}, "765109": {"name": "Propionibacterium humerusii HL044PA1", "rank": "Strain"}, "765108": {"name": "Propionibacterium acnes HL036PA3", "rank": "Strain"}, "1564": {"name": "Desulfotomaculum ruminis", "rank": "Species"}, "32024": {"name": "Campylobacter sputorum biovar sputorum", "rank": "Strain"}, "32025": {"name": "Helicobacter hepaticus", "rank": "Species"}, "32020": {"name": "Campylobacter fetus subsp. venerealis", "rank": "Subspecies"}, "32021": {"name": "Campylobacter jejuni subsp. doylei", "rank": "Subspecies"}, "32022": {"name": "Campylobacter jejuni subsp. jejuni", "rank": "Subspecies"}, "1408144": {"name": "Fikirini bat rhabdovirus", "rank": "Species"}, "1423347": {"name": "Sclerotinia sclerotiorum hypovirus 2", "rank": "Species"}, "417574": {"name": "Neptunomonas japonica", "rank": "Species"}, "318586": {"name": "Paracoccus denitrificans PD1222", "rank": "Strain"}, "559878": {"name": "Clerodendrum golden mosaic China virus", "rank": "Species"}, "1173297": {"name": "Halocynthia phage JM-2012", "rank": "Species"}, "1154861": {"name": "Streptococcus agalactiae LMG 14838", "rank": "Strain"}, "1542744": {"name": "Gemycircularvirus group", "rank": "No rank"}, "1542745": {"name": "Ancient caribou feces associated virus", "rank": "Species"}, "1542743": {"name": "Caribou feces-associated gemycircularvirus", "rank": "Species"}, "1310605": {"name": "Acinetobacter baumannii 348935", "rank": "Strain"}, "1417079": {"name": "Staphylococcus aureus H38226", "rank": "Strain"}, "1417078": {"name": "Staphylococcus aureus W62972", "rank": "Strain"}, "568715": {"name": "Astrovirus MLB1", "rank": "Species"}, "1159201": {"name": "Mycoplasma gallisepticum WI01_2001.043-13-2P", "rank": "Strain"}, "1417071": {"name": "Staphylococcus aureus M35933", "rank": "Strain"}, "1417070": {"name": "Staphylococcus aureus F70051", "rank": "Strain"}, "1417073": {"name": "Staphylococcus aureus W57390", "rank": "Strain"}, "1417072": {"name": "Staphylococcus aureus M35938", "rank": "Strain"}, "1417075": {"name": "Staphylococcus aureus M35955", "rank": "Strain"}, "1417074": {"name": "Staphylococcus aureus M35954", "rank": "Strain"}, "1417077": {"name": "Staphylococcus aureus W62934", "rank": "Strain"}, "1417076": {"name": "Staphylococcus aureus M35965", "rank": "Strain"}, "1332188": {"name": "Candidatus Saccharimonas aalborgensis", "rank": "Species"}, "1303692": {"name": "Streptomyces fulvissimus DSM 40593", "rank": "Strain"}, "1380377": {"name": "Halomonas sp. 19A_GOM-1509m", "rank": "Species"}, "1410869": {"name": "Staphylococcus aureus F92765", "rank": "Strain"}, "1410868": {"name": "Staphylococcus aureus F92753", "rank": "Strain"}, "1410867": {"name": "Staphylococcus aureus H54403", "rank": "Strain"}, "1410866": {"name": "Staphylococcus aureus W79328", "rank": "Strain"}, "1410865": {"name": "Staphylococcus aureus T12923", "rank": "Strain"}, "327079": {"name": "Pseudozyma hubeiensis", "rank": "Species"}, "1410863": {"name": "Staphylococcus aureus F89468", "rank": "Strain"}, "1410862": {"name": "Staphylococcus aureus F89441", "rank": "Strain"}, "1410861": {"name": "Staphylococcus aureus T87972", "rank": "Strain"}, "1410860": {"name": "Staphylococcus aureus T87965", "rank": "Strain"}, "1232456": {"name": "Lachnospiraceae bacterium VE202-23", "rank": "Species"}, "1221524": {"name": "Amycolatopsis mediterranei RB", "rank": "Strain"}, "1232457": {"name": "Clostridiales bacterium VE202-27", "rank": "Species"}, "1413512": {"name": "Staphylococcus aureus P0218", "rank": "Strain"}, "1413510": {"name": "Staphylococcus aureus C0673", "rank": "Strain"}, "1413511": {"name": "Staphylococcus aureus C0676", "rank": "Strain"}, "2723": {"name": "Hirschia", "rank": "Genus"}, "1413517": {"name": "Staphylococcus aureus 2010-60-6511-39", "rank": "Strain"}, "1413514": {"name": "Staphylococcus aureus 2010-60-1240-1", "rank": "Strain"}, "1413515": {"name": "Staphylococcus aureus 2010-60-6511-10", "rank": "Strain"}, "292": {"name": "Burkholderia cepacia", "rank": "Species"}, "293": {"name": "Brevundimonas diminuta", "rank": "Species"}, "294": {"name": "Pseudomonas fluorescens", "rank": "Species"}, "296": {"name": "Pseudomonas fragi", "rank": "Species"}, "37554": {"name": "Enterobacteria phage HK97", "rank": "Species"}, "1131270": {"name": "Nitrospina sp. AB-629-B06", "rank": "Species"}, "1432097": {"name": "Streptococcus pneumoniae ECC_3510", "rank": "Strain"}, "255507": {"name": "Arcobacter cibarius", "rank": "Species"}, "1131274": {"name": "Gamma proteobacterium SCGC AB-629-P17", "rank": "Species"}, "652103": {"name": "Rhodopseudomonas palustris DX-1", "rank": "Strain"}, "1131276": {"name": "Alpha proteobacterium SCGC AB-629-G21", "rank": "Species"}, "1288036": {"name": "Mycobacterium marinum MB2", "rank": "Strain"}, "1410709": {"name": "Staphylococcus aureus M92071", "rank": "Strain"}, "1341644": {"name": "Pseudomonas aeruginosa WS136", "rank": "Strain"}, "526215": {"name": "Thalassobaculum", "rank": "Genus"}, "526216": {"name": "Oceanibaculum indicum", "rank": "Species"}, "1346615": {"name": "Lactobacillus gasseri 2016", "rank": "Strain"}, "1341640": {"name": "Yersinia sp. WP-930601", "rank": "Species"}, "1346613": {"name": "Brevibacillus thermoruber 423", "rank": "Strain"}, "1410707": {"name": "Staphylococcus aureus H12822", "rank": "Strain"}, "526218": {"name": "Sebaldella termitidis ATCC 33386", "rank": "Strain"}, "562017": {"name": "Streptococcus pyogenes SS1447", "rank": "Strain"}, "1211025": {"name": "Enterobacter cloacae subsp. cloacae ENHKU01", "rank": "Strain"}, "1410703": {"name": "Staphylococcus aureus F45300", "rank": "Strain"}, "164416": {"name": "Wesselsbron virus", "rank": "Species"}, "237368": {"name": "Candidatus Scalindua brodae", "rank": "Species"}, "65555": {"name": "Desulfocapsa sulfexigens", "rank": "Species"}, "656519": {"name": "Halanaerobium hydrogeniformans", "rank": "Species"}, "1281212": {"name": "Escherichia coli UMEA 3199-1", "rank": "Strain"}, "192523": {"name": "Agaricus bisporus var. bisporus", "rank": "Varietas"}, "1333586": {"name": "Serratia marcescens AB42556419-isolate1", "rank": "Strain"}, "1333587": {"name": "Escherichia coli 112469215-isolate1", "rank": "Strain"}, "1333584": {"name": "Serratia marcescens MC6001", "rank": "Strain"}, "1333585": {"name": "Serratia marcescens MC620", "rank": "Strain"}, "1412645": {"name": "Staphylococcus aureus F84732", "rank": "Strain"}, "1333583": {"name": "Serratia marcescens MC6000", "rank": "Strain"}, "515618": {"name": "Candidatus Riesia pediculicola USDA", "rank": "Strain"}, "1333581": {"name": "Serratia marcescens MC459", "rank": "Strain"}, "1412649": {"name": "Staphylococcus aureus F88387", "rank": "Strain"}, "515617": {"name": "Mycobacterium tuberculosis T92", "rank": "Strain"}, "515615": {"name": "Mycobacterium tuberculosis 94_M4241A", "rank": "Strain"}, "1333588": {"name": "Escherichia coli 112469218-isolate1", "rank": "Strain"}, "515611": {"name": "Ureaplasma urealyticum serovar 13 str. ATCC 33698", "rank": "Strain"}, "1281213": {"name": "Escherichia coli UMEA 3200-1", "rank": "Strain"}, "449659": {"name": "Lactobacillus pobuzihii", "rank": "Species"}, "1421878": {"name": "Staphylococcus aureus M79684", "rank": "Strain"}, "1421879": {"name": "Staphylococcus aureus M79686", "rank": "Strain"}, "1421870": {"name": "Staphylococcus aureus M42184", "rank": "Strain"}, "1421871": {"name": "Staphylococcus aureus M67938", "rank": "Strain"}, "1421872": {"name": "Staphylococcus aureus M70017", "rank": "Strain"}, "1421873": {"name": "Staphylococcus aureus M70018", "rank": "Strain"}, "1421874": {"name": "Staphylococcus aureus M72097", "rank": "Strain"}, "1421875": {"name": "Staphylococcus aureus M79254", "rank": "Strain"}, "1421876": {"name": "Staphylococcus aureus M79256", "rank": "Strain"}, "1421877": {"name": "Staphylococcus aureus M79671", "rank": "Strain"}, "478749": {"name": "Marvinbryantia formatexigens DSM 14469", "rank": "Strain"}, "1382366": {"name": "Lactobacillus plantarum 4_3", "rank": "Strain"}, "1382367": {"name": "Legionella pneumophila W1046", "rank": "Strain"}, "478741": {"name": "Verrucomicrobia bacterium LP2A", "rank": "Species"}, "1053196": {"name": "Bacillus cereus BMG1.7", "rank": "Strain"}, "339722": {"name": "Desulfovermiculus halophilus", "rank": "Species"}, "1354240": {"name": "Riemerella anatipestifer CH3", "rank": "Strain"}, "339721": {"name": "Desulfovermiculus", "rank": "Genus"}, "754477": {"name": "Methylophaga frappieri", "rank": "Species"}, "754476": {"name": "Methylophaga nitratireducenticrescens", "rank": "Species"}, "580340": {"name": "Thermovirga lienii DSM 17291", "rank": "Strain"}, "1125717": {"name": "Actinomyces georgiae F0490", "rank": "Strain"}, "1416030": {"name": "Escherichia phage bV_EcoS_AHS24", "rank": "Species"}, "1411023": {"name": "Unclassified Peptostreptococcaceae (miscellaneous)", "rank": "No rank"}, "1125712": {"name": "Olsenella profusa F0195", "rank": "Strain"}, "45709": {"name": "Sabia virus", "rank": "Species"}, "1125718": {"name": "Actinomyces massiliensis F0489", "rank": "Strain"}, "1125719": {"name": "Capnocytophaga ochracea str. Holt 25", "rank": "Strain"}, "564646": {"name": "Deltalipothrixvirus", "rank": "Genus"}, "1418254": {"name": "Mycobacterium tuberculosis 51628", "rank": "Strain"}, "1418255": {"name": "Mycobacterium tuberculosis 38088", "rank": "Strain"}, "1418256": {"name": "Mycobacterium tuberculosis 36361", "rank": "Strain"}, "1418250": {"name": "Mycobacterium tuberculosis OFXR-28", "rank": "Strain"}, "1418251": {"name": "Mycobacterium tuberculosis 38765", "rank": "Strain"}, "1418252": {"name": "Mycobacterium tuberculosis 49375", "rank": "Strain"}, "1418253": {"name": "Mycobacterium tuberculosis 44503", "rank": "Strain"}, "111504": {"name": "Bartonella birtlesii", "rank": "Species"}, "111500": {"name": "Muricauda", "rank": "Genus"}, "111501": {"name": "Muricauda ruestringensis", "rank": "Species"}, "1005450": {"name": "Escherichia coli 3.4870", "rank": "Strain"}, "550682": {"name": "Escherichia coli B799", "rank": "Strain"}, "1232437": {"name": "Desulfobacula sp. TS", "rank": "Species"}, "550687": {"name": "Escherichia coli E482", "rank": "Strain"}, "550685": {"name": "Escherichia coli E101", "rank": "Strain"}, "405": {"name": "Methylobacillus flagellatus", "rank": "Species"}, "404": {"name": "Methylobacillus", "rank": "Genus"}, "407": {"name": "Methylobacterium", "rank": "Genus"}, "406": {"name": "Methylobacillus glycogenes", "rank": "Species"}, "1388108": {"name": "Staphylococcus aureus M0166", "rank": "Strain"}, "1388109": {"name": "Staphylococcus aureus M0168", "rank": "Strain"}, "403": {"name": "Methylococcaceae", "rank": "Family"}, "1389487": {"name": "Listeria monocytogenes serotype 4bV str. LS645", "rank": "Strain"}, "1388104": {"name": "Staphylococcus aureus M0162", "rank": "Strain"}, "1388105": {"name": "Staphylococcus aureus M0163", "rank": "Strain"}, "1388106": {"name": "Staphylococcus aureus M0164", "rank": "Strain"}, "1388107": {"name": "Staphylococcus aureus M0165", "rank": "Strain"}, "1388100": {"name": "Staphylococcus aureus M0158", "rank": "Strain"}, "1388101": {"name": "Staphylococcus aureus M0159", "rank": "Strain"}, "249188": {"name": "Haemophilus pittmaniae", "rank": "Species"}, "1388103": {"name": "Staphylococcus aureus M0161", "rank": "Strain"}, "1072568": {"name": "Salmonella enterica subsp. enterica serovar Paratyphi A str. GXS2268", "rank": "Strain"}, "1072569": {"name": "Salmonella enterica subsp. enterica serovar Paratyphi A str. GZ9A00052", "rank": "Strain"}, "1151207": {"name": "Enterococcus faecalis EnGen0071", "rank": "Strain"}, "1151206": {"name": "Enterococcus faecalis EnGen0084", "rank": "Strain"}, "1151205": {"name": "Enterococcus faecalis EnGen0083", "rank": "Strain"}, "1151204": {"name": "Enterococcus faecalis EnGen0082", "rank": "Strain"}, "1151202": {"name": "Enterococcus faecalis EnGen0081", "rank": "Strain"}, "1151201": {"name": "Enterococcus faecalis EnGen0060", "rank": "Strain"}, "1151200": {"name": "Enterococcus faecalis EnGen0079", "rank": "Strain"}, "1311009": {"name": "Acinetobacter baumannii 25681_5", "rank": "Strain"}, "1311007": {"name": "Acinetobacter baumannii 25681_3", "rank": "Strain"}, "1311006": {"name": "Acinetobacter baumannii 25681_2", "rank": "Strain"}, "1311004": {"name": "Acinetobacter baumannii 44857_10", "rank": "Strain"}, "1311003": {"name": "Acinetobacter baumannii 44857_9", "rank": "Strain"}, "1182702": {"name": "Escherichia coli KTE103", "rank": "Strain"}, "1182703": {"name": "Escherichia coli KTE107", "rank": "Strain"}, "1182700": {"name": "Escherichia coli KTE101", "rank": "Strain"}, "1463879": {"name": "Streptomyces sp. NRRL F-6677", "rank": "Species"}, "1182706": {"name": "Escherichia coli KTE111", "rank": "Strain"}, "1182707": {"name": "Escherichia coli KTE115", "rank": "Strain"}, "1182704": {"name": "Escherichia coli KTE108", "rank": "Strain"}, "1182708": {"name": "Escherichia coli KTE116", "rank": "Strain"}, "1182709": {"name": "Escherichia coli KTE118", "rank": "Strain"}, "1210908": {"name": "Halogranum salarium B-1", "rank": "Strain"}, "1138926": {"name": "Enterococcus faecium EnGen0047", "rank": "Strain"}, "1210907": {"name": "Acinetobacter baumannii BZICU-2", "rank": "Strain"}, "1227557": {"name": "Mulberry badnavirus 1", "rank": "Species"}, "36834": {"name": "Clostridium celatum", "rank": "Species"}, "795955": {"name": "Nesterenkonia sp. F", "rank": "Species"}, "36832": {"name": "Clostridium aerotolerans", "rank": "Species"}, "36363": {"name": "Lymphocystis disease virus 1", "rank": "Species"}, "682370": {"name": "Streptococcus phage ALQ13.2", "rank": "Species"}, "36831": {"name": "Clostridium botulinum F", "rank": "Strain"}, "362399": {"name": "Sugarcane bacilliform MO virus", "rank": "Species"}, "362398": {"name": "Sugarcane bacilliform IM virus", "rank": "Species"}, "1486991": {"name": "Candidatus Sodalis pierantonius", "rank": "Species"}, "240176": {"name": "Coprinopsis cinerea okayama7#130", "rank": "Strain"}, "36830": {"name": "Clostridium botulinum E", "rank": "Strain"}, "1124924": {"name": "Salmonella enterica subsp. enterica serovar Anatum str. USDA 100", "rank": "Strain"}, "146784": {"name": "Bacteriovorax", "rank": "Genus"}, "1051": {"name": "Ectothiorhodospira", "rank": "Genus"}, "1052": {"name": "Halorhodospira halochloris", "rank": "Species"}, "1053": {"name": "Halorhodospira halophila", "rank": "Species"}, "1056": {"name": "Thiocapsa", "rank": "Genus"}, "1438753": {"name": "Klebsiella pneumoniae CHS 47", "rank": "Strain"}, "1438752": {"name": "Klebsiella pneumoniae CHS 46", "rank": "Strain"}, "1438751": {"name": "Klebsiella pneumoniae CHS 45", "rank": "Strain"}, "1438750": {"name": "Klebsiella pneumoniae CHS 44", "rank": "Strain"}, "1438757": {"name": "Klebsiella pneumoniae CHS 51", "rank": "Strain"}, "1438756": {"name": "Klebsiella pneumoniae CHS 50", "rank": "Strain"}, "1438755": {"name": "Klebsiella pneumoniae CHS 49", "rank": "Strain"}, "1438754": {"name": "Klebsiella pneumoniae CHS 48", "rank": "Strain"}, "188350": {"name": "Pseudomonas phage PaP3", "rank": "Species"}, "37126": {"name": "Citrus leaf rugose virus", "rank": "Species"}, "37127": {"name": "Citrus variegation virus", "rank": "Species"}, "251722": {"name": "Pseudomonas syringae pv. aesculi", "rank": "Strain"}, "1250303": {"name": "Sunflower leaf curl Karnataka alphasatellite", "rank": "Species"}, "1384484": {"name": "Adlercreutzia equolifaciens DSM 19450", "rank": "Strain"}, "947843": {"name": "Erwinia phage ENT90", "rank": "Species"}, "215158": {"name": "Salmonella phage epsilon15", "rank": "Species"}, "37128": {"name": "Potato mop-top virus", "rank": "Species"}, "936587": {"name": "Streptococcus sp. OBRC6", "rank": "Species"}, "1077263": {"name": "Chthonomonadales", "rank": "Order"}, "1077264": {"name": "Chthonomonadaceae", "rank": "Family"}, "1077265": {"name": "Chthonomonas", "rank": "Genus"}, "72173": {"name": "Citromicrobium", "rank": "Genus"}, "72174": {"name": "Citromicrobium bathyomarinum", "rank": "Species"}, "623276": {"name": "Maritalea", "rank": "Genus"}, "1220026": {"name": "Pasteurella multocida subsp. multocida str. PMTB", "rank": "Strain"}, "1220027": {"name": "Xanthomonas citri pv. malvacearum X18", "rank": "Strain"}, "1220025": {"name": "Pokeweed mosaic virus", "rank": "Species"}, "1116008": {"name": "Escherichia coli 2735000", "rank": "Strain"}, "1116009": {"name": "Escherichia coli 2741950", "rank": "Strain"}, "1116004": {"name": "Escherichia coli 2729250", "rank": "Strain"}, "1116005": {"name": "Escherichia coli 2730350", "rank": "Strain"}, "1116006": {"name": "Escherichia coli 2730450", "rank": "Strain"}, "1116007": {"name": "Escherichia coli 2731150", "rank": "Strain"}, "1116000": {"name": "Escherichia coli Jurua 20/10", "rank": "Strain"}, "1116001": {"name": "Escherichia coli ThroopD", "rank": "Strain"}, "1116002": {"name": "Escherichia coli C-34666", "rank": "Strain"}, "1116003": {"name": "Escherichia coli 174900", "rank": "Strain"}, "70992": {"name": "Flexithrix", "rank": "Genus"}, "70993": {"name": "Flexithrix dorotheae", "rank": "Species"}, "255131": {"name": "Burkholderia phage phi1026b", "rank": "Species"}, "70994": {"name": "Lewinella", "rank": "Genus"}, "70995": {"name": "Lewinella cohaerens", "rank": "Species"}, "267894": {"name": "Psychromonadaceae", "rank": "Family"}, "903897": {"name": "Acinetobacter baumannii Naval-18", "rank": "Strain"}, "70998": {"name": "Lewinella persica", "rank": "Species"}, "267890": {"name": "Shewanellaceae", "rank": "Family"}, "267891": {"name": "Moritellaceae", "rank": "Family"}, "267892": {"name": "Ferrimonadaceae", "rank": "Family"}, "267893": {"name": "Idiomarinaceae", "rank": "Family"}, "105487": {"name": "Valsa mali", "rank": "Species"}, "1267580": {"name": "Anoxybacillus flavithermus TNO-09.006", "rank": "Strain"}, "105483": {"name": "Desulfotomaculum alkaliphilum", "rank": "Species"}, "1032457": {"name": "Passion fruit mosaic virus", "rank": "Species"}, "1052004": {"name": "Granulibacter bethesdensis CGDNIH3", "rank": "Strain"}, "1569209": {"name": "Paracoccus sp. PAMC 22219", "rank": "Species"}, "358743": {"name": "Clostridium citroniae", "rank": "Species"}, "1217628": {"name": "Acinetobacter baumannii NIPH 70", "rank": "Strain"}, "1217629": {"name": "Acinetobacter baumannii NIPH 80", "rank": "Strain"}, "196093": {"name": "Tomato leaf curl Taiwan virus", "rank": "Species"}, "196095": {"name": "Velvet tobacco mottle virus Satellite RNA", "rank": "Species"}, "294934": {"name": "Streptococcus pyogenes M49 591", "rank": "Strain"}, "1310840": {"name": "Acinetobacter baumannii 24860_6", "rank": "Strain"}, "1310841": {"name": "Acinetobacter baumannii 24860_7", "rank": "Strain"}, "1310842": {"name": "Acinetobacter baumannii 24860_8", "rank": "Strain"}, "1310843": {"name": "Acinetobacter baumannii 24860_9", "rank": "Strain"}, "1310844": {"name": "Acinetobacter baumannii 24860_10", "rank": "Strain"}, "1310846": {"name": "Acinetobacter baumannii 24812_2", "rank": "Strain"}, "1310848": {"name": "Acinetobacter baumannii 24812_4", "rank": "Strain"}, "61624": {"name": "Paenibacillus mucilaginosus", "rank": "Species"}, "240492": {"name": "Tomato chino La Paz virus", "rank": "Species"}, "82135": {"name": "Atopobium vaginae", "rank": "Species"}, "1402578": {"name": "Pseudomonas aeruginosa C52", "rank": "Strain"}, "1402579": {"name": "Pseudomonas aeruginosa CF77", "rank": "Strain"}, "1051060": {"name": "Brucella abortus bv. 1 str. NI016", "rank": "Strain"}, "1051061": {"name": "Brucella abortus bv. 1 str. NI021", "rank": "Strain"}, "1051062": {"name": "Brucella abortus bv. 1 str. NI259", "rank": "Strain"}, "1402572": {"name": "Pseudomonas aeruginosa C20", "rank": "Strain"}, "1402573": {"name": "Pseudomonas aeruginosa C23", "rank": "Strain"}, "1379689": {"name": "Klebsiella pneumoniae subsp. pneumoniae T69", "rank": "Strain"}, "1379688": {"name": "Klebsiella pneumoniae subsp. pneumoniae SA1", "rank": "Strain"}, "1402576": {"name": "Pseudomonas aeruginosa C48", "rank": "Strain"}, "1402577": {"name": "Pseudomonas aeruginosa C51", "rank": "Strain"}, "1402574": {"name": "Pseudomonas aeruginosa C40", "rank": "Strain"}, "1402575": {"name": "Pseudomonas aeruginosa C41", "rank": "Strain"}, "1310157": {"name": "Bacillus subtilis subsp. subtilis str. MP9", "rank": "Strain"}, "215167": {"name": "Staphylococcus phage 3A", "rank": "Species"}, "487173": {"name": "Dialister succinatiphilus", "rank": "Species"}, "359919": {"name": "Spodoptera litura granulovirus", "rank": "Species"}, "1156722": {"name": "Halogeometricum pleomorphic virus 1", "rank": "Species"}, "1187894": {"name": "Clostridium phage PhiS63", "rank": "Species"}, "487175": {"name": "Parasutterella excrementihominis", "rank": "Species"}, "1310159": {"name": "Klebsiella pneumoniae Kb677", "rank": "Strain"}, "545619": {"name": "Paraoerskovia marina", "rank": "Species"}, "675120": {"name": "Dothistroma septosporum NZE10", "rank": "Strain"}, "60919": {"name": "Sanguibacter", "rank": "Genus"}, "566546": {"name": "Escherichia coli W", "rank": "Strain"}, "713949": {"name": "Tomato leaf curl Oman virus", "rank": "Species"}, "194949": {"name": "Stx2 converting phage II", "rank": "Species"}, "566549": {"name": "Corynebacterium matruchotii ATCC 33806", "rank": "Strain"}, "1280965": {"name": "Escherichia coli HVH 12 (4-7653042)", "rank": "Strain"}, "1280964": {"name": "Escherichia coli HVH 10 (4-6832164)", "rank": "Strain"}, "357544": {"name": "Helicobacter pylori HPAG1", "rank": "Strain"}, "1280966": {"name": "Escherichia coli HVH 13 (4-7634056)", "rank": "Strain"}, "1280961": {"name": "Escherichia coli HVH 6 (3-8296502)", "rank": "Strain"}, "1280960": {"name": "Escherichia coli HVH 5 (4-7148410)", "rank": "Strain"}, "1944": {"name": "Streptomyces halstedii", "rank": "Species"}, "1280962": {"name": "Escherichia coli HVH 7 (4-7315031)", "rank": "Strain"}, "38501": {"name": "Blastococcus", "rank": "Genus"}, "76594": {"name": "Cellulophaga baltica", "rank": "Species"}, "1280968": {"name": "Escherichia coli HVH 17 (4-7473087)", "rank": "Strain"}, "1169366": {"name": "Escherichia coli KTE88", "rank": "Strain"}, "317013": {"name": "Xanthomonas axonopodis pv. phaseoli", "rank": "Strain"}, "1169364": {"name": "Escherichia coli KTE85", "rank": "Strain"}, "1439181": {"name": "Streptococcus pyogenes ABC020048503", "rank": "Strain"}, "429572": {"name": "Sulfolobus islandicus L.S.2.15", "rank": "Strain"}, "1439183": {"name": "Streptococcus pyogenes ABC020048543", "rank": "Strain"}, "1433126": {"name": "Mucinivorans hirudinis", "rank": "Species"}, "1439185": {"name": "Streptococcus pyogenes ABC020048606", "rank": "Strain"}, "1439187": {"name": "Streptococcus pyogenes ABC020048885", "rank": "Strain"}, "1439188": {"name": "Streptococcus pyogenes ABC020049250", "rank": "Strain"}, "1433129": {"name": "Escherichia coli IS5", "rank": "Strain"}, "1236517": {"name": "Prevotella fusca JCM 17724", "rank": "Strain"}, "1579504": {"name": "Shewanella sp. ECSMB14102", "rank": "Species"}, "1216976": {"name": "Achromobacter xylosoxidans NBRC 15126 = ATCC 27061", "rank": "Strain"}, "580026": {"name": "Enterorhabdus mucosicola", "rank": "Species"}, "393480": {"name": "Fusobacterium nucleatum subsp. polymorphum ATCC 10953", "rank": "Strain"}, "213236": {"name": "Mycobacterium phage PG1", "rank": "Species"}, "765057": {"name": "Propionibacterium acnes HL096PA3", "rank": "Strain"}, "765058": {"name": "Propionibacterium acnes HL096PA2", "rank": "Strain"}, "535289": {"name": "Acidovorax ebreus TPSY", "rank": "Strain"}, "1195641": {"name": "Sida yellow mosaic China virus", "rank": "Species"}, "1094175": {"name": "Pseudomonas syringae pv. theae NCPPB 2598", "rank": "Strain"}, "1094174": {"name": "Xanthomonas vasicola pv. vasculorum NCPPB 1326", "rank": "Strain"}, "1094177": {"name": "Pseudomonas syringae pv. actinidiae KW41", "rank": "Strain"}, "1094176": {"name": "Pseudomonas syringae pv. actinidiae CFBP 7286", "rank": "Strain"}, "1094171": {"name": "Klebsiella pneumoniae subsp. pneumoniae KPNIH11", "rank": "Strain"}, "1094170": {"name": "Klebsiella pneumoniae subsp. pneumoniae KPNIH10", "rank": "Strain"}, "1126937": {"name": "Escherichia coli C9_92", "rank": "Strain"}, "1126936": {"name": "Escherichia coli C93_11", "rank": "Strain"}, "1126935": {"name": "Escherichia coli C900_01", "rank": "Strain"}, "1126934": {"name": "Escherichia coli C887_10", "rank": "Strain"}, "1126933": {"name": "Escherichia coli C87_11", "rank": "Strain"}, "1126932": {"name": "Escherichia coli C844_97", "rank": "Strain"}, "1126931": {"name": "Escherichia coli C842_97", "rank": "Strain"}, "1398949": {"name": "Acinetobacter baumannii UH10707", "rank": "Strain"}, "1398948": {"name": "Acinetobacter baumannii UH10107", "rank": "Strain"}, "504092": {"name": "Kushneria aurantia", "rank": "Species"}, "504090": {"name": "Kushneria", "rank": "Genus"}, "1398943": {"name": "Acinetobacter baumannii UH0207", "rank": "Strain"}, "1398945": {"name": "Acinetobacter baumannii UH0807", "rank": "Strain"}, "1398944": {"name": "Acinetobacter baumannii UH0707", "rank": "Strain"}, "1398947": {"name": "Acinetobacter baumannii UH10007", "rank": "Strain"}, "1398946": {"name": "Acinetobacter baumannii UH1007", "rank": "Strain"}, "1280380": {"name": "Synechococcus sp. KORDI-100", "rank": "Species"}, "622637": {"name": "Methylocystis sp. ATCC 49242", "rank": "Species"}, "1437113": {"name": "Campylobacter jejuni subsp. jejuni 81-176-UMCW9", "rank": "Strain"}, "85274": {"name": "Rhodovibrio", "rank": "Genus"}, "1017264": {"name": "Bordetella pertussis CS", "rank": "Strain"}, "1017266": {"name": "Lactococcus garvieae UNIUD074", "rank": "Strain"}, "140568": {"name": "Allexivirus", "rank": "Genus"}, "1534550": {"name": "Chicken gallivirus 1", "rank": "Species"}, "1408890": {"name": "Rhodobacter sp. CACIA14H1", "rank": "Species"}, "1408895": {"name": "Dill cryptic virus 1", "rank": "Species"}, "1408894": {"name": "Red clover cryptic virus 1", "rank": "Species"}, "405746": {"name": "Leisingera daeponensis", "rank": "Species"}, "1436999": {"name": "Burkholderia pseudomallei MSHR733", "rank": "Strain"}, "1418282": {"name": "Staphylococcus aureus F42556", "rank": "Strain"}, "335952": {"name": "Halococcus thailandensis", "rank": "Species"}, "48075": {"name": "Marinobacterium", "rank": "Genus"}, "48073": {"name": "Microbulbifer", "rank": "Genus"}, "1418289": {"name": "Staphylococcus aureus F48950", "rank": "Strain"}, "1423748": {"name": "Lactobacillus gallinarum DSM 10532 = JCM 2011", "rank": "Strain"}, "442954": {"name": "Knoellia aerolata", "rank": "Species"}, "70203": {"name": "Vibrio phage fs1", "rank": "Species"}, "1423747": {"name": "Lactobacillus fuchuensis DSM 14340 = JCM 11249", "rank": "Strain"}, "1423740": {"name": "Lactobacillus equi DSM 15833 = JCM 10991", "rank": "Strain"}, "1423743": {"name": "Lactobacillus farraginis DSM 18382 = JCM 14108", "rank": "Strain"}, "993517": {"name": "Rhodopirellula baltica SH28", "rank": "Strain"}, "141692": {"name": "Nocardiopsis halophila", "rank": "Species"}, "993513": {"name": "Escherichia coli cloneA_i1", "rank": "Strain"}, "993512": {"name": "Streptococcus suis A7", "rank": "Strain"}, "1256210": {"name": "Lactobacillus paracasei subsp. paracasei Lpp37", "rank": "Strain"}, "1256212": {"name": "Lactobacillus paracasei subsp. paracasei Lpp43", "rank": "Strain"}, "1256213": {"name": "Lactobacillus paracasei subsp. paracasei Lpp49", "rank": "Strain"}, "1256216": {"name": "Lactobacillus paracasei subsp. paracasei Lpp125", "rank": "Strain"}, "1448516": {"name": "Mycobacterium tuberculosis TKK_05MA_0051", "rank": "Strain"}, "1448517": {"name": "Mycobacterium tuberculosis TKK_05MA_0052", "rank": "Strain"}, "1448514": {"name": "Mycobacterium tuberculosis TKK_05MA_0048", "rank": "Strain"}, "1009710": {"name": "Gamma proteobacterium SCGC AAA536-J20", "rank": "Species"}, "1448512": {"name": "Mycobacterium tuberculosis TKK_05MA_0044", "rank": "Strain"}, "1448513": {"name": "Mycobacterium tuberculosis TKK_05MA_0046", "rank": "Strain"}, "1201032": {"name": "Campylobacter jejuni subsp. jejuni PT14", "rank": "Strain"}, "439386": {"name": "Sulfolobus islandicus Y.G.57.14", "rank": "Strain"}, "1201039": {"name": "Bacillus subtilis Hal1", "rank": "Strain"}, "1448519": {"name": "Mycobacterium tuberculosis TKK_05MA_0055", "rank": "Strain"}, "391619": {"name": "Phaeobacter inhibens DSM 17395", "rank": "Strain"}, "998429": {"name": "Rhodocyclaceae bacterium RZ94", "rank": "Species"}, "43759": {"name": "Streptomyces wedmorensis", "rank": "Species"}, "391613": {"name": "Roseovarius sp. TM1035", "rank": "Species"}, "391615": {"name": "Gamma proteobacterium HTCC5015", "rank": "Species"}, "391616": {"name": "Octadecabacter arcticus 238", "rank": "Strain"}, "856854": {"name": "Exiguobacterium sp. S17", "rank": "Species"}, "296141": {"name": "Chitinivibrionia", "rank": "Class"}, "1235473": {"name": "Vibrio cholerae CP1115", "rank": "Strain"}, "1347760": {"name": "Staphylococcus phage SA12", "rank": "Species"}, "1235479": {"name": "Pelosinus sp. HCF1", "rank": "Species"}, "1343075": {"name": "Acinetobacter baumannii CI77", "rank": "Strain"}, "1343074": {"name": "Acinetobacter baumannii CI79", "rank": "Strain"}, "1343077": {"name": "Candidatus Nasuia deltocephalinicola str. NAS-ALF", "rank": "Strain"}, "1343076": {"name": "Candidatus Sulcia muelleri str. Sulcia-ALF", "rank": "Strain"}, "1343071": {"name": "Acinetobacter nosocomialis M2", "rank": "Strain"}, "273057": {"name": "Sulfolobus solfataricus P2", "rank": "Strain"}, "1343072": {"name": "Acinetobacter baumannii CI86", "rank": "Strain"}, "1343079": {"name": "Burkholderia pseudomallei MSHR338", "rank": "Strain"}, "1343078": {"name": "Pseudomonas chlororaphis HT66", "rank": "Strain"}, "1354512": {"name": "Mycobacterium phage PhrostyMug", "rank": "Species"}, "935635": {"name": "Sigmapapillomavirus", "rank": "Genus"}, "575584": {"name": "Acinetobacter baumannii ATCC 19606 = CIP 70.34", "rank": "Strain"}, "575585": {"name": "Acinetobacter calcoaceticus RUH2202", "rank": "Strain"}, "575586": {"name": "Acinetobacter johnsonii SH046", "rank": "Strain"}, "575587": {"name": "Acinetobacter junii SH205", "rank": "Strain"}, "1428424": {"name": "Oenococcus oeni IOEB_C28", "rank": "Strain"}, "1428425": {"name": "Oenococcus oeni IOEB_C52", "rank": "Strain"}, "1428426": {"name": "Oenococcus oeni IOEB_CiNe", "rank": "Strain"}, "1428427": {"name": "Oenococcus oeni IOEB_L18_3", "rank": "Strain"}, "1428428": {"name": "Oenococcus oeni IOEB_L26_1", "rank": "Strain"}, "1428429": {"name": "Oenococcus oeni IOEB_L40_4", "rank": "Strain"}, "44746": {"name": "Holosporaceae", "rank": "Family"}, "44747": {"name": "Holospora", "rank": "Genus"}, "575588": {"name": "Acinetobacter lwoffii SH145", "rank": "Strain"}, "575589": {"name": "Acinetobacter radioresistens SH164", "rank": "Strain"}, "913025": {"name": "Thermococcus sp. PK", "rank": "Species"}, "1118959": {"name": "Staphylococcus aureus subsp. aureus M013", "rank": "Strain"}, "1094955": {"name": "Chitinophagaceae bacterium JGI 0001002-J12", "rank": "Species"}, "1094954": {"name": "Candidate division TM7 bacterium JGI 0001002-L20", "rank": "Species"}, "1094953": {"name": "Burkholderiales bacterium JGI 0001003-L21", "rank": "Species"}, "1094951": {"name": "Burkholderiales bacterium JGI 0001003-A5", "rank": "Species"}, "1206566": {"name": "Blueberry virus A", "rank": "Species"}, "1094959": {"name": "Intrasporangiaceae bacterium JGI 0001002-M5", "rank": "Species"}, "1094958": {"name": "Cytophagaceae bacterium JGI 0001001-B3", "rank": "Species"}, "93061": {"name": "Staphylococcus aureus subsp. aureus NCTC 8325", "rank": "Strain"}, "93060": {"name": "Prochlorococcus marinus str. MIT 9215", "rank": "Strain"}, "93062": {"name": "Staphylococcus aureus subsp. aureus COL", "rank": "Strain"}, "1120968": {"name": "Algoriphagus vanfongensis DSM 17529", "rank": "Strain"}, "1120969": {"name": "Aliagarivorans marinus DSM 23064", "rank": "Strain"}, "886721": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. CDC_2010K_1808", "rank": "Strain"}, "886720": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. CDC_2010K_1795", "rank": "Strain"}, "886723": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. CDC_2010K_0956", "rank": "Strain"}, "886722": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. CDC_2010K_1811", "rank": "Strain"}, "886725": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. CDC_2010K_1575", "rank": "Strain"}, "886724": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. CDC_2010K_1455", "rank": "Strain"}, "1120960": {"name": "Agromyces subbeticus DSM 16689", "rank": "Strain"}, "886726": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. CDC_2010K_1725", "rank": "Strain"}, "939637": {"name": "Gammaproteobacteria bacterium SCGC AAA003-E02", "rank": "Species"}, "10279": {"name": "Molluscum contagiosum virus", "rank": "Species"}, "10278": {"name": "Molluscipoxvirus", "rank": "Genus"}, "1047029": {"name": "Aminicenantes bacterium SCGC AAA252-L10", "rank": "Species"}, "1047028": {"name": "Aminicenantes bacterium SCGC AAA252-L02", "rank": "Species"}, "10275": {"name": "Suipoxvirus", "rank": "Genus"}, "1047026": {"name": "Aminicenantes bacterium SCGC AAA252-K07", "rank": "Species"}, "1047025": {"name": "Aminicenantes bacterium SCGC AAA252-J21", "rank": "Species"}, "10276": {"name": "Swinepox virus", "rank": "Species"}, "1047023": {"name": "Aminicenantes bacterium SCGC AAA252-J09", "rank": "Species"}, "10270": {"name": "Leporipoxvirus", "rank": "Genus"}, "10273": {"name": "Myxoma virus", "rank": "Species"}, "1047020": {"name": "Aminicenantes bacterium SCGC AAA252-G06", "rank": "Species"}, "931445": {"name": "Staphylococcus aureus subsp. aureus CIG1176", "rank": "Strain"}, "931444": {"name": "Staphylococcus aureus subsp. aureus CIG1150", "rank": "Strain"}, "931447": {"name": "Staphylococcus aureus subsp. aureus CIG1233", "rank": "Strain"}, "931446": {"name": "Staphylococcus aureus subsp. aureus CIG1213", "rank": "Strain"}, "931441": {"name": "Staphylococcus aureus subsp. aureus CIG1835", "rank": "Strain"}, "931440": {"name": "Staphylococcus aureus subsp. aureus CIG1769", "rank": "Strain"}, "931443": {"name": "Staphylococcus aureus subsp. aureus CIG1096", "rank": "Strain"}, "931442": {"name": "Staphylococcus aureus subsp. aureus CIG547", "rank": "Strain"}, "931449": {"name": "Staphylococcus aureus subsp. aureus CIG1770", "rank": "Strain"}, "931448": {"name": "Staphylococcus aureus subsp. aureus CIG1612", "rank": "Strain"}, "439481": {"name": "Aciduliprofundum boonei T469", "rank": "Strain"}, "1229908": {"name": "Candidatus Nitrosopumilus koreensis AR1", "rank": "Strain"}, "1229909": {"name": "Candidatus Nitrosopumilus sp. AR2", "rank": "Species"}, "1229903": {"name": "Brucella canis 118", "rank": "Strain"}, "1229906": {"name": "Brucella melitensis bv. 1 str. 133", "rank": "Strain"}, "134623": {"name": "Opitutaceae", "rank": "Family"}, "1229904": {"name": "Brucella melitensis bv. 3 str. 128", "rank": "Strain"}, "134621": {"name": "Verrucomicrobia subdivision 3", "rank": "Family"}, "1121901": {"name": "Flavobacterium tegetincola DSM 22377", "rank": "Strain"}, "1422199": {"name": "Staphylococcus aureus DAR3924", "rank": "Strain"}, "1337936": {"name": "Calothrix sp. 336/3", "rank": "Species"}, "1073388": {"name": "Bacteroides fragilis HMW 616", "rank": "Strain"}, "891974": {"name": "Plautia stali symbiont", "rank": "Species"}, "360313": {"name": "Ochrobactrum sp. CDB2", "rank": "Species"}, "1073385": {"name": "Aeromonas veronii AMC35", "rank": "Strain"}, "1422191": {"name": "Staphylococcus aureus DAR3897", "rank": "Strain"}, "686660": {"name": "Veillonella parvula ATCC 17745", "rank": "Strain"}, "10852": {"name": "Spiromicrovirus", "rank": "Genus"}, "10855": {"name": "Spiroplasma phage 4", "rank": "Species"}, "10854": {"name": "Spiroplasma phage 1-R8A2B", "rank": "Species"}, "10857": {"name": "Chlamydia phage 1", "rank": "Species"}, "1422197": {"name": "Staphylococcus aureus DAR3918", "rank": "Strain"}, "1422195": {"name": "Staphylococcus aureus DAR3911", "rank": "Strain"}, "11102": {"name": "Hepacivirus", "rank": "Genus"}, "11103": {"name": "Hepatitis C virus", "rank": "Species"}, "948595": {"name": "Vavraia culicis subsp. floridensis", "rank": "Subspecies"}, "1541445": {"name": "Candidatus Phaeomarinobacter", "rank": "Genus"}, "12360": {"name": "Staphylococcus phage 11", "rank": "Species"}, "1333865": {"name": "Streptococcus tigurinus 2426", "rank": "Strain"}, "1333864": {"name": "Streptococcus tigurinus 2425", "rank": "Strain"}, "1333863": {"name": "Paenibacillus polymyxa 1-43", "rank": "Strain"}, "693582": {"name": "Pseudomonas phage phi-2", "rank": "Species"}, "1249975": {"name": "Gillisia sp. Hel_I_29", "rank": "Species"}, "1249972": {"name": "Cellulophaga sp. Hel_I_12", "rank": "Species"}, "1422134": {"name": "Staphylococcus aureus DAR3578", "rank": "Strain"}, "1422135": {"name": "Staphylococcus aureus DAR3581", "rank": "Strain"}, "106654": {"name": "Acinetobacter nosocomialis", "rank": "Species"}, "1422137": {"name": "Staphylococcus aureus DAR3584", "rank": "Strain"}, "1422130": {"name": "Staphylococcus aureus DAR3567", "rank": "Strain"}, "1422131": {"name": "Staphylococcus aureus DAR3574", "rank": "Strain"}, "898": {"name": "Desulfomicrobium", "rank": "Genus"}, "899": {"name": "Desulfomicrobium baculatum", "rank": "Species"}, "896": {"name": "Desulfococcus", "rank": "Genus"}, "897": {"name": "Desulfococcus multivorans", "rank": "Species"}, "894": {"name": "Desulfobulbus propionicus", "rank": "Species"}, "1422138": {"name": "Staphylococcus aureus DAR3586", "rank": "Strain"}, "893": {"name": "Desulfobulbus", "rank": "Genus"}, "890": {"name": "Desulfuromonas", "rank": "Genus"}, "891": {"name": "Desulfuromonas acetoxidans", "rank": "Species"}, "1441466": {"name": "Staphylococcus aureus subsp. aureus AMRF1", "rank": "Strain"}, "28031": {"name": "Lysinibacillus fusiformis", "rank": "Species"}, "28033": {"name": "Sulfobacillus", "rank": "Genus"}, "28034": {"name": "Sulfobacillus thermosulfidooxidans", "rank": "Species"}, "28035": {"name": "Staphylococcus lugdunensis", "rank": "Species"}, "28037": {"name": "Streptococcus mitis", "rank": "Species"}, "241425": {"name": "Crinalium epipsammum", "rank": "Species"}, "1048757": {"name": "Candidatus Moranella", "rank": "Genus"}, "241421": {"name": "Crinalium", "rank": "Genus"}, "246432": {"name": "Staphylococcus equorum", "rank": "Species"}, "1580605": {"name": "Phomopsis vexans RNA virus", "rank": "Species"}, "1580607": {"name": "Magnaporthe oryzae RNA virus", "rank": "Species"}, "1580606": {"name": "Alternaria brassicicola endornavirus", "rank": "Species"}, "1100720": {"name": "Limnohabitans sp. Rim28", "rank": "Species"}, "1100721": {"name": "Limnohabitans sp. Rim47", "rank": "Species"}, "385025": {"name": "Cycloclasticus sp. P1", "rank": "Species"}, "1219013": {"name": "Rhodococcus equi NBRC 101255 = C 7", "rank": "Strain"}, "1219015": {"name": "Rhodococcus fascians NBRC 12155 = LMG 3623", "rank": "Strain"}, "410289": {"name": "Mycobacterium bovis BCG str. Pasteur 1173P2", "rank": "Strain"}, "528321": {"name": "Mycobacterium phage Adjutor", "rank": "Species"}, "1122143": {"name": "Lacticigenium naphtae DSM 19658", "rank": "Strain"}, "1122146": {"name": "Lactobacillus ceti DSM 22408", "rank": "Strain"}, "1122147": {"name": "Lactobacillus harbinensis DSM 16991", "rank": "Strain"}, "869669": {"name": "Escherichia coli 1.2741", "rank": "Strain"}, "869662": {"name": "Synechococcus phage S-RIM2 R1_1999", "rank": "Strain"}, "168694": {"name": "Salinispora", "rank": "Genus"}, "168695": {"name": "Salinispora tropica", "rank": "Species"}, "407392": {"name": "Thermus phage phiYS40", "rank": "Species"}, "318464": {"name": "Clostridium sulfidigenes", "rank": "Species"}, "455227": {"name": "Staphylococcus aureus D30", "rank": "Strain"}, "287535": {"name": "Balneola vulgaris", "rank": "Species"}, "300695": {"name": "Unclassified Alteromonadales", "rank": "No rank"}, "1422035": {"name": "Mycobacterium tuberculosis TB_RSA119", "rank": "Strain"}, "1396": {"name": "Bacillus cereus", "rank": "Species"}, "349370": {"name": "Starling circovirus", "rank": "Species"}, "663610": {"name": "Methylocapsa aurea", "rank": "Species"}, "1080187": {"name": "Cupriavidus sp. UYPR2.512", "rank": "Species"}, "1357399": {"name": "Helicobacter canis NCTC 12740", "rank": "Strain"}, "1357398": {"name": "Fusobacterium nucleatum 13_3C", "rank": "Strain"}, "1116108": {"name": "Escherichia coli 178900", "rank": "Strain"}, "1159038": {"name": "Helicobacter pylori GAM249T", "rank": "Strain"}, "1159039": {"name": "Helicobacter pylori GAM250AFi", "rank": "Strain"}, "373409": {"name": "Mycobacterium phage Orion", "rank": "Species"}, "373408": {"name": "Mycobacterium phage Llij", "rank": "Species"}, "200938": {"name": "Chrysiogenetes", "rank": "Phylum"}, "1513193": {"name": "Dipteran brevidensovirus 1", "rank": "Species"}, "200930": {"name": "Deferribacteres", "rank": "Phylum"}, "373404": {"name": "Mycobacterium phage Catera", "rank": "Species"}, "373407": {"name": "Mycobacterium phage Halo", "rank": "Species"}, "373406": {"name": "Mycobacterium phage Cooper", "rank": "Species"}, "1159034": {"name": "Helicobacter pylori GAM239Bi", "rank": "Strain"}, "340095": {"name": "Thermodesulfovibrio thiophilus", "rank": "Species"}, "340096": {"name": "Tuberibacillus", "rank": "Genus"}, "1159035": {"name": "Helicobacter pylori GAM244Ai", "rank": "Strain"}, "83461": {"name": "Corallococcus", "rank": "Genus"}, "83463": {"name": "Unclassified Myxococcales", "rank": "No rank"}, "1444099": {"name": "Escherichia coli 2-427-07_S1_C3", "rank": "Strain"}, "157018": {"name": "Scallion mosaic virus", "rank": "Species"}, "157019": {"name": "Unclassified Potyviridae", "rank": "No rank"}, "868138": {"name": "Escherichia coli DEC2A", "rank": "Strain"}, "868139": {"name": "Escherichia coli DEC2B", "rank": "Strain"}, "33925": {"name": "Entomoplasmataceae", "rank": "Family"}, "868131": {"name": "Methanobacterium paludis", "rank": "Species"}, "868133": {"name": "Escherichia coli DEC1A", "rank": "Strain"}, "868134": {"name": "Escherichia coli DEC1B", "rank": "Strain"}, "868135": {"name": "Escherichia coli DEC1C", "rank": "Strain"}, "868136": {"name": "Escherichia coli DEC1D", "rank": "Strain"}, "868137": {"name": "Escherichia coli DEC1E", "rank": "Strain"}, "309788": {"name": "Lysinibacillus boronitolerans", "rank": "Species"}, "525325": {"name": "Lactobacillus fermentum ATCC 14931", "rank": "Strain"}, "525326": {"name": "Lactobacillus gasseri JV-V03", "rank": "Strain"}, "490193": {"name": "Synechococcus sp. NKBG042902", "rank": "Species"}, "525329": {"name": "Lactobacillus jensenii JV-V16", "rank": "Strain"}, "525328": {"name": "Lactobacillus iners DSM 13335", "rank": "Strain"}, "169679": {"name": "Clostridium saccharobutylicum", "rank": "Species"}, "627087": {"name": "Enterococcus phage EFAP-1", "rank": "Species"}, "129725": {"name": "Foveavirus", "rank": "Genus"}, "1495314": {"name": "Methanoculleus sp. MH98A", "rank": "Species"}, "129727": {"name": "Bovine papular stomatitis virus", "rank": "Species"}, "129726": {"name": "Pseudocowpox virus", "rank": "Species"}, "626934": {"name": "Slackia piriformis", "rank": "Species"}, "626935": {"name": "Collinsella tanakaei", "rank": "Species"}, "1495315": {"name": "Bacillus subtilis subsp. niger", "rank": "Subspecies"}, "1341165": {"name": "Flavobacterium enshiense", "rank": "Species"}, "626931": {"name": "Bacteroides oleiciplenus", "rank": "Species"}, "626932": {"name": "Alistipes indistinctus", "rank": "Species"}, "165779": {"name": "Anaerococcus", "rank": "Genus"}, "626938": {"name": "Succinatimonas hippei", "rank": "Species"}, "518603": {"name": "Ureaplasma urealyticum serovar 5 str. ATCC 27817", "rank": "Strain"}, "283942": {"name": "Idiomarina loihiensis L2TR", "rank": "Strain"}, "1075091": {"name": "Clostridium sporogenes PA 3679", "rank": "Strain"}, "1075090": {"name": "Gordonia amarae NBRC 15530", "rank": "Strain"}, "148880": {"name": "Discula destructiva virus 1", "rank": "Species"}, "591946": {"name": "Escherichia coli LF82", "rank": "Strain"}, "536466": {"name": "Synechococcus phage S-SSM4", "rank": "Species"}, "45258": {"name": "Rickettsia conorii subsp. israelensis", "rank": "Subspecies"}, "1438723": {"name": "Klebsiella pneumoniae CHS 17", "rank": "Strain"}, "1438720": {"name": "Klebsiella pneumoniae CHS 14", "rank": "Strain"}, "1523503": {"name": "Pseudomonas sp. ML96", "rank": "Species"}, "868280": {"name": "Salinivibrio socompensis S10B", "rank": "Strain"}, "298338": {"name": "Lactobacillus phage LP65", "rank": "Species"}, "996839": {"name": "Leptospira interrogans serovar Copenhageni str. Fiocruz LV2832", "rank": "Strain"}, "996838": {"name": "Leptospira interrogans serovar Copenhageni str. Fiocruz LV2825", "rank": "Strain"}, "996837": {"name": "Leptospira interrogans serovar Copenhageni str. Fiocruz LV2812", "rank": "Strain"}, "996836": {"name": "Leptospira interrogans serovar Copenhageni str. Fiocruz LV2811", "rank": "Strain"}, "996835": {"name": "Leptospira interrogans serovar Copenhageni str. Fiocruz LV2806", "rank": "Strain"}, "996834": {"name": "Leptospira interrogans serovar Copenhageni str. Fiocruz LV2805", "rank": "Strain"}, "996833": {"name": "Leptospira interrogans serovar Copenhageni str. Fiocruz LV2804", "rank": "Strain"}, "996832": {"name": "Leptospira interrogans serovar Copenhageni str. Fiocruz LV2799", "rank": "Strain"}, "996831": {"name": "Leptospira interrogans serovar Copenhageni str. Fiocruz LV2791", "rank": "Strain"}, "996830": {"name": "Leptospira interrogans serovar Copenhageni str. Fiocruz LV2790", "rank": "Strain"}, "1074058": {"name": "Streptococcus sobrinus TCI-54", "rank": "Strain"}, "1036963": {"name": "Apodemus sylvaticus papillomavirus 1", "rank": "Species"}, "1438724": {"name": "Klebsiella pneumoniae CHS 18", "rank": "Strain"}, "1036964": {"name": "Mus musculus papillomavirus 1", "rank": "Species"}, "1074052": {"name": "Streptococcus sobrinus TCI-9", "rank": "Strain"}, "1074053": {"name": "Streptococcus sobrinus TCI-13", "rank": "Strain"}, "1074054": {"name": "Streptococcus sobrinus TCI-16", "rank": "Strain"}, "1074056": {"name": "Streptococcus sobrinus TCI-50", "rank": "Strain"}, "1074057": {"name": "Streptococcus sobrinus TCI-53", "rank": "Strain"}, "384848": {"name": "Corynebacterium phage P1201", "rank": "Species"}, "1397928": {"name": "Mycobacterium tuberculosis TKK_04_0034", "rank": "Strain"}, "1397929": {"name": "Mycobacterium tuberculosis TKK_04_0036", "rank": "Strain"}, "1397926": {"name": "Mycobacterium tuberculosis TKK_04_0013", "rank": "Strain"}, "1397927": {"name": "Mycobacterium tuberculosis TKK_04_0020", "rank": "Strain"}, "1397924": {"name": "Mycobacterium tuberculosis TKK_04_0007", "rank": "Strain"}, "1397925": {"name": "Mycobacterium tuberculosis TKK_04_0008", "rank": "Strain"}, "1397922": {"name": "Mycobacterium tuberculosis TKK_04_0048", "rank": "Strain"}, "1397923": {"name": "Mycobacterium tuberculosis TKK_04_0005", "rank": "Strain"}, "1397920": {"name": "Mycobacterium tuberculosis TKK_04_0043", "rank": "Strain"}, "1397921": {"name": "Mycobacterium tuberculosis TKK_04_0047", "rank": "Strain"}, "1452537": {"name": "Microbacterium sp. Cr-K1W", "rank": "Species"}, "1452536": {"name": "Microbacterium sp. Cr-K20", "rank": "Species"}, "1452535": {"name": "Microbacterium sp. Cr-K32", "rank": "Species"}, "1452534": {"name": "Microbacterium sp. Cr-K29", "rank": "Species"}, "384035": {"name": "Wolbachia endosymbiont of Drosophila willistoni TSC#14030-0811.24", "rank": "Strain"}, "294369": {"name": "Solenopsis invicta virus-1", "rank": "Species"}, "294365": {"name": "Israeli acute paralysis virus", "rank": "Species"}, "85708": {"name": "Porcine circovirus-2", "rank": "Species"}, "1511133": {"name": "Candidate division TM6 bacterium Zodletone_IIa", "rank": "Species"}, "205880": {"name": "Mycobacterium phage Barnyard", "rank": "Species"}, "85701": {"name": "Bartonella tribocorum", "rank": "Species"}, "1422739": {"name": "Staphylococcus aureus VET1901R", "rank": "Strain"}, "271417": {"name": "Aeromonas molluscorum", "rank": "Species"}, "1294266": {"name": "Coxiella burnetii Cb175_Guyana", "rank": "Strain"}, "57483": {"name": "European bat lyssavirus 2", "rank": "Species"}, "1590649": {"name": "Avipolyomavirus group", "rank": "No rank"}, "57481": {"name": "Thermoanaerobacter mathranii subsp. mathranii", "rank": "Subspecies"}, "57480": {"name": "Microvirgula aerodenitrificans", "rank": "Species"}, "57487": {"name": "Thermotoga hypogea", "rank": "Species"}, "1448597": {"name": "Mycobacterium tuberculosis TKK_04_0140", "rank": "Strain"}, "1160719": {"name": "Propionibacterium granulosum DSM 20700", "rank": "Strain"}, "1235275": {"name": "Staphylococcus aureus PPUKM-261-2009", "rank": "Strain"}, "1235277": {"name": "Staphylococcus aureus PPUKM-377-2009", "rank": "Strain"}, "1511868": {"name": "Carnivore bocaparvovirus 3", "rank": "Species"}, "459957": {"name": "Swan circovirus", "rank": "Species"}, "1511861": {"name": "Amalgavirus", "rank": "No rank"}, "1511860": {"name": "Amalgaviridae", "rank": "Family"}, "1235279": {"name": "Bhargavaea cecembensis DSE10", "rank": "Strain"}, "1511866": {"name": "Carnivore bocaparvovirus 1", "rank": "Species"}, "1511865": {"name": "Galliform aveparvovirus 1", "rank": "Species"}, "1511864": {"name": "Aveparvovirus", "rank": "Genus"}, "1418351": {"name": "Staphylococcus aureus T66632", "rank": "Strain"}, "1418350": {"name": "Staphylococcus aureus T66622", "rank": "Strain"}, "1418353": {"name": "Staphylococcus aureus T83543", "rank": "Strain"}, "1418352": {"name": "Staphylococcus aureus T70161", "rank": "Strain"}, "1418355": {"name": "Staphylococcus aureus T86825", "rank": "Strain"}, "1418354": {"name": "Staphylococcus aureus T83563", "rank": "Strain"}, "1151418": {"name": "Peptoclostridium difficile P36", "rank": "Strain"}, "1151419": {"name": "Peptoclostridium difficile P37", "rank": "Strain"}, "1418359": {"name": "Staphylococcus aureus W25814", "rank": "Strain"}, "1418358": {"name": "Staphylococcus aureus W25787", "rank": "Strain"}, "1151414": {"name": "Peptoclostridium difficile P32", "rank": "Strain"}, "1151415": {"name": "Peptoclostridium difficile P33", "rank": "Strain"}, "1151412": {"name": "Peptoclostridium difficile P30", "rank": "Strain"}, "760861": {"name": "Streptococcus pneumoniae GA47901", "rank": "Strain"}, "557722": {"name": "Pseudomonas aeruginosa LESB58", "rank": "Strain"}, "557723": {"name": "Haemophilus parasuis SH0165", "rank": "Strain"}, "227387": {"name": "Thermodesulfobiaceae", "rank": "Family"}, "159087": {"name": "Dechloromonas aromatica RCB", "rank": "Strain"}, "69277": {"name": "Phyllobacteriaceae", "rank": "Family"}, "481009": {"name": "Rickettsia philipii str. 364D", "rank": "Strain"}, "69278": {"name": "Aquamicrobium", "rank": "Genus"}, "1154899": {"name": "Streptococcus agalactiae GB00084", "rank": "Strain"}, "661367": {"name": "Legionella longbeachae NSW150", "rank": "Strain"}, "1294274": {"name": "Streptococcus equinus JB1", "rank": "Strain"}, "1404258": {"name": "Bacillus subtilis subsp. subtilis str. OH 131.1", "rank": "Strain"}, "1393736": {"name": "Photorhabdus luminescens BA1", "rank": "Strain"}, "1393735": {"name": "Photorhabdus temperata subsp. temperata Meg1", "rank": "Strain"}, "1393734": {"name": "Staphylococcus aureus M0771", "rank": "Strain"}, "1393733": {"name": "Staphylococcus aureus M0768", "rank": "Strain"}, "1393732": {"name": "Staphylococcus aureus M0767", "rank": "Strain"}, "1393731": {"name": "Staphylococcus aureus M0766", "rank": "Strain"}, "1393730": {"name": "Staphylococcus aureus M0765", "rank": "Strain"}, "1154898": {"name": "Streptococcus agalactiae GB00083", "rank": "Strain"}, "1352289": {"name": "Clostera anastomosis granulovirus", "rank": "Species"}, "1289135": {"name": "Brachyspira hampsonii 30446", "rank": "Strain"}, "1215114": {"name": "Pseudomonas parafulva NBRC 16636", "rank": "Strain"}, "1215115": {"name": "Pseudomonas plecoglossicida NBRC 103162 = DSM 15088", "rank": "Strain"}, "1214148": {"name": "Streptococcus suis 11611", "rank": "Strain"}, "1214149": {"name": "Streptococcus suis 07SC3", "rank": "Strain"}, "1317118": {"name": "Roseivivax atlanticus", "rank": "Species"}, "1400181": {"name": "Klebsiella pneumoniae UCI 38", "rank": "Strain"}, "548912": {"name": "Unclassified Proboscivirus", "rank": "No rank"}, "1400183": {"name": "Klebsiella pneumoniae UCI 42", "rank": "Strain"}, "1400182": {"name": "Klebsiella pneumoniae UCI 41", "rank": "Strain"}, "1400185": {"name": "Klebsiella pneumoniae UCI 44", "rank": "Strain"}, "1400184": {"name": "Klebsiella pneumoniae UCI 43", "rank": "Strain"}, "1400187": {"name": "Serratia marcescens BIDMC 50", "rank": "Strain"}, "1400186": {"name": "Serratia marcescens BIDMC 44", "rank": "Strain"}, "743525": {"name": "Thermus scotoductus SA-01", "rank": "Strain"}, "1427304": {"name": "Mycobacterium tuberculosis XTB13-233", "rank": "Strain"}, "359337": {"name": "Marinimicrobium", "rank": "Genus"}, "359336": {"name": "Castellaniella", "rank": "Genus"}, "359335": {"name": "Strawberry lethal yellows phytoplasma (CPA)", "rank": "Strain"}, "1053250": {"name": "Bacillus cereus VDM062", "rank": "Strain"}, "520466": {"name": "Brucella melitensis bv. 3 str. Ether", "rank": "Strain"}, "1350000": {"name": "Unclassified Megrivirus", "rank": "No rank"}, "347814": {"name": "Unclassified Orthopoxvirus", "rank": "No rank"}, "477666": {"name": "Bacteroides graminisolvens", "rank": "Species"}, "1388333": {"name": "Staphylococcus aureus M0503", "rank": "Strain"}, "1427200": {"name": "Mycobacterium tuberculosis XTB13-108", "rank": "Strain"}, "1427203": {"name": "Mycobacterium tuberculosis XTB13-111", "rank": "Strain"}, "1427202": {"name": "Mycobacterium tuberculosis XTB13-110", "rank": "Strain"}, "1427205": {"name": "Mycobacterium tuberculosis XTB13-113", "rank": "Strain"}, "1388336": {"name": "Staphylococcus aureus M0508", "rank": "Strain"}, "1388335": {"name": "Staphylococcus aureus M0506", "rank": "Strain"}, "1427206": {"name": "Mycobacterium tuberculosis XTB13-114", "rank": "Strain"}, "1427209": {"name": "Mycobacterium tuberculosis XTB13-117", "rank": "Strain"}, "1427208": {"name": "Mycobacterium tuberculosis XTB13-116", "rank": "Strain"}, "1388339": {"name": "Staphylococcus aureus M0514", "rank": "Strain"}, "1388338": {"name": "Staphylococcus aureus M0512", "rank": "Strain"}, "1143190": {"name": "Brucella melitensis 16M1W", "rank": "Strain"}, "1143191": {"name": "Brucella melitensis 16M13W", "rank": "Strain"}, "1217098": {"name": "Jiangellineae", "rank": "Suborder"}, "1283285": {"name": "Pseudomonas sp. URIL14HWK12:I7", "rank": "Species"}, "1283284": {"name": "Tolumonas sp. BRL6-1", "rank": "Species"}, "1283287": {"name": "Nocardioides sp. Iso805N", "rank": "Species"}, "1283286": {"name": "Gillisia sp. JM1", "rank": "Species"}, "1283280": {"name": "Lactococcus lactis subsp. lactis bv. diacetylactis str. TIFN4", "rank": "Strain"}, "1283283": {"name": "Frankia sp. Iso899", "rank": "Species"}, "1283282": {"name": "Pseudomonas sp. URIL14HWK12:I4", "rank": "Species"}, "1245591": {"name": "Mariniradius saccharolyticus", "rank": "Species"}, "1245590": {"name": "Mariniradius", "rank": "Genus"}, "1091495": {"name": "Taylorella asinigenitalis 14/45", "rank": "Strain"}, "1280956": {"name": "Escherichia coli HVH 1 (4-6876161)", "rank": "Strain"}, "1091497": {"name": "Taylorella equigenitalis 14/56", "rank": "Strain"}, "586425": {"name": "Senecavirus", "rank": "Genus"}, "1338032": {"name": "Vibrio parahaemolyticus O1:K33 str. CDC_K4557", "rank": "Strain"}, "997827": {"name": "Peptoclostridium difficile 002-P50-2011", "rank": "Strain"}, "1217418": {"name": "Cupriavidus sp. HPC(L)", "rank": "Species"}, "1575": {"name": "Leifsonia xyli", "rank": "Species"}, "997824": {"name": "Escherichia coli O157:H7 str. 1044", "rank": "Strain"}, "1573": {"name": "Clavibacter", "rank": "Genus"}, "1571": {"name": "Sporosarcina ureae", "rank": "Species"}, "1570": {"name": "Halobacillus halophilus", "rank": "Species"}, "544448": {"name": "Tenericutes", "rank": "Phylum"}, "1367456": {"name": "Pantoea ananatis DAR 76143", "rank": "Strain"}, "1367451": {"name": "Pseudomonas fuscovaginae ICMP 5940", "rank": "Strain"}, "1579": {"name": "Lactobacillus acidophilus", "rank": "Species"}, "1578": {"name": "Lactobacillus", "rank": "Genus"}, "1198013": {"name": "Aeromonas phage Aes508", "rank": "Species"}, "1198014": {"name": "Aeromonas phage Aes012", "rank": "Species"}, "135842": {"name": "Buchnera aphidicola (Baizongia pistaciae)", "rank": "Strain"}, "1206769": {"name": "Oenococcus oeni AWRIB418", "rank": "Strain"}, "1217689": {"name": "Acinetobacter pittii ANC 4052", "rank": "Strain"}, "1206767": {"name": "Desulfovibrio magneticus str. Maddingley MBC34", "rank": "Strain"}, "86661": {"name": "Bacillus cereus group", "rank": "Species group"}, "1521392": {"name": "McMurdo Ice Shelf pond-associated circular DNA virus-8", "rank": "Species"}, "360911": {"name": "Exiguobacterium sp. AT1b", "rank": "Species"}, "86662": {"name": "Bacillus weihenstephanensis", "rank": "Species"}, "86665": {"name": "Bacillus halodurans", "rank": "Species"}, "86664": {"name": "Bacillus flexus", "rank": "Species"}, "86668": {"name": "Bacillus niacini", "rank": "Species"}, "1041930": {"name": "Methanocella conradii HZ254", "rank": "Strain"}, "1521390": {"name": "McMurdo Ice Shelf pond-associated circular DNA virus-6", "rank": "Species"}, "1287296": {"name": "Mesorhizobium sp. LSHC424B00", "rank": "Species"}, "1521391": {"name": "McMurdo Ice Shelf pond-associated circular DNA virus-7", "rank": "Species"}, "278028": {"name": "Naumovozyma", "rank": "Genus"}, "685588": {"name": "Galerina marginata CBS 339.88", "rank": "Strain"}, "1287294": {"name": "Mesorhizobium sp. LSHC422A00", "rank": "Species"}, "1124913": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 442692 2-5", "rank": "Strain"}, "1124912": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 442692 2-4", "rank": "Strain"}, "1124911": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 409753-6", "rank": "Strain"}, "1124910": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 620239", "rank": "Strain"}, "1124917": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 460004 2-1", "rank": "Strain"}, "1124916": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 460004 1-1", "rank": "Strain"}, "1124915": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 447967 2-1", "rank": "Strain"}, "1124914": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 447967 1-1", "rank": "Strain"}, "1124919": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 632182-2", "rank": "Strain"}, "1124918": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 339787", "rank": "Strain"}, "1158543": {"name": "Enterococcus faecium EnGen0255", "rank": "Strain"}, "1158542": {"name": "Enterococcus faecalis EnGen0232", "rank": "Strain"}, "1158541": {"name": "Enterococcus faecium EnGen0254", "rank": "Strain"}, "1158540": {"name": "Enterococcus faecalis EnGen0253", "rank": "Strain"}, "1158547": {"name": "Enterococcus faecium EnGen0258", "rank": "Strain"}, "1041939": {"name": "Prochlorococcus marinus bv. HNLC2", "rank": "Strain"}, "1158545": {"name": "Enterococcus faecium EnGen0257", "rank": "Strain"}, "1158544": {"name": "Enterococcus faecium EnGen0256", "rank": "Strain"}, "1158549": {"name": "Enterococcus faecium EnGen0260", "rank": "Strain"}, "904778": {"name": "Staphylococcus aureus subsp. aureus IS-88", "rank": "Strain"}, "1150775": {"name": "Agrobacterium sp. 10MFCol1.1", "rank": "Species"}, "1051347": {"name": "Escherichia coli 3.4880", "rank": "Strain"}, "1051346": {"name": "Escherichia coli 95.0083", "rank": "Strain"}, "1051349": {"name": "Escherichia coli PA11", "rank": "Strain"}, "1051348": {"name": "Escherichia coli 7.1982", "rank": "Strain"}, "1121895": {"name": "Flavobacterium rivuli WB 3.3-2 = DSM 21788", "rank": "Strain"}, "1121897": {"name": "Flavobacterium soli DSM 19725", "rank": "Strain"}, "1121896": {"name": "Flavobacterium sasangense DSM 21067", "rank": "Strain"}, "1121891": {"name": "Flavobacterium gelidilacus DSM 15343", "rank": "Strain"}, "1121890": {"name": "Flavobacterium frigidarium DSM 17623", "rank": "Strain"}, "386": {"name": "Rhizobium leguminosarum bv. trifolii", "rank": "Strain"}, "1121899": {"name": "Flavobacterium suncheonense GH29-5 = DSM 17707", "rank": "Strain"}, "1121898": {"name": "Flavobacterium subsaxonicum WB 4.1-42 = DSM 21790", "rank": "Strain"}, "387": {"name": "Rhizobium leguminosarum bv. viciae", "rank": "Strain"}, "1154894": {"name": "Streptococcus agalactiae GB00013", "rank": "Strain"}, "1218708": {"name": "Penicillium chrysogenum KF-25", "rank": "Strain"}, "907931": {"name": "Leuconostoc fallax KCTC 3537", "rank": "Strain"}, "47716": {"name": "Streptomyces olivaceus", "rank": "Species"}, "47714": {"name": "Lactobacillus paracasei subsp. paracasei", "rank": "Subspecies"}, "47715": {"name": "Lactobacillus rhamnosus", "rank": "Species"}, "1116233": {"name": "Acinetobacter baumannii AB4857", "rank": "Strain"}, "1116232": {"name": "Streptomyces acidiscabies 84-104", "rank": "Strain"}, "1116231": {"name": "Streptococcus macedonicus ACA-DC 198", "rank": "Strain"}, "1116230": {"name": "Wolbachia pipientis wAlbB", "rank": "Strain"}, "100715": {"name": "Chloroherpeton", "rank": "Genus"}, "1116236": {"name": "Acinetobacter baumannii AB5711", "rank": "Strain"}, "1116235": {"name": "Acinetobacter baumannii AB5256", "rank": "Strain"}, "1116234": {"name": "Acinetobacter baumannii AB5075", "rank": "Strain"}, "1325371": {"name": "Edwardsiella phage PEi2", "rank": "Species"}, "333931": {"name": "Gammapapillomavirus 5", "rank": "Species"}, "1249484": {"name": "Leptospira interrogans serovar Copenhageni str. M20", "rank": "Strain"}, "333933": {"name": "Primate papillomaviruses", "rank": "No rank"}, "1249481": {"name": "Brachybacterium muris UCD-AY4", "rank": "Strain"}, "1249480": {"name": "Candidatus Sulfuricurvum sp. RIFRC-1", "rank": "Species"}, "1249483": {"name": "Leptospira yanagawae serovar Saopaulo str. Sao Paulo = ATCC 700523", "rank": "Strain"}, "333938": {"name": "Non-primate mammal papillomaviruses", "rank": "No rank"}, "137555": {"name": "Unclassified Tombusviridae", "rank": "No rank"}, "137556": {"name": "Maize necrotic streak virus", "rank": "Species"}, "984894": {"name": "Chlamydia psittaci Cal10", "rank": "Strain"}, "1155385": {"name": "Proteiniclasticum", "rank": "Genus"}, "1315182": {"name": "Acinetobacter baumannii TG27395", "rank": "Strain"}, "1315183": {"name": "Acinetobacter baumannii TG27399", "rank": "Strain"}, "1315180": {"name": "Acinetobacter baumannii TG27387", "rank": "Strain"}, "1315181": {"name": "Acinetobacter baumannii TG27391", "rank": "Strain"}, "1315184": {"name": "Acinetobacter baumannii TG27407", "rank": "Strain"}, "1315185": {"name": "Acinetobacter baumannii TG27411", "rank": "Strain"}, "768672": {"name": "Desulfurococcus fermentans DSM 16532", "rank": "Strain"}, "63745": {"name": "Sideroxydans lithotrophicus", "rank": "Species"}, "63743": {"name": "Natronomonas", "rank": "Genus"}, "63742": {"name": "Natrialba", "rank": "Genus"}, "5010": {"name": "Taphrina", "rank": "Genus"}, "5011": {"name": "Taphrina deformans", "rank": "Species"}, "1421967": {"name": "Mycobacterium tuberculosis TB_RSA51", "rank": "Strain"}, "5014": {"name": "Dothideales", "rank": "Order"}, "12162": {"name": "Citrus tristeza virus", "rank": "Species"}, "5016": {"name": "Bipolaris maydis", "rank": "Species"}, "12160": {"name": "Closterovirus", "rank": "Genus"}, "266068": {"name": "Rickettsia sibirica subgroup", "rank": "Species subgroup"}, "119602": {"name": "Streptococcus dysgalactiae subsp. equisimilis", "rank": "Subspecies"}, "12169": {"name": "Potato virus S", "rank": "Species"}, "255531": {"name": "Rickettsiales genera incertae sedis", "rank": "No rank"}, "1329895": {"name": "Novosphingobium lindaniclasticum", "rank": "Species"}, "62654": {"name": "SAR116 cluster", "rank": "No rank"}, "680277": {"name": "Phieco32likevirus", "rank": "Genus"}, "1329899": {"name": "Cycloclasticus zancles", "rank": "Species"}, "1422338": {"name": "Staphylococcus aureus DAR5836", "rank": "Strain"}, "1422339": {"name": "Staphylococcus aureus DAR5835", "rank": "Strain"}, "1422332": {"name": "Staphylococcus aureus DAR5843", "rank": "Strain"}, "1422333": {"name": "Staphylococcus aureus DAR5841", "rank": "Strain"}, "1422330": {"name": "Staphylococcus aureus DAR5846", "rank": "Strain"}, "1422331": {"name": "Staphylococcus aureus DAR5845", "rank": "Strain"}, "1422336": {"name": "Staphylococcus aureus DAR5838", "rank": "Strain"}, "1422337": {"name": "Staphylococcus aureus DAR5837", "rank": "Strain"}, "1422334": {"name": "Staphylococcus aureus DAR5840", "rank": "Strain"}, "1422335": {"name": "Staphylococcus aureus DAR5839", "rank": "Strain"}, "338903": {"name": "Capra hircus papillomavirus 1", "rank": "Strain"}, "1243621": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20110356", "rank": "Strain"}, "77763": {"name": "Banna virus", "rank": "Species"}, "509193": {"name": "Thermoanaerobacter brockii subsp. finnii Ako-1", "rank": "Strain"}, "77768": {"name": "Prevotella albensis", "rank": "Species"}, "244365": {"name": "Methylohalobius crimeensis", "rank": "Species"}, "354585": {"name": "Candidatus Rickettsia gravesii", "rank": "Species"}, "1331220": {"name": "Bordetella bronchiseptica MBORD595", "rank": "Strain"}, "1156800": {"name": "Aeromonas dhakensis AAK1", "rank": "Strain"}, "1333716": {"name": "Schleiferia", "rank": "Genus"}, "1333713": {"name": "Schleiferiaceae", "rank": "Family"}, "1412875": {"name": "Lactococcus phage phiL47", "rank": "Species"}, "244366": {"name": "Klebsiella variicola", "rank": "Species"}, "1286640": {"name": "Sinorhizobium meliloti 2011", "rank": "Strain"}, "1233951": {"name": "Epilithonimonas sp. FH1", "rank": "Species"}, "1331224": {"name": "Bordetella bronchiseptica MBORD665", "rank": "Strain"}, "1328859": {"name": "Escherichia coli O157:H7 str. SS17", "rank": "Strain"}, "1160705": {"name": "Streptomyces viridochromogenes Tue57", "rank": "Strain"}, "1160702": {"name": "Oenococcus oeni AWRIB304", "rank": "Strain"}, "1331227": {"name": "Bordetella bronchiseptica MBORD675", "rank": "Strain"}, "543538": {"name": "Staphylococcus aureus subsp. aureus CGS00", "rank": "Strain"}, "1331226": {"name": "Bordetella bronchiseptica MBORD670", "rank": "Strain"}, "390846": {"name": "Echinicola", "rank": "Genus"}, "390844": {"name": "Culex flavivirus", "rank": "Species"}, "172278": {"name": "Chilli leaf curl virus", "rank": "Species"}, "52769": {"name": "Actinomyces gerencseriae", "rank": "Species"}, "52768": {"name": "Actinomyces georgiae", "rank": "Species"}, "390841": {"name": "Lactobacillus farraginis", "rank": "Species"}, "52765": {"name": "Caldicellulosiruptor kristjanssonii", "rank": "Species"}, "52764": {"name": "Bartonella alsatica", "rank": "Species"}, "52766": {"name": "Caldicellulosiruptor lactoaceticus", "rank": "Species"}, "1240350": {"name": "Pseudomonas putida MTCC 5279", "rank": "Strain"}, "261591": {"name": "Bacillus anthracis str. Vollum", "rank": "Strain"}, "56688": {"name": "Halorubrum", "rank": "Genus"}, "438482": {"name": "Synechococcus phage Syn5", "rank": "Species"}, "228582": {"name": "Cereal yellow dwarf virus-RPS", "rank": "Species"}, "228581": {"name": "Barley yellow dwarf virus-PAS", "rank": "Species"}, "1145143": {"name": "Neisseria meningitidis NM606", "rank": "Strain"}, "932040": {"name": "Actinobacterium SCGC AAA027-J17", "rank": "Species"}, "932041": {"name": "Actinobacterium SCGC AAA027-M14", "rank": "Species"}, "932042": {"name": "Actinobacterium SCGC AAA041-L13", "rank": "Species"}, "932043": {"name": "Actinobacterium SCGC AAA044-N04", "rank": "Species"}, "932044": {"name": "Actinobacterium SCGC AAA278-O22", "rank": "Species"}, "55085": {"name": "Streptococcus thoraltensis", "rank": "Species"}, "55080": {"name": "Brevibacillus", "rank": "Genus"}, "263578": {"name": "Tomato leaf curl Java virus-Ageratum satellite DNA", "rank": "Strain"}, "1151187": {"name": "Enterococcus faecalis EnGen0062", "rank": "Strain"}, "743040": {"name": "Tomato leaf curl Cameroon alphasatellite", "rank": "Species"}, "1138452": {"name": "Bacillus megaterium NCT-2", "rank": "Strain"}, "1441628": {"name": "Leptospirillum ferriphilum YSK", "rank": "Strain"}, "1095923": {"name": "Stenotrophomonas maltophilia RR-10", "rank": "Strain"}, "1175306": {"name": "Herbaspirillum sp. GW103", "rank": "Species"}, "53010": {"name": "Cotton leaf curl virus", "rank": "Species"}, "44930": {"name": "Natronobacterium gregoryi", "rank": "Species"}, "697024": {"name": "Unclassified Corynebacterineae", "rank": "No rank"}, "1122179": {"name": "Lewinella persica DSM 23188", "rank": "Strain"}, "1071779": {"name": "Chlamydia trachomatis L2b/Ams2", "rank": "Strain"}, "1071776": {"name": "Chlamydia trachomatis L2b/CV204", "rank": "Strain"}, "1122176": {"name": "Lewinella cohaerens DSM 23179", "rank": "Strain"}, "1071774": {"name": "Chlamydia trachomatis L2b/UCH-2", "rank": "Strain"}, "1122174": {"name": "Leptotrichia wadei DSM 19758", "rank": "Strain"}, "1071772": {"name": "Chlamydia trachomatis L2/25667R", "rank": "Strain"}, "1122172": {"name": "Leptotrichia shahii DSM 19757", "rank": "Strain"}, "1071770": {"name": "Chlamydia trachomatis L1/115", "rank": "Strain"}, "1122170": {"name": "Legionella wadsworthii DSM 21896 = ATCC 33877", "rank": "Strain"}, "1240687": {"name": "Leptospira kirschneri serovar Bulgarica str. Nikolaevo", "rank": "Strain"}, "1240688": {"name": "Leptospira kirschneri serovar Bim str. PUO 1247", "rank": "Strain"}, "1346330": {"name": "Sphingobacterium paucimobilis HER1398", "rank": "Strain"}, "73780": {"name": "Methylocaldum szegediense", "rank": "Species"}, "1224747": {"name": "Acinetobacter baumannii AC30", "rank": "Strain"}, "1224746": {"name": "Gluconobacter oxydans H24", "rank": "Strain"}, "1224744": {"name": "Methylococcus capsulatus str. Texas = ATCC 19069", "rank": "Strain"}, "1224743": {"name": "Vibrio rotiferianus CAIM 577 = LMG 21460", "rank": "Strain"}, "1224742": {"name": "Vibrio campbellii CAIM 519 = NBRC 15631", "rank": "Strain"}, "1224749": {"name": "Exiguobacterium sp. ZWU0009", "rank": "Species"}, "1224748": {"name": "Bacillus isronensis B3W22", "rank": "Strain"}, "447599": {"name": "Papaya leaf curl China betasatellite", "rank": "Species"}, "447598": {"name": "Mimosa yellow leaf curl virus-associated DNA 1", "rank": "Species"}, "243365": {"name": "Chromobacterium violaceum ATCC 12472", "rank": "Strain"}, "463800": {"name": "Kwoniella mangrovensis", "rank": "Species"}, "447597": {"name": "Sida yellow vein Vietnam alphasatellite", "rank": "Species"}, "446462": {"name": "Actinosynnema mirum DSM 43827", "rank": "Strain"}, "446466": {"name": "Cellulomonas flavigena DSM 20109", "rank": "Strain"}, "446465": {"name": "Brachybacterium faecium DSM 4810", "rank": "Strain"}, "446468": {"name": "Nocardiopsis dassonvillei subsp. dassonvillei DSM 43111", "rank": "Strain"}, "446469": {"name": "Sanguibacter keddieii DSM 10542", "rank": "Strain"}, "156614": {"name": "Environmental samples", "rank": "No rank"}, "10868": {"name": "Enterobacteria phage If1", "rank": "Species"}, "206041": {"name": "Flavobacterium gelidilacus", "rank": "Species"}, "981325": {"name": "Acinetobacter genomosp. 13TU str. NCTC 8102", "rank": "Strain"}, "391009": {"name": "Thermosipho melanesiensis BI429", "rank": "Strain"}, "391008": {"name": "Stenotrophomonas maltophilia R551-3", "rank": "Strain"}, "412384": {"name": "Bacillus aryabhattai", "rank": "Species"}, "904749": {"name": "Staphylococcus aureus subsp. aureus 21269", "rank": "Strain"}, "491080": {"name": "Treponema pallidum subsp. pertenue str. Gauthier", "rank": "Strain"}, "412383": {"name": "Bacillus isronensis", "rank": "Species"}, "1121406": {"name": "Desulfocurvus vexinensis DSM 17965", "rank": "Strain"}, "904743": {"name": "Staphylococcus aureus subsp. aureus 21252", "rank": "Strain"}, "1121404": {"name": "Desulfobulbus mediterraneus DSM 13871", "rank": "Strain"}, "1121405": {"name": "Desulfococcus multivorans DSM 2059", "rank": "Strain"}, "1121402": {"name": "Desulfobulbus elongatus DSM 2908", "rank": "Strain"}, "1121403": {"name": "Desulfobulbus japonicus DSM 18378", "rank": "Strain"}, "904744": {"name": "Staphylococcus aureus subsp. aureus 21259", "rank": "Strain"}, "904745": {"name": "Staphylococcus aureus subsp. aureus 21262", "rank": "Strain"}, "1515618": {"name": "Porphyromonas sp. UQD_349_COT-052_OH4946", "rank": "Species"}, "185955": {"name": "Hibiscus latent Singapore virus", "rank": "Species"}, "1515614": {"name": "Porphyromonas sp. COT-108 OH2963", "rank": "Species"}, "1515615": {"name": "Porphyromonas sp. COT-290 OH860", "rank": "Species"}, "1515617": {"name": "Porphyromonas sp. COT-290 OH3588", "rank": "Species"}, "1515610": {"name": "Prauserella sp. Am3", "rank": "Species"}, "1515612": {"name": "Sphingopyxis sp. Kp5.2", "rank": "Species"}, "1515613": {"name": "Porphyromonas sp. COT-239 OH1446", "rank": "Species"}, "1388544": {"name": "Staphylococcus aureus M0139", "rank": "Strain"}, "29552": {"name": "Acholeplasma axanthum", "rank": "Species"}, "1181779": {"name": "Escherichia coli KTE235", "rank": "Strain"}, "165826": {"name": "Melon chlorotic leaf curl virus", "rank": "Species"}, "29555": {"name": "Mycoplasma canis", "rank": "Species"}, "29557": {"name": "Mycoplasma gallinarum", "rank": "Species"}, "1181772": {"name": "Escherichia coli KTE226", "rank": "Strain"}, "1181773": {"name": "Escherichia coli KTE227", "rank": "Strain"}, "1181770": {"name": "Escherichia coli KTE224", "rank": "Strain"}, "1181771": {"name": "Escherichia coli KTE225", "rank": "Strain"}, "1181776": {"name": "Escherichia coli KTE230", "rank": "Strain"}, "1181777": {"name": "Escherichia coli KTE233", "rank": "Strain"}, "1181774": {"name": "Escherichia coli KTE228", "rank": "Strain"}, "1181775": {"name": "Escherichia coli KTE229", "rank": "Strain"}, "1388540": {"name": "Staphylococcus aureus M0352", "rank": "Strain"}, "78540": {"name": "Sleeping disease virus", "rank": "Strain"}, "1388541": {"name": "Staphylococcus aureus M0365", "rank": "Strain"}, "1388542": {"name": "Staphylococcus aureus M0121", "rank": "Strain"}, "1274413": {"name": "Chloroflexi bacterium JGI 0002000-F10", "rank": "Species"}, "1310579": {"name": "Acinetobacter baumannii 58452", "rank": "Strain"}, "452982": {"name": "Roseomonas aerilata", "rank": "Species"}, "50338": {"name": "Rhizobium sullae", "rank": "Species"}, "50339": {"name": "Thermoplasma volcanium", "rank": "Species"}, "414715": {"name": "Actinospica", "rank": "Genus"}, "414714": {"name": "Catenulisporineae", "rank": "Suborder"}, "414713": {"name": "Actinospicaceae", "rank": "Family"}, "451866": {"name": "Taphrinomycotina", "rank": "Subphylum"}, "451867": {"name": "Dothideomycetidae", "rank": "Subclass"}, "451864": {"name": "Dikarya", "rank": "Subkingdom"}, "451868": {"name": "Pleosporomycetidae", "rank": "Subclass"}, "1388549": {"name": "Staphylococcus aureus M0195", "rank": "Strain"}, "536453": {"name": "Prochlorococcus phage P-SSM3", "rank": "Species"}, "1293914": {"name": "Brucella ovis IntaBari-2010-47-268", "rank": "Strain"}, "526978": {"name": "Bacillus cereus BDRD-Cer4", "rank": "Strain"}, "526975": {"name": "Bacillus cereus BDRD-ST26", "rank": "Strain"}, "526974": {"name": "Bacillus cereus BDRD-ST24", "rank": "Strain"}, "526977": {"name": "Bacillus cereus ATCC 4342", "rank": "Strain"}, "526976": {"name": "Bacillus cereus BDRD-ST196", "rank": "Strain"}, "526971": {"name": "Bacillus cereus MM3", "rank": "Strain"}, "526970": {"name": "Bacillus cereus BGSC 6E1", "rank": "Strain"}, "526973": {"name": "Bacillus cereus m1293", "rank": "Strain"}, "526972": {"name": "Bacillus cereus AH621", "rank": "Strain"}, "384638": {"name": "Bacteroides pectinophilus", "rank": "Species"}, "595460": {"name": "Rhodopirellula sp. SWK7", "rank": "Species"}, "558169": {"name": "Lentibacillus jeotgali", "rank": "Species"}, "204773": {"name": "Herminiimonas arsenicoxydans", "rank": "Species"}, "598494": {"name": "Euphorbia yellow mosaic virus", "rank": "Species"}, "658612": {"name": "Pseudomonas sp. H2", "rank": "Species"}, "1422071": {"name": "Mycobacterium tuberculosis TB_RSA155", "rank": "Strain"}, "1422070": {"name": "Mycobacterium tuberculosis TB_RSA154", "rank": "Strain"}, "1422073": {"name": "Mycobacterium tuberculosis TB_RSA157", "rank": "Strain"}, "1422072": {"name": "Mycobacterium tuberculosis TB_RSA156", "rank": "Strain"}, "1422075": {"name": "Mycobacterium tuberculosis TB_RSA159", "rank": "Strain"}, "1422074": {"name": "Mycobacterium tuberculosis TB_RSA158", "rank": "Strain"}, "1422077": {"name": "Mycobacterium tuberculosis TB_RSA161", "rank": "Strain"}, "1422076": {"name": "Mycobacterium tuberculosis TB_RSA160", "rank": "Strain"}, "1422079": {"name": "Mycobacterium tuberculosis TB_RSA163", "rank": "Strain"}, "1422078": {"name": "Mycobacterium tuberculosis TB_RSA162", "rank": "Strain"}, "171558": {"name": "Unclassified Bacteroidetes", "rank": "No rank"}, "33898": {"name": "Streptomyces galbus", "rank": "Species"}, "33892": {"name": "Mycobacterium bovis BCG", "rank": "Strain"}, "33894": {"name": "Mycobacterium africanum", "rank": "Species"}, "1265313": {"name": "Haliea rubra DSM 19751", "rank": "Strain"}, "1265312": {"name": "Mycobacterium neoaurum ATCC 25795", "rank": "Strain"}, "1265310": {"name": "Mycobacterium asiaticum DSM 44297", "rank": "Strain"}, "1224926": {"name": "Staphylococcus aureus M0279", "rank": "Strain"}, "1413437": {"name": "Staphylococcus aureus 1111206270", "rank": "Strain"}, "991955": {"name": "Vibrio cholerae HC-28A1", "rank": "Strain"}, "991954": {"name": "Vibrio cholerae HC-22A1", "rank": "Strain"}, "991957": {"name": "Vibrio cholerae HC-33A2", "rank": "Strain"}, "991956": {"name": "Vibrio cholerae HC-32A1", "rank": "Strain"}, "991951": {"name": "Vibrio cholerae HC-17A1", "rank": "Strain"}, "991950": {"name": "Vibrio cholerae HC-06A1", "rank": "Strain"}, "991953": {"name": "Vibrio cholerae HC-21A1", "rank": "Strain"}, "991952": {"name": "Vibrio cholerae HC-19A1", "rank": "Strain"}, "1463811": {"name": "Mycobacterium phage Hosp", "rank": "Species"}, "1463812": {"name": "Mycobacterium phage Jolie1", "rank": "Species"}, "991959": {"name": "Vibrio cholerae HC-38A1", "rank": "Strain"}, "991958": {"name": "Vibrio cholerae HC-37A1", "rank": "Strain"}, "1463817": {"name": "Fulmarus glacialis papillomavirus 1", "rank": "Species"}, "417288": {"name": "Crassocephalum yellow vein virus - Jinghong", "rank": "Strain"}, "1413433": {"name": "Staphylococcus aureus 1111102620", "rank": "Strain"}, "553151": {"name": "Pseudomonas pelagia", "rank": "Species"}, "417280": {"name": "Burkholderia phage BcepF1", "rank": "Species"}, "866630": {"name": "Haemophilus influenzae F3031", "rank": "Strain"}, "1224920": {"name": "Staphylococcus aureus M0171", "rank": "Strain"}, "417287": {"name": "Crassocephalum yellow vein virus", "rank": "Species"}, "1292047": {"name": "Desulfobulbus sp. oral taxon 041 str. Dsb2", "rank": "Strain"}, "1292046": {"name": "Desulfobulbus sp. oral taxon 041 str. Dsb1-5", "rank": "Strain"}, "1292040": {"name": "Helicobacter pylori CG-IMSS-2012", "rank": "Strain"}, "1292043": {"name": "Bacillus flexus 27Col1.1E", "rank": "Strain"}, "1292042": {"name": "Arthrobacter nicotinovorans 26Cvi1.1E", "rank": "Strain"}, "1157399": {"name": "Enterococcus faecalis EnGen0213", "rank": "Strain"}, "1292048": {"name": "Desulfobulbus sp. oral taxon 041 str. Dsb3", "rank": "Strain"}, "2037": {"name": "Actinomycetales", "rank": "Order"}, "2035": {"name": "Curtobacterium flaccumfaciens", "rank": "Species"}, "2034": {"name": "Curtobacterium", "rank": "Genus"}, "2033": {"name": "Microbacterium testaceum", "rank": "Species"}, "2039": {"name": "Tropheryma whipplei", "rank": "Species"}, "2038": {"name": "Tropheryma", "rank": "Genus"}, "387344": {"name": "Lactobacillus brevis ATCC 367", "rank": "Strain"}, "387341": {"name": "Halovivax ruber", "rank": "Species"}, "387343": {"name": "Halopiger xanaduensis", "rank": "Species"}, "1281224": {"name": "Escherichia coli UMEA 3222-1", "rank": "Strain"}, "1157398": {"name": "Enterococcus faecalis EnGen0212", "rank": "Strain"}, "1281227": {"name": "Escherichia coli UMEA 3240-1", "rank": "Strain"}, "64363": {"name": "Mycosphaerella pini", "rank": "Species"}, "1409440": {"name": "Staphylococcus aureus AMMC6072", "rank": "Strain"}, "1281221": {"name": "Escherichia coli UMEA 3217-1", "rank": "Strain"}, "303682": {"name": "Thauera sp. 28", "rank": "Species"}, "381754": {"name": "Pseudomonas aeruginosa PA7", "rank": "Strain"}, "1281220": {"name": "Escherichia coli UMEA 3216-1", "rank": "Strain"}, "1409445": {"name": "Staphylococcus aureus LAMC0047", "rank": "Strain"}, "287478": {"name": "Hellea balneolensis", "rank": "Species"}, "1281222": {"name": "Escherichia coli UMEA 3220-1", "rank": "Strain"}, "45972": {"name": "Staphylococcus pasteuri", "rank": "Species"}, "1552409": {"name": "Sea otter polyomavirus 1", "rank": "Species"}, "656025": {"name": "Gossypium darwinii symptomless alphasatellite", "rank": "Species"}, "656024": {"name": "Frankia symbiont of Datisca glomerata", "rank": "Species"}, "656026": {"name": "Gossypium mustilinum symptomless alphasatellite", "rank": "Species"}, "656028": {"name": "Gossypium davidsonii symptomless alphasatellite", "rank": "Species"}, "1513256": {"name": "Gammapapillomavirus 11", "rank": "Species"}, "1513257": {"name": "Gammapapillomavirus 12", "rank": "Species"}, "1513254": {"name": "Dyosigmapapillomavirus 1", "rank": "Species"}, "1513255": {"name": "Dyoxipapillomavirus 1", "rank": "Species"}, "1513252": {"name": "Dyopipapillomavirus 1", "rank": "Species"}, "1513253": {"name": "Dyorhopapillomavirus 1", "rank": "Species"}, "1513250": {"name": "Dyonupapillomavirus 1", "rank": "Species"}, "1513251": {"name": "Dyoomikronpapillomavirus 1", "rank": "Species"}, "420684": {"name": "Pumpkin yellow mosaic Malaysia virus", "rank": "Strain"}, "1074213": {"name": "Mouse kobuvirus M-5/USA/2010", "rank": "Species"}, "1513258": {"name": "Gammapapillomavirus 13", "rank": "Species"}, "1513259": {"name": "Gammapapillomavirus 14", "rank": "Species"}, "305677": {"name": "Chimpanzee polyomavirus", "rank": "Species"}, "305676": {"name": "Deerpox virus W-1170-84", "rank": "Species"}, "305674": {"name": "Deerpox virus W-848-83", "rank": "Species"}, "1380359": {"name": "Pseudoalteromonas sp. 6BO_GOM-1096m", "rank": "Species"}, "1380358": {"name": "Halomonas sp. 23_GOM-1509m", "rank": "Species"}, "1380355": {"name": "Bradyrhizobium sp. URHD0069", "rank": "Species"}, "1380354": {"name": "Cellulomonas sp. URHE0023", "rank": "Species"}, "1380356": {"name": "Blastococcus sp. URHD0036", "rank": "Species"}, "1380351": {"name": "Mesorhizobium sp. URHB0007", "rank": "Species"}, "1380350": {"name": "Mesorhizobium sp. URHC0008", "rank": "Species"}, "1380353": {"name": "Geodermatophilaceae bacterium URHB0062", "rank": "Species"}, "1380352": {"name": "Bradyrhizobium sp. URHA0013", "rank": "Species"}, "1367213": {"name": "Streptococcus pneumoniae WL400", "rank": "Strain"}, "1367212": {"name": "Clostridium cellulosi CS-4-4", "rank": "Strain"}, "1367211": {"name": "Streptococcus pneumoniae B605", "rank": "Strain"}, "1367214": {"name": "Streptococcus pneumoniae WL677", "rank": "Strain"}, "1281195": {"name": "Escherichia coli UMEA 3152-1", "rank": "Strain"}, "1771": {"name": "Mycobacterium phlei", "rank": "Species"}, "1770": {"name": "Mycobacterium avium subsp. paratuberculosis", "rank": "Subspecies"}, "1773": {"name": "Mycobacterium tuberculosis", "rank": "Species"}, "1772": {"name": "Mycobacterium smegmatis", "rank": "Species"}, "1774": {"name": "Mycobacterium chelonae", "rank": "Species"}, "1422580": {"name": "Staphylococcus aureus VET0315R", "rank": "Strain"}, "1281194": {"name": "Escherichia coli UMEA 3151-1", "rank": "Strain"}, "362865": {"name": "Sandarakinorhabdus", "rank": "Genus"}, "1335322": {"name": "Mycobacterium sp. MAC_080597_8934", "rank": "Species"}, "206324": {"name": "Gymnopus luxurians", "rank": "Species"}, "1291365": {"name": "Leptospira interrogans str. Fiocruz LV4117", "rank": "Strain"}, "1291364": {"name": "Leptospira interrogans str. Fiocruz LV4114", "rank": "Strain"}, "941765": {"name": "Tuber aestivum endornavirus", "rank": "Species"}, "1291366": {"name": "Leptospira interrogans str. Fiocruz LV4225", "rank": "Strain"}, "1291361": {"name": "Leptospira interrogans serovar Naam str. Naam", "rank": "Strain"}, "1291360": {"name": "Leptospira interrogans serovar Pomona str. 2006006968", "rank": "Strain"}, "1291363": {"name": "Leptospira interrogans serovar Manilae str. K56", "rank": "Strain"}, "1291362": {"name": "Leptospira interrogans serovar Manilae str. UP-OM", "rank": "Strain"}, "470704": {"name": "Cladophialophora yegresii", "rank": "Species"}, "1104605": {"name": "Armatimonadetes bacterium JGI 0000077-K19", "rank": "Species"}, "1104604": {"name": "Atribacteria bacterium JGI 0000079-F20", "rank": "Species"}, "1104607": {"name": "Microgenomates bacterium SCGC AAA011-A19", "rank": "Species"}, "1104601": {"name": "Atribacteria bacterium SCGC AB-164-A22", "rank": "Species"}, "1104600": {"name": "Atribacteria bacterium SCGC AB-164-M20", "rank": "Species"}, "1104603": {"name": "Atribacteria bacterium JGI 0000079-L04", "rank": "Species"}, "1104602": {"name": "Atribacteria bacterium JGI 0000014-F07", "rank": "Species"}, "1104609": {"name": "Microgenomates bacterium SCGC AAA011-M05", "rank": "Species"}, "476281": {"name": "Candidatus Ishikawaella capsulata Mpkobe", "rank": "Strain"}, "476282": {"name": "Bradyrhizobium japonicum SEMIA 5079", "rank": "Strain"}, "993034": {"name": "Mavirus", "rank": "Species"}, "191768": {"name": "Plesiocystis pacifica", "rank": "Species"}, "191767": {"name": "Plesiocystis", "rank": "Genus"}, "943945": {"name": "Mycoplasma fermentans M64", "rank": "Strain"}, "1303729": {"name": "Leptospira borgpetersenii serovar Hardjo-bovis str. Sponselee", "rank": "Strain"}, "1236047": {"name": "Culex originated Tymoviridae-like virus", "rank": "Species"}, "1236046": {"name": "Mesotoga infera", "rank": "Species"}, "538998": {"name": "Pasteuriaceae", "rank": "Family"}, "538999": {"name": "Clostridiales incertae sedis", "rank": "No rank"}, "1115834": {"name": "Methylophilus sp. 42", "rank": "Species"}, "1115835": {"name": "Methylotenera versatilis 79", "rank": "Strain"}, "1115830": {"name": "Streptococcus pyogenes GA16797", "rank": "Strain"}, "1307759": {"name": "Desulfovibrio sp. L21-Syr-AB", "rank": "Species"}, "479106": {"name": "Arthrobacter sanguinis", "rank": "Species"}, "909210": {"name": "Simian adenovirus 18", "rank": "Species"}, "757418": {"name": "Mycobacterium tuberculosis H37RvMA", "rank": "Strain"}, "757419": {"name": "Mycobacterium tuberculosis H37RvCO", "rank": "Strain"}, "1130284": {"name": "Aenigmarchaeota archaeon JGI 0000106-F11", "rank": "Species"}, "1130285": {"name": "Aigarchaeota archaeon JGI 0000106-J15", "rank": "Species"}, "1418444": {"name": "Staphylococcus aureus W89579", "rank": "Strain"}, "757417": {"name": "Mycobacterium tuberculosis H37RvAE", "rank": "Strain"}, "482957": {"name": "Burkholderia lata", "rank": "Species"}, "291027": {"name": "Unclassified Begomovirus", "rank": "No rank"}, "409316": {"name": "Halorubrum litoreum", "rank": "Species"}, "78245": {"name": "Xanthobacter autotrophicus Py2", "rank": "Strain"}, "1454202": {"name": "Photobacterium phosphoreum ANT220", "rank": "Strain"}, "1293051": {"name": "Afipia sp. OHSU_II-uncloned", "rank": "Species"}, "946483": {"name": "Candidatus Symbiobacter mobilis CR", "rank": "Strain"}, "310783": {"name": "Deinococcus deserti", "rank": "Species"}, "1210520": {"name": "Francisella tularensis subsp. tularensis 80700075", "rank": "Strain"}, "1210521": {"name": "Francisella tularensis subsp. tularensis 831", "rank": "Strain"}, "1210522": {"name": "Francisella tularensis subsp. tularensis AS_713", "rank": "Strain"}, "1448389": {"name": "Tomitella biformata AHU 1821", "rank": "Strain"}, "1212567": {"name": "Shigella boydii S6614", "rank": "Strain"}, "1394691": {"name": "Vibrio parahaemolyticus S158", "rank": "Strain"}, "1394692": {"name": "Vibrio parahaemolyticus S159", "rank": "Strain"}, "1394694": {"name": "Vibrio parahaemolyticus S161", "rank": "Strain"}, "945689": {"name": "Xylella fastidiosa EB92.1", "rank": "Strain"}, "1212565": {"name": "Shigella dysenteriae S6554", "rank": "Strain"}, "945681": {"name": "Acetobacter pomorum DM001", "rank": "Strain"}, "197614": {"name": "Streptococcus pasteurianus", "rank": "Species"}, "1281199": {"name": "Escherichia coli UMEA 3161-1", "rank": "Strain"}, "181798": {"name": "Salmonella enterica subsp. enterica serovar Sloterdijk", "rank": "Strain"}, "1406974": {"name": "Pseudomonas phage TL", "rank": "Species"}, "142864": {"name": "Cylindrospermum stagnale", "rank": "Species"}, "1281198": {"name": "Escherichia coli UMEA 3160-1", "rank": "Strain"}, "670483": {"name": "Gloeophyllum trabeum ATCC 11539", "rank": "Strain"}, "327275": {"name": "Shewanella sp. HN-41", "rank": "Species"}, "670487": {"name": "Oceanithermus profundus DSM 14977", "rank": "Strain"}, "670486": {"name": "Dehalogenimonas", "rank": "Genus"}, "1328": {"name": "Streptococcus anginosus", "rank": "Species"}, "1329": {"name": "Streptococcus canis", "rank": "Species"}, "1435480": {"name": "Staphylococcus aureus MUF168", "rank": "Strain"}, "1435481": {"name": "Staphylococcus aureus MUM270", "rank": "Strain"}, "1435482": {"name": "Staphylococcus aureus MUM475", "rank": "Strain"}, "1435483": {"name": "Staphylococcus aureus MUF256", "rank": "Strain"}, "1322": {"name": "Blautia hansenii", "rank": "Species"}, "1323": {"name": "Faecalicoccus pleomorphus", "rank": "Species"}, "925986": {"name": "Erwinia phage phiEa104", "rank": "Strain"}, "712976": {"name": "Lachnospiraceae bacterium oral taxon 082", "rank": "Species"}, "1195163": {"name": "Amazon lily mild mottle virus", "rank": "Species"}, "685778": {"name": "Sphingomonas sp. PR090111-T3T-6A", "rank": "Species"}, "189423": {"name": "Streptococcus pneumoniae 670-6B", "rank": "Strain"}, "189425": {"name": "Paenibacillus graminis", "rank": "Species"}, "796392": {"name": "Escherichia coli MS 79-10", "rank": "Strain"}, "1448817": {"name": "Mycobacterium tuberculosis H3033", "rank": "Strain"}, "1448816": {"name": "Mycobacterium tuberculosis H3005", "rank": "Strain"}, "1448815": {"name": "Mycobacterium tuberculosis H3004", "rank": "Strain"}, "1448814": {"name": "Mycobacterium tuberculosis H2760", "rank": "Strain"}, "1448813": {"name": "Mycobacterium tuberculosis H2438", "rank": "Strain"}, "1448812": {"name": "Mycobacterium tuberculosis H2300", "rank": "Strain"}, "1448811": {"name": "Mycobacterium tuberculosis H2102", "rank": "Strain"}, "1448810": {"name": "Mycobacterium tuberculosis H2101", "rank": "Strain"}, "101358": {"name": "Unclassified rotaviruses", "rank": "No rank"}, "1448819": {"name": "Mycobacterium tuberculosis H3361", "rank": "Strain"}, "1448818": {"name": "Mycobacterium tuberculosis H3360", "rank": "Strain"}, "977913": {"name": "Santeuil nodavirus", "rank": "Species"}, "880526": {"name": "Rikenella microfusus DSM 15922", "rank": "Strain"}, "1379389": {"name": "Thaumarchaeota archaeon JGI OTU-4", "rank": "Species"}, "1379386": {"name": "Thaumarchaeota archaeon JGI OTU-3", "rank": "Species"}, "1379385": {"name": "Aminicenantes bacterium JGI OTU-2", "rank": "Species"}, "1564113": {"name": "Sphingomonas sp. Ant H11", "rank": "Species"}, "444919": {"name": "Psychromonas aquimarina", "rank": "Species"}, "1233167": {"name": "Unclassified Poacevirus", "rank": "No rank"}, "346173": {"name": "Unclassified Mastadenovirus", "rank": "No rank"}, "105154": {"name": "Chlamydia phage 2", "rank": "Species"}, "202747": {"name": "Sulfurimonas autotrophica", "rank": "Species"}, "202746": {"name": "Sulfurimonas", "rank": "Genus"}, "1273150": {"name": "Lactobacillus reuteri 1063", "rank": "Strain"}, "1333698": {"name": "Zygosaccharomyces bailii CLIB 213", "rank": "Strain"}, "1116084": {"name": "Escherichia coli P0305260.10", "rank": "Strain"}, "1116085": {"name": "Escherichia coli P0305260.11", "rank": "Strain"}, "1116086": {"name": "Escherichia coli P0305260.12", "rank": "Strain"}, "1116087": {"name": "Escherichia coli P0305260.13", "rank": "Strain"}, "1116080": {"name": "Escherichia coli P0305260.6", "rank": "Strain"}, "1508644": {"name": "Candidatus Arthromitus sp. SFB-mouse-NL", "rank": "Species"}, "1116082": {"name": "Escherichia coli P0305260.8", "rank": "Strain"}, "1116083": {"name": "Escherichia coli P0305260.9", "rank": "Strain"}, "438855": {"name": "Methylomarinum vadi", "rank": "Species"}, "1116088": {"name": "Escherichia coli P0305260.15", "rank": "Strain"}, "1116089": {"name": "Escherichia coli p0305293.1", "rank": "Strain"}, "547188": {"name": "Phycisphaera mikurensis", "rank": "Species"}, "428406": {"name": "Ralstonia pickettii 12D", "rank": "Strain"}, "283699": {"name": "Pseudoalteromonas sp. Bsw20308", "rank": "Species"}, "1198114": {"name": "Granulicella tundricola MP5ACTX9", "rank": "Strain"}, "1198115": {"name": "Thaumarchaeota archaeon SCGC AB-539-E09", "rank": "Species"}, "1198116": {"name": "Thermoplasmatales archaeon SCGC AB-539-N05", "rank": "Species"}, "114185": {"name": "Candidatus Carsonella", "rank": "Genus"}, "114186": {"name": "Candidatus Carsonella ruddii", "rank": "Species"}, "883078": {"name": "Afipia broomeae ATCC 49717", "rank": "Strain"}, "883079": {"name": "Afipia clevelandensis ATCC 49720", "rank": "Strain"}, "883077": {"name": "Actinomyces turicensis ACS-279-V-Col4", "rank": "Strain"}, "109633": {"name": "Galerina marginata", "rank": "Species"}, "109632": {"name": "Galerina", "rank": "Genus"}, "278148": {"name": "Mesorhizobium ciceri biovar biserrulae", "rank": "Strain"}, "38322": {"name": "Thermotoga elfii", "rank": "Species"}, "1530085": {"name": "Ralstonia phage RSY1", "rank": "Species"}, "86502": {"name": "Tomato yellow mottle virus", "rank": "Species"}, "1323361": {"name": "Rhodococcus defluvii", "rank": "Species"}, "1412731": {"name": "Staphylococcus aureus F50126", "rank": "Strain"}, "138677": {"name": "Chlamydophila pneumoniae J138", "rank": "Strain"}, "59765": {"name": "Fusarium oxysporum f. sp. lycopersici", "rank": "Strain"}, "709015": {"name": "Pontibacter actiniarum DSM 19842", "rank": "Strain"}, "1207063": {"name": "Oceanibaculum indicum P24", "rank": "Strain"}, "45989": {"name": "Methanoculleus", "rank": "Genus"}, "322710": {"name": "Azotobacter vinelandii DJ", "rank": "Strain"}, "545693": {"name": "Bacillus megaterium QM B1551", "rank": "Strain"}, "545697": {"name": "Clostridium celatum DSM 1785", "rank": "Strain"}, "545696": {"name": "Holdemania filiformis DSM 12042", "rank": "Strain"}, "545695": {"name": "Treponema azotonutricium ZAS-9", "rank": "Strain"}, "545694": {"name": "Treponema primitia ZAS-2", "rank": "Strain"}, "1421957": {"name": "Mycobacterium tuberculosis TB_RSA41", "rank": "Strain"}, "235994": {"name": "Rosellinia necatrix partitivirus 1-W8", "rank": "Strain"}, "1421956": {"name": "Mycobacterium tuberculosis TB_RSA40", "rank": "Strain"}, "1284680": {"name": "Actinomyces sp. S6-Spd3", "rank": "Species"}, "1167732": {"name": "Bacillus sp. JGI 001011-F15", "rank": "Species"}, "342596": {"name": "Unclassified Cytomegalovirus", "rank": "No rank"}, "623144": {"name": "Avian paramyxovirus 8", "rank": "Species"}, "1167733": {"name": "Bacillus sp. JGI 001006-L10", "rank": "Species"}, "1458919": {"name": "Acinetobacter baumannii LY2", "rank": "Strain"}, "76517": {"name": "Campylobacter hominis", "rank": "Species"}, "1458918": {"name": "Acinetobacter baumannii LY1", "rank": "Strain"}, "1238210": {"name": "Vibrio parahaemolyticus IDH02640", "rank": "Strain"}, "1238211": {"name": "Vibrio parahaemolyticus IDH02189", "rank": "Strain"}, "1238212": {"name": "Vibrio parahaemolyticus EKP-028", "rank": "Strain"}, "1238213": {"name": "Vibrio parahaemolyticus NIHCB0603", "rank": "Strain"}, "1287887": {"name": "Vibrio harveyi AOD131", "rank": "Strain"}, "1238215": {"name": "Vibrio parahaemolyticus NIHCB0757", "rank": "Strain"}, "1238216": {"name": "Vibrio parahaemolyticus EKP-021", "rank": "Strain"}, "1238217": {"name": "Vibrio parahaemolyticus EKP-026", "rank": "Strain"}, "1238218": {"name": "Vibrio parahaemolyticus VP-NY4", "rank": "Strain"}, "935852": {"name": "Pseudoxanthomonas sp. J35", "rank": "Species"}, "935851": {"name": "Pseudoxanthomonas sp. J31", "rank": "Species"}, "644346": {"name": "Brucella suis bv. 1", "rank": "Strain"}, "644340": {"name": "Brucella melitensis bv. 3", "rank": "Strain"}, "1409498": {"name": "Staphylococcus aureus SJOS6027", "rank": "Strain"}, "1409499": {"name": "Staphylococcus aureus OCMM6004", "rank": "Strain"}, "1409494": {"name": "Staphylococcus aureus LPIH6001", "rank": "Strain"}, "1409495": {"name": "Staphylococcus aureus MISS6048", "rank": "Strain"}, "1409496": {"name": "Staphylococcus aureus MISS6042", "rank": "Strain"}, "1409497": {"name": "Staphylococcus aureus SJOS6022", "rank": "Strain"}, "1409490": {"name": "Staphylococcus aureus HBHO6002", "rank": "Strain"}, "696125": {"name": "Bartonella clarridgeiae 73", "rank": "Strain"}, "1409492": {"name": "Staphylococcus aureus AGEN6009", "rank": "Strain"}, "1409493": {"name": "Staphylococcus aureus AMMC6012", "rank": "Strain"}, "535206": {"name": "Enterococcus faecium E1162", "rank": "Strain"}, "535205": {"name": "Enterococcus faecium E1071", "rank": "Strain"}, "984996": {"name": "Mobilicoccus", "rank": "Genus"}, "984991": {"name": "Mycoplasma parvum", "rank": "Species"}, "1284798": {"name": "Klebsiella pneumoniae DMC1097", "rank": "Strain"}, "1284799": {"name": "Klebsiella pneumoniae DMC1316", "rank": "Strain"}, "316057": {"name": "Rhodopseudomonas palustris BisB5", "rank": "Strain"}, "294382": {"name": "Bacillus phage BCJA1c", "rank": "Species"}, "316055": {"name": "Rhodopseudomonas palustris BisA53", "rank": "Strain"}, "1238209": {"name": "Vibrio parahaemolyticus VP232", "rank": "Strain"}, "1097579": {"name": "Escherichia coli P4-96", "rank": "Strain"}, "316058": {"name": "Rhodopseudomonas palustris HaA2", "rank": "Strain"}, "1409728": {"name": "Staphylococcus aureus WMCA6123", "rank": "Strain"}, "221037": {"name": "Honeysuckle yellow vein betasatellite", "rank": "Species"}, "1281108": {"name": "Escherichia coli HVH 180 (4-3051617)", "rank": "Strain"}, "1281109": {"name": "Escherichia coli HVH 182 (4-0985554)", "rank": "Strain"}, "1409722": {"name": "Staphylococcus aureus GGMC6036", "rank": "Strain"}, "5114": {"name": "Diaporthales", "rank": "Order"}, "5117": {"name": "Valsaceae", "rank": "Family"}, "1281107": {"name": "Escherichia coli HVH 178 (4-3189163)", "rank": "Strain"}, "1281100": {"name": "Escherichia coli HVH 170 (4-3026949)", "rank": "Strain"}, "5110": {"name": "Claviceps", "rank": "Genus"}, "1281102": {"name": "Escherichia coli HVH 172 (4-3248542)", "rank": "Strain"}, "41515": {"name": "Salmonella enterica subsp. arizonae serovar 62:z36:-", "rank": "Strain"}, "1422475": {"name": "Staphylococcus aureus VET0165R", "rank": "Strain"}, "1422474": {"name": "Staphylococcus aureus VET0164R", "rank": "Strain"}, "1422477": {"name": "Staphylococcus aureus VET0167R", "rank": "Strain"}, "1422476": {"name": "Staphylococcus aureus VET0166R", "rank": "Strain"}, "1422471": {"name": "Staphylococcus aureus VET0159R", "rank": "Strain"}, "1422470": {"name": "Staphylococcus aureus VET0158R", "rank": "Strain"}, "1422473": {"name": "Staphylococcus aureus VET0162R", "rank": "Strain"}, "1422472": {"name": "Staphylococcus aureus VET0161R", "rank": "Strain"}, "1422479": {"name": "Staphylococcus aureus VET0176R", "rank": "Strain"}, "1422478": {"name": "Staphylococcus aureus VET0171R", "rank": "Strain"}, "77643": {"name": "Mycobacterium tuberculosis complex", "rank": "Species group"}, "77647": {"name": "Cotton leaf crumple virus", "rank": "Species"}, "45456": {"name": "Unclassified Deltaproteobacteria", "rank": "No rank"}, "45455": {"name": "Macacine herpesvirus 4", "rank": "Species"}, "391904": {"name": "Bifidobacterium longum subsp. infantis ATCC 15697 = JCM 1222 = DSM 20088", "rank": "Strain"}, "1437448": {"name": "Ochrobactrum rhizosphaerae SJY1", "rank": "Strain"}, "1437449": {"name": "Xanthomonas axonopodis pv. allii CFBP6369", "rank": "Strain"}, "1421862": {"name": "Staphylococcus aureus H75421", "rank": "Strain"}, "1081644": {"name": "Candidatus Aquiluna sp. IMCC13023", "rank": "Species"}, "1081646": {"name": "Borrelia garinii BgVir", "rank": "Strain"}, "1284686": {"name": "Anaerococcus lactolyticus S7-1-13", "rank": "Strain"}, "1081640": {"name": "Sphingomonas elodea ATCC 31461", "rank": "Strain"}, "1468449": {"name": "Holdemania massiliensis", "rank": "Species"}, "96054": {"name": "Tomato leaf curl Philippines virus", "rank": "Species"}, "376921": {"name": "Leptospira borgpetersenii serovar Castellonis", "rank": "Strain"}, "1496689": {"name": "Arthrobacter sp. L77", "rank": "Species"}, "456999": {"name": "Rhizoctonia solani", "rank": "Species"}, "715221": {"name": "Caldicoprobacteraceae", "rank": "Family"}, "2029": {"name": "Kibdelosporangium", "rank": "Genus"}, "699036": {"name": "Peptoclostridium difficile CF5", "rank": "Strain"}, "44294": {"name": "Actinobacillus pleuropneumoniae serovar 5", "rank": "Strain"}, "123841": {"name": "Helicobacter canadensis", "rank": "Species"}, "754518": {"name": "Rhizobium leguminosarum bv. trifolii CC278f", "rank": "Strain"}, "573900": {"name": "Morogoro virus", "rank": "Species"}, "1398204": {"name": "Xenorhabdus bovienii str. kraussei Becker Underwood", "rank": "Strain"}, "699032": {"name": "Peptoclostridium difficile BI9", "rank": "Strain"}, "1357994": {"name": "Campylobacter jejuni subsp. jejuni 00-2425", "rank": "Strain"}, "1094249": {"name": "Blueberry necrotic ring blotch virus", "rank": "Species"}, "935646": {"name": "Dyoepsilonpapillomavirus", "rank": "Genus"}, "1071383": {"name": "Kazachstania naganishii CBS 8797", "rank": "Strain"}, "1071382": {"name": "Kazachstania africana CBS 2517", "rank": "Strain"}, "743725": {"name": "Diapherotrites", "rank": "Phylum"}, "1071380": {"name": "Tetrapisispora blattae CBS 6284", "rank": "Strain"}, "743722": {"name": "Sphingobacterium sp. 21", "rank": "Species"}, "743721": {"name": "Pseudoxanthomonas suwonensis 11-1", "rank": "Strain"}, "743720": {"name": "Pseudomonas fulva 12-X", "rank": "Strain"}, "743729": {"name": "Nanoarchaeota archaeon SCGC AAA011-D5", "rank": "Species"}, "709839": {"name": "Herbaspirillum sp. TSA66", "rank": "Species"}, "1500734": {"name": "Lactobacillus phage Ld25A", "rank": "Species"}, "1276282": {"name": "Staphylococcus pasteuri SP1", "rank": "Strain"}, "209854": {"name": "Maize fine streak virus", "rank": "Species"}, "441952": {"name": "Francisella tularensis subsp. mediasiatica FSC147", "rank": "Strain"}, "1500733": {"name": "Lactobacillus phage Ld17", "rank": "Species"}, "533205": {"name": "Holophagae", "rank": "Class"}, "1047033": {"name": "Aminicenantes bacterium SCGC AAA252-O10", "rank": "Species"}, "157688": {"name": "Leptotrichia hofstadii", "rank": "Species"}, "634457": {"name": "Acetobacter pasteurianus IFO 3283-32", "rank": "Strain"}, "157687": {"name": "Leptotrichia wadei", "rank": "Species"}, "663554": {"name": "Mycobacterium phage ET08", "rank": "Species"}, "663557": {"name": "Mycobacterium phage Peaches", "rank": "Species"}, "56107": {"name": "Cylindrospermum stagnale PCC 7417", "rank": "Strain"}, "56106": {"name": "Cylindrospermum", "rank": "Genus"}, "227866": {"name": "Bacillus tequilensis", "rank": "Species"}, "857109": {"name": "Streptococcus mutans SM4", "rank": "Strain"}, "857108": {"name": "Streptococcus mutans SM1", "rank": "Strain"}, "135575": {"name": "Idiomarina", "rank": "Genus"}, "135577": {"name": "Idiomarina loihiensis", "rank": "Species"}, "857103": {"name": "Streptococcus mutans SA41", "rank": "Strain"}, "857102": {"name": "Streptococcus mutans SF12", "rank": "Strain"}, "857101": {"name": "Streptococcus mutans R221", "rank": "Strain"}, "857100": {"name": "Streptococcus mutans M230", "rank": "Strain"}, "857107": {"name": "Streptococcus mutans 24", "rank": "Strain"}, "857106": {"name": "Streptococcus mutans U2B", "rank": "Strain"}, "857105": {"name": "Streptococcus mutans S1B", "rank": "Strain"}, "857104": {"name": "Streptococcus mutans SA38", "rank": "Strain"}, "1133568": {"name": "Brachyspira pilosicoli B2904", "rank": "Strain"}, "1133569": {"name": "Lactobacillus vini DSM 20605", "rank": "Strain"}, "1133560": {"name": "Unclassified I3-like viruses", "rank": "No rank"}, "10589": {"name": "Human papillomavirus type 41", "rank": "Strain"}, "467200": {"name": "Streptomyces griseoflavus Tu4000", "rank": "Strain"}, "47669": {"name": "Olive latent virus 1", "rank": "Species"}, "370895": {"name": "Burkholderia mallei 2002721280", "rank": "Strain"}, "64988": {"name": "Alcanivorax jadensis", "rank": "Species"}, "1421988": {"name": "Mycobacterium tuberculosis TB_RSA72", "rank": "Strain"}, "1421989": {"name": "Mycobacterium tuberculosis TB_RSA73", "rank": "Strain"}, "1421984": {"name": "Mycobacterium tuberculosis TB_RSA68", "rank": "Strain"}, "1421985": {"name": "Mycobacterium tuberculosis TB_RSA69", "rank": "Strain"}, "1421986": {"name": "Mycobacterium tuberculosis TB_RSA70", "rank": "Strain"}, "1421987": {"name": "Mycobacterium tuberculosis TB_RSA71", "rank": "Strain"}, "1421980": {"name": "Mycobacterium tuberculosis TB_RSA64", "rank": "Strain"}, "1169295": {"name": "Enterococcus faecalis EnGen0352", "rank": "Strain"}, "1421982": {"name": "Mycobacterium tuberculosis TB_RSA66", "rank": "Strain"}, "1421983": {"name": "Mycobacterium tuberculosis TB_RSA67", "rank": "Strain"}, "1308978": {"name": "Salinivibrio socompensis S35", "rank": "Strain"}, "1348058": {"name": "Pseudomonas mediterranea CFBP 5447", "rank": "Strain"}, "1348059": {"name": "Bacillus cereus LCT-BC235", "rank": "Strain"}, "69042": {"name": "Synechococcus sp. WH 5701", "rank": "Species"}, "698971": {"name": "Corynebacterium diphtheriae VA01", "rank": "Strain"}, "698970": {"name": "Corynebacterium diphtheriae HC04", "rank": "Strain"}, "698973": {"name": "Corynebacterium diphtheriae BH8", "rank": "Strain"}, "698972": {"name": "Corynebacterium diphtheriae INCA 402", "rank": "Strain"}, "203135": {"name": "Halomicrobium", "rank": "Genus"}, "1116192": {"name": "Escherichia coli P0305260.3", "rank": "Strain"}, "203133": {"name": "Propionimicrobium", "rank": "Genus"}, "1116193": {"name": "Escherichia coli P0305260.4", "rank": "Strain"}, "1085630": {"name": "Xanthomonas axonopodis pv. punicae str. LMG 859", "rank": "Strain"}, "39752": {"name": "Entomobirnavirus", "rank": "Genus"}, "129009": {"name": "Staphylococcus prophage phiPV83", "rank": "Species"}, "762570": {"name": "Rhodothermus marinus SG0.5JP17-172", "rank": "Strain"}, "129001": {"name": "Syntrophothermus", "rank": "Genus"}, "39750": {"name": "Aquabirnavirus", "rank": "Genus"}, "1123078": {"name": "Runella zeae DSM 19591", "rank": "Strain"}, "1009464": {"name": "Gardnerella vaginalis HMP9231", "rank": "Strain"}, "155680": {"name": "Streptococcus entericus", "rank": "Species"}, "305899": {"name": "Endozoicomonas", "rank": "Genus"}, "866889": {"name": "Salmonella phage Vi06", "rank": "Species"}, "394566": {"name": "Ferrimonas senticii", "rank": "Species"}, "543913": {"name": "Beta proteobacterium CB", "rank": "Species"}, "369257": {"name": "Yersinia phage Berlin", "rank": "Species"}, "1484460": {"name": "Psychroserpens sp. PAMC 27130", "rank": "Species"}, "588581": {"name": "Clostridium papyrosolvens DSM 2782", "rank": "Strain"}, "11632": {"name": "Retroviridae", "rank": "Family"}, "466152": {"name": "Singulisphaera", "rank": "Genus"}, "466153": {"name": "Singulisphaera acidiphila", "rank": "Species"}, "11636": {"name": "Reticuloendotheliosis virus", "rank": "Species"}, "1116168": {"name": "Escherichia coli P0304777.7", "rank": "Strain"}, "515814": {"name": "Nesterenkonia alba", "rank": "Species"}, "865861": {"name": "Clostridium ultunense DSM 10521", "rank": "Strain"}, "865867": {"name": "Mycoplasma mycoides subsp. mycoides SC str. Gladysdale", "rank": "Strain"}, "1223498": {"name": "Lactococcus garvieae NBRC 100934", "rank": "Strain"}, "1548711": {"name": "Gyrovirus GyV7-SF", "rank": "Species"}, "29348": {"name": "Clostridium spiroforme", "rank": "Species"}, "590409": {"name": "Dickeya dadantii Ech586", "rank": "Strain"}, "29341": {"name": "Clostridium argentinense", "rank": "Species"}, "29340": {"name": "Bacillus thuringiensis serovar sotto", "rank": "Strain"}, "29343": {"name": "Clostridium cellulosi", "rank": "Species"}, "29347": {"name": "Clostridium scindens", "rank": "Species"}, "590403": {"name": "Red clover vein mosaic virus", "rank": "Species"}, "302070": {"name": "Begomovirus-associated DNA-III", "rank": "Species"}, "1123001": {"name": "Propionimicrobium lymphophilum DSM 4903", "rank": "Strain"}, "585535": {"name": "Helicobacter pylori 35A", "rank": "Strain"}, "332248": {"name": "Truepera", "rank": "Genus"}, "332249": {"name": "Truepera radiovictrix", "rank": "Species"}, "585530": {"name": "Brevibacterium mcbrellneri ATCC 49030", "rank": "Strain"}, "585531": {"name": "Aeromicrobium marinum DSM 15272", "rank": "Strain"}, "332246": {"name": "Halalkalicoccus", "rank": "Genus"}, "332247": {"name": "Trueperaceae", "rank": "Family"}, "1418335": {"name": "Staphylococcus aureus M90396", "rank": "Strain"}, "585538": {"name": "Helicobacter pylori 83", "rank": "Strain"}, "31989": {"name": "Rhodobacteraceae", "rank": "Family"}, "510946": {"name": "Flavobacterium cauense", "rank": "Species"}, "1418330": {"name": "Staphylococcus aureus M79664", "rank": "Strain"}, "1352589": {"name": "Mycobacterium tuberculosis PanR0804", "rank": "Strain"}, "816": {"name": "Bacteroides", "rank": "Genus"}, "817": {"name": "Bacteroides fragilis", "rank": "Species"}, "815": {"name": "Bacteroidaceae", "rank": "Family"}, "813": {"name": "Chlamydia trachomatis", "rank": "Species"}, "810": {"name": "Chlamydia", "rank": "Genus"}, "131540": {"name": "Thiomicrospira arctica", "rank": "Species"}, "818": {"name": "Bacteroides thetaiotaomicron", "rank": "Species"}, "1038862": {"name": "Bradyrhizobium japonicum USDA 124", "rank": "Strain"}, "1438849": {"name": "Mycobacterium tuberculosis 2094HD", "rank": "Strain"}, "542343": {"name": "Adoxophyes orana nucleopolyhedrovirus", "rank": "Species"}, "1438847": {"name": "Mycobacterium tuberculosis 2092HD", "rank": "Strain"}, "1438846": {"name": "Mycobacterium tuberculosis 2091HD", "rank": "Strain"}, "1438845": {"name": "Mycobacterium tuberculosis 2089HD", "rank": "Strain"}, "1438844": {"name": "Mycobacterium tuberculosis 2088HD", "rank": "Strain"}, "1438843": {"name": "Mycobacterium tuberculosis 2074CJ", "rank": "Strain"}, "1438842": {"name": "Mycobacterium tuberculosis 1755BN", "rank": "Strain"}, "1438841": {"name": "Mycobacterium tuberculosis UT0028", "rank": "Strain"}, "1438840": {"name": "Mycobacterium tuberculosis UT0043", "rank": "Strain"}, "1418339": {"name": "Staphylococcus aureus T42550", "rank": "Strain"}, "1352581": {"name": "Mycobacterium tuberculosis PanR0610", "rank": "Strain"}, "1409670": {"name": "Staphylococcus aureus GGMC6024", "rank": "Strain"}, "1352580": {"name": "Mycobacterium tuberculosis PanR0609", "rank": "Strain"}, "1409671": {"name": "Staphylococcus aureus WAMC6043", "rank": "Strain"}, "1281018": {"name": "Escherichia coli HVH 80 (4-2428830)", "rank": "Strain"}, "33756": {"name": "European brown hare syndrome virus", "rank": "Species"}, "1409673": {"name": "Staphylococcus aureus OCMM6103", "rank": "Strain"}, "1352585": {"name": "Mycobacterium tuberculosis PanR0707", "rank": "Strain"}, "1131551": {"name": "Methylotenera sp. 1P/1", "rank": "Species"}, "1409674": {"name": "Staphylococcus aureus WMCA6180", "rank": "Strain"}, "1131553": {"name": "Nitrosomonas cryotolerans ATCC 49181", "rank": "Strain"}, "1131552": {"name": "Methylomonas sp. MK1", "rank": "Species"}, "1409675": {"name": "Staphylococcus aureus COAS6095", "rank": "Strain"}, "1409676": {"name": "Staphylococcus aureus UCIM6115", "rank": "Strain"}, "1409677": {"name": "Staphylococcus aureus UCIM6119", "rank": "Strain"}, "37692": {"name": "Candidatus Phytoplasma mali", "rank": "Species"}, "1439075": {"name": "Streptococcus pyogenes ABC020033020", "rank": "Strain"}, "1444268": {"name": "Escherichia coli 2-474-04_S4_C3", "rank": "Strain"}, "553212": {"name": "Staphylococcus capitis SK14", "rank": "Strain"}, "1439076": {"name": "Streptococcus pyogenes ABC020033193", "rank": "Strain"}, "1439071": {"name": "Streptococcus pyogenes ABC020032183", "rank": "Strain"}, "651137": {"name": "Thaumarchaeota", "rank": "Phylum"}, "1439073": {"name": "Streptococcus pyogenes ABC020032523", "rank": "Strain"}, "1409679": {"name": "Staphylococcus lugdunensis UCIM6116", "rank": "Strain"}, "553218": {"name": "Campylobacter rectus RM3267", "rank": "Strain"}, "553219": {"name": "Campylobacter showae RM3277", "rank": "Strain"}, "1439079": {"name": "Streptococcus pyogenes ABC020033799", "rank": "Strain"}, "36873": {"name": "Burkholderia xenovorans", "rank": "Species"}, "36870": {"name": "Wigglesworthia glossinidia endosymbiont of Glossina brevipalpis", "rank": "Strain"}, "36876": {"name": "Porphyromonas cansulci", "rank": "Species"}, "36875": {"name": "Porphyromonas canoris", "rank": "Species"}, "36874": {"name": "Porphyromonas cangingivalis", "rank": "Species"}, "1281016": {"name": "Escherichia coli HVH 78 (4-2735946)", "rank": "Strain"}, "1346765": {"name": "Mycobacterium tuberculosis PanR0412", "rank": "Strain"}, "269084": {"name": "Synechococcus elongatus PCC 6301", "rank": "Strain"}, "751585": {"name": "Coprococcus sp. ART55/1", "rank": "Species"}, "751586": {"name": "Brevundimonas diminuta ATCC 11568", "rank": "Strain"}, "254759": {"name": "Bacillus fordii", "rank": "Species"}, "1307834": {"name": "Gluconobacter frateurii NBRC 103465", "rank": "Strain"}, "2374": {"name": "Acetonema longum", "rank": "Species"}, "2375": {"name": "Sporomusa", "rank": "Genus"}, "2370": {"name": "Xylella", "rank": "Genus"}, "2371": {"name": "Xylella fastidiosa", "rank": "Species"}, "2373": {"name": "Acetonema", "rank": "Genus"}, "1424279": {"name": "Cherry twisted leaf associated virus", "rank": "Species"}, "1147137": {"name": "Clostridium phage phi8074-B1", "rank": "Species"}, "1147132": {"name": "Acinetobacter pittii 42F", "rank": "Strain"}, "1147130": {"name": "Pasteurella multocida subsp. multocida str. HB03", "rank": "Strain"}, "1147131": {"name": "Acinetobacter nosocomialis 28F", "rank": "Strain"}, "512767": {"name": "Streptococcus pneumoniae BS397", "rank": "Strain"}, "1422527": {"name": "Staphylococcus aureus VET0241R", "rank": "Strain"}, "1458357": {"name": "Burkholderia sp. MP-1", "rank": "Species"}, "1401263": {"name": "Fathead minnow picornavirus", "rank": "Species"}, "1204725": {"name": "Methanobacterium formicicum DSM 3637", "rank": "Strain"}, "1401260": {"name": "Sediminibacillus halophilus NSP9.3", "rank": "Strain"}, "1559980": {"name": "Sulfuricellaceae", "rank": "Family"}, "1034345": {"name": "Senegalimassilia anaerobia JC110", "rank": "Strain"}, "1034346": {"name": "Dielma fastidiosa", "rank": "Species"}, "1034347": {"name": "Bacillus massiliosenegalensis JC6", "rank": "Strain"}, "868208": {"name": "Escherichia coli DEC15C", "rank": "Strain"}, "67263": {"name": "Streptomyces griseus subsp. griseus", "rank": "Subspecies"}, "34349": {"name": "Mixia osmundae", "rank": "Species"}, "67267": {"name": "Streptomyces alboflavus", "rank": "Species"}, "868202": {"name": "Escherichia coli DEC14B", "rank": "Strain"}, "67269": {"name": "Streptomyces alboviridis", "rank": "Species"}, "868200": {"name": "Escherichia coli DEC13E", "rank": "Strain"}, "868201": {"name": "Escherichia coli DEC14A", "rank": "Strain"}, "868206": {"name": "Escherichia coli DEC15A", "rank": "Strain"}, "868207": {"name": "Escherichia coli DEC15B", "rank": "Strain"}, "868204": {"name": "Escherichia coli DEC14D", "rank": "Strain"}, "76759": {"name": "Pseudomonas monteilii", "rank": "Species"}, "399599": {"name": "Shewanella baltica OS195", "rank": "Strain"}, "1284787": {"name": "Klebsiella pneumoniae UHKPC40", "rank": "Strain"}, "1461752": {"name": "Sphingobium sp. Ant17", "rank": "Species"}, "356658": {"name": "Bacillus kribbensis", "rank": "Species"}, "665874": {"name": "Limnohabitans", "rank": "Genus"}, "293091": {"name": "Haloquadratum walsbyi", "rank": "Species"}, "1227463": {"name": "Haloferax sp. ATCC BAA-645", "rank": "Species"}, "1262136": {"name": "Salmonella enterica subsp. enterica serovar Typhimurium str. CDC_2009K1288", "rank": "Strain"}, "1262132": {"name": "Candidatus Caldatribacterium saccharofermentans OP9-77CS", "rank": "Strain"}, "1368166": {"name": "Staphylococcus aureus subsp. aureus SA268", "rank": "Strain"}, "445708": {"name": "Burkholderia kururiensis subsp. thiooxydans", "rank": "Subspecies"}, "445700": {"name": "Prochlorococcus phage P-HM1", "rank": "Species"}, "408580": {"name": "Bacillus coahuilensis", "rank": "Species"}, "941640": {"name": "Mycoplasma haemofelis str. Langford 1", "rank": "Strain"}, "113286": {"name": "Pseudoramibacter", "rank": "Genus"}, "45219": {"name": "Guanarito virus", "rank": "Species"}, "45218": {"name": "Amapari virus", "rank": "Species"}, "113288": {"name": "Aeromonas salmonicida subsp. achromogenes", "rank": "Subspecies"}, "186806": {"name": "Eubacteriaceae", "rank": "Family"}, "186805": {"name": "Goatpox virus", "rank": "Species"}, "1442": {"name": "Bacillus thuringiensis serovar tolworthi", "rank": "Strain"}, "163908": {"name": "Anabaena sp. PCC 7108", "rank": "Species"}, "194439": {"name": "Chlorobium tepidum TLS", "rank": "Strain"}, "1578770": {"name": "Pan troglodytes verus polyomavirus 1", "rank": "Species"}, "754350": {"name": "Actinobacillus pleuropneumoniae serovar 13", "rank": "Strain"}, "767031": {"name": "Prevotella denticola F0289", "rank": "Strain"}, "435897": {"name": "Lysobacter capsici", "rank": "Species"}, "1087441": {"name": "Klebsiella pneumoniae subsp. pneumoniae KPNIH2", "rank": "Strain"}, "1087440": {"name": "Klebsiella pneumoniae subsp. pneumoniae KPNIH1", "rank": "Strain"}, "1087443": {"name": "Klebsiella pneumoniae subsp. pneumoniae KPNIH4", "rank": "Strain"}, "1087445": {"name": "Klebsiella pneumoniae subsp. pneumoniae KPNIH6", "rank": "Strain"}, "1449": {"name": "Amphibacillus xylanus", "rank": "Species"}, "1087449": {"name": "Aquimarina agarilytica", "rank": "Species"}, "1087448": {"name": "Exiguobacterium antarcticum B7", "rank": "Strain"}, "1439857": {"name": "Burkholderia pseudomallei A79D", "rank": "Strain"}, "1439856": {"name": "Burkholderia pseudomallei A79C", "rank": "Strain"}, "1439855": {"name": "Burkholderia pseudomallei A79A", "rank": "Strain"}, "1439854": {"name": "Burkholderia pseudomallei B03", "rank": "Strain"}, "908827": {"name": "Punctulariaceae", "rank": "Family"}, "1439852": {"name": "Burkholderia pseudomallei K42", "rank": "Strain"}, "446680": {"name": "Eudoraea", "rank": "Genus"}, "1439859": {"name": "Burkholderia pseudomallei TSV32", "rank": "Strain"}, "1439858": {"name": "Burkholderia pseudomallei TSV44", "rank": "Strain"}, "796606": {"name": "Bacillus methanolicus MGA3", "rank": "Strain"}, "1378080": {"name": "Thaumarchaeota archaeon JGI OTU-1", "rank": "Species"}, "1423499": {"name": "Mycobacterium tuberculosis BTB09-085", "rank": "Strain"}, "758847": {"name": "Leptospira santarosai serovar Shermani str. LT 821", "rank": "Strain"}, "27974": {"name": "Nosematidae", "rank": "Family"}, "1403938": {"name": "Propionibacterium sp. DORA_15", "rank": "Species"}, "27973": {"name": "Encephalitozoon hellem", "rank": "Species"}, "1403931": {"name": "Staphylococcus aureus M1559", "rank": "Strain"}, "1403930": {"name": "Staphylococcus aureus M1558", "rank": "Strain"}, "1403935": {"name": "Staphylococcus sp. DORA_6_22", "rank": "Species"}, "1403937": {"name": "Streptococcus sp. DORA_10", "rank": "Species"}, "1145189": {"name": "Neisseria meningitidis NM3158", "rank": "Strain"}, "1145188": {"name": "Neisseria meningitidis NM3144", "rank": "Strain"}, "47900": {"name": "Garlic common latent virus", "rank": "Species"}, "1145185": {"name": "Neisseria meningitidis NM3042", "rank": "Strain"}, "1145184": {"name": "Neisseria meningitidis NM90", "rank": "Strain"}, "1145187": {"name": "Neisseria meningitidis NM3131", "rank": "Strain"}, "1145186": {"name": "Neisseria meningitidis NM3222", "rank": "Strain"}, "1145181": {"name": "Neisseria meningitidis 2003051", "rank": "Strain"}, "1145180": {"name": "Neisseria meningitidis 2008223", "rank": "Strain"}, "1145183": {"name": "Neisseria meningitidis NM115", "rank": "Strain"}, "1145182": {"name": "Neisseria meningitidis NM271", "rank": "Strain"}, "1392869": {"name": "Escherichia coli K1", "rank": "Strain"}, "1051140": {"name": "Mycobacterium phage Euphoria", "rank": "Species"}, "71972": {"name": "Beet virus Q", "rank": "Species"}, "1392862": {"name": "Escherichia coli M17", "rank": "Strain"}, "1392863": {"name": "Escherichia coli M18", "rank": "Strain"}, "1392864": {"name": "Escherichia coli M19", "rank": "Strain"}, "1392865": {"name": "Escherichia coli M20", "rank": "Strain"}, "1392866": {"name": "Escherichia coli M21", "rank": "Strain"}, "1552758": {"name": "Xanthomonas sp. Nyagatare", "rank": "Species"}, "1049928": {"name": "Leptospira interrogans serovar Pyrogenes str. L0374", "rank": "Strain"}, "1049929": {"name": "Leptospira interrogans serovar Pyrogenes str. R168", "rank": "Strain"}, "1049924": {"name": "Leptospira interrogans serovar Pomona str. Kennewicki LC82-25", "rank": "Strain"}, "1049925": {"name": "Leptospira interrogans serovar Pomona str. UT364", "rank": "Strain"}, "1049926": {"name": "Leptospira interrogans serovar Pyrogenes str. 2006006956", "rank": "Strain"}, "1049927": {"name": "Leptospira interrogans serovar Pyrogenes str. 2006006960", "rank": "Strain"}, "1049920": {"name": "Leptospira interrogans serovar Medanensis str. L0448", "rank": "Strain"}, "1049921": {"name": "Leptospira interrogans serovar Medanensis str. L0887", "rank": "Strain"}, "1049922": {"name": "Leptospira interrogans serovar Medanensis str. UT053", "rank": "Strain"}, "1049923": {"name": "Leptospira interrogans serovar Muenchen str. Brem 129", "rank": "Strain"}, "1197951": {"name": "Celeribacter phage P12053L", "rank": "Species"}, "1197953": {"name": "Staphylococcus phage vB_SepiS-phiIPLA7", "rank": "Species"}, "1197952": {"name": "Staphylococcus phage vB_SepiS-phiIPLA5", "rank": "Species"}, "1035817": {"name": "Bifidobacterium longum subsp. longum KACC 91563", "rank": "Strain"}, "991944": {"name": "Vibrio cholerae HE-25", "rank": "Strain"}, "1054834": {"name": "Enterobacteria phage ime09", "rank": "Species"}, "1457188": {"name": "Listeria monocytogenes WSLC1042", "rank": "Strain"}, "1068620": {"name": "Escherichia coli O104:H4 str. 11-4632 C4", "rank": "Strain"}, "1068621": {"name": "Escherichia coli O104:H4 str. 11-4632 C5", "rank": "Strain"}, "640707": {"name": "Bacillus atrophaeus ATCC 9372", "rank": "Strain"}, "1457183": {"name": "Bifidobacterium longum subsp. infantis EK3", "rank": "Strain"}, "1457185": {"name": "Bifidobacterium longum subsp. longum EK5", "rank": "Strain"}, "1457184": {"name": "Bifidobacterium longum subsp. longum 72B", "rank": "Strain"}, "1457187": {"name": "Listeria monocytogenes WSLC1001", "rank": "Strain"}, "1457186": {"name": "Bifidobacterium longum subsp. longum EK13", "rank": "Strain"}, "10508": {"name": "Adenoviridae", "rank": "Family"}, "1005461": {"name": "Escherichia coli 8.0586", "rank": "Strain"}, "1005460": {"name": "Escherichia coli 8.2524", "rank": "Strain"}, "1448547": {"name": "Mycobacterium tuberculosis TKK_05SA_0044", "rank": "Strain"}, "1448546": {"name": "Mycobacterium tuberculosis TKK_05SA_0043", "rank": "Strain"}, "1236494": {"name": "Prevotella pleuritidis JCM 14110", "rank": "Strain"}, "1236497": {"name": "Prevotella oulorum JCM 14966", "rank": "Strain"}, "1236498": {"name": "Bacteroides paurosaccharolyticus JCM 15092", "rank": "Strain"}, "145357": {"name": "Dermacoccaceae", "rank": "Family"}, "1005464": {"name": "Escherichia coli 8.0569", "rank": "Strain"}, "404589": {"name": "Anaeromyxobacter sp. Fw109-5", "rank": "Species"}, "1005466": {"name": "Escherichia coli 10.0833", "rank": "Strain"}, "260909": {"name": "Tomato yellow margin leaf curl virus", "rank": "Species"}, "1291050": {"name": "Clostridium josui JCM 17888", "rank": "Strain"}, "1046958": {"name": "Cloacimonetes bacterium SCGC AAA252-I11", "rank": "Species"}, "1046959": {"name": "Cloacimonetes bacterium SCGC AAA252-I16", "rank": "Species"}, "1046954": {"name": "Cloacimonetes bacterium SCGC AAA252-E20", "rank": "Species"}, "1046955": {"name": "Cloacimonetes bacterium SCGC AAA252-F02", "rank": "Species"}, "1046956": {"name": "Cloacimonetes bacterium SCGC AAA252-G07", "rank": "Species"}, "1046957": {"name": "Cloacimonetes bacterium SCGC AAA252-G08", "rank": "Species"}, "1046952": {"name": "Cloacimonetes bacterium SCGC AAA252-D03", "rank": "Species"}, "685506": {"name": "Mycobacterium phage Ardmore", "rank": "Species"}, "254410": {"name": "Bacillus aurantiacus", "rank": "Species"}, "1095748": {"name": "Neisseria sicca VK64", "rank": "Strain"}, "1402644": {"name": "Staphylococcus aureus M1130", "rank": "Strain"}, "1402645": {"name": "Staphylococcus aureus M1131", "rank": "Strain"}, "1402646": {"name": "Staphylococcus aureus M1132", "rank": "Strain"}, "1402647": {"name": "Staphylococcus aureus M1134", "rank": "Strain"}, "1402640": {"name": "Staphylococcus aureus M1125", "rank": "Strain"}, "1328389": {"name": "Klebsiella pneumoniae UCICRE 1", "rank": "Strain"}, "1402642": {"name": "Staphylococcus aureus M1128", "rank": "Strain"}, "1402643": {"name": "Staphylococcus aureus M1129", "rank": "Strain"}, "1328384": {"name": "Klebsiella pneumoniae BWH 28", "rank": "Strain"}, "1328385": {"name": "Klebsiella pneumoniae BWH 30", "rank": "Strain"}, "1328386": {"name": "Klebsiella pneumoniae BWH 36", "rank": "Strain"}, "1328387": {"name": "Klebsiella pneumoniae BWH 41", "rank": "Strain"}, "1328380": {"name": "Klebsiella pneumoniae MGH 48", "rank": "Strain"}, "1328381": {"name": "Klebsiella pneumoniae BWH 2", "rank": "Strain"}, "1328382": {"name": "Klebsiella pneumoniae BWH 15", "rank": "Strain"}, "1328383": {"name": "Klebsiella pneumoniae BWH 22", "rank": "Strain"}, "707248": {"name": "Pseudomonas gingeri NCPPB 3146", "rank": "Strain"}, "1446758": {"name": "Escherichia coli O81:NM", "rank": "Strain"}, "1446759": {"name": "Escherichia coli O86:H34", "rank": "Strain"}, "1446752": {"name": "Escherichia coli O69:H11 str. 07-4281", "rank": "Strain"}, "1446753": {"name": "Escherichia coli O69:H11 str. 08-4661", "rank": "Strain"}, "1446750": {"name": "Escherichia coli O69:H11 str. 06-3325", "rank": "Strain"}, "1446751": {"name": "Escherichia coli O69:H11 str. 07-3763", "rank": "Strain"}, "1446756": {"name": "Escherichia coli O78:H12 str. 00-3279", "rank": "Strain"}, "1446757": {"name": "Escherichia coli O79:H7", "rank": "Strain"}, "1446754": {"name": "Escherichia coli O69:H11 str. 2009C-3601", "rank": "Strain"}, "1446755": {"name": "Escherichia coli O78:H12", "rank": "Strain"}, "208479": {"name": "Clostridium bolteae", "rank": "Species"}, "1329381": {"name": "Tomato leaf curl China virus - OX2", "rank": "Species"}, "99598": {"name": "Calothrix sp. PCC 7507", "rank": "Species"}, "1213379": {"name": "Aparavirus", "rank": "Genus"}, "647113": {"name": "Methanothermococcus okinawensis IH1", "rank": "Strain"}, "1388449": {"name": "Staphylococcus aureus M0672", "rank": "Strain"}, "1388448": {"name": "Staphylococcus aureus M0671", "rank": "Strain"}, "1388445": {"name": "Staphylococcus aureus M0668", "rank": "Strain"}, "1388444": {"name": "Staphylococcus aureus M0667", "rank": "Strain"}, "1388447": {"name": "Staphylococcus aureus M0670", "rank": "Strain"}, "1388446": {"name": "Staphylococcus aureus M0669", "rank": "Strain"}, "1388441": {"name": "Staphylococcus aureus M0661", "rank": "Strain"}, "1388440": {"name": "Staphylococcus aureus M0659", "rank": "Strain"}, "1388443": {"name": "Staphylococcus aureus M0666", "rank": "Strain"}, "1388442": {"name": "Staphylococcus aureus M0664", "rank": "Strain"}, "1101189": {"name": "Paracoccus sp. N5", "rank": "Species"}, "1101188": {"name": "Arthrobacter sp. MA-N2", "rank": "Species"}, "717522": {"name": "Mycobacterium bovis BCG str. Mexico", "rank": "Strain"}, "683219": {"name": "Streptomyces sp. SA3_actG", "rank": "Species"}, "1500279": {"name": "Microbacterium sp. CF335", "rank": "Species"}, "307486": {"name": "Tepidimonas taiwanensis", "rank": "Species"}, "590646": {"name": "Candida tenuis ATCC 10573", "rank": "Strain"}, "590647": {"name": "Nariva virus", "rank": "Species"}, "307480": {"name": "Chryseobacterium vrystaatense", "rank": "Species"}, "1231063": {"name": "Microbacterium sp. G3", "rank": "Species"}, "175628": {"name": "Gordonia paraffinivorans", "rank": "Species"}, "338321": {"name": "Turneriella", "rank": "Genus"}, "338323": {"name": "Human papillomavirus type 103", "rank": "Strain"}, "1283209": {"name": "Alphacarmotetravirus", "rank": "Genus"}, "1283208": {"name": "Carmotetraviridae", "rank": "Family"}, "607712": {"name": "Neisseria shayeganii", "rank": "Species"}, "552811": {"name": "Dehalogenimonas lykanthroporepellens BL-DC-9", "rank": "Strain"}, "671095": {"name": "Croton yellow vein virus", "rank": "Species"}, "1168594": {"name": "Mycobacterium phage Avani", "rank": "Species"}, "537010": {"name": "Desulfitobacterium hafniense DP7", "rank": "Strain"}, "537011": {"name": "Prevotella copri DSM 18205", "rank": "Strain"}, "537012": {"name": "Bacteroides cellulosilyticus DSM 14838", "rank": "Strain"}, "537013": {"name": "Clostridium methylpentosum DSM 5476", "rank": "Strain"}, "1266716": {"name": "Bifidobacterium longum subsp. longum CMCC P0001", "rank": "Strain"}, "1266717": {"name": "Staphylococcus pseudintermedius E140", "rank": "Strain"}, "10744": {"name": "Podoviridae", "rank": "Family"}, "1578828": {"name": "Edwardsiella sp. EA181011", "rank": "Species"}, "10742": {"name": "Enterobacteria phage HK022", "rank": "Species"}, "1434321": {"name": "Staphylococcus aureus CUHK_HK1997", "rank": "Strain"}, "105560": {"name": "Methylibium petroleiphilum", "rank": "Species"}, "1434325": {"name": "Dyadobacter tibetensis Y620-1", "rank": "Strain"}, "114628": {"name": "Alkaliphilus transvaalensis", "rank": "Species"}, "889933": {"name": "Staphylococcus aureus subsp. aureus ECT-R 2", "rank": "Strain"}, "889932": {"name": "Lactobacillus plantarum subsp. plantarum ST-III", "rank": "Strain"}, "114627": {"name": "Alkaliphilus", "rank": "Genus"}, "1397666": {"name": "Alpha proteobacterium RS24", "rank": "Species"}, "40542": {"name": "Leptotrichia buccalis", "rank": "Species"}, "40540": {"name": "Human papillomavirus type 60", "rank": "Strain"}, "40544": {"name": "Sutterella", "rank": "Genus"}, "40545": {"name": "Sutterella wadsworthensis", "rank": "Species"}, "1168591": {"name": "Acinetobacter baumannii Ab44444", "rank": "Strain"}, "562971": {"name": "Achromobacter xylosoxidans C54", "rank": "Strain"}, "562970": {"name": "Kyrpidia tusciae DSM 2912", "rank": "Strain"}, "562973": {"name": "Actinomyces viscosus C505", "rank": "Strain"}, "280240": {"name": "Nocardiopsis baichengensis", "rank": "Species"}, "1124991": {"name": "Morganella morganii subsp. morganii KT", "rank": "Strain"}, "95486": {"name": "Burkholderia cenocepacia", "rank": "Species"}, "1034809": {"name": "Staphylococcus lugdunensis N920143", "rank": "Strain"}, "390157": {"name": "Seneca valley virus", "rank": "Species"}, "1034808": {"name": "Mycoplasma anatis 1340", "rank": "Strain"}, "530557": {"name": "Vibrio splendidus 12F01", "rank": "Strain"}, "1505768": {"name": "Candidatus Schmidhempelia", "rank": "Genus"}, "279006": {"name": "Acinetobacter phage 133", "rank": "Species"}, "1346829": {"name": "Peridroma alphabaculovirus", "rank": "Species"}, "1346828": {"name": "Choristoneura murinana alphabaculovirus", "rank": "Species"}, "482460": {"name": "Sediminibacillus", "rank": "Genus"}, "482461": {"name": "Sediminibacillus halophilus", "rank": "Species"}, "342410": {"name": "Unclassified Simplexvirus", "rank": "No rank"}, "1034807": {"name": "Flavobacterium branchiophilum FL-15", "rank": "Strain"}, "1392491": {"name": "Ruminococcaceae bacterium AE2021", "rank": "Species"}, "1392490": {"name": "Sediminibacter sp. Hel_I_10", "rank": "Species"}, "1392493": {"name": "Lachnospiraceae bacterium AC2031", "rank": "Species"}, "1392494": {"name": "Lachnospiraceae bacterium AC2012", "rank": "Species"}, "1392497": {"name": "Clostridium mangenotii LM2", "rank": "Strain"}, "1392499": {"name": "Klebsiella pneumoniae subsp. pneumoniae 1158", "rank": "Strain"}, "1392498": {"name": "Maribacter forsetii DSM 18668", "rank": "Strain"}, "232523": {"name": "Hylemonella", "rank": "Genus"}, "1204528": {"name": "Salmonella phage SKML-39", "rank": "Species"}, "1204522": {"name": "Escherichia phage ECML-134", "rank": "Species"}, "1204525": {"name": "Streptomyces phage SV1", "rank": "Species"}, "1204524": {"name": "Streptomyces phage phiHau3", "rank": "Species"}, "448181": {"name": "Rhizobium selenitireducens", "rank": "Species"}, "1204526": {"name": "Streptomyce phage TG1", "rank": "Species"}, "1409519": {"name": "Staphylococcus aureus LPIH6008", "rank": "Strain"}, "1409518": {"name": "Staphylococcus aureus OCMM6015", "rank": "Strain"}, "1409511": {"name": "Staphylococcus aureus COAS6049", "rank": "Strain"}, "1409510": {"name": "Staphylococcus aureus GGMC6003", "rank": "Strain"}, "1409513": {"name": "Staphylococcus aureus SCLE6005", "rank": "Strain"}, "1409512": {"name": "Staphylococcus aureus HBHO6050", "rank": "Strain"}, "1409515": {"name": "Staphylococcus aureus AGEN6010", "rank": "Strain"}, "1409514": {"name": "Staphylococcus aureus KINW6003", "rank": "Strain"}, "1409517": {"name": "Staphylococcus aureus LPIH6004", "rank": "Strain"}, "1409516": {"name": "Staphylococcus aureus UCIM6050", "rank": "Strain"}, "1422624": {"name": "Staphylococcus aureus VET0389R", "rank": "Strain"}, "1422625": {"name": "Staphylococcus aureus VET0390R", "rank": "Strain"}, "1422626": {"name": "Staphylococcus aureus VET0393R", "rank": "Strain"}, "352450": {"name": "Simplicispira", "rank": "Genus"}, "1422620": {"name": "Staphylococcus aureus VET0383R", "rank": "Strain"}, "1422621": {"name": "Staphylococcus aureus VET0384R", "rank": "Strain"}, "1422622": {"name": "Staphylococcus aureus VET0387R", "rank": "Strain"}, "1422623": {"name": "Staphylococcus aureus VET0388R", "rank": "Strain"}, "262406": {"name": "Thermobaculum", "rank": "Genus"}, "173509": {"name": "Shewanella fidelis", "rank": "Species"}, "1422628": {"name": "Staphylococcus aureus VET0395R", "rank": "Strain"}, "1422629": {"name": "Staphylococcus aureus VET0396R", "rank": "Strain"}, "1160968": {"name": "Rabbit coronavirus HKU14", "rank": "Species"}, "561501": {"name": "Buchnera aphidicola str. Tuc7 (Acyrthosiphon pisum)", "rank": "Strain"}, "402880": {"name": "Methanococcus maripaludis C5", "rank": "Strain"}, "402881": {"name": "Parvibaculum lavamentivorans DS-1", "rank": "Strain"}, "402882": {"name": "Shewanella baltica OS185", "rank": "Strain"}, "1237159": {"name": "Enterobacteria phage NJ01", "rank": "Species"}, "553": {"name": "Pantoea ananatis", "rank": "Species"}, "552": {"name": "Erwinia amylovora", "rank": "Species"}, "551": {"name": "Erwinia", "rank": "Genus"}, "550": {"name": "Enterobacter cloacae", "rank": "Species"}, "190486": {"name": "Xanthomonas axonopodis pv. citri str. 306", "rank": "Strain"}, "556": {"name": "Dickeya chrysanthemi", "rank": "Species"}, "555": {"name": "Pectobacterium carotovorum subsp. carotovorum", "rank": "Subspecies"}, "554": {"name": "Pectobacterium carotovorum", "rank": "Species"}, "232380": {"name": "Tomato yellow leaf curl Axarquia virus", "rank": "Species"}, "5094": {"name": "Talaromyces", "rank": "Genus"}, "589436": {"name": "Prevotella fusca", "rank": "Species"}, "929509": {"name": "Solitalea", "rank": "Genus"}, "929508": {"name": "Clostridium botulinum V891", "rank": "Strain"}, "929507": {"name": "Clostridium botulinum BKT028387", "rank": "Strain"}, "929506": {"name": "Clostridium botulinum BKT015925", "rank": "Strain"}, "318558": {"name": "Tupaia virus", "rank": "Species"}, "736": {"name": "Haemophilus paraphrohaemolyticus", "rank": "Species"}, "1380412": {"name": "Devosia sp. DBB001", "rank": "Species"}, "158836": {"name": "Enterobacter hormaechei", "rank": "Species"}, "279896": {"name": "Maize mosaic virus", "rank": "Species"}, "1121084": {"name": "Bacillus acidiproducens", "rank": "Species"}, "1423573": {"name": "Mycobacterium tuberculosis BTB13-128", "rank": "Strain"}, "1423572": {"name": "Mycobacterium tuberculosis BTB13-127", "rank": "Strain"}, "1423571": {"name": "Mycobacterium tuberculosis BTB13-089", "rank": "Strain"}, "1423570": {"name": "Mycobacterium tuberculosis BTB13-063", "rank": "Strain"}, "373391": {"name": "Thiomicrospira halophila", "rank": "Species"}, "1423576": {"name": "Mycobacterium tuberculosis BTB13-222", "rank": "Strain"}, "1423575": {"name": "Mycobacterium tuberculosis BTB13-206", "rank": "Strain"}, "1423574": {"name": "Mycobacterium tuberculosis BTB13-156", "rank": "Strain"}, "679935": {"name": "Alistipes finegoldii DSM 17242", "rank": "Strain"}, "679936": {"name": "Sulfobacillus acidophilus DSM 10332", "rank": "Strain"}, "679937": {"name": "Bacteroides coprosuis DSM 18011", "rank": "Strain"}, "1123228": {"name": "Saccharospirillum impatiens DSM 12546", "rank": "Strain"}, "1123229": {"name": "Salinarimonas rosea DSM 21201", "rank": "Strain"}, "491915": {"name": "Anoxybacillus flavithermus WK1", "rank": "Strain"}, "281689": {"name": "Desulfuromonas acetoxidans DSM 684", "rank": "Strain"}, "270673": {"name": "Pseudomonas phage PaP2", "rank": "Species"}, "1460648": {"name": "Vibrio sp. JCM 19053", "rank": "Species"}, "1460649": {"name": "Geomicrobium sp. JCM 19055", "rank": "Species"}, "1460647": {"name": "Vibrio sp. JCM 19052", "rank": "Species"}, "1460640": {"name": "Bacillus sp. JCM 19046", "rank": "Species"}, "1460641": {"name": "Bacillus sp. JCM 19047", "rank": "Species"}, "220754": {"name": "Jeotgalibacillus campisalis", "rank": "Species"}, "413888": {"name": "Caldicellulosiruptor hydrothermalis", "rank": "Species"}, "413889": {"name": "Caldicellulosiruptor kronotskyensis", "rank": "Species"}, "74385": {"name": "Gracilibacillus", "rank": "Genus"}, "1031288": {"name": "Caloramator sp. ALD01", "rank": "Species"}, "596154": {"name": "Alicycliphilus denitrificans K601", "rank": "Strain"}, "596155": {"name": "Salmonella enterica subsp. enterica serovar Infantis str. SARB27", "rank": "Strain"}, "596151": {"name": "Desulfovibrio fructosivorans JJ", "rank": "Strain"}, "596152": {"name": "Desulfovibrio sp. U5L", "rank": "Species"}, "596153": {"name": "Alicycliphilus denitrificans BC", "rank": "Strain"}, "635013": {"name": "Thermincola potens JR", "rank": "Strain"}, "294702": {"name": "Proteiniphilum", "rank": "Genus"}, "190146": {"name": "Actinobaculum urinale", "rank": "Species"}, "301148": {"name": "Caldibacillus debilis", "rank": "Species"}, "34103": {"name": "Sphaerotilus natans", "rank": "Species"}, "34102": {"name": "Sphaerotilus", "rank": "Genus"}, "34105": {"name": "Streptobacillus moniliformis", "rank": "Species"}, "34104": {"name": "Streptobacillus", "rank": "Genus"}, "452529": {"name": "Streptomyces scopuliridis", "rank": "Species"}, "1412564": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20120765", "rank": "Strain"}, "1412565": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20121671", "rank": "Strain"}, "1412566": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20120555", "rank": "Strain"}, "1412567": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20111554", "rank": "Strain"}, "1412560": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20121748", "rank": "Strain"}, "1412561": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20121672", "rank": "Strain"}, "1412562": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20121747", "rank": "Strain"}, "1412563": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20121746", "rank": "Strain"}, "1412568": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20120497", "rank": "Strain"}, "1412569": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20120994", "rank": "Strain"}, "1286170": {"name": "Raoultella ornithinolytica B6", "rank": "Strain"}, "1286171": {"name": "Eubacterium acidaminophilum DSM 3953", "rank": "Strain"}, "40631": {"name": "Enterobacteria phage N15", "rank": "Species"}, "1417138": {"name": "Staphylococcus aureus F26021", "rank": "Strain"}, "1417139": {"name": "Staphylococcus aureus F29447", "rank": "Strain"}, "1417134": {"name": "Staphylococcus aureus F16108", "rank": "Strain"}, "1417135": {"name": "Staphylococcus aureus F19466", "rank": "Strain"}, "1417136": {"name": "Staphylococcus aureus F19470", "rank": "Strain"}, "1417137": {"name": "Staphylococcus aureus F19490", "rank": "Strain"}, "1417130": {"name": "Staphylococcus aureus F12926_081012", "rank": "Strain"}, "1090930": {"name": "Escherichia coli ONT:H33 str. C48/93", "rank": "Strain"}, "1417132": {"name": "Staphylococcus aureus F16106", "rank": "Strain"}, "1417133": {"name": "Staphylococcus aureus F16107", "rank": "Strain"}, "88870": {"name": "Mycobacterium phage TM4", "rank": "Species"}, "1182515": {"name": "Mannheimia phage vB_MhM_1152AP", "rank": "Species"}, "1030157": {"name": "Sphingomonas sp. KC8", "rank": "Species"}, "1182518": {"name": "Maize streak Reunion virus", "rank": "Species"}, "1151194": {"name": "Enterococcus faecalis EnGen0074", "rank": "Strain"}, "114399": {"name": "Whitefly endosymbionts", "rank": "No rank"}, "1413372": {"name": "Staphylococcus aureus 13-ST00049", "rank": "Strain"}, "1413373": {"name": "Staphylococcus aureus Tur-16", "rank": "Strain"}, "1459637": {"name": "Candidatus Nitrososphaera evergladensis", "rank": "Species"}, "1459636": {"name": "Candidatus Nitrososphaera evergladensis SR1", "rank": "Strain"}, "1074168": {"name": "Streptococcus mutans TCI-239", "rank": "Strain"}, "1074169": {"name": "Streptococcus mutans TCI-242", "rank": "Strain"}, "1413374": {"name": "Staphylococcus aureus Sau 44", "rank": "Strain"}, "1413375": {"name": "Staphylococcus aureus Sau 46", "rank": "Strain"}, "1074164": {"name": "Streptococcus mutans TCI-224", "rank": "Strain"}, "1500297": {"name": "Pseudomonas sp. PTA1", "rank": "Species"}, "1074166": {"name": "Streptococcus mutans TCI-228", "rank": "Strain"}, "1074167": {"name": "Streptococcus mutans TCI-234", "rank": "Strain"}, "1074160": {"name": "Streptococcus mutans TCI-219", "rank": "Strain"}, "1074161": {"name": "Streptococcus mutans TCI-220", "rank": "Strain"}, "1500290": {"name": "Chryseobacterium sp. YR460", "rank": "Species"}, "1074163": {"name": "Streptococcus mutans TCI-223", "rank": "Strain"}, "1121333": {"name": "Clostridium saccharogumia DSM 17460", "rank": "Strain"}, "1121334": {"name": "Clostridium sporosphaeroides DSM 1294", "rank": "Strain"}, "1121335": {"name": "Clostridium stercorarium subsp. stercorarium DSM 8532", "rank": "Strain"}, "637380": {"name": "Bacillus cereus biovar anthracis str. CI", "rank": "Strain"}, "1345576": {"name": "Helicobacter pylori SA169C", "rank": "Strain"}, "1345577": {"name": "Helicobacter pylori SA170A", "rank": "Strain"}, "1345574": {"name": "Helicobacter pylori SA168C", "rank": "Strain"}, "1345575": {"name": "Helicobacter pylori SA169A", "rank": "Strain"}, "1345572": {"name": "Helicobacter pylori SA166A", "rank": "Strain"}, "1345573": {"name": "Helicobacter pylori SA168A", "rank": "Strain"}, "1345570": {"name": "Helicobacter pylori SA165A", "rank": "Strain"}, "156690": {"name": "Beet mild yellowing virus", "rank": "Species"}, "1524467": {"name": "Serratia sp. Ag1", "rank": "Species"}, "744724": {"name": "Halarchaeum", "rank": "Genus"}, "1524460": {"name": "Phaeodactylibacter xiamenensis", "rank": "Species"}, "285575": {"name": "Streptomyces griseus subsp. rhodochrous", "rank": "Subspecies"}, "285574": {"name": "Streptomyces erythrochromogenes", "rank": "Species"}, "1121485": {"name": "Dysgonomonas capnocytophagoides DSM 22835", "rank": "Strain"}, "1121482": {"name": "Dyadobacter beijingensis DSM 21582", "rank": "Strain"}, "1121483": {"name": "Dyadobacter crusticola DSM 16708", "rank": "Strain"}, "1121480": {"name": "Pseudoduganella violaceinigra DSM 15887", "rank": "Strain"}, "1121481": {"name": "Dyadobacter alkalitolerans DSM 23607", "rank": "Strain"}, "155920": {"name": "Xylella fastidiosa subsp. sandyi Ann-1", "rank": "Strain"}, "1287226": {"name": "Mesorhizobium sp. LNHC209A00", "rank": "Species"}, "5296": {"name": "Puccinia", "rank": "Genus"}, "941258": {"name": "Wolbachia endosymbiont wVitB of Nasonia vitripennis", "rank": "Strain"}, "1138374": {"name": "Nematocida sp. 1 ERTm6", "rank": "Strain"}, "1416914": {"name": "Pandoraea pnomenusa 3kgm", "rank": "Strain"}, "676": {"name": "Vibrio fluvialis", "rank": "Species"}, "674": {"name": "Vibrio mimicus", "rank": "Species"}, "672": {"name": "Vibrio vulnificus", "rank": "Species"}, "673": {"name": "Grimontia hollisae", "rank": "Species"}, "670": {"name": "Vibrio parahaemolyticus", "rank": "Species"}, "671": {"name": "Vibrio proteolyticus", "rank": "Species"}, "888819": {"name": "Streptococcus sanguinis SK678", "rank": "Strain"}, "888818": {"name": "Streptococcus sanguinis SK408", "rank": "Strain"}, "888815": {"name": "Streptococcus sanguinis SK353", "rank": "Strain"}, "1223515": {"name": "Corynebacterium humireducens NBRC 106098 = DSM 45392", "rank": "Strain"}, "1223514": {"name": "Corynebacterium humireducens", "rank": "Species"}, "888814": {"name": "Streptococcus sanguinis SK340", "rank": "Strain"}, "1451353": {"name": "Candidatus Synechococcus spongiarum SH4", "rank": "Strain"}, "1541883": {"name": "Escherichia phage vB_EcoM-ep3", "rank": "Species"}, "325461": {"name": "Omikronpapillomavirus", "rank": "Genus"}, "1217674": {"name": "Acinetobacter radioresistens NIPH 2130", "rank": "Strain"}, "1108949": {"name": "Canine bocavirus", "rank": "Species"}, "329545": {"name": "Planktothrix agardhii NIVA-CYA 56/3", "rank": "Strain"}, "364745": {"name": "Choristoneura occidentalis granulovirus", "rank": "Species"}, "888811": {"name": "Streptococcus sanguinis SK150", "rank": "Strain"}, "334545": {"name": "Rickettsia tamurae", "rank": "Species"}, "334543": {"name": "Psychrobacter arcticus", "rank": "Species"}, "334542": {"name": "Rhodococcus qingshengii", "rank": "Species"}, "1006006": {"name": "Metallosphaera cuprina Ar-4", "rank": "Strain"}, "1006007": {"name": "Bacillus megaterium WSH-002", "rank": "Strain"}, "1006004": {"name": "Buttiauxella agrestis ATCC 33320", "rank": "Strain"}, "1006005": {"name": "Metallosphaera cuprina", "rank": "Species"}, "1006003": {"name": "Citrobacter freundii ATCC 8090 = MTCC 1658", "rank": "Strain"}, "1006000": {"name": "Kluyvera ascorbata ATCC 33433", "rank": "Strain"}, "1388603": {"name": "Staphylococcus aureus M0820", "rank": "Strain"}, "1388602": {"name": "Staphylococcus aureus M0819", "rank": "Strain"}, "1388601": {"name": "Staphylococcus aureus M0818", "rank": "Strain"}, "1388600": {"name": "Staphylococcus aureus M0817", "rank": "Strain"}, "1388607": {"name": "Staphylococcus aureus M0830", "rank": "Strain"}, "1388606": {"name": "Staphylococcus aureus M0826", "rank": "Strain"}, "1388605": {"name": "Staphylococcus aureus M0824", "rank": "Strain"}, "1388604": {"name": "Staphylococcus aureus M0821", "rank": "Strain"}, "1388609": {"name": "Staphylococcus aureus M0833", "rank": "Strain"}, "1388608": {"name": "Staphylococcus aureus M0832", "rank": "Strain"}, "789332": {"name": "Salmonella enterica subsp. enterica serovar Montevideo str. MD_MDA09249507", "rank": "Strain"}, "158190": {"name": "Sphaerochaeta pleomorpha str. Grapes", "rank": "Strain"}, "1007064": {"name": "Streptococcus suis ST3", "rank": "Strain"}, "556524": {"name": "Armigeres subalbatus virus SaX06-AK20", "rank": "Species"}, "65093": {"name": "Halothece sp. PCC 7418", "rank": "Species"}, "154347": {"name": "Thiorhodospira sibirica", "rank": "Species"}, "154346": {"name": "Thiorhodospira", "rank": "Genus"}, "427140": {"name": "Leuconostoc mesenteroides KFRI-MG", "rank": "Strain"}, "1566023": {"name": "Flavobacterium sp. KMS", "rank": "Species"}, "34008": {"name": "Rhodovulum", "rank": "Genus"}, "1566022": {"name": "Flavobacterium sp. JRM", "rank": "Species"}, "499235": {"name": "Halomonas phage phiHAP-1", "rank": "Species"}, "1422571": {"name": "Staphylococcus aureus VET0304R", "rank": "Strain"}, "99822": {"name": "Streptococcus dysgalactiae subsp. dysgalactiae", "rank": "Subspecies"}, "218158": {"name": "Arthrobacter sp. I3", "rank": "Species"}, "743813": {"name": "Pseudomonas phage PAK_P1", "rank": "Species"}, "581103": {"name": "Geobacillus sp. Y4.1MC1", "rank": "Species"}, "521460": {"name": "Caldicellulosiruptor bescii DSM 6725", "rank": "Strain"}, "350701": {"name": "Burkholderia dolosa AUO158", "rank": "Strain"}, "35621": {"name": "Streptomyces mobaraensis", "rank": "Species"}, "350702": {"name": "Burkholderia cenocepacia PC184", "rank": "Strain"}, "350704": {"name": "Pseudomonas aeruginosa C3719", "rank": "Strain"}, "674971": {"name": "Aurantiochytrium single-stranded RNA virus 01", "rank": "Species"}, "674970": {"name": "Labyrnavirus", "rank": "Genus"}, "674977": {"name": "Vibrio alginolyticus 40B", "rank": "Strain"}, "674976": {"name": "Dinornavirus", "rank": "Genus"}, "1183388": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN000965", "rank": "Strain"}, "73141": {"name": "Thiocystis violascens", "rank": "Species"}, "674979": {"name": "Bacilladnavirus", "rank": "Genus"}, "674978": {"name": "Unassigned ssRNA viruses", "rank": "No rank"}, "73144": {"name": "Fijivirus group 1", "rank": "No rank"}, "73145": {"name": "Fijivirus group 2", "rank": "No rank"}, "83655": {"name": "Leclercia adecarboxylata", "rank": "Species"}, "83654": {"name": "Leclercia", "rank": "Genus"}, "31658": {"name": "Cell fusing agent virus", "rank": "Species"}, "1550091": {"name": "Sphingobacteriaceae bacterium DW12", "rank": "Species"}, "669359": {"name": "Geminocystis herdmanii", "rank": "Species"}, "82300": {"name": "Adeno-associated virus - 5", "rank": "Strain"}, "1592211": {"name": "Sewage-associated circular DNA molecule-1", "rank": "Species"}, "1592212": {"name": "Sewage-associated circular DNA molecule-3", "rank": "Species"}, "669357": {"name": "Geminocystis", "rank": "Genus"}, "59931": {"name": "Synechococcus sp. WH 7805", "rank": "Species"}, "59930": {"name": "Cyanobium gracile", "rank": "Species"}, "1221583": {"name": "Harpophora oryzae", "rank": "Species"}, "788929": {"name": "Xylella fastidiosa subsp. fastidiosa GB514", "rank": "Strain"}, "1439224": {"name": "Streptococcus pyogenes ABC020052980", "rank": "Strain"}, "71433": {"name": "Mesorhizobium amorphae", "rank": "Species"}, "1391478": {"name": "Enterococcus faecalis EnGen0408", "rank": "Strain"}, "1391479": {"name": "Enterococcus faecalis EnGen0409", "rank": "Strain"}, "1439220": {"name": "Streptococcus pyogenes ABC020052558", "rank": "Strain"}, "163003": {"name": "Thermococcus sp. CL1", "rank": "Species"}, "1439223": {"name": "Streptococcus pyogenes ABC020052898", "rank": "Strain"}, "87882": {"name": "Burkholderia cepacia complex", "rank": "Species group"}, "87883": {"name": "Burkholderia multivorans", "rank": "Species"}, "1391470": {"name": "Enterococcus faecalis EnGen0400", "rank": "Strain"}, "1391471": {"name": "Enterococcus faecalis EnGen0401", "rank": "Strain"}, "1391476": {"name": "Enterococcus faecalis EnGen0406", "rank": "Strain"}, "1391477": {"name": "Enterococcus faecalis EnGen0407", "rank": "Strain"}, "1391474": {"name": "Enterococcus faecalis EnGen0404", "rank": "Strain"}, "526118": {"name": "Morganella phage MmP1", "rank": "Species"}, "1259804": {"name": "Pseudomonas sp. LAIL14HWK12:I9", "rank": "Species"}, "86170": {"name": "Syntrophothermus lipocalidus", "rank": "Species"}, "1259806": {"name": "Pseudomonas sp. LAIL14HWK12:I6", "rank": "Species"}, "1259800": {"name": "Pseudomonas sp. LAMO17WK12:I4", "rank": "Species"}, "1259801": {"name": "Pseudomonas sp. LAIL14HWK12:I7", "rank": "Species"}, "1259803": {"name": "Pseudomonas sp. LAIL14HWK12:I12", "rank": "Species"}, "1259808": {"name": "Firmicutes bacterium JGI 0000119-C08", "rank": "Species"}, "1259809": {"name": "Proteobacteria bacterium JGI 0000113-D06", "rank": "Species"}, "1122228": {"name": "Metascardovia criceti DSM 17774", "rank": "Strain"}, "1282886": {"name": "Aeromonas sp. MDS8", "rank": "Species"}, "1282887": {"name": "Lachnospira multipara ATCC 19207", "rank": "Strain"}, "1282880": {"name": "Helicobacter pylori NAK7", "rank": "Strain"}, "70411": {"name": "Frateuria", "rank": "Genus"}, "1464056": {"name": "Streptomyces capuensis", "rank": "Species"}, "1122225": {"name": "Mesoflavibacter zeaxanthinifaciens DSM 18436", "rank": "Strain"}, "1311128": {"name": "Acinetobacter baumannii 45057_1", "rank": "Strain"}, "122203": {"name": "Fer-de-Lance paramyxovirus", "rank": "Species"}, "57743": {"name": "Salmonella enterica subsp. enterica serovar Weltevreden", "rank": "Strain"}, "1311122": {"name": "Acinetobacter baumannii 25442_5", "rank": "Strain"}, "1311124": {"name": "Acinetobacter baumannii 25442_7", "rank": "Strain"}, "1311126": {"name": "Acinetobacter baumannii 25442_9", "rank": "Strain"}, "913325": {"name": "Lysobacter arseniciresistens ZS79", "rank": "Strain"}, "180199": {"name": "Novispirillum itersonii subsp. itersonii", "rank": "Subspecies"}, "33706": {"name": "Caviid herpesvirus 2", "rank": "Species"}, "1402982": {"name": "Bartonella henselae JK 51", "rank": "Strain"}, "1402981": {"name": "Bartonella henselae JK 50", "rank": "Strain"}, "1402980": {"name": "Bartonella henselae JK 42", "rank": "Strain"}, "1400857": {"name": "Competibacteraceae", "rank": "Family"}, "1400859": {"name": "Candidatus Contendobacter", "rank": "Genus"}, "398767": {"name": "Geobacter lovleyi SZ", "rank": "Strain"}, "1104688": {"name": "Unclassified Aerophobetes", "rank": "No rank"}, "1104685": {"name": "Pseudomonas syringae pv. actinidiae TP6-1", "rank": "Strain"}, "1104684": {"name": "Pseudomonas syringae pv. actinidiae TP1", "rank": "Strain"}, "1104681": {"name": "Pseudomonas syringae pv. actinidiae ICMP 18800", "rank": "Strain"}, "1104680": {"name": "Pseudomonas syringae pv. actinidiae ICMP 18744", "rank": "Strain"}, "1104683": {"name": "Pseudomonas syringae ICMP 18806", "rank": "Strain"}, "1104682": {"name": "Pseudomonas syringae pv. actinidiae ICMP 18804", "rank": "Strain"}, "264729": {"name": "Burkholderia phage BcepMu", "rank": "Species"}, "662761": {"name": "Candidatus Parvarchaeum acidophilus", "rank": "Species"}, "278991": {"name": "Aneurinibacillus terranovensis", "rank": "Species"}, "1339308": {"name": "Bacteroides fragilis str. 3774 T13", "rank": "Strain"}, "1339309": {"name": "Bacteroides fragilis str. 3783N1-2", "rank": "Strain"}, "1208611": {"name": "Salmonella enterica subsp. enterica serovar Abaetetuba str. ATCC 35640", "rank": "Strain"}, "1408918": {"name": "Mycobacterium tuberculosis UT0030", "rank": "Strain"}, "1408919": {"name": "Mycobacterium tuberculosis UT0034", "rank": "Strain"}, "1339302": {"name": "Bacteroides fragilis str. 3986T(B)10", "rank": "Strain"}, "1339303": {"name": "Bacteroides fragilis str. 3986 T(B)13", "rank": "Strain"}, "1408914": {"name": "Mycobacterium tuberculosis UT0022", "rank": "Strain"}, "1408915": {"name": "Mycobacterium tuberculosis UT0024", "rank": "Strain"}, "1408912": {"name": "Mycobacterium tuberculosis UT0016", "rank": "Strain"}, "347329": {"name": "Pseudomonas phage F8", "rank": "Species"}, "1339304": {"name": "Bacteroides fragilis str. 3986 N3", "rank": "Strain"}, "1339305": {"name": "Bacteroides fragilis str. 3986 N(B)22", "rank": "Strain"}, "1398048": {"name": "Staphylococcus aureus M1433", "rank": "Strain"}, "1398049": {"name": "Staphylococcus aureus M1434", "rank": "Strain"}, "99007": {"name": "Pyrobaculum oguniense", "rank": "Species"}, "873160": {"name": "Spinach severe curly top virus", "rank": "Species"}, "99000": {"name": "Tanapox virus", "rank": "Species"}, "1398040": {"name": "Staphylococcus aureus M1423", "rank": "Strain"}, "1398041": {"name": "Staphylococcus aureus M1424", "rank": "Strain"}, "1398042": {"name": "Staphylococcus aureus M1425", "rank": "Strain"}, "1398043": {"name": "Staphylococcus aureus M1428", "rank": "Strain"}, "1048264": {"name": "Streptococcus pyogenes HKU QMH11M0907901", "rank": "Strain"}, "1398045": {"name": "Staphylococcus aureus M1430", "rank": "Strain"}, "1398046": {"name": "Staphylococcus aureus M1431", "rank": "Strain"}, "1398047": {"name": "Staphylococcus aureus M1432", "rank": "Strain"}, "703222": {"name": "Kibdelosporangium sp. MJ126-NF4", "rank": "Species"}, "92963": {"name": "Tomato severe leaf curl virus", "rank": "Species"}, "1196216": {"name": "Staphylococcus aureus subsp. aureus ST72", "rank": "Strain"}, "1322061": {"name": "Rhizoctonia", "rank": "Genus"}, "992077": {"name": "Helicobacter pylori Hp P-8", "rank": "Strain"}, "992075": {"name": "Helicobacter pylori Hp P-4", "rank": "Strain"}, "992074": {"name": "Helicobacter pylori Hp P-3", "rank": "Strain"}, "992073": {"name": "Helicobacter pylori Hp P-2", "rank": "Strain"}, "992072": {"name": "Helicobacter pylori Hp P-1", "rank": "Strain"}, "992079": {"name": "Helicobacter pylori Hp P-13", "rank": "Strain"}, "992078": {"name": "Helicobacter pylori Hp P-11", "rank": "Strain"}, "1291310": {"name": "Leptospira interrogans serovar Szwajizak str. Szwajizak", "rank": "Strain"}, "1085541": {"name": "Leptospira interrogans serovar Australis str. 200703203", "rank": "Strain"}, "944557": {"name": "Prevotella denticola CRIS 18C-A", "rank": "Strain"}, "944559": {"name": "Paenibacillus sp. HGF7", "rank": "Species"}, "1537989": {"name": "Curvularia papendorfii", "rank": "Species"}, "405531": {"name": "Bacillus cereus G9842", "rank": "Strain"}, "405533": {"name": "Bacillus cereus AH1134", "rank": "Strain"}, "405532": {"name": "Bacillus cereus B4264", "rank": "Strain"}, "405535": {"name": "Bacillus cereus AH820", "rank": "Strain"}, "405534": {"name": "Bacillus cereus AH187", "rank": "Strain"}, "405536": {"name": "Bacillus anthracis str. Tsiankovskii-I", "rank": "Strain"}, "216572": {"name": "Oscillospiraceae", "rank": "Family"}, "1053198": {"name": "Bacillus cereus CER057", "rank": "Strain"}, "1053199": {"name": "Bacillus cereus CER074", "rank": "Strain"}, "401526": {"name": "Thermosinus carboxydivorans Nor1", "rank": "Strain"}, "1053197": {"name": "Bacillus cereus BtB2-4", "rank": "Strain"}, "1053194": {"name": "Bacillus cereus BAG6X1-1", "rank": "Strain"}, "1053195": {"name": "Bacillus cereus BAG6X1-2", "rank": "Strain"}, "1053192": {"name": "Bacillus cereus BAG6O-1", "rank": "Strain"}, "1053193": {"name": "Bacillus cereus BAG6O-2", "rank": "Strain"}, "1053190": {"name": "Bacillus cereus BAG5X12-1", "rank": "Strain"}, "1053191": {"name": "Bacillus cereus BAG5X2-1", "rank": "Strain"}, "889254": {"name": "Campylobacter jejuni subsp. jejuni 2008-979", "rank": "Strain"}, "889255": {"name": "Campylobacter jejuni subsp. jejuni 2008-831", "rank": "Strain"}, "889250": {"name": "Campylobacter jejuni subsp. jejuni 2008-1025", "rank": "Strain"}, "889251": {"name": "Campylobacter jejuni subsp. jejuni 2008-894", "rank": "Strain"}, "889252": {"name": "Campylobacter jejuni subsp. jejuni 2008-872", "rank": "Strain"}, "889253": {"name": "Campylobacter jejuni subsp. jejuni 2008-988", "rank": "Strain"}, "1286373": {"name": "Glomeribacter sp. 1016415", "rank": "Species"}, "1286376": {"name": "Delta proteobacterium PSCGC 5451", "rank": "Species"}, "1286374": {"name": "Delta proteobacterium PSCGC 5296", "rank": "Species"}, "1286375": {"name": "Delta proteobacterium PSCGC 5342", "rank": "Species"}, "310575": {"name": "Advenella kashmirensis", "rank": "Species"}, "1089448": {"name": "Fusarium oxysporum f. sp. radicis-lycopersici 26381", "rank": "Strain"}, "1089447": {"name": "Aggregatibacter actinomycetemcomitans RhAA1", "rank": "Strain"}, "1089446": {"name": "Corynebacterium pseudotuberculosis 267", "rank": "Strain"}, "1089445": {"name": "Escherichia coli AI27", "rank": "Strain"}, "1089444": {"name": "Dickeya solani", "rank": "Species"}, "1089443": {"name": "Bacillus subtilis subsp. subtilis str. SC-8", "rank": "Strain"}, "1394612": {"name": "Vibrio parahaemolyticus S069", "rank": "Strain"}, "1394615": {"name": "Vibrio parahaemolyticus S072", "rank": "Strain"}, "1394614": {"name": "Vibrio parahaemolyticus S071", "rank": "Strain"}, "1394619": {"name": "Vibrio parahaemolyticus S076", "rank": "Strain"}, "1560339": {"name": "Enterobacter sp. E20", "rank": "Species"}, "1169363": {"name": "Escherichia coli KTE82", "rank": "Strain"}, "1169362": {"name": "Escherichia coli KTE45", "rank": "Strain"}, "1169361": {"name": "Escherichia coli KTE44", "rank": "Strain"}, "1169360": {"name": "Escherichia coli KTE43", "rank": "Strain"}, "1169367": {"name": "Escherichia coli KTE90", "rank": "Strain"}, "1236518": {"name": "Prevotella scopos JCM 17725", "rank": "Strain"}, "1169365": {"name": "Escherichia coli KTE232", "rank": "Strain"}, "403673": {"name": "Batrachochytrium dendrobatidis JEL423", "rank": "Strain"}, "1236515": {"name": "Bacteroides sartorii JCM 17136 = DSM 21941", "rank": "Strain"}, "1236514": {"name": "Bacteroides stercorirosoris JCM 17103", "rank": "Strain"}, "1169369": {"name": "Escherichia coli KTE95", "rank": "Strain"}, "1169368": {"name": "Escherichia coli KTE94", "rank": "Strain"}, "1236513": {"name": "Bacteroides faecichinchillae JCM 17102", "rank": "Strain"}, "1236512": {"name": "Bacteroides rodentium JCM 16496", "rank": "Strain"}, "1310736": {"name": "Acinetobacter baumannii 233846", "rank": "Strain"}, "1310737": {"name": "Acinetobacter baumannii 1271213", "rank": "Strain"}, "1310734": {"name": "Acinetobacter baumannii 216872", "rank": "Strain"}, "1310735": {"name": "Acinetobacter baumannii 737393", "rank": "Strain"}, "1310732": {"name": "Acinetobacter baumannii 1271651", "rank": "Strain"}, "1310733": {"name": "Acinetobacter baumannii 1195185_11", "rank": "Strain"}, "1310730": {"name": "Acinetobacter baumannii 1207552", "rank": "Strain"}, "1310731": {"name": "Acinetobacter baumannii 1178044", "rank": "Strain"}, "1310738": {"name": "Acinetobacter baumannii 273929", "rank": "Strain"}, "1310739": {"name": "Acinetobacter baumannii 1045092", "rank": "Strain"}, "1534553": {"name": "Duck aviadenovirus B", "rank": "No rank"}, "889872": {"name": "Unclassified Nidovirales", "rank": "No rank"}, "55952": {"name": "Streptomyces toyocaensis", "rank": "Species"}, "55951": {"name": "Grapevine leafroll-associated virus 3", "rank": "Species"}, "1352579": {"name": "Mycobacterium tuberculosis PanR0607", "rank": "Strain"}, "1400139": {"name": "Enterobacter aerogenes UCI 16", "rank": "Strain"}, "1402163": {"name": "Wolbachia endosymbiont wPip_Mol of Culex molestus", "rank": "Strain"}, "1158639": {"name": "Enterococcus faecium EnGen0317", "rank": "Strain"}, "1158638": {"name": "Enterococcus faecium EnGen0315", "rank": "Strain"}, "1158635": {"name": "Enterococcus faecium EnGen0267", "rank": "Strain"}, "1158634": {"name": "Enterococcus faecalis EnGen0250", "rank": "Strain"}, "1158637": {"name": "Enterococcus faecalis EnGen0299", "rank": "Strain"}, "1158636": {"name": "Enterococcus faecium EnGen0313", "rank": "Strain"}, "1158631": {"name": "Enterococcus faecalis EnGen0251", "rank": "Strain"}, "1158630": {"name": "Enterococcus faecalis EnGen0252", "rank": "Strain"}, "1158633": {"name": "Enterococcus faecalis EnGen0249", "rank": "Strain"}, "1158632": {"name": "Enterococcus faecalis EnGen0231", "rank": "Strain"}, "1449076": {"name": "Sphingomonas sp. UNC305MFCol5.2", "rank": "Species"}, "1449077": {"name": "Streptomyces sp. UNC401CLCol", "rank": "Species"}, "1449070": {"name": "Nocardioides sp. UNC345MFTsu5.1", "rank": "Species"}, "108619": {"name": "Salmonella enterica subsp. enterica serovar Newport", "rank": "Strain"}, "334857": {"name": "Goodfellowiella", "rank": "Genus"}, "314256": {"name": "Oceanicola granulosus HTCC2516", "rank": "Strain"}, "314255": {"name": "Oceanicola batsensis", "rank": "Species"}, "314254": {"name": "Oceanicaulis sp. HTCC2633", "rank": "Species"}, "314253": {"name": "Nitrobacter sp. Nb-311A", "rank": "Species"}, "68260": {"name": "Streptomyces pyridomyceticus", "rank": "Species"}, "771875": {"name": "Fervidobacterium pennivorans DSM 9078", "rank": "Strain"}, "79668": {"name": "Clostridium perfringens C", "rank": "Strain"}, "1444093": {"name": "Escherichia coli 2-011-08_S1_C3", "rank": "Strain"}, "1444092": {"name": "Escherichia coli 2-005-03_S1_C3", "rank": "Strain"}, "1444091": {"name": "Escherichia coli 6-537-08_S1_C2", "rank": "Strain"}, "1444090": {"name": "Escherichia coli 6-319-05_S1_C2", "rank": "Strain"}, "1444097": {"name": "Escherichia coli 2-210-07_S1_C3", "rank": "Strain"}, "1444096": {"name": "Escherichia coli 2-177-06_S1_C3", "rank": "Strain"}, "1444095": {"name": "Escherichia coli 2-156-04_S1_C3", "rank": "Strain"}, "1444094": {"name": "Escherichia coli 2-052-05_S1_C3", "rank": "Strain"}, "33926": {"name": "Candidatus Phytoplasma", "rank": "Genus"}, "93929": {"name": "Thermotoga petrophila", "rank": "Species"}, "33924": {"name": "Mycoplasma testudinis", "rank": "Species"}, "1444098": {"name": "Escherichia coli 2-222-05_S1_C3", "rank": "Strain"}, "1159030": {"name": "Helicobacter pylori GAM121Aii", "rank": "Strain"}, "33923": {"name": "Mycoplasma felis", "rank": "Species"}, "1159032": {"name": "Helicobacter pylori GAM210Bi", "rank": "Strain"}, "1159033": {"name": "Helicobacter pylori GAM231Ai", "rank": "Strain"}, "926559": {"name": "Joostella marina DSM 19592", "rank": "Strain"}, "1495316": {"name": "Soybean cyst nematode virus 5", "rank": "Species"}, "926551": {"name": "Capnocytophaga cynodegmi DSM 19736", "rank": "Strain"}, "926550": {"name": "Caldilinea aerophila DSM 14535 = NBRC 104270", "rank": "Strain"}, "926556": {"name": "Echinicola vietnamensis DSM 17526", "rank": "Strain"}, "926554": {"name": "Deinococcus pimensis DSM 21231", "rank": "Strain"}, "1571532": {"name": "Streptomyces sp. CNQ431", "rank": "Species"}, "388435": {"name": "Lecanoromycetidae", "rank": "Subclass"}, "1234603": {"name": "Candidatus Moranella endobia PCVAL", "rank": "Strain"}, "1234601": {"name": "Lactococcus lactis subsp. lactis bv. diacetylactis str. TIFN2", "rank": "Strain"}, "1234600": {"name": "Helicobacter pylori Rif2", "rank": "Strain"}, "1234606": {"name": "Gayadomonas joobiniege", "rank": "Species"}, "1234605": {"name": "Gayadomonas", "rank": "Genus"}, "184607": {"name": "Crocinitomix catalasitica", "rank": "Species"}, "563008": {"name": "Prevotella oris C735", "rank": "Strain"}, "1229202": {"name": "Vibrio vulnificus B2", "rank": "Strain"}, "1229205": {"name": "Burkholderia phenoliruptrix BR3459a", "rank": "Strain"}, "1229204": {"name": "Alpha proteobacterium L41A", "rank": "Species"}, "566037": {"name": "Saccharomycetaceae sp. 'Ashbya aceri'", "rank": "Species"}, "1121130": {"name": "Butyricimonas virosa DSM 23226", "rank": "Strain"}, "272240": {"name": "Pseudoclavibacter faecalis", "rank": "Species"}, "449133": {"name": "Epizootic hemorrhagic disease virus (serotype 1 / strain New Jersey)", "rank": "Strain"}, "943272": {"name": "Honeysuckle ringspot virus", "rank": "Species"}, "336959": {"name": "Chicken astrovirus", "rank": "Species"}, "1333855": {"name": "Pseudomonas aeruginosa WC55", "rank": "Strain"}, "1094469": {"name": "Acinetobacter baumannii ABNIH5", "rank": "Strain"}, "1041521": {"name": "Lactobacillus salivarius GJ-24", "rank": "Strain"}, "1041522": {"name": "Mycobacterium colombiense CECT 3035", "rank": "Strain"}, "482630": {"name": "Hassallia byssoidea", "rank": "Species"}, "1041524": {"name": "Enterobacteria phage K30", "rank": "Species"}, "312063": {"name": "Azohydromonas", "rank": "Genus"}, "1041526": {"name": "Staphylococcus phage S25-3", "rank": "Species"}, "1041527": {"name": "Staphylococcus phage S25-4", "rank": "Species"}, "570967": {"name": "Fodinicurvata fenggangensis DSM 21160", "rank": "Strain"}, "311453": {"name": "Anncaliia", "rank": "Genus"}, "345250": {"name": "Raven circovirus", "rank": "Species"}, "40990": {"name": "Saccharomonospora glauca", "rank": "Species"}, "1327758": {"name": "Streptomyces phage Lika", "rank": "Species"}, "1327759": {"name": "Streptomyces phage Sujidade", "rank": "Species"}, "561276": {"name": "Streptococcus pneumoniae ATCC 700669", "rank": "Strain"}, "1094466": {"name": "Flavobacterium indicum GPTSA100-9 = DSM 17447", "rank": "Strain"}, "28261": {"name": "Thermodesulfovibrio", "rank": "Genus"}, "28263": {"name": "Arcanobacterium", "rank": "Genus"}, "28262": {"name": "Thermodesulfovibrio yellowstonii", "rank": "Species"}, "28265": {"name": "St. Augustine decline satellite virus", "rank": "Species"}, "28264": {"name": "Arcanobacterium haemolyticum", "rank": "Species"}, "1479623": {"name": "Curtobacterium sp. S6", "rank": "Species"}, "1151392": {"name": "Peptoclostridium difficile Y401", "rank": "Strain"}, "1112215": {"name": "Salinibacterium sp. PAMC 21357", "rank": "Species"}, "452589": {"name": "Trichoderma atroviride IMI 206040", "rank": "Strain"}, "1112216": {"name": "Sphingomonas sp. PAMC 26617", "rank": "Species"}, "1151395": {"name": "Peptoclostridium difficile P3", "rank": "Strain"}, "273116": {"name": "Thermoplasma volcanium GSS1", "rank": "Strain"}, "1402875": {"name": "Ralstonia phage RSB3", "rank": "Species"}, "273119": {"name": "Ureaplasma parvum serovar 3 str. ATCC 700970", "rank": "Strain"}, "1833": {"name": "Rhodococcus erythropolis", "rank": "Species"}, "1502761": {"name": "Methylotenera sp. N17", "rank": "Species"}, "1502762": {"name": "Janthinobacterium sp. RA13", "rank": "Species"}, "1422581": {"name": "Staphylococcus aureus VET0316R", "rank": "Strain"}, "1335321": {"name": "Mycobacterium sp. MAC_011194_8550", "rank": "Species"}, "1422583": {"name": "Staphylococcus aureus VET0318R", "rank": "Strain"}, "1422582": {"name": "Staphylococcus aureus VET0317R", "rank": "Strain"}, "1422585": {"name": "Staphylococcus aureus VET0320R", "rank": "Strain"}, "1422584": {"name": "Staphylococcus aureus VET0319R", "rank": "Strain"}, "1422587": {"name": "Staphylococcus aureus VET0323R", "rank": "Strain"}, "1422586": {"name": "Staphylococcus aureus VET0322R", "rank": "Strain"}, "1422589": {"name": "Staphylococcus aureus VET0326R", "rank": "Strain"}, "1422588": {"name": "Staphylococcus aureus VET0325R", "rank": "Strain"}, "209650": {"name": "Acidicaldus organivorans", "rank": "Species"}, "1281074": {"name": "Escherichia coli HVH 141 (4-5995973)", "rank": "Strain"}, "1271862": {"name": "Salmonella enterica subsp. enterica serovar Typhimurium var. 5- str. CFSAN001921", "rank": "Strain"}, "1271863": {"name": "Salmonella enterica subsp. enterica serovar Cubana str. CFSAN002050", "rank": "Strain"}, "1271864": {"name": "Salmonella enterica subsp. enterica serovar Heidelberg str. CFSAN002069", "rank": "Strain"}, "648757": {"name": "Rhodomicrobium vannielii ATCC 17100", "rank": "Strain"}, "1366420": {"name": "Sulfobacillus thermosulfidooxidans ST", "rank": "Strain"}, "64713": {"name": "Halorubrum coriense", "rank": "Species"}, "223301": {"name": "Pepper golden mosaic virus", "rank": "Species"}, "223303": {"name": "Pepper huasteco yellow vein virus", "rank": "Species"}, "223305": {"name": "Pepper leaf curl Bangladesh virus", "rank": "Species"}, "223307": {"name": "Potato yellow mosaic Panama virus", "rank": "Species"}, "223308": {"name": "Potato yellow mosaic Trinidad virus", "rank": "Species"}, "1312445": {"name": "Ustilaginoidea virens RNA virus 1", "rank": "Species"}, "1273125": {"name": "Rhodococcus rhodnii LMG 5362", "rank": "Strain"}, "690871": {"name": "Anoxybacillus sp. DT3-1", "rank": "Species"}, "438033": {"name": "Ruminococcus gauvreauii", "rank": "Species"}, "1412739": {"name": "Staphylococcus aureus F60346", "rank": "Strain"}, "1412738": {"name": "Staphylococcus aureus F57036", "rank": "Strain"}, "1412735": {"name": "Staphylococcus aureus F53404", "rank": "Strain"}, "1412734": {"name": "Staphylococcus aureus F53399", "rank": "Strain"}, "1412737": {"name": "Staphylococcus aureus F57033", "rank": "Strain"}, "1412736": {"name": "Staphylococcus aureus F57021", "rank": "Strain"}, "283643": {"name": "Cryptococcus neoformans var. neoformans B-3501A", "rank": "Strain"}, "1412730": {"name": "Staphylococcus aureus F50121", "rank": "Strain"}, "1412733": {"name": "Staphylococcus aureus F53393", "rank": "Strain"}, "1412732": {"name": "Staphylococcus aureus F53388", "rank": "Strain"}, "1331272": {"name": "Bordetella pertussis I176", "rank": "Strain"}, "1331273": {"name": "Bordetella pertussis STO1-CHOC-0008", "rank": "Strain"}, "1331270": {"name": "Bordetella pertussis I002", "rank": "Strain"}, "1331271": {"name": "Bordetella pertussis I036", "rank": "Strain"}, "1331276": {"name": "Bordetella pertussis STO1-CHOC-0016", "rank": "Strain"}, "1331277": {"name": "Bordetella pertussis STO1-CHOC-0017", "rank": "Strain"}, "1331274": {"name": "Bordetella pertussis STO1-CHOM-0012", "rank": "Strain"}, "1331275": {"name": "Bordetella pertussis STO1-CNMC-0004", "rank": "Strain"}, "1331278": {"name": "Bordetella pertussis STO1-CHOC-0018", "rank": "Strain"}, "1331279": {"name": "Bordetella pertussis STO1-CHOC-0019", "rank": "Strain"}, "1423436": {"name": "Mycobacterium tuberculosis BTB04-097", "rank": "Strain"}, "1423437": {"name": "Mycobacterium tuberculosis BTB03-142", "rank": "Strain"}, "1423435": {"name": "Mycobacterium tuberculosis BTB04-011", "rank": "Strain"}, "1423432": {"name": "Mycobacterium tuberculosis BTB04-001", "rank": "Strain"}, "1423430": {"name": "Mycobacterium tuberculosis BTB03-168", "rank": "Strain"}, "1423431": {"name": "Mycobacterium tuberculosis BTB03-169", "rank": "Strain"}, "1108865": {"name": "Salmonella phage PhiSH19", "rank": "Species"}, "1423438": {"name": "Mycobacterium tuberculosis BTB04-128", "rank": "Strain"}, "1423439": {"name": "Mycobacterium tuberculosis BTB04-158", "rank": "Strain"}, "660062": {"name": "Methermicoccaceae", "rank": "Family"}, "660063": {"name": "Methermicoccus", "rank": "Genus"}, "660064": {"name": "Methermicoccus shengliensis", "rank": "Species"}, "85004": {"name": "Bifidobacteriales", "rank": "Order"}, "85005": {"name": "Actinomycineae", "rank": "Suborder"}, "655314": {"name": "Unclassified Kobuvirus", "rank": "No rank"}, "85006": {"name": "Micrococcineae", "rank": "Suborder"}, "29430": {"name": "Acinetobacter haemolyticus", "rank": "Species"}, "1247713": {"name": "Burkholderia pseudomallei MSHR1043", "rank": "Strain"}, "85000": {"name": "Sphaerobacteridae", "rank": "Subclass"}, "1247714": {"name": "Microbacterium sp. UCD-TDU", "rank": "Species"}, "85002": {"name": "Sphaerobacteraceae", "rank": "Family"}, "1055352": {"name": "Streptomyces sp. W007", "rank": "Species"}, "85003": {"name": "Actinobacteridae", "rank": "Subclass"}, "89463": {"name": "Sacbrood virus", "rank": "Species"}, "1400909": {"name": "Mycobacterium tuberculosis KT-0058", "rank": "Strain"}, "1518574": {"name": "Burkina Faso astrovirus", "rank": "Species"}, "1400908": {"name": "Mycobacterium tuberculosis KT-0057", "rank": "Strain"}, "82171": {"name": "Desulfovibrio zosterae", "rank": "Species"}, "110457": {"name": "Yersinia phage phiYeO3-12", "rank": "Species"}, "110456": {"name": "T7likevirus", "rank": "Genus"}, "1177767": {"name": "Dyoetapapillomavirus 1", "rank": "Species"}, "716929": {"name": "Unclassified Single stranded DNA satellites", "rank": "No rank"}, "447601": {"name": "Sida leaf curl virus satellite DNA beta", "rank": "Species"}, "1346766": {"name": "Mycobacterium tuberculosis PanR0411", "rank": "Strain"}, "1346767": {"name": "Mycobacterium tuberculosis PanR0410", "rank": "Strain"}, "1133653": {"name": "Porcine bocavirus 5", "rank": "Species"}, "1346768": {"name": "Mycobacterium tuberculosis PanR0409", "rank": "Strain"}, "1302630": {"name": "Listeria monocytogenes SHL010", "rank": "Strain"}, "1302631": {"name": "Listeria monocytogenes SHL011", "rank": "Strain"}, "1302632": {"name": "Listeria monocytogenes SHL012", "rank": "Strain"}, "1302633": {"name": "Listeria monocytogenes SHL013", "rank": "Strain"}, "53357": {"name": "Intrasporangium", "rank": "Genus"}, "53354": {"name": "Streptococcus gallolyticus subsp. gallolyticus", "rank": "Subspecies"}, "53358": {"name": "Intrasporangium calvum", "rank": "Species"}, "762633": {"name": "Thermus thermophilus SG0.5JP17-16", "rank": "Strain"}, "1335757": {"name": "Spiribacter sp. UAH-SP71", "rank": "Species"}, "656429": {"name": "Escherichia coli TA007", "rank": "Strain"}, "718254": {"name": "Enterobacter cloacae subsp. cloacae NCTC 9394", "rank": "Strain"}, "1464061": {"name": "Streptomyces carneus", "rank": "Species"}, "656421": {"name": "Escherichia coli M919", "rank": "Strain"}, "656420": {"name": "Escherichia coli M863", "rank": "Strain"}, "1410467": {"name": "Halyomorpha halys virus", "rank": "Species"}, "10501": {"name": "Phycodnaviridae", "rank": "Family"}, "4761": {"name": "Chytridiomycota", "rank": "Phylum"}, "10506": {"name": "Paramecium bursaria Chlorella virus 1", "rank": "Species"}, "10509": {"name": "Mastadenovirus", "rank": "Genus"}, "876044": {"name": "Gamma proteobacterium IMCC3088", "rank": "Species"}, "1074089": {"name": "Streptococcus sobrinus TCI-395", "rank": "Strain"}, "1074088": {"name": "Streptococcus sobrinus TCI-392", "rank": "Strain"}, "1074086": {"name": "Streptococcus sobrinus TCI-384", "rank": "Strain"}, "1074085": {"name": "Streptococcus sobrinus TCI-381", "rank": "Strain"}, "1074084": {"name": "Streptococcus sobrinus TCI-377", "rank": "Strain"}, "1074082": {"name": "Streptococcus sobrinus TCI-374", "rank": "Strain"}, "1074081": {"name": "Streptococcus sobrinus TCI-373", "rank": "Strain"}, "1074080": {"name": "Streptococcus sobrinus TCI-367", "rank": "Strain"}, "1421904": {"name": "Staphylococcus aureus W19256", "rank": "Strain"}, "1421905": {"name": "Staphylococcus aureus W19270", "rank": "Strain"}, "1421906": {"name": "Staphylococcus aureus W19276", "rank": "Strain"}, "1421907": {"name": "Staphylococcus aureus W25797", "rank": "Strain"}, "1421900": {"name": "Staphylococcus aureus W15974", "rank": "Strain"}, "1421901": {"name": "Staphylococcus aureus W15976", "rank": "Strain"}, "1421902": {"name": "Staphylococcus aureus W15990", "rank": "Strain"}, "1421903": {"name": "Staphylococcus aureus W15995", "rank": "Strain"}, "1421908": {"name": "Staphylococcus aureus W25799", "rank": "Strain"}, "1421909": {"name": "Staphylococcus aureus W28921", "rank": "Strain"}, "379068": {"name": "Galbibacter", "rank": "Genus"}, "379065": {"name": "Caldalkalibacillus", "rank": "Genus"}, "379064": {"name": "Cyanobacterium aponinum", "rank": "Species"}, "379067": {"name": "Streptomyces bingchenggensis", "rank": "Species"}, "379066": {"name": "Gemmatimonas aurantiaca T-27", "rank": "Strain"}, "339656": {"name": "Halomonas smyrnensis AAD6", "rank": "Strain"}, "363555": {"name": "Lactobacillus phage KC5a", "rank": "Species"}, "104580": {"name": "Kadipiro virus", "rank": "Species"}, "760568": {"name": "Desulfotomaculum kuznetsovii DSM 6115", "rank": "Strain"}, "104581": {"name": "St Croix River virus", "rank": "Species"}, "1353528": {"name": "Thioclava sp. DT23-4", "rank": "Species"}, "1353529": {"name": "Bacteriovorax sp. BSW11_IV", "rank": "Species"}, "1007654": {"name": "Bacillus sp. 916", "rank": "Species"}, "1007656": {"name": "Pseudomonas fluorescens Wayne1", "rank": "Strain"}, "909932": {"name": "Negativicutes", "rank": "Class"}, "66084": {"name": "Wolbachia sp. wRi", "rank": "Species"}, "941190": {"name": "Salmonella enterica subsp. enterica serovar Chester str. ATCC 11997", "rank": "Strain"}, "941193": {"name": "Pseudomonas aeruginosa M18", "rank": "Strain"}, "909930": {"name": "Acidaminococcaceae", "rank": "Family"}, "1511899": {"name": "Squamate dependoparvovirus 1", "rank": "Species"}, "46469": {"name": "Orenia marismortui", "rank": "Species"}, "1511892": {"name": "Adeno-associated dependoparvovirus B", "rank": "Species"}, "1511890": {"name": "Ungulate copiparvovirus 2", "rank": "Species"}, "1511891": {"name": "Adeno-associated dependoparvovirus A", "rank": "Species"}, "51290": {"name": "Chlamydiae/Verrucomicrobia group", "rank": "Superphylum"}, "51291": {"name": "Chlamydiales", "rank": "Order"}, "1511894": {"name": "Avian dependoparvovirus 1", "rank": "Species"}, "1511895": {"name": "Anseriform dependoparvovirus 1", "rank": "Species"}, "1295756": {"name": "Mycobacterium tuberculosis TKK_02_0040", "rank": "Strain"}, "1295757": {"name": "Mycobacterium tuberculosis TKK_02_0041", "rank": "Strain"}, "1295751": {"name": "Mycobacterium tuberculosis TKK_02_0035", "rank": "Strain"}, "1295753": {"name": "Mycobacterium tuberculosis TKK_02_0037", "rank": "Strain"}, "31932": {"name": "Nitrosopumilales", "rank": "Order"}, "1295758": {"name": "Mycobacterium tuberculosis TKK_02_0042", "rank": "Strain"}, "1295759": {"name": "Mycobacterium tuberculosis TKK_02_0043", "rank": "Strain"}, "119224": {"name": "Streptococcus phocae", "rank": "Species"}, "1223410": {"name": "Altibacter lentus", "rank": "Species"}, "941449": {"name": "Desulfovibrio sp. X2", "rank": "Species"}, "454155": {"name": "Paraprevotella xylaniphila", "rank": "Species"}, "295084": {"name": "Wolbachia endosymbiont of Drosophila willistoni", "rank": "Species"}, "1086054": {"name": "Rhizoctonia solani AG-3 Rhs1AP", "rank": "Strain"}, "151528": {"name": "Synechococcus phage P60", "rank": "Species"}, "1427503": {"name": "Holospora elegans E1", "rank": "Strain"}, "1318615": {"name": "Streptococcus agalactiae ILRI112", "rank": "Strain"}, "127906": {"name": "Vibrio cholerae O1", "rank": "Strain"}, "1318617": {"name": "Candidatus Mycoplasma girerdii", "rank": "Species"}, "1288492": {"name": "Enterococcus durans IPLA 655", "rank": "Strain"}, "673266": {"name": "Pseudomonas syringae pv. syringae 642", "rank": "Strain"}, "673265": {"name": "Pseudomonas syringae pv. tomato NCPPB 1108", "rank": "Strain"}, "626096": {"name": "Ureaplasma urealyticum serovar 2 str. ATCC 27814", "rank": "Strain"}, "626095": {"name": "Ureaplasma urealyticum serovar 8 str. ATCC 27618", "rank": "Strain"}, "1183389": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN000966", "rank": "Strain"}, "1395125": {"name": "Prevotella salivae F0493", "rank": "Strain"}, "1395123": {"name": "Cupriavidus metallidurans H1130", "rank": "Strain"}, "1183380": {"name": "Campylobacter coli RM5611", "rank": "Strain"}, "1183387": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN000964", "rank": "Strain"}, "1084232": {"name": "Yersinia pestis biovar Orientalis str. AS200902147", "rank": "Strain"}, "1281276": {"name": "Escherichia coli UMEA 3955-1", "rank": "Strain"}, "1281277": {"name": "Escherichia coli UMEA 4075-1", "rank": "Strain"}, "470934": {"name": "Pantoea vagans", "rank": "Species"}, "292052": {"name": "White clover cryptic virus 1", "rank": "Species"}, "1281274": {"name": "Escherichia coli UMEA 3893-1", "rank": "Strain"}, "365046": {"name": "Ramlibacter tataouinensis TTB310", "rank": "Strain"}, "365044": {"name": "Polaromonas naphthalenivorans CJ2", "rank": "Strain"}, "1281272": {"name": "Escherichia coli UMEA 3834-1", "rank": "Strain"}, "365048": {"name": "Geobacillus phage GBSV1", "rank": "Species"}, "1281273": {"name": "Escherichia coli UMEA 3889-1", "rank": "Strain"}, "1137249": {"name": "Salinispora tropica CNS197", "rank": "Strain"}, "1137248": {"name": "Salinispora tropica CNH898", "rank": "Strain"}, "1400136": {"name": "Citrobacter freundii UCI 31", "rank": "Strain"}, "1400137": {"name": "Citrobacter freundii UCI 32", "rank": "Strain"}, "1400138": {"name": "Enterobacter aerogenes UCI 15", "rank": "Strain"}, "69825": {"name": "Clostridium indolis", "rank": "Species"}, "69823": {"name": "Selenomonas sputigena", "rank": "Species"}, "1397689": {"name": "Cronobacter sakazakii 8399", "rank": "Strain"}, "599737": {"name": "Wickerhamomyces", "rank": "Genus"}, "712148": {"name": "Aggregatibacter sp. oral taxon 458", "rank": "Species"}, "1839": {"name": "Nocardioides", "rank": "Genus"}, "1836": {"name": "Saccharopolyspora erythraea", "rank": "Species"}, "1112214": {"name": "Sphingomonas sp. PAMC 26605", "rank": "Species"}, "1112217": {"name": "Pseudomonas psychrotolerans L19", "rank": "Strain"}, "1835": {"name": "Saccharopolyspora", "rank": "Genus"}, "1112211": {"name": "Janthinobacterium lividum PAMC 25724", "rank": "Strain"}, "915293": {"name": "Ageratum yellow vein Singapore alphasatellite", "rank": "Species"}, "1830": {"name": "Rhodococcus ruber", "rank": "Species"}, "1112212": {"name": "Sphingomonas echinoides ATCC 14820", "rank": "Strain"}, "712213": {"name": "Capnocytophaga sp. oral taxon 332", "rank": "Species"}, "1434049": {"name": "Thermophagus", "rank": "Genus"}, "1434048": {"name": "Thermoanaerobaculum", "rank": "Genus"}, "992125": {"name": "Helicobacter pylori Hp M9", "rank": "Strain"}, "543728": {"name": "Variovorax paradoxus S110", "rank": "Strain"}, "72003": {"name": "Diatraea saccharalis densovirus", "rank": "Species"}, "72000": {"name": "Kocuria rhizophila", "rank": "Species"}, "162491": {"name": "Oerskovia", "rank": "Genus"}, "146015": {"name": "Elephantid herpesvirus 1", "rank": "Species"}, "1368424": {"name": "Bacillus licheniformis CG-B52", "rank": "Strain"}, "1146845": {"name": "Dongia", "rank": "Genus"}, "1001746": {"name": "Streptococcus pneumoniae BR1064", "rank": "Strain"}, "1079895": {"name": "Mycobacterium phage Pleione", "rank": "Species"}, "1079894": {"name": "Mycobacterium phage Redi", "rank": "Species"}, "356302": {"name": "Chitinimonas koreensis", "rank": "Species"}, "507750": {"name": "Peptoniphilus duerdenii", "rank": "Species"}, "720557": {"name": "Bacillus atrophaeus Detrick-2", "rank": "Strain"}, "720556": {"name": "Bacillus atrophaeus Detrick-1", "rank": "Strain"}, "720555": {"name": "Bacillus atrophaeus 1942", "rank": "Strain"}, "720554": {"name": "Clostridium clariflavum DSM 19732", "rank": "Strain"}, "720558": {"name": "Bacillus atrophaeus Detrick-3", "rank": "Strain"}, "1415628": {"name": "Gyrovirus Tu789", "rank": "Species"}, "140410": {"name": "P2likevirus", "rank": "Genus"}, "348824": {"name": "Rhizobium sp. LPU83", "rank": "Species"}, "69974": {"name": "Mesorhizobium plurifarium", "rank": "Species"}, "1348973": {"name": "Bacillus azotoformans MEV2011", "rank": "Strain"}, "169050": {"name": "Gelidibacter mesophilus", "rank": "Species"}, "13773": {"name": "Pyrobaculum aerophilum", "rank": "Species"}, "1324329": {"name": "Staphylococcus aureus HST-107", "rank": "Strain"}, "1324326": {"name": "Staphylococcus aureus HST-084", "rank": "Strain"}, "1415626": {"name": "Methanobrevibacter oralis JMR01", "rank": "Strain"}, "985683": {"name": "Donggang virus", "rank": "Species"}, "1415627": {"name": "Gyrovirus Tu243", "rank": "Species"}, "270117": {"name": "Euphorbia leaf curl virus", "rank": "Species"}, "136100": {"name": "Knoellia sinensis", "rank": "Species"}, "1435464": {"name": "Bifidobacterium psychraerophilum DSM 22366", "rank": "Strain"}, "1411542": {"name": "Staphylococcus aureus H70826", "rank": "Strain"}, "1499680": {"name": "Bacillus sp. MT2", "rank": "Species"}, "85076": {"name": "Marichromatium", "rank": "Genus"}, "85072": {"name": "Allochromatium", "rank": "Genus"}, "754025": {"name": "Staphylococcus aureus subsp. aureus MRSA131", "rank": "Strain"}, "754026": {"name": "Staphylococcus aureus subsp. aureus MRSA177", "rank": "Strain"}, "754027": {"name": "Treponema phagedenis F0421", "rank": "Strain"}, "40666": {"name": "Ryegrass mosaic virus", "rank": "Species"}, "1403315": {"name": "Pseudomonas fluorescens PA4C2", "rank": "Strain"}, "1403314": {"name": "Pseudomonas brassicacearum PP1_210F", "rank": "Strain"}, "1403316": {"name": "Mycoplasma parvum str. Indiana", "rank": "Strain"}, "1403313": {"name": "Bacillus simplex BA2H3", "rank": "Strain"}, "1403312": {"name": "Lactobacillus gasseri 130918", "rank": "Strain"}, "290434": {"name": "Borrelia garinii PBi", "rank": "Strain"}, "160232": {"name": "Nanoarchaeum equitans", "rank": "Species"}, "164750": {"name": "Helminthosporium victoriae 145S virus", "rank": "Species"}, "164757": {"name": "Mycobacterium sp. JLS", "rank": "Species"}, "164756": {"name": "Mycobacterium sp. MCS", "rank": "Species"}, "110319": {"name": "Nocardioides sp. CF8", "rank": "Species"}, "1432050": {"name": "Rhizobium etli bv. mimosae str. IE4771", "rank": "Strain"}, "1432056": {"name": "Mannheimia varigena USDA-ARS-USMARC-1261", "rank": "Strain"}, "1432057": {"name": "Xanthomonas arboricola 3004", "rank": "Strain"}, "1432055": {"name": "Komagataeibacter rhaeticus AF1", "rank": "Strain"}, "1339265": {"name": "Pseudomonas aeruginosa IGB83", "rank": "Strain"}, "1339264": {"name": "Pseudomonas aeruginosa ID4365", "rank": "Strain"}, "1151366": {"name": "Peptoclostridium difficile F249", "rank": "Strain"}, "1151367": {"name": "Peptoclostridium difficile F253", "rank": "Strain"}, "1151360": {"name": "Peptoclostridium difficile DA00306", "rank": "Strain"}, "1151361": {"name": "Peptoclostridium difficile DA00307", "rank": "Strain"}, "1339263": {"name": "Pseudomonas aeruginosa 148", "rank": "Strain"}, "1151363": {"name": "Peptoclostridium difficile DA00313", "rank": "Strain"}, "1339269": {"name": "Bacteroides fragilis str. Korea 419", "rank": "Strain"}, "998088": {"name": "Aeromonas veronii B565", "rank": "Strain"}, "998089": {"name": "Mycobacterium bovis BCG str. China", "rank": "Strain"}, "1154909": {"name": "Streptococcus agalactiae GB00226", "rank": "Strain"}, "1154908": {"name": "Streptococcus agalactiae GB00219", "rank": "Strain"}, "998084": {"name": "Streptomyces himastatinicus", "rank": "Species"}, "1154906": {"name": "Streptococcus agalactiae GB00202", "rank": "Strain"}, "1154905": {"name": "Streptococcus agalactiae GB00190", "rank": "Strain"}, "998087": {"name": "Lactococcus garvieae 21881", "rank": "Strain"}, "1154903": {"name": "Streptococcus agalactiae GB00115", "rank": "Strain"}, "1154902": {"name": "Streptococcus agalactiae GB00111", "rank": "Strain"}, "1154901": {"name": "Streptococcus agalactiae GB00097", "rank": "Strain"}, "1154900": {"name": "Streptococcus agalactiae GB00092", "rank": "Strain"}, "546367": {"name": "Hafnia paralvei", "rank": "Species"}, "1327969": {"name": "Cellulophaga phage phi12:2", "rank": "Species"}, "1327968": {"name": "Cellulophaga phage phi48:2", "rank": "Species"}, "1327965": {"name": "Pseudomonas phage CHA_P1", "rank": "Species"}, "1327964": {"name": "Pseudomonas phage PAK_P5", "rank": "Species"}, "1327966": {"name": "Pseudomonas phage PAK_P4", "rank": "Species"}, "1235850": {"name": "Methanomassiliicoccales", "rank": "Order"}, "710686": {"name": "Mycobacterium smegmatis JS623", "rank": "Strain"}, "1328881": {"name": "Candidatus Midichloriaceae", "rank": "Family"}, "572290": {"name": "Thrush coronavirus HKU12-600", "rank": "Strain"}, "47985": {"name": "Grapevine leafroll-associated virus 1", "rank": "Species"}, "714083": {"name": "Leucobacter chromiiresistens JG 31", "rank": "Strain"}, "69499": {"name": "Petrotoga mobilis", "rank": "Species"}, "690585": {"name": "Rhizobium vignae", "rank": "Species"}, "243063": {"name": "Thioalkalivibrio thiocyanodenitrificans", "rank": "Species"}, "1070417": {"name": "Human papillomavirus type 144", "rank": "Strain"}, "1070410": {"name": "Human papillomavirus type 137", "rank": "Strain"}, "1070413": {"name": "Human papillomavirus type 140", "rank": "Species"}, "264995": {"name": "Anaerofustis", "rank": "Genus"}, "10651": {"name": "Soybean chlorotic mottle virus", "rank": "Species"}, "346": {"name": "Xanthomonas citri", "rank": "Species"}, "1409961": {"name": "Klebsiella pneumoniae MRSN 1319", "rank": "Strain"}, "57732": {"name": "Enterococcus asini", "rank": "Species"}, "343": {"name": "Xanthomonas translucens", "rank": "Species"}, "340": {"name": "Xanthomonas campestris pv. campestris", "rank": "Strain"}, "706191": {"name": "Pantoea ananatis LMG 20103", "rank": "Strain"}, "706196": {"name": "Saccharomyces arboricola", "rank": "Species"}, "706194": {"name": "Candidatus Sulcia muelleri CARI", "rank": "Strain"}, "96565": {"name": "Lactobacillus hamsteri", "rank": "Species"}, "96563": {"name": "Pseudomonas stutzeri ATCC 17588 = LMG 11199", "rank": "Strain"}, "96561": {"name": "Desulfococcus oleovorans Hxd3", "rank": "Strain"}, "1448462": {"name": "Mycobacterium tuberculosis TKK_04_0051", "rank": "Strain"}, "1448463": {"name": "Mycobacterium tuberculosis TKK_04_0054", "rank": "Strain"}, "1448460": {"name": "Mycobacterium tuberculosis TKK_03_0159", "rank": "Strain"}, "1448461": {"name": "Mycobacterium tuberculosis TKK_03_0160", "rank": "Strain"}, "1448466": {"name": "Mycobacterium tuberculosis TKK_04_0061", "rank": "Strain"}, "1448467": {"name": "Mycobacterium tuberculosis TKK_04_0062", "rank": "Strain"}, "1448464": {"name": "Mycobacterium tuberculosis TKK_04_0059", "rank": "Strain"}, "1448465": {"name": "Mycobacterium tuberculosis TKK_04_0060", "rank": "Strain"}, "1448468": {"name": "Mycobacterium tuberculosis TKK_04_0063", "rank": "Strain"}, "1448469": {"name": "Mycobacterium tuberculosis TKK_04_0064", "rank": "Strain"}, "508419": {"name": "Lactobacillus phage c5", "rank": "Species"}, "439495": {"name": "Pseudovibrio sp. JE062", "rank": "Species"}, "439497": {"name": "Ruegeria sp. R11", "rank": "Species"}, "439496": {"name": "Rhodobacterales bacterium Y4I", "rank": "Species"}, "439491": {"name": "Solenopsis invicta virus 2", "rank": "Species"}, "439490": {"name": "Unclassified ssRNA viruses", "rank": "No rank"}, "439493": {"name": "Candidatus Pelagibacter sp. HTCC7211", "rank": "Species"}, "629258": {"name": "Pseudomonas syringae pv. aesculi str. 0893_23", "rank": "Strain"}, "629259": {"name": "Pseudomonas syringae pv. morsprunorum str. M302280", "rank": "Strain"}, "988656": {"name": "Pseudomonas phage phi15", "rank": "Species"}, "444163": {"name": "Brucella microti", "rank": "Species"}, "47001": {"name": "Equine rhinitis B virus 1", "rank": "Strain"}, "1158710": {"name": "Staphylococcus aureus M1016", "rank": "Strain"}, "222814": {"name": "Glaciecola polaris", "rank": "Species"}, "909663": {"name": "Syntrophorhabdus aromaticivorans UI", "rank": "Strain"}, "910954": {"name": "Dietzia cinnamea P4", "rank": "Strain"}, "1329650": {"name": "Bat circovirus", "rank": "Species"}, "227942": {"name": "Lactobacillus gastricus", "rank": "Species"}, "227943": {"name": "Lactobacillus antri", "rank": "Species"}, "591197": {"name": "Ignavibacterium album", "rank": "Species"}, "227941": {"name": "Chlamydophila caviae GPIC", "rank": "Strain"}, "233894": {"name": "Aeromonas phage 25", "rank": "Species"}, "227945": {"name": "Lactobacillus ultunensis", "rank": "Species"}, "1328306": {"name": "Rhizobium etli bv. mimosae str. Mim1", "rank": "Strain"}, "1160279": {"name": "Microcystis sp. T1-4", "rank": "Species"}, "1328309": {"name": "Lactobacillus plantarum IPLA88", "rank": "Strain"}, "580240": {"name": "Saccharomyces cerevisiae W303", "rank": "Strain"}, "1168067": {"name": "Thiomicrospira kuenenii DSM 12350", "rank": "Strain"}, "1168065": {"name": "Gamma proteobacterium BDW918", "rank": "Species"}, "1168064": {"name": "Klebsiella pneumoniae subsp. pneumoniae KPNIH23", "rank": "Strain"}, "694009": {"name": "Severe acute respiratory syndrome-related coronavirus", "rank": "Species"}, "694008": {"name": "Pipistrellus bat coronavirus HKU5", "rank": "Species"}, "1168061": {"name": "Pseudomonas aeruginosa LCT-PA102", "rank": "Strain"}, "745776": {"name": "Deinococcus gobiensis I-0", "rank": "Strain"}, "694007": {"name": "Tylonycteris bat coronavirus HKU4", "rank": "Species"}, "694006": {"name": "Rousettus bat coronavirus HKU9", "rank": "Species"}, "694001": {"name": "Miniopterus bat coronavirus HKU8", "rank": "Species"}, "694003": {"name": "Betacoronavirus 1", "rank": "Species"}, "694002": {"name": "Betacoronavirus", "rank": "Genus"}, "1031564": {"name": "Campylobacter insulaenigrae NCTC 12927", "rank": "Strain"}, "1540823": {"name": "Salmonella phage LSPA1", "rank": "Species"}, "1391475": {"name": "Enterococcus faecalis EnGen0405", "rank": "Strain"}, "502821": {"name": "Halomonas stevensii", "rank": "Species"}, "1160188": {"name": "Brucella abortus F6/05-4", "rank": "Strain"}, "1160189": {"name": "Brucella abortus 78/36", "rank": "Strain"}, "1435058": {"name": "Pseudomonas monteilii SB3101", "rank": "Strain"}, "1160180": {"name": "Brucella abortus F6/05-2", "rank": "Strain"}, "1160181": {"name": "Brucella abortus 63/294", "rank": "Strain"}, "1160182": {"name": "Brucella abortus 67/781", "rank": "Strain"}, "1160183": {"name": "Brucella abortus 63/59", "rank": "Strain"}, "1160184": {"name": "Brucella abortus F3/07-1", "rank": "Strain"}, "1160185": {"name": "Brucella abortus 80/101", "rank": "Strain"}, "1160187": {"name": "Brucella abortus 85/140", "rank": "Strain"}, "1415165": {"name": "Bacillus amyloliquefaciens LFB112", "rank": "Strain"}, "1415164": {"name": "Staphylococcus cohnii hu-01", "rank": "Strain"}, "1415167": {"name": "Bacillus subtilis PY79", "rank": "Strain"}, "1415166": {"name": "Nocardia nova SH22a", "rank": "Strain"}, "28108": {"name": "Alteromonas macleodii", "rank": "Species"}, "1415160": {"name": "Rhodobacter capsulatus DE442", "rank": "Strain"}, "41275": {"name": "Brevundimonas", "rank": "Genus"}, "1415162": {"name": "Rhodobacter capsulatus B6", "rank": "Strain"}, "28104": {"name": "Mesorhizobium huakuii", "rank": "Species"}, "28105": {"name": "Sinorhizobium", "rank": "Genus"}, "1541065": {"name": "Myxosarcina sp. GI1", "rank": "Species"}, "28100": {"name": "Phyllobacterium", "rank": "Genus"}, "1415168": {"name": "Lactococcus lactis subsp. cremoris GE214", "rank": "Strain"}, "926690": {"name": "Haloplanus natans DSM 17983", "rank": "Strain"}, "926692": {"name": "Halonatronum saccharophilum DSM 13868", "rank": "Strain"}, "1444199": {"name": "Escherichia coli 6-537-08_S3_C3", "rank": "Strain"}, "1444196": {"name": "Escherichia coli 4-203-08_S3_C3", "rank": "Strain"}, "1444197": {"name": "Escherichia coli 6-175-07_S3_C3", "rank": "Strain"}, "1444194": {"name": "Escherichia coli 3-373-03_S3_C3", "rank": "Strain"}, "1444192": {"name": "Escherichia coli 1-392-07_S3_C3", "rank": "Strain"}, "1444193": {"name": "Escherichia coli 3-105-05_S3_C3", "rank": "Strain"}, "1219709": {"name": "Burkholderia sp. 2385", "rank": "Species"}, "1444191": {"name": "Escherichia coli 1-182-04_S3_C3", "rank": "Strain"}, "487521": {"name": "Mycobacterium intracellulare ATCC 13950", "rank": "Strain"}, "688270": {"name": "Cellulophaga algicola DSM 14237", "rank": "Strain"}, "306205": {"name": "Rheinheimera texasensis", "rank": "Species"}, "497963": {"name": "Streptococcus pneumoniae SP-BS293", "rank": "Strain"}, "497962": {"name": "Streptococcus pneumoniae SP14-BS292", "rank": "Strain"}, "497965": {"name": "Cyanothece sp. PCC 7822", "rank": "Species"}, "1310614": {"name": "Acinetobacter baumannii 1397084", "rank": "Strain"}, "137992": {"name": "Asfarviridae", "rank": "Family"}, "11212": {"name": "Human parainfluenza virus 2", "rank": "Species"}, "29271": {"name": "Dasheen mosaic virus", "rank": "Species"}, "11215": {"name": "Bovine parainfluenza virus 3", "rank": "Species"}, "11216": {"name": "Human parainfluenza virus 3", "rank": "Species"}, "29272": {"name": "Turnip vein-clearing virus", "rank": "Species"}, "929585": {"name": "Saccharomyces cerevisiae T7", "rank": "Strain"}, "929586": {"name": "Saccharomyces cerevisiae YJM269", "rank": "Strain"}, "693743": {"name": "Vibrio cholerae PS15", "rank": "Strain"}, "1319815": {"name": "Cetobacterium somerae ATCC BAA-474", "rank": "Strain"}, "693746": {"name": "Oscillibacter valericigenes Sjm18-20", "rank": "Strain"}, "693745": {"name": "Helicobacter pylori B8", "rank": "Strain"}, "642926": {"name": "Ostreococcus tauri virus 1", "rank": "Species"}, "1283207": {"name": "Alphatetraviridae", "rank": "Family"}, "186764": {"name": "L5likevirus", "rank": "Genus"}, "1201112": {"name": "Saccharomyces cerevisiae N85", "rank": "Strain"}, "304208": {"name": "Pseudoalteromonas sp. '520P1 No. 412'", "rank": "Species"}, "304207": {"name": "Lactobacillus harbinensis", "rank": "Species"}, "12291": {"name": "Furovirus", "rank": "Genus"}, "445974": {"name": "Erysipelatoclostridium ramosum DSM 1402", "rank": "Strain"}, "12293": {"name": "Tobravirus", "rank": "Genus"}, "231233": {"name": "Streptococcus devriesei", "rank": "Species"}, "12294": {"name": "Pea early-browning virus", "rank": "Species"}, "445973": {"name": "Intestinibacter bartlettii DSM 16795", "rank": "Strain"}, "445972": {"name": "Anaerotruncus colihominis DSM 17241", "rank": "Strain"}, "263358": {"name": "Verrucosispora maris AB-18-032", "rank": "Strain"}, "1410913": {"name": "Staphylococcus aureus T12818", "rank": "Strain"}, "987045": {"name": "Jiangella gansuensis DSM 44835", "rank": "Strain"}, "768507": {"name": "Cytophagales", "rank": "Order"}, "768503": {"name": "Cytophagia", "rank": "Class"}, "858305": {"name": "Salmonella enterica subsp. enterica serovar Newport str. CVM 22462", "rank": "Strain"}, "858306": {"name": "Salmonella enterica subsp. enterica serovar Newport str. CVM N18486", "rank": "Strain"}, "858307": {"name": "Salmonella enterica subsp. enterica serovar Newport str. CVM N1543", "rank": "Strain"}, "858308": {"name": "Salmonella enterica subsp. enterica serovar Newport str. CVM 21554", "rank": "Strain"}, "858309": {"name": "Salmonella enterica subsp. enterica serovar Newport str. CVM 19443", "rank": "Strain"}, "1074863": {"name": "Bat picornavirus 1", "rank": "Species"}, "304736": {"name": "Sulfurihydrogenibium yellowstonense", "rank": "Species"}, "1074865": {"name": "Bat picornavirus 3", "rank": "Species"}, "1074864": {"name": "Bat picornavirus 2", "rank": "Species"}, "1358027": {"name": "Lactobacillus reuteri TD1", "rank": "Strain"}, "1446663": {"name": "Escherichia coli O157:H7 str. K1420", "rank": "Strain"}, "1033734": {"name": "Bacillus timonensis", "rank": "Species"}, "451274": {"name": "Unclassified Rhodospirillales", "rank": "No rank"}, "1223561": {"name": "CAS virus", "rank": "Species"}, "322611": {"name": "Sphingomonas sp. BHC-A", "rank": "Species"}, "1151252": {"name": "Peptoclostridium difficile CD3", "rank": "Strain"}, "1033730": {"name": "Aeromicrobium massiliense JC14", "rank": "Strain"}, "661505": {"name": "Chilli leaf curl Multan alphasatellite", "rank": "Species"}, "1033731": {"name": "Alistipes timonensis JC136", "rank": "Strain"}, "29466": {"name": "Veillonella parvula", "rank": "Species"}, "176279": {"name": "Staphylococcus epidermidis RP62A", "rank": "Strain"}, "94694": {"name": "Desulfurococcus amylolyticus", "rank": "Species"}, "1409591": {"name": "Staphylococcus aureus MISS6052", "rank": "Strain"}, "617135": {"name": "Aliivibrio fischeri ZF-211", "rank": "Strain"}, "1409593": {"name": "Staphylococcus aureus UCIM6066", "rank": "Strain"}, "1409592": {"name": "Staphylococcus aureus UCIM6065", "rank": "Strain"}, "1409595": {"name": "Staphylococcus aureus SJUD6114", "rank": "Strain"}, "617131": {"name": "Vibrio ordalii FF-167", "rank": "Strain"}, "617132": {"name": "Vibrio ordalii FF-93", "rank": "Strain"}, "617133": {"name": "Vibrio ordalii FS-238", "rank": "Strain"}, "1409599": {"name": "Staphylococcus aureus FVRH6021", "rank": "Strain"}, "1409598": {"name": "Staphylococcus aureus UCIM6070", "rank": "Strain"}, "1408174": {"name": "Vibrio parahaemolyticus VIP4-0447", "rank": "Strain"}, "1408176": {"name": "Campylobacter jejuni subsp. jejuni F38011", "rank": "Strain"}, "1408177": {"name": "Pantoea agglomerans Eh318", "rank": "Strain"}, "107637": {"name": "Methylomonas sp. LW13", "rank": "Species"}, "107636": {"name": "Methylosinus sp. PW1", "rank": "Species"}, "1408172": {"name": "Vibrio parahaemolyticus VIP4-0219", "rank": "Strain"}, "1408173": {"name": "Vibrio parahaemolyticus VIP4-0444", "rank": "Strain"}, "1408178": {"name": "Streptococcus thermophilus ASCC 1275", "rank": "Strain"}, "1408179": {"name": "Streptococcus pneumoniae A026", "rank": "Strain"}, "1151255": {"name": "Peptoclostridium difficile CD13", "rank": "Strain"}, "1246365": {"name": "Streptococcus suis SC070731", "rank": "Strain"}, "179408": {"name": "Oscillatoria nigro-viridis PCC 7112", "rank": "Strain"}, "427754": {"name": "Humibacter albus", "rank": "Species"}, "427753": {"name": "Humibacter", "rank": "Genus"}, "441500": {"name": "Corynebacterium timonense", "rank": "Species"}, "441501": {"name": "Corynebacterium massiliense", "rank": "Species"}, "431269": {"name": "Mycobacterium setense", "rank": "Species"}, "386891": {"name": "Moraxella bovoculi", "rank": "Species"}, "386894": {"name": "Streptococcus iniae 9117", "rank": "Strain"}, "289380": {"name": "Clostridium perfringens SM101", "rank": "Strain"}, "204286": {"name": "Cobetia", "rank": "Genus"}, "37989": {"name": "Xylariales", "rank": "Order"}, "1335": {"name": "Streptococcus equinus", "rank": "Species"}, "37987": {"name": "Pneumocystidales", "rank": "Order"}, "1273087": {"name": "Cardioderma polyomavirus", "rank": "Species"}, "293256": {"name": "Desulfovibrio alkalitolerans", "rank": "Species"}, "1354157": {"name": "Mycobacterium tuberculosis MAL010117", "rank": "Strain"}, "1354154": {"name": "Mycobacterium tuberculosis MAL010133", "rank": "Strain"}, "1354155": {"name": "Mycobacterium tuberculosis MAL010134", "rank": "Strain"}, "1071400": {"name": "Lactobacillus buchneri CD034", "rank": "Strain"}, "1354152": {"name": "Mycobacterium tuberculosis MAL010109", "rank": "Strain"}, "1354153": {"name": "Mycobacterium tuberculosis MAL010110", "rank": "Strain"}, "1354150": {"name": "Mycobacterium tuberculosis MAL010106", "rank": "Strain"}, "1354151": {"name": "Mycobacterium tuberculosis MAL010108", "rank": "Strain"}, "1458669": {"name": "Acinetobacter phage IME_AB3", "rank": "Species"}, "1208103": {"name": "Pseudomonas aeruginosa AH16", "rank": "Strain"}, "1208104": {"name": "Aeromonas media WS", "rank": "Strain"}, "1307437": {"name": "Pseudoalteromonas agarivorans S816", "rank": "Strain"}, "1307436": {"name": "Bacillus firmus DS1", "rank": "Strain"}, "1312959": {"name": "Arthrobacter sp. H14", "rank": "Species"}, "1312954": {"name": "Arthrobacter sp. Br18", "rank": "Species"}, "1307439": {"name": "Neisseria meningitidis Nm9418", "rank": "Strain"}, "1307438": {"name": "Neisseria meningitidis Nm10259", "rank": "Strain"}, "1185677": {"name": "Xanthomonas axonopodis pv. manihotis str. IBSBF 2665", "rank": "Strain"}, "1185676": {"name": "Xanthomonas axonopodis pv. manihotis str. IBSBF 2539", "rank": "Strain"}, "1084717": {"name": "Porcine bocavirus 4-1", "rank": "Strain"}, "1185673": {"name": "Xanthomonas axonopodis pv. manihotis str. IBSBF 2345", "rank": "Strain"}, "1185671": {"name": "Xanthomonas axonopodis pv. manihotis str. IBSBF 1411", "rank": "Strain"}, "1084719": {"name": "Bacillus phage G", "rank": "Species"}, "1185679": {"name": "Xanthomonas axonopodis pv. manihotis str. IBSBF 2667", "rank": "Strain"}, "1185678": {"name": "Xanthomonas axonopodis pv. manihotis str. IBSBF 2666", "rank": "Strain"}, "195105": {"name": "Haematobacter massiliensis", "rank": "Species"}, "1220558": {"name": "Paenibacillus chitinolyticus NBRC 15660", "rank": "Strain"}, "469381": {"name": "Dethiosulfovibrio peptidovorans DSM 11002", "rank": "Strain"}, "469382": {"name": "Halogeometricum borinquense DSM 11551", "rank": "Strain"}, "469383": {"name": "Conexibacter woesei DSM 14684", "rank": "Strain"}, "1432058": {"name": "Mycobacterium tuberculosis HM", "rank": "Strain"}, "195103": {"name": "Clostridium perfringens ATCC 13124", "rank": "Strain"}, "1122601": {"name": "Nesiotobacter exalbescens DSM 16456", "rank": "Strain"}, "1122603": {"name": "Nevskia ramosa DSM 11499", "rank": "Strain"}, "133552": {"name": "Methylocapsa acidiphila", "rank": "Species"}, "1122605": {"name": "Niabella aurantiaca DSM 17617", "rank": "Strain"}, "164514": {"name": "Blattabacterium punctulatus", "rank": "Species"}, "1122607": {"name": "Nisaea denitrificans DSM 18348", "rank": "Strain"}, "1122609": {"name": "Nocardioides halotolerans DSM 19273", "rank": "Strain"}, "1122608": {"name": "Nocardioides alkalitolerans DSM 16699", "rank": "Strain"}, "1001587": {"name": "Leptospira interrogans serovar Pomona str. Pomona", "rank": "Strain"}, "1173957": {"name": "Vibrio parahaemolyticus 98-513-F52", "rank": "Strain"}, "1173954": {"name": "Vibrio parahaemolyticus O4:K12 str. K1203", "rank": "Strain"}, "1173951": {"name": "Salmonella enterica subsp. salamae serovar 58:l,z13,z28:z6 str. 00-0163", "rank": "Strain"}, "1173950": {"name": "Salmonella enterica subsp. indica serovar 6,14,25:z10:1,(2),7 str. 1121", "rank": "Strain"}, "1133751": {"name": "Artemisia virus A", "rank": "Species"}, "523849": {"name": "Thermococcus litoralis DSM 5473", "rank": "Strain"}, "1224163": {"name": "Corynebacterium maris DSM 45190", "rank": "Strain"}, "1305594": {"name": "Kingella kingae KK156", "rank": "Strain"}, "551760": {"name": "Aromatoleum aromaticum", "rank": "Species"}, "1157400": {"name": "Enterococcus faecalis EnGen0214", "rank": "Strain"}, "523846": {"name": "Methanothermus fervidus DSM 2088", "rank": "Strain"}, "1224166": {"name": "Acinetobacter baumannii ABNIH26", "rank": "Strain"}, "1224165": {"name": "Acinetobacter baumannii ABNIH25", "rank": "Strain"}, "523845": {"name": "Methanothermococcus thermolithotrophicus DSM 2095", "rank": "Strain"}, "687358": {"name": "Torque teno virus 19", "rank": "Species"}, "911574": {"name": "Malvastrum yellow vein Changa Manga virus", "rank": "Species"}, "1046989": {"name": "Parcubacteria bacterium SCGC AAA011-J21", "rank": "Species"}, "1134404": {"name": "Ignavibacteriae", "rank": "Phylum"}, "1134405": {"name": "Melioribacter roseus", "rank": "Species"}, "376758": {"name": "Propionibacterium phage PA6", "rank": "Species"}, "1046988": {"name": "Parcubacteria bacterium SCGC AAA011-G05", "rank": "Species"}, "206664": {"name": "Desulfonauticus", "rank": "Genus"}, "1134403": {"name": "Melioribacter", "rank": "Genus"}, "1154805": {"name": "Streptococcus agalactiae FSL S3-001", "rank": "Strain"}, "332112": {"name": "Saccharomyces cerevisiae x Saccharomyces kudriavzevii", "rank": "Species"}, "322098": {"name": "Aster yellows witches'-broom phytoplasma AYWB", "rank": "Strain"}, "1151364": {"name": "Peptoclostridium difficile F152", "rank": "Strain"}, "310748": {"name": "Endornavirus", "rank": "Genus"}, "1339267": {"name": "Lactobacillus fermentum FTDC8312", "rank": "Strain"}, "626119": {"name": "Ruania", "rank": "Genus"}, "1151333": {"name": "Peptoclostridium difficile DA00160", "rank": "Strain"}, "1306787": {"name": "Alcanivorax pacificus", "rank": "Species"}, "1046982": {"name": "Hydrogenedentes bacterium JGI 0000039-J10", "rank": "Species"}, "687353": {"name": "Torque teno virus 14", "rank": "Species"}, "999394": {"name": "Acidovorax radicis N35v", "rank": "Strain"}, "260677": {"name": "Salmonella enterica subsp. enterica serovar Urbana", "rank": "Strain"}, "687355": {"name": "Torque teno virus 16", "rank": "Species"}, "1046986": {"name": "Parcubacteria bacterium SCGC AAA011-J16", "rank": "Species"}, "1001708": {"name": "Mycobacterium abscessus subsp. bolletii 2B-0626", "rank": "Strain"}, "1001709": {"name": "Mycobacterium abscessus subsp. bolletii 2B-1231", "rank": "Strain"}, "1048254": {"name": "Escherichia coli O104:H4 str. C227-11", "rank": "Strain"}, "1046985": {"name": "Parcubacteria bacterium SCGC AAA011-A08", "rank": "Species"}, "1182590": {"name": "Pseudomonas pseudoalcaligenes CECT 5344", "rank": "Strain"}, "1001704": {"name": "Mycobacterium abscessus subsp. bolletii 1S-151-0930", "rank": "Strain"}, "1001705": {"name": "Mycobacterium abscessus subsp. bolletii 1S-152-0914", "rank": "Strain"}, "1001706": {"name": "Mycobacterium abscessus subsp. bolletii 1S-153-0915", "rank": "Strain"}, "1001707": {"name": "Mycobacterium abscessus subsp. bolletii 1S-154-0310", "rank": "Strain"}, "760732": {"name": "Acinetobacter phage Acj61", "rank": "Species"}, "1151368": {"name": "Peptoclostridium difficile F314", "rank": "Strain"}, "1419711": {"name": "Penaeus monodon circovirus VN11", "rank": "Species"}, "460926": {"name": "Tomato zonate spot virus", "rank": "Species"}, "1416772": {"name": "Burkholderia sp. WP42", "rank": "Species"}, "749530": {"name": "Escherichia coli MS 60-1", "rank": "Strain"}, "749531": {"name": "Escherichia coli MS 69-1", "rank": "Strain"}, "749532": {"name": "Escherichia coli MS 78-1", "rank": "Strain"}, "749533": {"name": "Escherichia coli MS 84-1", "rank": "Strain"}, "749535": {"name": "Klebsiella sp. MS 92-3", "rank": "Species"}, "749536": {"name": "Escherichia coli MS 110-3", "rank": "Strain"}, "749537": {"name": "Escherichia coli MS 115-1", "rank": "Strain"}, "749538": {"name": "Escherichia coli MS 116-1", "rank": "Strain"}, "749539": {"name": "Escherichia coli MS 117-3", "rank": "Strain"}, "1048256": {"name": "Escherichia coli O104:H4 str. C236-11", "rank": "Strain"}, "913847": {"name": "Lactococcus garvieae 8831", "rank": "Strain"}, "913848": {"name": "Lactobacillus coryniformis subsp. coryniformis KCTC 3167 = DSM 20001", "rank": "Strain"}, "144": {"name": "Borrelia coriaceae", "rank": "Species"}, "1154907": {"name": "Streptococcus agalactiae GB00206", "rank": "Strain"}, "146": {"name": "Spirochaeta", "rank": "Genus"}, "140": {"name": "Borrelia hermsii", "rank": "Species"}, "141": {"name": "Borrelia parkeri", "rank": "Species"}, "142": {"name": "Borrelia turicatae", "rank": "Species"}, "143": {"name": "Borrelia anserina", "rank": "Species"}, "1137745": {"name": "Cyanophage S-TIM5", "rank": "Species"}, "148": {"name": "Spirochaeta bajacaliforniensis", "rank": "Species"}, "1154904": {"name": "Streptococcus agalactiae GB00174", "rank": "Strain"}, "1511913": {"name": "Primate tetraparvovirus 1", "rank": "Species"}, "1511912": {"name": "Chiropteran tetraparvovirus 1", "rank": "Species"}, "1511911": {"name": "Tetraparvovirus", "rank": "Genus"}, "1511910": {"name": "Ungulate protoparvovirus 1", "rank": "Species"}, "1388027": {"name": "Staphylococcus aureus M0058", "rank": "Strain"}, "1388026": {"name": "Staphylococcus aureus M0057", "rank": "Strain"}, "51313": {"name": "Helicoverpa armigera nucleopolyhedrovirus", "rank": "Species"}, "1291339": {"name": "Leptospira interrogans serovar Copenhageni str. Fiocruz LV3213", "rank": "Strain"}, "1427371": {"name": "Chlamydia pecorum VR629", "rank": "Strain"}, "1427370": {"name": "Chlamydia pecorum DBDeUG", "rank": "Strain"}, "1388021": {"name": "Staphylococcus aureus M0050", "rank": "Strain"}, "1388020": {"name": "Staphylococcus aureus M0049", "rank": "Strain"}, "1355015": {"name": "Streptomyces pluripotens", "rank": "Species"}, "702035": {"name": "Cjw1-like phages", "rank": "No rank"}, "1410632": {"name": "Lachnospiraceae bacterium V9D3004", "rank": "Species"}, "1410633": {"name": "Lachnospiraceae bacterium YSB2008", "rank": "Species"}, "1410630": {"name": "Lachnospiraceae bacterium P6A3", "rank": "Species"}, "1410631": {"name": "Lachnospiraceae bacterium P6B14", "rank": "Species"}, "1410634": {"name": "Propionibacteriaceae bacterium P6A17", "rank": "Species"}, "1291336": {"name": "Leptospira interrogans serovar Copenhageni str. Fiocruz LV2919", "rank": "Strain"}, "1311760": {"name": "Mannheimia haemolytica D174", "rank": "Strain"}, "1311761": {"name": "Unclassified Betaentomopoxvirus", "rank": "No rank"}, "1144340": {"name": "Pseudomonas sp. GM84", "rank": "Species"}, "1144341": {"name": "Pantoea sp. YR343", "rank": "Species"}, "1144342": {"name": "Herbaspirillum sp. YR522", "rank": "Species"}, "1144343": {"name": "Phyllobacterium sp. YR531", "rank": "Species"}, "1144344": {"name": "Bradyrhizobium sp. YR681", "rank": "Species"}, "1182669": {"name": "Escherichia coli KTE62", "rank": "Strain"}, "1182668": {"name": "Escherichia coli KTE61", "rank": "Strain"}, "1291337": {"name": "Leptospira interrogans serovar Copenhageni str. Fiocruz LV4173", "rank": "Strain"}, "1182665": {"name": "Escherichia coli KTE58", "rank": "Strain"}, "1182664": {"name": "Escherichia coli KTE57", "rank": "Strain"}, "1182667": {"name": "Escherichia coli KTE60", "rank": "Strain"}, "1182666": {"name": "Escherichia coli KTE59", "rank": "Strain"}, "1182661": {"name": "Escherichia coli KTE54", "rank": "Strain"}, "1182660": {"name": "Escherichia coli KTE53", "rank": "Strain"}, "1182663": {"name": "Escherichia coli KTE56", "rank": "Strain"}, "1182662": {"name": "Escherichia coli KTE55", "rank": "Strain"}, "1227452": {"name": "Haloarcula amylolytica JCM 13557", "rank": "Strain"}, "1227453": {"name": "Haloarcula japonica DSM 6131", "rank": "Strain"}, "1403537": {"name": "Fervidicella metallireducens AeB", "rank": "Strain"}, "586413": {"name": "Oceanobacillus manasiensis", "rank": "Species"}, "1227456": {"name": "Halococcus salifodinae DSM 8989", "rank": "Strain"}, "1227457": {"name": "Halococcus thailandensis JCM 13552", "rank": "Strain"}, "1227454": {"name": "Halobiforma nitratireducens JCM 10879", "rank": "Strain"}, "1227455": {"name": "Halococcus saccharolyticus DSM 5350", "rank": "Strain"}, "586418": {"name": "Cosavirus", "rank": "Genus"}, "586419": {"name": "Human cosavirus A", "rank": "Strain"}, "1227458": {"name": "Haloferax alexandrinus JCM 10717", "rank": "Strain"}, "556258": {"name": "Bacteroides sp. D1", "rank": "Species"}, "1403538": {"name": "Fervidicella", "rank": "Genus"}, "195801": {"name": "Streptomyces speibonae", "rank": "Species"}, "1486659": {"name": "Bacillus phage Hakuna", "rank": "Species"}, "1486658": {"name": "Bacillus phage Evoli", "rank": "Species"}, "1486657": {"name": "Bacillus phage CAM003", "rank": "Species"}, "269454": {"name": "Arthrobacter sp. 35/47", "rank": "Species"}, "1266370": {"name": "Nitrospina gracilis 3/211", "rank": "Strain"}, "1400346": {"name": "Acinetobacter lwoffii NIPH 512", "rank": "Strain"}, "1388689": {"name": "Staphylococcus aureus M0918", "rank": "Strain"}, "1388688": {"name": "Staphylococcus aureus M0917", "rank": "Strain"}, "1388683": {"name": "Staphylococcus aureus M0911", "rank": "Strain"}, "1388682": {"name": "Staphylococcus aureus M0910", "rank": "Strain"}, "1388681": {"name": "Staphylococcus aureus M0909", "rank": "Strain"}, "1388680": {"name": "Staphylococcus aureus M0908", "rank": "Strain"}, "1388687": {"name": "Staphylococcus aureus M0916", "rank": "Strain"}, "1388686": {"name": "Staphylococcus aureus M0915", "rank": "Strain"}, "1388685": {"name": "Staphylococcus aureus M0914", "rank": "Strain"}, "1388684": {"name": "Staphylococcus aureus M0913", "rank": "Strain"}, "1158": {"name": "Oscillatoria", "rank": "Genus"}, "1154": {"name": "Spirulina", "rank": "Genus"}, "1150": {"name": "Oscillatoriales", "rank": "Order"}, "1152": {"name": "Pseudanabaena", "rank": "Genus"}, "1434166": {"name": "Shigella flexneri 2002110", "rank": "Strain"}, "1413370": {"name": "Staphylococcus aureus 12-ST01564", "rank": "Strain"}, "1196417": {"name": "Milkweed yellows phytoplasma str. MW1", "rank": "Strain"}, "1196416": {"name": "Poinsettia branch-inducing phytoplasma str. JR1", "rank": "Strain"}, "1196419": {"name": "Vaccinium witches'-broom phytoplasma str. VAC", "rank": "Strain"}, "1078763": {"name": "Mycobacterium tuberculosis NCGM2209", "rank": "Strain"}, "1109445": {"name": "Pseudomonas stutzeri SDM-LAC", "rank": "Strain"}, "1321823": {"name": "Porphyromonas gingivalis W4087", "rank": "Strain"}, "1312234": {"name": "Streptomyces prunicolor NBRC 13075", "rank": "Strain"}, "1448660": {"name": "Mycobacterium tuberculosis M1319", "rank": "Strain"}, "1448661": {"name": "Mycobacterium tuberculosis M1324", "rank": "Strain"}, "1448662": {"name": "Mycobacterium tuberculosis M1325", "rank": "Strain"}, "1448663": {"name": "Mycobacterium tuberculosis M1340", "rank": "Strain"}, "1448664": {"name": "Mycobacterium tuberculosis M1373", "rank": "Strain"}, "1448665": {"name": "Mycobacterium tuberculosis M1374", "rank": "Strain"}, "1448666": {"name": "Mycobacterium tuberculosis M1381", "rank": "Strain"}, "146938": {"name": "Azovibrio restrictus", "rank": "Species"}, "1448668": {"name": "Mycobacterium tuberculosis M1389", "rank": "Strain"}, "1448669": {"name": "Mycobacterium tuberculosis M1392", "rank": "Strain"}, "146935": {"name": "Azovibrio", "rank": "Genus"}, "585148": {"name": "Staphylococcus aureus subsp. aureus Btn1260", "rank": "Strain"}, "624186": {"name": "Blattabacterium sp. (Blattella germanica)", "rank": "Species"}, "1323664": {"name": "Burkholderia caribensis MBA4", "rank": "Strain"}, "1323662": {"name": "Staphylococcus aureus subsp. aureus PS187", "rank": "Strain"}, "1323663": {"name": "Pseudomonas pelagia CL-AP6", "rank": "Strain"}, "1323661": {"name": "Staphylococcus aureus CA-347", "rank": "Strain"}, "1116129": {"name": "Escherichia coli 201600.1", "rank": "Strain"}, "1116128": {"name": "Escherichia coli 2851500", "rank": "Strain"}, "1116127": {"name": "Escherichia coli 2848050", "rank": "Strain"}, "1116126": {"name": "Escherichia coli 2846750", "rank": "Strain"}, "1116125": {"name": "Escherichia coli 2845650", "rank": "Strain"}, "1116124": {"name": "Escherichia coli 2845350", "rank": "Strain"}, "1116123": {"name": "Escherichia coli 2726950", "rank": "Strain"}, "1116122": {"name": "Escherichia coli 2726800", "rank": "Strain"}, "1116121": {"name": "Escherichia coli 2722950", "rank": "Strain"}, "1116120": {"name": "Escherichia coli 2720900", "rank": "Strain"}, "1194086": {"name": "Yersinia enterocolitica subsp. enterocolitica WA-314", "rank": "Strain"}, "1194085": {"name": "Staphylococcus aureus subsp. aureus SA40", "rank": "Strain"}, "1213463": {"name": "Mycoplasma pneumoniae 19294", "rank": "Strain"}, "222523": {"name": "Bacillus cereus ATCC 10987", "rank": "Strain"}, "1217705": {"name": "Acinetobacter sp. ANC 3862", "rank": "Species"}, "1482": {"name": "Virgibacillus halodenitrificans", "rank": "Species"}, "1217707": {"name": "Acinetobacter sp. ANC 3929", "rank": "Species"}, "142479": {"name": "Prochlorococcus marinus subsp. pastoris", "rank": "Subspecies"}, "1217701": {"name": "Acinetobacter sp. ANC 3880", "rank": "Species"}, "1217700": {"name": "Acinetobacter sp. CIP 70.18", "rank": "Species"}, "1485": {"name": "Clostridium", "rank": "Genus"}, "1217702": {"name": "Acinetobacter sp. NIPH 1867", "rank": "Species"}, "1157380": {"name": "Enterococcus faecalis EnGen0196", "rank": "Strain"}, "1157381": {"name": "Enterococcus faecalis EnGen0197", "rank": "Strain"}, "1157382": {"name": "Enterococcus faecalis EnGen0198", "rank": "Strain"}, "1488": {"name": "Clostridium acetobutylicum", "rank": "Species"}, "1157384": {"name": "Enterococcus faecalis EnGen0200", "rank": "Strain"}, "1157385": {"name": "Enterococcus faecalis EnGen0201", "rank": "Strain"}, "1157386": {"name": "Enterococcus faecalis EnGen0202", "rank": "Strain"}, "1157387": {"name": "Enterococcus faecalis EnGen0203", "rank": "Strain"}, "1310961": {"name": "Acinetobacter baumannii 25561_7", "rank": "Strain"}, "1384051": {"name": "Bacillus amyloliquefaciens UASWS BA1", "rank": "Strain"}, "1384056": {"name": "Arenimonas metalli CF5-1", "rank": "Strain"}, "1384057": {"name": "Lysinibacillus sinduriensis BLB-1 = JCM 15800", "rank": "Strain"}, "1310965": {"name": "Acinetobacter baumannii 25750_1", "rank": "Strain"}, "1310964": {"name": "Acinetobacter baumannii 25561_10", "rank": "Strain"}, "190898": {"name": "Desulfotignum phosphitoxidans", "rank": "Species"}, "1229794": {"name": "Propionibacterium phage ATCC29399B_C", "rank": "Species"}, "266117": {"name": "Rubrobacter xylanophilus DSM 9941", "rank": "Strain"}, "41707": {"name": "Lawsonia", "rank": "Genus"}, "1229792": {"name": "Propionibacterium phage P1.1", "rank": "Species"}, "500638": {"name": "Edwardsiella tarda ATCC 23685", "rank": "Strain"}, "500639": {"name": "Enterobacter cancerogenus ATCC 35316", "rank": "Strain"}, "1229791": {"name": "Propionibacterium phage P100_1", "rank": "Species"}, "500632": {"name": "Tyzzerella nexilis DSM 1787", "rank": "Strain"}, "500633": {"name": "Clostridium hiranonis DSM 13275", "rank": "Strain"}, "1284801": {"name": "Klebsiella pneumoniae UHKPC48", "rank": "Strain"}, "500637": {"name": "Providencia rustigianii DSM 4541", "rank": "Strain"}, "500634": {"name": "Bifidobacterium bifidum ATCC 29521 = JCM 1255 = DSM 20456", "rank": "Strain"}, "343874": {"name": "Empedobacter falsenii", "rank": "Species"}, "261299": {"name": "Intestinibacter bartlettii", "rank": "Species"}, "194867": {"name": "Sphingomonas sp. ATCC 31555", "rank": "Species"}, "1475062": {"name": "Porcine stool-associated circular virus 4", "rank": "Species"}, "1475063": {"name": "Porcine stool-associated circular virus 5", "rank": "Species"}, "608534": {"name": "Oribacterium sp. oral taxon 078 str. F0262", "rank": "Strain"}, "1413379": {"name": "Staphylococcus aureus Sau 95", "rank": "Strain"}, "1291540": {"name": "Candidatus Methanomethylophilus alvus", "rank": "Species"}, "147375": {"name": "Paenibacillus larvae subsp. larvae", "rank": "Subspecies"}, "608538": {"name": "Hydrogenobacter thermophilus TK-6", "rank": "Strain"}, "246198": {"name": "Prevotella intermedia 17", "rank": "Strain"}, "261292": {"name": "Nitrosomonas sp. Is79A3", "rank": "Species"}, "39791": {"name": "Corynebacterium glucuronolyticum", "rank": "Species"}, "359786": {"name": "Staphylococcus aureus subsp. aureus JH9", "rank": "Strain"}, "359787": {"name": "Staphylococcus aureus subsp. aureus JH1", "rank": "Strain"}, "246199": {"name": "Ruminococcus albus 8", "rank": "Strain"}, "344417": {"name": "Unclassified Aquabirnavirus", "rank": "No rank"}, "183190": {"name": "Xylella fastidiosa Temecula1", "rank": "Strain"}, "1148157": {"name": "Acinetobacter oleivorans", "rank": "Species"}, "395492": {"name": "Rhizobium leguminosarum bv. trifolii WSM2304", "rank": "Strain"}, "395493": {"name": "Beggiatoa alba B18LD", "rank": "Strain"}, "395491": {"name": "Rhizobium leguminosarum bv. trifolii WSM1325", "rank": "Strain"}, "395494": {"name": "Gallionella capsiferriformans ES-2", "rank": "Strain"}, "395495": {"name": "Leptothrix cholodnii SP-6", "rank": "Strain"}, "333849": {"name": "Enterococcus faecium DO", "rank": "Strain"}, "1429780": {"name": "Eremothecium coryli CBS 5749", "rank": "Strain"}, "518766": {"name": "Rhodothermus marinus DSM 4252", "rank": "Strain"}, "279714": {"name": "Pseudogulbenkiania ferrooxidans 2002", "rank": "Strain"}, "798128": {"name": "Thermus thermophilus JL-18", "rank": "Strain"}, "1441925": {"name": "Mycobacterium tuberculosis INS_MDR", "rank": "Strain"}, "1441926": {"name": "Mycobacterium tuberculosis INS_SEN", "rank": "Strain"}, "1441927": {"name": "Mycobacterium tuberculosis INS_XDR", "rank": "Strain"}, "215802": {"name": "Enhygromyxa", "rank": "Genus"}, "215803": {"name": "Enhygromyxa salina", "rank": "Species"}, "33906": {"name": "Actinopolyspora mortivallis", "rank": "Species"}, "1054461": {"name": "Escherichia phage vB_EcoP_G7C", "rank": "Species"}, "1054460": {"name": "Streptococcus pseudopneumoniae IS7493", "rank": "Strain"}, "1235649": {"name": "Propionibacterium phage PHL067M10", "rank": "Species"}, "759701": {"name": "Bettongia penicillata papillomavirus 1", "rank": "Strain"}, "1235645": {"name": "Propionibacterium phage PHL010M04", "rank": "Species"}, "1235646": {"name": "Propionibacterium phage PHL037M02", "rank": "Species"}, "1235647": {"name": "Propionibacterium phage PHL060L00", "rank": "Species"}, "531813": {"name": "Pelagibacterium halotolerans", "rank": "Species"}, "1436892": {"name": "Pea yellow stunt virus", "rank": "Species"}, "1436890": {"name": "Unclassified Nanoviridae", "rank": "No rank"}, "1436891": {"name": "Black medic leafroll virus", "rank": "Species"}, "1088719": {"name": "Vibrio fischeri SR5", "rank": "Strain"}, "1049759": {"name": "Leptospira alexanderi serovar Manhao 3 str. L 60", "rank": "Strain"}, "262316": {"name": "Mycobacterium avium subsp. paratuberculosis K-10", "rank": "Strain"}, "1096546": {"name": "Methylobacterium sp. GXF4", "rank": "Species"}, "436229": {"name": "Streptacidiphilus jeojiense", "rank": "Species"}, "11809": {"name": "Moloney murine sarcoma virus", "rank": "Species"}, "11801": {"name": "Moloney murine leukemia virus", "rank": "Strain"}, "633130": {"name": "Thalassobium", "rank": "Genus"}, "633131": {"name": "Thalassobium sp. R2A62", "rank": "Species"}, "58231": {"name": "Treponema medium", "rank": "Species"}, "633135": {"name": "Streptococcus phage Abc2", "rank": "Species"}, "1090321": {"name": "Desulfitobacterium hafniense PCP-1", "rank": "Strain"}, "347": {"name": "Xanthomonas oryzae", "rank": "Species"}, "1510531": {"name": "Bosea sp. UNC402CLCol", "rank": "Species"}, "73913": {"name": "Methanocaldococcus vulcanius", "rank": "Species"}, "73919": {"name": "Thermaerobacter marianensis", "rank": "Species"}, "73918": {"name": "Thermaerobacter", "rank": "Genus"}, "565664": {"name": "Enterococcus faecium C68", "rank": "Strain"}, "565665": {"name": "Enterococcus faecium D344SRF", "rank": "Strain"}, "565666": {"name": "Enterococcus faecium TC 6", "rank": "Strain"}, "565660": {"name": "Enterococcus faecium 1,231,410", "rank": "Strain"}, "565661": {"name": "Enterococcus faecium 1,231,408", "rank": "Strain"}, "565662": {"name": "Enterococcus faecium Com12", "rank": "Strain"}, "565663": {"name": "Enterococcus faecium Com15", "rank": "Strain"}, "1169675": {"name": "Streptococcus sp. GMD6S", "rank": "Species"}, "1169674": {"name": "Streptococcus sp. GMD5S", "rank": "Species"}, "1071177": {"name": "Psychrobacter phage Psymv2", "rank": "Species"}, "244787": {"name": "Nautilia profundicola", "rank": "Species"}, "1169670": {"name": "Streptococcus sp. GMD1S", "rank": "Species"}, "1169672": {"name": "Streptococcus sp. GMD3S", "rank": "Species"}, "766155": {"name": "Shigella flexneri 1485-80", "rank": "Strain"}, "561175": {"name": "Actinomadura flavalba DSM 45200", "rank": "Strain"}, "766157": {"name": "Shigella flexneri 2747-71", "rank": "Strain"}, "561177": {"name": "Anaerococcus hydrogenalis DSM 7454", "rank": "Strain"}, "766151": {"name": "Shigella flexneri K-404", "rank": "Strain"}, "766150": {"name": "Shigella flexneri K-315", "rank": "Strain"}, "766153": {"name": "Shigella flexneri K-1770", "rank": "Strain"}, "766152": {"name": "Shigella flexneri K-671", "rank": "Strain"}, "766159": {"name": "Shigella flexneri 2930-71", "rank": "Strain"}, "766158": {"name": "Shigella flexneri 2850-71", "rank": "Strain"}, "1123719": {"name": "Bacillaceae bacterium MTCC 8252", "rank": "Species"}, "222991": {"name": "Alkanindiges", "rank": "Genus"}, "1111069": {"name": "Thermus sp. CCB_US3_UF1", "rank": "Species"}, "1111068": {"name": "Geobacillus thermoleovorans CCB_US3_UF5", "rank": "Strain"}, "1446521": {"name": "Escherichia coli O111:NM str. 2010C-4592", "rank": "Strain"}, "1446520": {"name": "Escherichia coli O111:NM str. 2010C-4221", "rank": "Strain"}, "1446523": {"name": "Escherichia coli O111:NM str. 2010C-4715", "rank": "Strain"}, "1446522": {"name": "Escherichia coli O111:NM str. 2010C-4622", "rank": "Strain"}, "1446525": {"name": "Escherichia coli O111:NM str. 2010C-4746", "rank": "Strain"}, "1446524": {"name": "Escherichia coli O111:NM str. 2010C-4735", "rank": "Strain"}, "1446527": {"name": "Escherichia coli O111:NM str. 2010C-4818", "rank": "Strain"}, "1446526": {"name": "Escherichia coli O111:NM str. 2010C-4799", "rank": "Strain"}, "1446529": {"name": "Escherichia coli O111:NM str. 2011C-3362", "rank": "Strain"}, "1446528": {"name": "Escherichia coli O111:NM str. 2011C-3170", "rank": "Strain"}, "151755": {"name": "Xenophilus azovorans", "rank": "Species"}, "151754": {"name": "Xenophilus", "rank": "Genus"}, "1539978": {"name": "Reptile bornavirus 1", "rank": "Species"}, "796943": {"name": "Oribacterium parvum ACB1", "rank": "Strain"}, "1310618": {"name": "Acinetobacter baumannii 118362", "rank": "Strain"}, "796942": {"name": "Stomatobaculum longum", "rank": "Species"}, "1447434": {"name": "Mycobacterium tuberculosis MD17902", "rank": "Strain"}, "1447435": {"name": "Mycobacterium tuberculosis MD18320", "rank": "Strain"}, "1447436": {"name": "Mycobacterium tuberculosis MD18486", "rank": "Strain"}, "1447437": {"name": "Mycobacterium tuberculosis MD16555", "rank": "Strain"}, "1447432": {"name": "Mycobacterium tuberculosis MD17898", "rank": "Strain"}, "1447433": {"name": "Mycobacterium tuberculosis MD17904", "rank": "Strain"}, "390442": {"name": "Tomato yellow leaf curl Vietnam virus", "rank": "Species"}, "390443": {"name": "Erectites yellow mosaic virus", "rank": "Species"}, "390440": {"name": "Mimosa yellow leaf curl virus", "rank": "Species"}, "390441": {"name": "Sida yellow vein Vietnam virus", "rank": "Species"}, "1447438": {"name": "Mycobacterium tuberculosis MD18478", "rank": "Strain"}, "1447439": {"name": "Mycobacterium tuberculosis MD18489", "rank": "Strain"}, "1122999": {"name": "Propionicicella superfundia DSM 22317", "rank": "Strain"}, "1122998": {"name": "Propionibacterium thoenii DSM 20276", "rank": "Strain"}, "1122991": {"name": "Prevotella shahii DSM 15611 = JCM 12083", "rank": "Strain"}, "1122990": {"name": "Prevotella paludivivens DSM 17968 = JCM 13650", "rank": "Strain"}, "1122993": {"name": "Prevotella veroralis DSM 19559 = JCM 6290", "rank": "Strain"}, "1122992": {"name": "Prevotella timonensis 4401737 = DSM 22865 = JCM 15640", "rank": "Strain"}, "1122995": {"name": "Propionibacterium acnes DSM 1897", "rank": "Strain"}, "1122994": {"name": "Propionibacterium acidifaciens DSM 21887", "rank": "Strain"}, "4932": {"name": "Saccharomyces cerevisiae", "rank": "Species"}, "1163730": {"name": "Fervidicoccus fontis Kam940", "rank": "Strain"}, "1005042": {"name": "Streptococcus suis D9", "rank": "Strain"}, "1005041": {"name": "Streptococcus suis SS12", "rank": "Strain"}, "228908": {"name": "Nanoarchaeum equitans Kin4-M", "rank": "Strain"}, "1176491": {"name": "Pseudomonas syringae pv. panici str. LMG 2367", "rank": "Strain"}, "1176490": {"name": "Pseudomonas fuscovaginae CB98818", "rank": "Strain"}, "1163738": {"name": "Escherichia coli O26:H11 str. CVM9952", "rank": "Strain"}, "1163739": {"name": "Helicobacter pylori Shi417", "rank": "Strain"}, "1005048": {"name": "Collimonas fungivorans Ter331", "rank": "Strain"}, "938288": {"name": "Clostridiales bacterium 9401234", "rank": "Species"}, "938289": {"name": "Clostridiales bacterium 9403326", "rank": "Species"}, "231455": {"name": "Dyella japonica", "rank": "Species"}, "231454": {"name": "Dyella", "rank": "Genus"}, "743685": {"name": "Merino Walk virus", "rank": "Species"}, "466051": {"name": "Thermus phage P23-45", "rank": "Species"}, "466052": {"name": "Thermus phage P74-26", "rank": "Species"}, "1471437": {"name": "Prochlorococcus sp. scB241_526B17", "rank": "Species"}, "1471439": {"name": "Prochlorococcus sp. scB241_526B22", "rank": "Species"}, "1471438": {"name": "Prochlorococcus sp. scB241_526B19", "rank": "Species"}, "1455295": {"name": "Mycobacterium tuberculosis NRITLD21", "rank": "Strain"}, "1232683": {"name": "Marinobacterium sp. AK27", "rank": "Species"}, "386445": {"name": "Staphylococcus phage 53 sensu lato", "rank": "Species"}, "408": {"name": "Methylobacterium extorquens", "rank": "Species"}, "1074451": {"name": "Lactobacillus curvatus CRL 705", "rank": "Strain"}, "334782": {"name": "Unclassified Mastrevirus", "rank": "No rank"}, "235201": {"name": "Lactobacillus phage phiJL-1", "rank": "Species"}, "329381": {"name": "Enterobacteria phage RB16", "rank": "Species"}, "329380": {"name": "Unclassified T4-like viruses", "rank": "No rank"}, "386414": {"name": "Prevotella timonensis", "rank": "Species"}, "386415": {"name": "Clostridium novyi NT", "rank": "Strain"}, "1229281": {"name": "Pediococcus lolii NGRI 0510Q", "rank": "Strain"}, "1005438": {"name": "Escherichia coli 99.1775", "rank": "Strain"}, "372457": {"name": "Streptococcus phage M102", "rank": "Species"}, "1116477": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. 53-407", "rank": "Strain"}, "903913": {"name": "Acinetobacter baumannii WC-692", "rank": "Strain"}, "1310611": {"name": "Acinetobacter baumannii 466760", "rank": "Strain"}, "903911": {"name": "Acinetobacter baumannii IS-143", "rank": "Strain"}, "908023": {"name": "Bhendi yellow vein India virus", "rank": "Species"}, "645465": {"name": "Streptomyces sp. e14", "rank": "Species"}, "1116472": {"name": "Methyloglobulus morosus KoM1", "rank": "Strain"}, "1001542": {"name": "Francisella tularensis subsp. tularensis TIGB03", "rank": "Strain"}, "1485225": {"name": "Thalassospira sp. GB04J01", "rank": "Species"}, "35797": {"name": "Nitrococcus mobilis", "rank": "Species"}, "35796": {"name": "Nitrococcus", "rank": "Genus"}, "35795": {"name": "Ehrlichia muris", "rank": "Species"}, "1413586": {"name": "Staphylococcus aureus 9P9", "rank": "Strain"}, "35793": {"name": "Rickettsia sibirica", "rank": "Species"}, "35792": {"name": "Rickettsia parkeri", "rank": "Species"}, "35791": {"name": "Rickettsia massiliae", "rank": "Species"}, "35790": {"name": "Rickettsia japonica", "rank": "Species"}, "35799": {"name": "Nitrosospira briensis", "rank": "Species"}, "35798": {"name": "Nitrosospira", "rank": "Genus"}, "1422277": {"name": "Staphylococcus aureus DAR2075", "rank": "Strain"}, "1422276": {"name": "Staphylococcus aureus DAR2072", "rank": "Strain"}, "1422275": {"name": "Staphylococcus aureus DAR2070", "rank": "Strain"}, "1422274": {"name": "Staphylococcus aureus DAR2068", "rank": "Strain"}, "1422273": {"name": "Staphylococcus aureus DAR2067", "rank": "Strain"}, "1413583": {"name": "Staphylococcus aureus ZTA09/03739-9HSA", "rank": "Strain"}, "1422271": {"name": "Staphylococcus aureus DAR2019", "rank": "Strain"}, "1422270": {"name": "Staphylococcus aureus DAR2018", "rank": "Strain"}, "1422279": {"name": "Staphylococcus aureus DAR3144", "rank": "Strain"}, "1422278": {"name": "Staphylococcus aureus DAR3143", "rank": "Strain"}, "453835": {"name": "Alishewanella aestuarii", "rank": "Species"}, "54258": {"name": "Ignicoccus", "rank": "Genus"}, "54254": {"name": "Thermosphaera aggregans", "rank": "Species"}, "54253": {"name": "Thermosphaera", "rank": "Genus"}, "54252": {"name": "Pyrolobus fumarii", "rank": "Species"}, "54251": {"name": "Pyrolobus", "rank": "Genus"}, "1388062": {"name": "Staphylococcus aureus M0109", "rank": "Strain"}, "35241": {"name": "Lactococcus phage Tuc2009", "rank": "Species"}, "589865": {"name": "Desulfurivibrio alkaliphilus AHT2", "rank": "Strain"}, "12558": {"name": "Sesbania mosaic virus", "rank": "Species"}, "35244": {"name": "Bovine herpesvirus 5", "rank": "Species"}, "35247": {"name": "Unclassified Alphaherpesvirinae", "rank": "No rank"}, "35246": {"name": "Cercopithecine herpesvirus 9", "rank": "Species"}, "35249": {"name": "Unclassified Gammaherpesvirinae", "rank": "No rank"}, "1017280": {"name": "Pseudoflavonifractor", "rank": "Genus"}, "1388061": {"name": "Staphylococcus aureus M0107", "rank": "Strain"}, "553386": {"name": "Halomonas jeotgali", "rank": "Species"}, "1427177": {"name": "Mycobacterium tuberculosis XTB13-081", "rank": "Strain"}, "1131454": {"name": "Mycoplasma canis UFG1", "rank": "Strain"}, "1131455": {"name": "Mycoplasma canis UFG4", "rank": "Strain"}, "1427179": {"name": "Mycobacterium tuberculosis XTB13-083", "rank": "Strain"}, "1427178": {"name": "Mycobacterium tuberculosis XTB13-082", "rank": "Strain"}, "1131451": {"name": "Xanthomonas fragariae LMG 25863", "rank": "Strain"}, "1131452": {"name": "Mycoplasma canis UF31", "rank": "Strain"}, "1131453": {"name": "Mycoplasma canis UF33", "rank": "Strain"}, "1202457": {"name": "Bacillus sp. CPSM8", "rank": "Species"}, "1202456": {"name": "Bacillus sp. Aph1", "rank": "Species"}, "553385": {"name": "Cobetia crustatorum", "rank": "Species"}, "653686": {"name": "Wenxinia", "rank": "Genus"}, "1202451": {"name": "Bartonella birtlesii E4", "rank": "Strain"}, "653685": {"name": "Bacillus subtilis group", "rank": "Species group"}, "577468": {"name": "Unclassified Micrococcineae", "rank": "No rank"}, "328812": {"name": "Parabacteroides goldsteinii", "rank": "Species"}, "328813": {"name": "Alistipes onderdonkii", "rank": "Species"}, "328814": {"name": "Alistipes shahii", "rank": "Species"}, "1463924": {"name": "Streptomyces sp. NRRL WC-3540", "rank": "Species"}, "1463925": {"name": "Streptomyces sp. NRRL WC-3549", "rank": "Species"}, "1463926": {"name": "Streptomyces sp. NRRL WC-3626", "rank": "Species"}, "1424337": {"name": "Pseudomonas aeruginosa ATCC 15442", "rank": "Strain"}, "1463920": {"name": "Streptomyces sp. NRRL S-87", "rank": "Species"}, "1463921": {"name": "Streptomyces sp. NRRL S-920", "rank": "Species"}, "1463922": {"name": "Streptomyces sp. NRRL S-98", "rank": "Species"}, "1424333": {"name": "Haemophilus influenzae 60294N1", "rank": "Strain"}, "200295": {"name": "Candidate division BRC1", "rank": "No rank"}, "1463929": {"name": "Streptomyces sp. NRRL WC-3702", "rank": "Species"}, "53572": {"name": "Deferribacter", "rank": "Genus"}, "644107": {"name": "Silicibacter lacuscaerulensis ITI-1157", "rank": "Strain"}, "651305": {"name": "Acinetobacter sp. GG2", "rank": "Species"}, "240236": {"name": "Woodsholea", "rank": "Genus"}, "210512": {"name": "Sandarakinorhabdus limnophila", "rank": "Species"}, "1489312": {"name": "Sweet potato leaf curl Guangxi virus", "rank": "Species"}, "1489311": {"name": "Sweet potato leaf curl Henan virus", "rank": "Species"}, "37333": {"name": "Nocardia transvalensis", "rank": "Species"}, "37332": {"name": "Nocardia seriolae", "rank": "Species"}, "494269": {"name": "Lactococcus phage bIBB29", "rank": "Strain"}, "37330": {"name": "Nocardia nova", "rank": "Species"}, "191610": {"name": "Corynebacterium atypicum", "rank": "Species"}, "11118": {"name": "Coronaviridae", "rank": "Family"}, "1427238": {"name": "Mycobacterium tuberculosis XTB13-152", "rank": "Strain"}, "168135": {"name": "Apium virus Y", "rank": "Species"}, "1388348": {"name": "Staphylococcus aureus M0527", "rank": "Strain"}, "33178": {"name": "Aspergillus terreus", "rank": "Species"}, "1458468": {"name": "Lachnoclostridium phytofermentans KNHs2132", "rank": "Strain"}, "83544": {"name": "Chinese wheat mosaic virus", "rank": "Species"}, "305072": {"name": "Unclassified Acidobacteria (miscellaneous)", "rank": "No rank"}, "1506575": {"name": "Unclassified Protoparvovirus", "rank": "No rank"}, "33170": {"name": "Eremothecium", "rank": "Genus"}, "33173": {"name": "Eremothecium coryli", "rank": "Species"}, "39152": {"name": "Methanococcus maripaludis", "rank": "Species"}, "53443": {"name": "Blautia hydrogenotrophica", "rank": "Species"}, "46659": {"name": "Thermoplasmataceae", "rank": "Family"}, "1388194": {"name": "Staphylococcus aureus M0296", "rank": "Strain"}, "1427230": {"name": "Mycobacterium tuberculosis XTB13-141", "rank": "Strain"}, "1427231": {"name": "Mycobacterium tuberculosis XTB13-142", "rank": "Strain"}, "669261": {"name": "Mannheimia haemolytica serotype A2 str. OVINE", "rank": "Strain"}, "669260": {"name": "Mannheimia haemolytica serotype A2", "rank": "Strain"}, "669262": {"name": "Mannheimia haemolytica serotype A2 str. BOVINE", "rank": "Strain"}, "210": {"name": "Helicobacter pylori", "rank": "Species"}, "212": {"name": "Helicobacter acinonychis", "rank": "Species"}, "213": {"name": "Helicobacter cinaedi", "rank": "Species"}, "214": {"name": "Helicobacter felis", "rank": "Species"}, "215": {"name": "Helicobacter fennelliae", "rank": "Species"}, "216": {"name": "Helicobacter muridarum", "rank": "Species"}, "217": {"name": "Helicobacter mustelae", "rank": "Species"}, "1427234": {"name": "Mycobacterium tuberculosis XTB13-145", "rank": "Strain"}, "227940": {"name": "Yersinia phage L-413C", "rank": "Species"}, "1388347": {"name": "Staphylococcus aureus M0525", "rank": "Strain"}, "525246": {"name": "Actinomyces urogenitalis DSM 15434", "rank": "Strain"}, "1392068": {"name": "Staphylococcus aureus M1067", "rank": "Strain"}, "525244": {"name": "Acinetobacter sp. ATCC 27244", "rank": "Species"}, "525245": {"name": "Actinomyces coleocanis DSM 15436", "rank": "Strain"}, "525242": {"name": "Acinetobacter baumannii 6014059", "rank": "Strain"}, "525243": {"name": "Acinetobacter baumannii 6013150", "rank": "Strain"}, "1427237": {"name": "Mycobacterium tuberculosis XTB13-150", "rank": "Strain"}, "767453": {"name": "Lactobacillus fermentum F-6", "rank": "Strain"}, "1217986": {"name": "Acinetobacter haemolyticus NIPH 261", "rank": "Strain"}, "1217985": {"name": "Acinetobacter nosocomialis NIPH 386", "rank": "Strain"}, "1217984": {"name": "Bacillus cereus FRI-35", "rank": "Strain"}, "1217988": {"name": "Acinetobacter schindleri CIP 107287", "rank": "Strain"}, "1336250": {"name": "Hallella seregens ATCC 51272", "rank": "Strain"}, "291112": {"name": "Photorhabdus asymbiotica", "rank": "Species"}, "1312852": {"name": "Thermoanaerobaculum aquaticum", "rank": "Species"}, "1160223": {"name": "Brucella melitensis UK19/04", "rank": "Strain"}, "1160222": {"name": "Brucella melitensis Uk24/06", "rank": "Strain"}, "1000373": {"name": "Rosellinia necatrix quadrivirus 1", "rank": "Species"}, "1273540": {"name": "Listeria monocytogenes FSL F6-684", "rank": "Strain"}, "1300351": {"name": "Vibrio parahaemolyticus v110", "rank": "Strain"}, "1300350": {"name": "Sulfitobacter donghicola DSW-25 = KCTC 12864 = JCM 14565", "rank": "Strain"}, "219596": {"name": "Tobacco curly shoot betasatellite", "rank": "Species"}, "170621": {"name": "Perina nuda virus", "rank": "Species"}, "1328353": {"name": "Brucella abortus 90-1280", "rank": "Strain"}, "364317": {"name": "Verminephrobacter eiseniae", "rank": "Species"}, "129577": {"name": "Oceanimonas", "rank": "Genus"}, "364316": {"name": "Verminephrobacter", "rank": "Genus"}, "1105242": {"name": "Streptococcus agalactiae str. Gottschalk 999B", "rank": "Strain"}, "1105240": {"name": "Streptococcus agalactiae str. Gottschalk 31825", "rank": "Strain"}, "1105241": {"name": "Streptococcus agalactiae str. Gottschalk 998A", "rank": "Strain"}, "1350471": {"name": "Bifidobacterium longum subsp. longum 1-5B", "rank": "Strain"}, "1350470": {"name": "Klebsiella oxytoca SA2", "rank": "Strain"}, "1350473": {"name": "Bifidobacterium longum subsp. longum 17-1B", "rank": "Strain"}, "1350472": {"name": "Bifidobacterium longum subsp. longum 7-1B", "rank": "Strain"}, "1281062": {"name": "Escherichia coli HVH 127 (4-7303629)", "rank": "Strain"}, "1523621": {"name": "Cellulosimicrobium sp. MM", "rank": "Species"}, "81947": {"name": "Vagococcus lutrae", "rank": "Species"}, "484021": {"name": "Klebsiella pneumoniae subsp. pneumoniae NTUH-K2044", "rank": "Strain"}, "1281060": {"name": "Escherichia coli HVH 125 (4-2634716)", "rank": "Strain"}, "1328355": {"name": "Brucella abortus 01-0648", "rank": "Strain"}, "213888": {"name": "Dahlia mosaic virus", "rank": "Species"}, "1378168": {"name": "Firmicutes bacterium ASF500", "rank": "Species"}, "339419": {"name": "Unclassified Ilarvirus", "rank": "No rank"}, "181086": {"name": "Prymnesiovirus", "rank": "Genus"}, "181084": {"name": "Prasinovirus", "rank": "Genus"}, "181085": {"name": "Phaeovirus", "rank": "Genus"}, "181082": {"name": "Emiliania huxleyi virus 86", "rank": "Species"}, "181083": {"name": "Chlorovirus", "rank": "Genus"}, "1310683": {"name": "Acinetobacter baumannii 1566109", "rank": "Strain"}, "1310680": {"name": "Acinetobacter baumannii 1239920", "rank": "Strain"}, "1310681": {"name": "Acinetobacter baumannii 1542444", "rank": "Strain"}, "1310686": {"name": "Acinetobacter baumannii 397971", "rank": "Strain"}, "1310684": {"name": "Acinetobacter baumannii 83444", "rank": "Strain"}, "1310685": {"name": "Acinetobacter baumannii 72431", "rank": "Strain"}, "1403878": {"name": "Staphylococcus aureus M1494", "rank": "Strain"}, "1403879": {"name": "Staphylococcus aureus M1496", "rank": "Strain"}, "1403874": {"name": "Staphylococcus aureus M1490", "rank": "Strain"}, "1403875": {"name": "Staphylococcus aureus M1491", "rank": "Strain"}, "1403876": {"name": "Staphylococcus aureus M1492", "rank": "Strain"}, "1403877": {"name": "Staphylococcus aureus M1493", "rank": "Strain"}, "1403870": {"name": "Staphylococcus aureus M1486", "rank": "Strain"}, "1403871": {"name": "Staphylococcus aureus M1487", "rank": "Strain"}, "1403872": {"name": "Staphylococcus aureus M1488", "rank": "Strain"}, "1403873": {"name": "Staphylococcus aureus M1489", "rank": "Strain"}, "876283": {"name": "Bacillus atrophaeus BACI051-N", "rank": "Strain"}, "1168063": {"name": "Klebsiella pneumoniae subsp. pneumoniae KPNIH22", "rank": "Strain"}, "1168062": {"name": "Klebsiella pneumoniae subsp. pneumoniae KPNIH21", "rank": "Strain"}, "1409649": {"name": "Staphylococcus aureus SCLE6032", "rank": "Strain"}, "1255359": {"name": "Planktothrix prolifica NIVA-CYA 540", "rank": "Strain"}, "1409648": {"name": "Staphylococcus aureus TUSH6007", "rank": "Strain"}, "1400526": {"name": "Donkey orchid symptomless virus", "rank": "Species"}, "1400525": {"name": "Candidatus Pelagibacter ubique HTCC7217", "rank": "Strain"}, "1400524": {"name": "Candidatus Pelagibacter ubique HTCC7214", "rank": "Strain"}, "1400522": {"name": "Sediminibacterium salmoneum NBRC 103935", "rank": "Strain"}, "1400521": {"name": "Enterococcus faecalis CBRD01", "rank": "Strain"}, "1400520": {"name": "Lactobacillus fabifermentans T30PCM01", "rank": "Strain"}, "992142": {"name": "Yersinia pestis PY-16", "rank": "Strain"}, "992145": {"name": "Yersinia pestis PY-29", "rank": "Strain"}, "1211579": {"name": "Pseudomonas putida NBRC 14164", "rank": "Strain"}, "1454024": {"name": "Dragonfly larvae associated circular virus-3", "rank": "Species"}, "1444251": {"name": "Escherichia coli 3-267-03_S4_C2", "rank": "Strain"}, "84599": {"name": "Staphylothermus hellenicus", "rank": "Species"}, "1444250": {"name": "Escherichia coli 3-105-05_S4_C2", "rank": "Strain"}, "84595": {"name": "Gordonia polyisoprenivorans", "rank": "Species"}, "84590": {"name": "Taylorella asinigenitalis", "rank": "Species"}, "84593": {"name": "Verrucosispora", "rank": "Genus"}, "1409642": {"name": "Staphylococcus aureus LAMC6084", "rank": "Strain"}, "196690": {"name": "Helicobasidium mompa totivirus 1-17", "rank": "Species"}, "1249531": {"name": "Mannheimia haemolytica USDA-ARS-USMARC-183", "rank": "Strain"}, "1444254": {"name": "Escherichia coli 4-203-08_S4_C2", "rank": "Strain"}, "1444257": {"name": "Escherichia coli 6-537-08_S4_C2", "rank": "Strain"}, "1444256": {"name": "Escherichia coli 6-319-05_S4_C2", "rank": "Strain"}, "1395983": {"name": "Escherichia phage vB_EcoP_PhAPEC5", "rank": "Species"}, "1294139": {"name": "Klebsiella pneumoniae KP4-R", "rank": "Strain"}, "1294138": {"name": "Klebsiella pneumoniae KP5-R", "rank": "Strain"}, "712359": {"name": "Leptotrichia sp. oral taxon 215", "rank": "Species"}, "1388184": {"name": "Staphylococcus aureus M0283", "rank": "Strain"}, "1388185": {"name": "Staphylococcus aureus M0285", "rank": "Strain"}, "1388186": {"name": "Staphylococcus aureus M0286", "rank": "Strain"}, "1388187": {"name": "Staphylococcus aureus M0287", "rank": "Strain"}, "1388180": {"name": "Staphylococcus aureus M0276", "rank": "Strain"}, "1388181": {"name": "Staphylococcus aureus M0277", "rank": "Strain"}, "1388182": {"name": "Staphylococcus aureus M0278", "rank": "Strain"}, "1388183": {"name": "Staphylococcus aureus M0281", "rank": "Strain"}, "1388188": {"name": "Staphylococcus aureus M0289", "rank": "Strain"}, "1388189": {"name": "Staphylococcus aureus M0290", "rank": "Strain"}, "1151287": {"name": "Peptoclostridium difficile CD132", "rank": "Strain"}, "1151286": {"name": "Peptoclostridium difficile CD131", "rank": "Strain"}, "1260222": {"name": "Chlamydia trachomatis IU824", "rank": "Strain"}, "1260223": {"name": "Chlamydia trachomatis IU888", "rank": "Strain"}, "1151283": {"name": "Peptoclostridium difficile CD113", "rank": "Strain"}, "1151282": {"name": "Peptoclostridium difficile CD111", "rank": "Strain"}, "1151281": {"name": "Peptoclostridium difficile CD109", "rank": "Strain"}, "1151280": {"name": "Peptoclostridium difficile CD104", "rank": "Strain"}, "1422013": {"name": "Mycobacterium tuberculosis TB_RSA97", "rank": "Strain"}, "1151289": {"name": "Peptoclostridium difficile CD144", "rank": "Strain"}, "1151288": {"name": "Peptoclostridium difficile CD133", "rank": "Strain"}, "1311087": {"name": "Acinetobacter baumannii 44298_10", "rank": "Strain"}, "1311086": {"name": "Acinetobacter baumannii 44298_9", "rank": "Strain"}, "1311085": {"name": "Acinetobacter baumannii 44298_8", "rank": "Strain"}, "1311084": {"name": "Acinetobacter baumannii 44298_7", "rank": "Strain"}, "1311083": {"name": "Acinetobacter baumannii 44298_6", "rank": "Strain"}, "1311082": {"name": "Acinetobacter baumannii 44298_5", "rank": "Strain"}, "1311081": {"name": "Acinetobacter baumannii 44298_4", "rank": "Strain"}, "1311080": {"name": "Acinetobacter baumannii 44298_3", "rank": "Strain"}, "1422010": {"name": "Mycobacterium tuberculosis TB_RSA94", "rank": "Strain"}, "1311089": {"name": "Acinetobacter baumannii 45075_2", "rank": "Strain"}, "488546": {"name": "Campylobacter peloridis", "rank": "Species"}, "368783": {"name": "Acidicaldus", "rank": "Genus"}, "262077": {"name": "Marinobacter daepoensis", "rank": "Species"}, "456298": {"name": "Haemophilus parasuis 29755", "rank": "Strain"}, "456299": {"name": "Chryseobacterium gregarium", "rank": "Species"}, "143919": {"name": "Betanodavirus", "rank": "Genus"}, "1042156": {"name": "Clostridium sp. SY8519", "rank": "Species"}, "243164": {"name": "Dehalococcoides mccartyi 195", "rank": "Strain"}, "243160": {"name": "Burkholderia mallei ATCC 23344", "rank": "Strain"}, "243161": {"name": "Chlamydia muridarum str. Nigg", "rank": "Strain"}, "712401": {"name": "Neisseria sp. oral taxon 020", "rank": "Species"}, "1200970": {"name": "French bean leaf curl virus-Kanpur", "rank": "Species"}, "1200971": {"name": "French bean leaf curl betasatellite-Kanpur", "rank": "Species"}, "92129": {"name": "Tupaia paramyxovirus", "rank": "Species"}, "1440772": {"name": "Streptococcus pyogenes STAB901", "rank": "Strain"}, "1440773": {"name": "Pantoea ananatis Sd-1", "rank": "Strain"}, "1440774": {"name": "Mycobacterium aromaticivorans JS19b1 = JCM 16368", "rank": "Strain"}, "1448567": {"name": "Mycobacterium tuberculosis TKK_04_0098", "rank": "Strain"}, "1448566": {"name": "Mycobacterium tuberculosis TKK_04_0097", "rank": "Strain"}, "1448565": {"name": "Mycobacterium tuberculosis TKK_04_0096", "rank": "Strain"}, "1050222": {"name": "Paenibacillus sp. Aloe-11", "rank": "Species"}, "1448563": {"name": "Mycobacterium tuberculosis TKK_04_0094", "rank": "Strain"}, "1448562": {"name": "Mycobacterium tuberculosis TKK_04_0090", "rank": "Strain"}, "1448561": {"name": "Mycobacterium tuberculosis TKK_04_0089", "rank": "Strain"}, "1448560": {"name": "Mycobacterium tuberculosis TKK_04_0085", "rank": "Strain"}, "476528": {"name": "Bibersteinia", "rank": "Genus"}, "476529": {"name": "Leisingera aquimarina", "rank": "Species"}, "939374": {"name": "Alpha proteobacterium SCGC AAA298-K06", "rank": "Species"}, "43240": {"name": "Bean common mosaic necrosis virus", "rank": "Species"}, "1276257": {"name": "Spiroplasma sabaudiense Ar-1343", "rank": "Strain"}, "1448569": {"name": "Mycobacterium tuberculosis TKK_04_0103", "rank": "Strain"}, "1448568": {"name": "Mycobacterium tuberculosis TKK_04_0099", "rank": "Strain"}, "10869": {"name": "Enterobacteria phage I2-2", "rank": "Species"}, "53329": {"name": "Desulfospira joergensenii", "rank": "Species"}, "1193039": {"name": "Leptospira interrogans str. Brem 329", "rank": "Strain"}, "502025": {"name": "Haliangium ochraceum DSM 14365", "rank": "Strain"}, "537457": {"name": "Actinobacillus pleuropneumoniae serovar 7 str. AP76", "rank": "Strain"}, "574976": {"name": "Holophagaceae", "rank": "Family"}, "574975": {"name": "Holophagales", "rank": "Order"}, "948563": {"name": "Staphylococcus aureus O46", "rank": "Strain"}, "948561": {"name": "Staphylococcus aureus O11", "rank": "Strain"}, "948565": {"name": "Avibacterium paragallinarum 72", "rank": "Strain"}, "1402701": {"name": "Staphylococcus aureus M1194", "rank": "Strain"}, "1402700": {"name": "Staphylococcus aureus M1192", "rank": "Strain"}, "1402703": {"name": "Staphylococcus aureus M1196", "rank": "Strain"}, "1402702": {"name": "Staphylococcus aureus M1195", "rank": "Strain"}, "1402705": {"name": "Staphylococcus aureus M1200", "rank": "Strain"}, "1402704": {"name": "Staphylococcus aureus M1197", "rank": "Strain"}, "1402707": {"name": "Staphylococcus aureus M1202", "rank": "Strain"}, "1402706": {"name": "Staphylococcus aureus M1201", "rank": "Strain"}, "1402709": {"name": "Staphylococcus aureus M1204", "rank": "Strain"}, "1402708": {"name": "Staphylococcus aureus M1203", "rank": "Strain"}, "707187": {"name": "Chlamydia trachomatis G/11074", "rank": "Strain"}, "707186": {"name": "Chlamydia trachomatis G/11222", "rank": "Strain"}, "707185": {"name": "Chlamydia trachomatis G/9768", "rank": "Strain"}, "707184": {"name": "Chlamydia trachomatis E/150", "rank": "Strain"}, "707183": {"name": "Chlamydia trachomatis E/11023", "rank": "Strain"}, "1428342": {"name": "Chilli leaf curl alphasatellite", "rank": "Species"}, "1238452": {"name": "Wolbachia pipientis wBol1-b", "rank": "Strain"}, "1238450": {"name": "Vibrio nigripulchritudo SOn1", "rank": "Strain"}, "1238451": {"name": "Vibrio nigripulchritudo Wn13", "rank": "Strain"}, "1094980": {"name": "Methanolobus psychrophilus R15", "rank": "Strain"}, "1094981": {"name": "Candida albicans 12C", "rank": "Strain"}, "1094982": {"name": "Candida albicans L26", "rank": "Strain"}, "1094983": {"name": "Candida albicans P94015", "rank": "Strain"}, "1094984": {"name": "Candida albicans P87", "rank": "Strain"}, "1094985": {"name": "Candida albicans P37005", "rank": "Strain"}, "1094986": {"name": "Candida albicans P60002", "rank": "Strain"}, "1094987": {"name": "Candida albicans 19F", "rank": "Strain"}, "687375": {"name": "Torque teno mini virus 7", "rank": "Species"}, "1279083": {"name": "Pseudomonas phage PPpW-4", "rank": "Species"}, "261302": {"name": "Burkholderia phytofirmans", "rank": "Species"}, "1534409": {"name": "Arthrobacter sp. MWB30", "rank": "Species"}, "1120919": {"name": "Acetobacter nitrogenifigens DSM 23921 = LMG 23498", "rank": "Strain"}, "1435052": {"name": "Clostridium botulinum CDC54088", "rank": "Strain"}, "1120917": {"name": "Acaricomes phytoseiuli DSM 14247", "rank": "Strain"}, "5111": {"name": "Claviceps purpurea", "rank": "Species"}, "1435051": {"name": "Bifidobacterium moukalabense DSM 27321", "rank": "Strain"}, "1435050": {"name": "Burkholderia pseudomallei MSHR5613", "rank": "Strain"}, "932677": {"name": "Pantoea ananatis AJ13355", "rank": "Strain"}, "932676": {"name": "Shigella boydii ATCC 9905", "rank": "Strain"}, "1435057": {"name": "Agrobacterium tumefaciens LBA4213 (Ach5)", "rank": "Strain"}, "706587": {"name": "Desulfomonile tiedjei DSM 6799", "rank": "Strain"}, "1163621": {"name": "Rheinheimera nanhaiensis", "rank": "Species"}, "79885": {"name": "Bacillus pseudofirmus", "rank": "Species"}, "79880": {"name": "Bacillus clausii", "rank": "Species"}, "1435054": {"name": "Clostridium botulinum CDC54085", "rank": "Strain"}, "312178": {"name": "Leptospira interrogans serovar Djasiman", "rank": "Strain"}, "109871": {"name": "Batrachochytrium dendrobatidis", "rank": "Species"}, "312175": {"name": "Leptospira interrogans serovar Bataviae", "rank": "Strain"}, "12407": {"name": "Enterobacteria phage PsP3", "rank": "Species"}, "12402": {"name": "Streptococcus phage EJ-1", "rank": "Species"}, "1219045": {"name": "Sphingobium herbicidovorans NBRC 16415", "rank": "Strain"}, "1415161": {"name": "Rhodobacter capsulatus Y262", "rank": "Strain"}, "1219049": {"name": "Sphingomonas parapaucimobilis NBRC 15100", "rank": "Strain"}, "1415163": {"name": "Rhodobacter capsulatus R121", "rank": "Strain"}, "765964": {"name": "Helicobacter pylori Cuz20", "rank": "Strain"}, "765963": {"name": "Helicobacter pylori PeCan4", "rank": "Strain"}, "765962": {"name": "Helicobacter pylori SJM180", "rank": "Strain"}, "308911": {"name": "N15likevirus", "rank": "Genus"}, "308912": {"name": "Phic3unalikevirus", "rank": "Genus"}, "12742": {"name": "Infectious flacherie virus", "rank": "Species"}, "102294": {"name": "Unclassified Caudovirales", "rank": "No rank"}, "1162288": {"name": "Mycobacterium abscessus M154", "rank": "Strain"}, "1162281": {"name": "Rickettsia conorii subsp. indica ITTR", "rank": "Strain"}, "1162280": {"name": "Tomato rugose yellow leaf curl virus", "rank": "Species"}, "1162283": {"name": "Mycobacterium abscessus subsp. bolletii M18", "rank": "Strain"}, "1162282": {"name": "Rhodanobacter sp. 115", "rank": "Species"}, "1162285": {"name": "Mycobacterium abscessus M159", "rank": "Strain"}, "1162284": {"name": "Mycobacterium abscessus M24", "rank": "Strain"}, "28375": {"name": "Soil-borne wheat mosaic virus", "rank": "Species"}, "1162286": {"name": "Mycobacterium abscessus M172", "rank": "Strain"}, "10806": {"name": "Ambidensovirus", "rank": "Genus"}, "10804": {"name": "Adeno-associated virus - 2", "rank": "Strain"}, "936595": {"name": "Lachnoanaerobaculum sp. OBRC5-5", "rank": "Species"}, "10803": {"name": "Dependoparvovirus", "rank": "Genus"}, "936591": {"name": "Veillonella sp. ICM51a", "rank": "Species"}, "522456": {"name": "Cycloclasticus sp. PY97M", "rank": "Species"}, "903889": {"name": "Acinetobacter baumannii OIFC137", "rank": "Strain"}, "10809": {"name": "Bombyx mori densovirus", "rank": "Strain"}, "1238180": {"name": "Amycolatopsis azurea DSM 43854", "rank": "Strain"}, "497865": {"name": "Cardiospermum yellow leaf curl betasatellite", "rank": "Species"}, "1238182": {"name": "Caenispirillum salinarum AK4", "rank": "Strain"}, "1238184": {"name": "Oceanobacillus kimchii X50", "rank": "Strain"}, "573657": {"name": "Candidatus Hodgkinia", "rank": "Genus"}, "1238186": {"name": "Leucobacter salsicius M1-8", "rank": "Strain"}, "497863": {"name": "Oat dwarf virus", "rank": "Species"}, "573658": {"name": "Candidatus Hodgkinia cicadicola", "rank": "Species"}, "380598": {"name": "Paramecium bursaria Chlorella virus AR158", "rank": "Species"}, "1310917": {"name": "Acinetobacter baumannii 25766_3", "rank": "Strain"}, "29397": {"name": "Lactobacillus delbrueckii subsp. lactis", "rank": "Subspecies"}, "29394": {"name": "Dolosigranulum pigrum", "rank": "Species"}, "11176": {"name": "Newcastle disease virus", "rank": "Species"}, "29393": {"name": "Dolosigranulum", "rank": "Genus"}, "29390": {"name": "Streptococcus gordonii str. Challis", "rank": "Strain"}, "29391": {"name": "Gemella morbillorum", "rank": "Species"}, "862751": {"name": "Streptomyces sp. SirexAA-E", "rank": "Species"}, "1444198": {"name": "Escherichia coli 6-319-05_S3_C3", "rank": "Strain"}, "1495064": {"name": "Methylobacter sp. BBA5.1", "rank": "Species"}, "56812": {"name": "Shewanella frigidimarina", "rank": "Species"}, "1495066": {"name": "Pseudomonas sp. WCS358", "rank": "Species"}, "1339315": {"name": "Bacteroides fragilis str. 3988T(B)14", "rank": "Strain"}, "81466": {"name": "Aminobacterium", "rank": "Genus"}, "1443910": {"name": "Turkey stool associated circular ssDNA virus", "rank": "Species"}, "867696": {"name": "Salmonella phage ViI", "rank": "Species"}, "1218315": {"name": "Brucella inopinata", "rank": "Species"}, "412963": {"name": "Burkholderia rhizoxinica", "rank": "Species"}, "412966": {"name": "Vibrio cholerae 1587", "rank": "Strain"}, "866344": {"name": "Helicobacter pylori F16", "rank": "Strain"}, "866346": {"name": "Helicobacter pylori F57", "rank": "Strain"}, "489089": {"name": "Ostreococcus virus OsV5", "rank": "Species"}, "412968": {"name": "Streptomyces sp. M10", "rank": "Species"}, "412969": {"name": "Porcine pestivirus isolate Bungowannah", "rank": "Species"}, "91844": {"name": "Candidatus Portiera aleyrodidarum", "rank": "Species"}, "586422": {"name": "Human cosavirus D", "rank": "Species"}, "283166": {"name": "Bartonella henselae str. Houston-1", "rank": "Strain"}, "283165": {"name": "Bartonella quintana str. Toulouse", "rank": "Strain"}, "1227485": {"name": "Halorubrum tebenquichense DSM 14210", "rank": "Strain"}, "283168": {"name": "Odoribacter", "rank": "Genus"}, "586424": {"name": "Unclassified Cosavirus", "rank": "No rank"}, "1422185": {"name": "Staphylococcus aureus DAR3871", "rank": "Strain"}, "1422184": {"name": "Staphylococcus aureus DAR3870", "rank": "Strain"}, "1422187": {"name": "Staphylococcus aureus DAR3886", "rank": "Strain"}, "1422186": {"name": "Staphylococcus aureus DAR3885", "rank": "Strain"}, "1422181": {"name": "Staphylococcus aureus DAR3862", "rank": "Strain"}, "1422180": {"name": "Staphylococcus aureus DAR3861", "rank": "Strain"}, "1422183": {"name": "Staphylococcus aureus DAR3868", "rank": "Strain"}, "1422182": {"name": "Staphylococcus aureus DAR3864", "rank": "Strain"}, "1078480": {"name": "Haemophilus sputorum", "rank": "Species"}, "1422189": {"name": "Staphylococcus aureus DAR3892", "rank": "Strain"}, "1422188": {"name": "Staphylococcus aureus DAR3891", "rank": "Strain"}, "641407": {"name": "Unclassified Lentisphaerae (miscellaneous)", "rank": "No rank"}, "1336597": {"name": "Tomato golden leaf spot virus", "rank": "Species"}, "928315": {"name": "Papaya leaf crumple virus", "rank": "Species"}, "1336599": {"name": "Unclassified Taupapillomavirus", "rank": "No rank"}, "130500": {"name": "Bovine adenovirus E", "rank": "Species"}, "1413448": {"name": "Staphylococcus aureus VE07/03048STA", "rank": "Strain"}, "1413449": {"name": "Staphylococcus aureus VE08/02126ST1", "rank": "Strain"}, "286636": {"name": "Streptococcus pyogenes MGAS10394", "rank": "Strain"}, "520140": {"name": "Mycobacterium tuberculosis EAS054", "rank": "Strain"}, "520141": {"name": "Mycobacterium tuberculosis T85", "rank": "Strain"}, "1413440": {"name": "Staphylococcus aureus FP_N5203 OX", "rank": "Strain"}, "1413441": {"name": "Staphylococcus aureus FP_N5208 OX", "rank": "Strain"}, "1413442": {"name": "Staphylococcus aureus M267-1", "rank": "Strain"}, "1413443": {"name": "Staphylococcus aureus M357", "rank": "Strain"}, "1413444": {"name": "Staphylococcus aureus M457-1", "rank": "Strain"}, "286638": {"name": "Massilia alkalitolerans", "rank": "Species"}, "1413446": {"name": "Staphylococcus aureus SARM C4155", "rank": "Strain"}, "1413447": {"name": "Staphylococcus aureus SARM C5621", "rank": "Strain"}, "1409476": {"name": "Staphylococcus aureus OCMM6003", "rank": "Strain"}, "1409477": {"name": "Staphylococcus aureus OCMM6002", "rank": "Strain"}, "1409474": {"name": "Staphylococcus aureus SJUD6015", "rank": "Strain"}, "1409475": {"name": "Staphylococcus aureus SJUD6018", "rank": "Strain"}, "1409472": {"name": "Staphylococcus aureus SJUD6014", "rank": "Strain"}, "1409473": {"name": "Staphylococcus aureus SJUD6010", "rank": "Strain"}, "1409470": {"name": "Staphylococcus aureus SMMC6038", "rank": "Strain"}, "1409471": {"name": "Staphylococcus aureus SCLE6003", "rank": "Strain"}, "1281250": {"name": "Escherichia coli UMEA 3489-1", "rank": "Strain"}, "1281251": {"name": "Escherichia coli UMEA 3490-1", "rank": "Strain"}, "1281252": {"name": "Escherichia coli UMEA 3585-1", "rank": "Strain"}, "1281253": {"name": "Escherichia coli UMEA 3592-1", "rank": "Strain"}, "153232": {"name": "Oceanicaulis", "rank": "Genus"}, "153233": {"name": "Oceanicaulis alexandrii", "rank": "Species"}, "1409478": {"name": "Staphylococcus aureus HOAG6017", "rank": "Strain"}, "1409479": {"name": "Staphylococcus aureus LAMC0010", "rank": "Strain"}, "1422721": {"name": "Staphylococcus aureus VET1869R", "rank": "Strain"}, "1422720": {"name": "Staphylococcus aureus VET1868R", "rank": "Strain"}, "1422723": {"name": "Staphylococcus aureus VET1872R", "rank": "Strain"}, "1422722": {"name": "Staphylococcus aureus VET1871R", "rank": "Strain"}, "1422725": {"name": "Staphylococcus aureus VET1875R", "rank": "Strain"}, "1422724": {"name": "Staphylococcus aureus VET1873R", "rank": "Strain"}, "659497": {"name": "Sclerotinia sclerotiorum partitivirus S", "rank": "Species"}, "1422726": {"name": "Staphylococcus aureus VET1876R", "rank": "Strain"}, "871925": {"name": "Actinobacillus pleuropneumoniae serovar 2 str. S1536", "rank": "Strain"}, "1422728": {"name": "Staphylococcus aureus VET1880R", "rank": "Strain"}, "1200547": {"name": "Prevotella sp. RM4", "rank": "Species"}, "760876": {"name": "Streptococcus pneumoniae 3063-00", "rank": "Strain"}, "760877": {"name": "Streptococcus pneumoniae EU-NP01", "rank": "Strain"}, "760870": {"name": "Streptococcus pneumoniae 7879-04", "rank": "Strain"}, "760871": {"name": "Streptococcus pneumoniae 5652-06", "rank": "Strain"}, "760872": {"name": "Streptococcus pneumoniae 7533-05", "rank": "Strain"}, "760873": {"name": "Streptococcus pneumoniae 4075-00", "rank": "Strain"}, "760878": {"name": "Streptococcus pneumoniae EU-NP02", "rank": "Strain"}, "760879": {"name": "Streptococcus pneumoniae EU-NP03", "rank": "Strain"}, "1284830": {"name": "Klebsiella pneumoniae VAKPC276", "rank": "Strain"}, "561440": {"name": "Lysinibacillus sinduriensis", "rank": "Species"}, "1367848": {"name": "Cronobacter sakazakii NCIMB 8272", "rank": "Strain"}, "55216": {"name": "Tomato yellow vein streak virus", "rank": "Species"}, "55218": {"name": "Ruegeria lacuscaerulensis", "rank": "Species"}, "863239": {"name": "Corynebacterium nuruki S6-4", "rank": "Strain"}, "337243": {"name": "Halorubrum ezzemoulense", "rank": "Species"}, "787": {"name": "Rickettsia australis", "rank": "Species"}, "784": {"name": "Orientia tsutsugamushi", "rank": "Species"}, "785": {"name": "Rickettsia typhi", "rank": "Species"}, "782": {"name": "Rickettsia prowazekii", "rank": "Species"}, "783": {"name": "Rickettsia rickettsii", "rank": "Species"}, "780": {"name": "Rickettsia", "rank": "Genus"}, "781": {"name": "Rickettsia conorii", "rank": "Species"}, "1069680": {"name": "Pneumocystis murina B123", "rank": "Subspecies"}, "512792": {"name": "Acidianus filamentous virus 9", "rank": "Species"}, "788": {"name": "Rickettsia canadensis", "rank": "Species"}, "1417219": {"name": "Staphylococcus aureus W83137", "rank": "Strain"}, "1417218": {"name": "Staphylococcus aureus W83133", "rank": "Strain"}, "1193049": {"name": "Leptospira kirschneri str. 2008720114", "rank": "Strain"}, "941967": {"name": "Brucella melitensis M28", "rank": "Strain"}, "66875": {"name": "Streptomyces catenulae", "rank": "Species"}, "941969": {"name": "Liberibacter phage SC1", "rank": "Species"}, "941968": {"name": "Clostridium botulinum H04402 065", "rank": "Strain"}, "1417213": {"name": "Staphylococcus aureus W73738", "rank": "Strain"}, "656444": {"name": "Escherichia coli TA280", "rank": "Strain"}, "1417215": {"name": "Staphylococcus aureus W76994_072512", "rank": "Strain"}, "1417214": {"name": "Staphylococcus aureus W76930", "rank": "Strain"}, "1417217": {"name": "Staphylococcus aureus W79990_080112", "rank": "Strain"}, "656440": {"name": "Escherichia coli TA206", "rank": "Strain"}, "1380773": {"name": "Streptococcus suis YB51", "rank": "Strain"}, "1380772": {"name": "Lactococcus garvieae TRF1", "rank": "Strain"}, "1380770": {"name": "Streptomycetaceae bacterium MP113-05", "rank": "Species"}, "1380774": {"name": "Pandoraea sp. RB-44", "rank": "Species"}, "354197": {"name": "Arenimonas malthae", "rank": "Species"}, "1305790": {"name": "Kingella kingae KK107", "rank": "Strain"}, "996848": {"name": "Leptospira interrogans serovar Copenhageni str. Fiocruz LV2973", "rank": "Strain"}, "996849": {"name": "Leptospira interrogans serovar Copenhageni str. Fiocruz LV3086", "rank": "Strain"}, "996846": {"name": "Leptospira interrogans serovar Copenhageni str. Fiocruz LV2958", "rank": "Strain"}, "996847": {"name": "Leptospira interrogans serovar Copenhageni str. Fiocruz LV2959", "rank": "Strain"}, "996844": {"name": "Leptospira interrogans serovar Copenhageni str. Fiocruz LV2948", "rank": "Strain"}, "996845": {"name": "Leptospira interrogans serovar Copenhageni str. Fiocruz LV2953", "rank": "Strain"}, "996841": {"name": "Leptospira interrogans serovar Copenhageni str. Fiocruz LV2897", "rank": "Strain"}, "1400927": {"name": "Mycobacterium tuberculosis KT-0089", "rank": "Strain"}, "191960": {"name": "Sedimenticola selenatireducens", "rank": "Species"}, "1404345": {"name": "Acheta domesticus mini ambidensovirus", "rank": "Species"}, "647910": {"name": "Listeria rocourtiae", "rank": "Species"}, "330879": {"name": "Aspergillus fumigatus Af293", "rank": "Strain"}, "1220585": {"name": "Bacillus weihenstephanensis NBRC 101238 = DSM 11821", "rank": "Strain"}, "309887": {"name": "Deinococcus maricopensis", "rank": "Species"}, "309888": {"name": "Deinococcus pimensis", "rank": "Species"}, "1169198": {"name": "Salinispora tropica CNR699", "rank": "Strain"}, "869209": {"name": "Treponema succinifaciens DSM 2489", "rank": "Strain"}, "44275": {"name": "Leptospira interrogans serovar Copenhageni", "rank": "Strain"}, "868169": {"name": "Escherichia coli DEC7E", "rank": "Strain"}, "868168": {"name": "Escherichia coli DEC7D", "rank": "Strain"}, "1123325": {"name": "Sulfurihydrogenibium subterraneum DSM 15120", "rank": "Strain"}, "868162": {"name": "Escherichia coli DEC6C", "rank": "Strain"}, "868161": {"name": "Escherichia coli DEC6B", "rank": "Strain"}, "868160": {"name": "Escherichia coli DEC6A", "rank": "Strain"}, "868167": {"name": "Escherichia coli DEC7C", "rank": "Strain"}, "1123320": {"name": "Streptomyces scabrisporus DSM 41855", "rank": "Strain"}, "868165": {"name": "Escherichia coli DEC7A", "rank": "Strain"}, "868164": {"name": "Escherichia coli DEC6E", "rank": "Strain"}, "713605": {"name": "Lactobacillus iners AB-1", "rank": "Strain"}, "713604": {"name": "Amycolatopsis mediterranei S699", "rank": "Strain"}, "713601": {"name": "Buchnera aphidicola str. JF99 (Acyrthosiphon pisum)", "rank": "Strain"}, "713600": {"name": "Buchnera aphidicola str. JF98 (Acyrthosiphon pisum)", "rank": "Strain"}, "713603": {"name": "Buchnera aphidicola str. LL01 (Acyrthosiphon pisum)", "rank": "Strain"}, "713602": {"name": "Buchnera aphidicola str. TLW03 (Acyrthosiphon pisum)", "rank": "Strain"}, "85752": {"name": "Tomato yellow leaf curl Thailand virus", "rank": "Species"}, "85753": {"name": "Soybean crinkle leaf virus", "rank": "Species"}, "501479": {"name": "Citreicella sp. SE45", "rank": "Species"}, "89404": {"name": "Glaciecola", "rank": "Genus"}, "191389": {"name": "Leifsonia rubra", "rank": "Species"}, "1000590": {"name": "Staphylococcus epidermidis 14.1.R1.SE", "rank": "Strain"}, "1473216": {"name": "Senegalimassilia anaerobia", "rank": "Species"}, "762569": {"name": "Rhodothermus marinus SG0.5JP17-171", "rank": "Strain"}, "496874": {"name": "Lactobacillus phage Lrm1", "rank": "Species"}, "1185420": {"name": "Klebsiella pneumoniae subsp. pneumoniae ST258-K28BO", "rank": "Strain"}, "1185421": {"name": "Staphylococcus hominis subsp. hominis ZBW5", "rank": "Strain"}, "264201": {"name": "Candidatus Protochlamydia amoebophila UWE25", "rank": "Strain"}, "1046962": {"name": "Cloacimonetes bacterium SCGC AAA252-L13", "rank": "Species"}, "1352235": {"name": "Castor canadensis papillomavirus 1", "rank": "Strain"}, "1352230": {"name": "Thermus phage phi OH2", "rank": "Species"}, "334406": {"name": "Bacillus cereus NC7401", "rank": "Strain"}, "5234": {"name": "Tremellales", "rank": "Order"}, "181667": {"name": "Lambdapapillomavirus 1", "rank": "Species"}, "1280698": {"name": "Dorea longicatena AGR2136", "rank": "Strain"}, "181663": {"name": "Desulfococcus oleovorans", "rank": "Species"}, "1280697": {"name": "Butyrivibrio fibrisolvens AB2020", "rank": "Strain"}, "321955": {"name": "Brevibacterium linens BL2", "rank": "Strain"}, "321956": {"name": "Lactobacillus delbrueckii subsp. bulgaricus ATCC BAA-365", "rank": "Strain"}, "1280692": {"name": "Clostridium cadaveris AGR2141", "rank": "Strain"}, "1181234": {"name": "Lactococcus garvieae IPLA 31405", "rank": "Strain"}, "1280690": {"name": "Streptococcus equinus B315", "rank": "Strain"}, "1421966": {"name": "Mycobacterium tuberculosis TB_RSA50", "rank": "Strain"}, "1411681": {"name": "Rhizoctonia solani dsRNA virus 2", "rank": "Species"}, "1421964": {"name": "Mycobacterium tuberculosis TB_RSA48", "rank": "Strain"}, "1421965": {"name": "Mycobacterium tuberculosis TB_RSA49", "rank": "Strain"}, "1421962": {"name": "Mycobacterium tuberculosis TB_RSA46", "rank": "Strain"}, "1411685": {"name": "Gammaproteobacteria bacterium MOLA455", "rank": "Species"}, "1421960": {"name": "Mycobacterium tuberculosis TB_RSA44", "rank": "Strain"}, "1421961": {"name": "Mycobacterium tuberculosis TB_RSA45", "rank": "Strain"}, "1421968": {"name": "Mycobacterium tuberculosis TB_RSA52", "rank": "Strain"}, "1421969": {"name": "Mycobacterium tuberculosis TB_RSA53", "rank": "Strain"}, "540500": {"name": "Psychrobacter lutiphocae", "rank": "Species"}, "199587": {"name": "Hollyhock leaf crumple virus", "rank": "Species"}, "944644": {"name": "Marseilleviridae", "rank": "Family"}, "244363": {"name": "Haloarcula californiae", "rank": "Species"}, "288793": {"name": "Salinimonas", "rank": "Genus"}, "1409707": {"name": "Staphylococcus aureus WMCS6115", "rank": "Strain"}, "749414": {"name": "Streptomyces bingchenggensis BCW-1", "rank": "Strain"}, "749413": {"name": "Deep-sea thermophilic phage D6E", "rank": "Species"}, "1354171": {"name": "Mycobacterium africanum MAL010099", "rank": "Strain"}, "1354172": {"name": "Mycobacterium africanum MAL010100", "rank": "Strain"}, "1354173": {"name": "Mycobacterium africanum MAL010102", "rank": "Strain"}, "1354174": {"name": "Mycobacterium africanum MAL010111", "rank": "Strain"}, "1354175": {"name": "Mycobacterium africanum MAL010112", "rank": "Strain"}, "1354176": {"name": "Mycobacterium africanum MAL010118", "rank": "Strain"}, "1354177": {"name": "Mycobacterium africanum MAL010120", "rank": "Strain"}, "1354178": {"name": "Mycobacterium africanum MAL010123", "rank": "Strain"}, "1354179": {"name": "Mycobacterium africanum MAL010128", "rank": "Strain"}, "1053208": {"name": "Bacillus cereus HuB13-1", "rank": "Strain"}, "1053209": {"name": "Bacillus cereus HuB2-9", "rank": "Strain"}, "767817": {"name": "Desulfotomaculum gibsoniae DSM 7213", "rank": "Strain"}, "351517": {"name": "Unclassified Rubulavirus", "rank": "No rank"}, "1053203": {"name": "Bacillus cereus HuA2-4", "rank": "Strain"}, "1053200": {"name": "Bacillus cereus HD73", "rank": "Strain"}, "1053201": {"name": "Bacillus cereus HuA2-1", "rank": "Strain"}, "1053206": {"name": "Bacillus cereus HuA4-10", "rank": "Strain"}, "1053207": {"name": "Bacillus cereus HuB1-1", "rank": "Strain"}, "1053204": {"name": "Bacillus cereus HuA2-9", "rank": "Strain"}, "998674": {"name": "Leucothrix mucor DSM 2157", "rank": "Strain"}, "693748": {"name": "Brucella sp. NF 2653", "rank": "Species"}, "1561217": {"name": "Acinetobacter sp. A47", "rank": "Species"}, "1049941": {"name": "Leptospira kirschneri serovar Bim str. 1051", "rank": "Strain"}, "1427252": {"name": "Mycobacterium tuberculosis XTB13-172", "rank": "Strain"}, "1427253": {"name": "Mycobacterium tuberculosis XTB13-173", "rank": "Strain"}, "1427250": {"name": "Mycobacterium tuberculosis XTB13-168", "rank": "Strain"}, "1427251": {"name": "Mycobacterium tuberculosis XTB13-169", "rank": "Strain"}, "1427256": {"name": "Mycobacterium tuberculosis XTB13-177", "rank": "Strain"}, "1427257": {"name": "Mycobacterium tuberculosis XTB13-178", "rank": "Strain"}, "1427254": {"name": "Mycobacterium tuberculosis XTB13-175", "rank": "Strain"}, "1427255": {"name": "Mycobacterium tuberculosis XTB13-176", "rank": "Strain"}, "1427258": {"name": "Mycobacterium tuberculosis XTB13-179", "rank": "Strain"}, "1427259": {"name": "Mycobacterium tuberculosis XTB13-180", "rank": "Strain"}, "945704": {"name": "Streptococcus suis JS14", "rank": "Strain"}, "651733": {"name": "Salivirus NG-J1", "rank": "Strain"}, "1388368": {"name": "Staphylococcus aureus M0556", "rank": "Strain"}, "1388369": {"name": "Staphylococcus aureus M0557", "rank": "Strain"}, "1388364": {"name": "Staphylococcus aureus M0550", "rank": "Strain"}, "1388365": {"name": "Staphylococcus aureus M0552", "rank": "Strain"}, "1388366": {"name": "Staphylococcus aureus M0554", "rank": "Strain"}, "1388367": {"name": "Staphylococcus aureus M0555", "rank": "Strain"}, "1388360": {"name": "Staphylococcus aureus M0545", "rank": "Strain"}, "1388361": {"name": "Staphylococcus aureus M0546", "rank": "Strain"}, "1388362": {"name": "Staphylococcus aureus M0548", "rank": "Strain"}, "1388363": {"name": "Staphylococcus aureus M0549", "rank": "Strain"}, "1418302": {"name": "Staphylococcus aureus H19404", "rank": "Strain"}, "31998": {"name": "Methylobacterium radiotolerans", "rank": "Species"}, "1531962": {"name": "Peptococcaceae bacterium BICA1-8", "rank": "Species"}, "1418301": {"name": "Staphylococcus aureus H19398", "rank": "Strain"}, "237020": {"name": "Porcine torovirus", "rank": "Species"}, "1418307": {"name": "Staphylococcus aureus H43690", "rank": "Strain"}, "1531966": {"name": "Torrubiella hemipterigena", "rank": "Species"}, "1418305": {"name": "Staphylococcus aureus H22637", "rank": "Strain"}, "190893": {"name": "Vibrio coralliilyticus", "rank": "Species"}, "190892": {"name": "Idiomarina baltica", "rank": "Species"}, "31993": {"name": "Methylocystaceae", "rank": "Family"}, "1418309": {"name": "Staphylococcus aureus H43700", "rank": "Strain"}, "702113": {"name": "Novosphingobium sp. PP1Y", "rank": "Species"}, "31994": {"name": "Beijerinckia indica subsp. indica", "rank": "Subspecies"}, "190895": {"name": "Vibrio rotiferianus", "rank": "Species"}, "1295739": {"name": "Mycobacterium tuberculosis TKK_02_0023", "rank": "Strain"}, "717605": {"name": "Thermobacillus composti KWC4", "rank": "Strain"}, "717606": {"name": "Paenibacillus curdlanolyticus YK9", "rank": "Strain"}, "717609": {"name": "Caldicellulosiruptor obsidiansis", "rank": "Species"}, "717608": {"name": "Clostridium cf. saccharolyticum K10", "rank": "Strain"}, "1454041": {"name": "Simian pegivirus", "rank": "Species"}, "1511782": {"name": "Pasivirus", "rank": "Genus"}, "1511783": {"name": "Pasivirus A", "rank": "Species"}, "1511780": {"name": "Oscivirus", "rank": "Genus"}, "1511781": {"name": "Oscivirus A", "rank": "Species"}, "1511784": {"name": "Pasivirus A1", "rank": "Strain"}, "1005452": {"name": "Escherichia coli 5.2239", "rank": "Strain"}, "980518": {"name": "Enterobacter mori LMG 25706", "rank": "Strain"}, "69222": {"name": "Erwinia mallotivora", "rank": "Species"}, "69223": {"name": "Dickeya paradisiaca", "rank": "Species"}, "1028384": {"name": "Glomerellales", "rank": "Order"}, "1206739": {"name": "Nocardia testacea NBRC 100365", "rank": "Strain"}, "1206732": {"name": "Nocardia otitidiscaviarum NBRC 14405", "rank": "Strain"}, "1206733": {"name": "Nocardia niigatensis NBRC 100131", "rank": "Strain"}, "1206730": {"name": "Nocardia higoensis NBRC 100133", "rank": "Strain"}, "1206731": {"name": "Nocardia jiangxiensis NBRC 101359", "rank": "Strain"}, "1206737": {"name": "Nocardia pneumoniae NBRC 100136", "rank": "Strain"}, "1206734": {"name": "Nocardia paucivorans NBRC 100373", "rank": "Strain"}, "1206735": {"name": "Nocardia takedensis NBRC 100417", "rank": "Strain"}, "358033": {"name": "Epilithonimonas", "rank": "Genus"}, "1144932": {"name": "Candidatus Pelagibacter ubique HIMB058", "rank": "Strain"}, "1144930": {"name": "Salinispora arenicola CNS673", "rank": "Strain"}, "1032505": {"name": "Fusobacterium sp. OBRC1", "rank": "Species"}, "675833": {"name": "Helicobasidium mompa endornavirus 1", "rank": "Species"}, "1231": {"name": "Nitrosospira multiformis", "rank": "Species"}, "1234": {"name": "Nitrospira", "rank": "Genus"}, "1266053": {"name": "Algiphilus", "rank": "Genus"}, "1237": {"name": "Piscirickettsia", "rank": "Genus"}, "1238": {"name": "Piscirickettsia salmonis", "rank": "Species"}, "1239": {"name": "Firmicutes", "rank": "Phylum"}, "869313": {"name": "Streptococcus pneumoniae SPN7465", "rank": "Strain"}, "869312": {"name": "Streptococcus pneumoniae SPN033038", "rank": "Strain"}, "869311": {"name": "Streptococcus pneumoniae SPN032672", "rank": "Strain"}, "869310": {"name": "Streptococcus pneumoniae SPN1041", "rank": "Strain"}, "1435377": {"name": "Sulfolobus acidocaldarius SUSAZ", "rank": "Strain"}, "1435374": {"name": "Burkholderia pseudomallei MSHR7500", "rank": "Strain"}, "1435372": {"name": "Burkholderia pseudomallei MSHR3965", "rank": "Strain"}, "1435373": {"name": "Burkholderia pseudomallei MSHR7504", "rank": "Strain"}, "1435370": {"name": "Burkholderia pseudomallei MSHR4000", "rank": "Strain"}, "1435371": {"name": "Burkholderia pseudomallei MSHR7527", "rank": "Strain"}, "251542": {"name": "Candidatus Blochmannia chromaiodes", "rank": "Species"}, "686578": {"name": "Pseudomonas sp. S9", "rank": "Species"}, "456455": {"name": "Bizionia argentinensis", "rank": "Species"}, "1310615": {"name": "Acinetobacter baumannii 1396970", "rank": "Strain"}, "1005455": {"name": "Escherichia coli 6.0172", "rank": "Strain"}, "171627": {"name": "Fusarium fujikuroi species complex", "rank": "No rank"}, "362242": {"name": "Mycobacterium ulcerans Agy99", "rank": "Strain"}, "389951": {"name": "Serpulaceae", "rank": "Family"}, "1136420": {"name": "Salinispora pacifica CNT131", "rank": "Strain"}, "1448765": {"name": "Mycobacterium tuberculosis M2248", "rank": "Strain"}, "1448764": {"name": "Mycobacterium tuberculosis M2140", "rank": "Strain"}, "1448767": {"name": "Mycobacterium tuberculosis M2211", "rank": "Strain"}, "1448766": {"name": "Mycobacterium tuberculosis M2218", "rank": "Strain"}, "1448761": {"name": "Mycobacterium tuberculosis M2137", "rank": "Strain"}, "1448760": {"name": "Mycobacterium tuberculosis M2136", "rank": "Strain"}, "1448763": {"name": "Mycobacterium tuberculosis M2138", "rank": "Strain"}, "1448762": {"name": "Mycobacterium tuberculosis M2139", "rank": "Strain"}, "68178": {"name": "Streptomyces avellaneus", "rank": "Species"}, "1448769": {"name": "Mycobacterium tuberculosis M2204", "rank": "Strain"}, "89184": {"name": "Ruegeria pomeroyi", "rank": "Species"}, "89187": {"name": "Roseovarius nubinhibens ISM", "rank": "Strain"}, "643648": {"name": "Syntrophothermus lipocalidus DSM 12680", "rank": "Strain"}, "445975": {"name": "Collinsella stercoris DSM 13279", "rank": "Strain"}, "1379281": {"name": "Desulfonauticus sp. A7A", "rank": "Species"}, "345249": {"name": "Unclassified Circovirus", "rank": "No rank"}, "1418437": {"name": "Staphylococcus aureus W76995", "rank": "Strain"}, "12295": {"name": "Tobacco rattle virus", "rank": "Species"}, "445970": {"name": "Alistipes putredinis DSM 17216", "rank": "Strain"}, "1449986": {"name": "Pseudomonas putida W15Oct28", "rank": "Strain"}, "1449987": {"name": "Pseudomonas putida T2-2", "rank": "Strain"}, "1449984": {"name": "Klebsiella pneumoniae T2-1-1", "rank": "Strain"}, "1449985": {"name": "Klebsiella pneumoniae T2-1-2", "rank": "Strain"}, "1449982": {"name": "Stenotrophomonas maltophilia MTCC 434", "rank": "Strain"}, "1449983": {"name": "Sporolactobacillus terrae HKM-1", "rank": "Strain"}, "1449980": {"name": "Pseudomonas aeruginosa MW3a", "rank": "Strain"}, "1508712": {"name": "Tent-making bat hepatitis B virus", "rank": "Species"}, "1508711": {"name": "Horseshoe bat hepatitis B virus", "rank": "Species"}, "1508710": {"name": "Roundleaf bat hepatitis B virus", "rank": "Species"}, "1367484": {"name": "Streptococcus pneumoniae 1417", "rank": "Strain"}, "1367485": {"name": "Streptococcus pneumoniae Spain9V", "rank": "Strain"}, "1367482": {"name": "Streptococcus pneumoniae 439-1", "rank": "Strain"}, "1367483": {"name": "Streptococcus pneumoniae 88-1", "rank": "Strain"}, "1367480": {"name": "Streptococcus pneumoniae Sp647", "rank": "Strain"}, "1367481": {"name": "Streptococcus pneumoniae Spain6B", "rank": "Strain"}, "162474": {"name": "Malasseziales", "rank": "Order"}, "1329840": {"name": "Enterobacter sp. BIDMC 28", "rank": "Species"}, "1329841": {"name": "Enterobacter sp. BIDMC 29", "rank": "Species"}, "1329842": {"name": "Enterobacter sp. BIDMC 30", "rank": "Species"}, "1329843": {"name": "Klebsiella pneumoniae BIDMC 33B", "rank": "Strain"}, "1329844": {"name": "Enterobacter cloacae BWH 29", "rank": "Strain"}, "1329845": {"name": "Enterobacter cloacae BWH 31", "rank": "Strain"}, "1329846": {"name": "Enterobacter cloacae BIDMC 8", "rank": "Strain"}, "585146": {"name": "Staphylococcus aureus subsp. aureus 68-397", "rank": "Strain"}, "5042": {"name": "Eurotiales", "rank": "Order"}, "585145": {"name": "Staphylococcus aureus subsp. aureus 65-1322", "rank": "Strain"}, "1513234": {"name": "Cafeteriavirus", "rank": "Genus"}, "1537994": {"name": "Alteromonas sp. LOR", "rank": "Species"}, "1124948": {"name": "Salmonella enterica subsp. enterica serovar Heidelberg str. CVM20752", "rank": "Strain"}, "1124944": {"name": "Salmonella enterica subsp. enterica serovar Heidelberg str. N20134", "rank": "Strain"}, "1124945": {"name": "Salmonella enterica subsp. enterica serovar Heidelberg str. CVM24391", "rank": "Strain"}, "1124946": {"name": "Salmonella enterica subsp. enterica serovar Heidelberg str. CVM24359", "rank": "Strain"}, "1124947": {"name": "Salmonella enterica subsp. enterica serovar Heidelberg str. CVM24388", "rank": "Strain"}, "1124940": {"name": "Salmonella enterica subsp. enterica serovar Heidelberg str. N18393", "rank": "Strain"}, "1124941": {"name": "Salmonella enterica subsp. enterica serovar Heidelberg str. 41563", "rank": "Strain"}, "1124942": {"name": "Salmonella enterica subsp. enterica serovar Heidelberg str. 41566", "rank": "Strain"}, "1124943": {"name": "Salmonella enterica subsp. enterica serovar Heidelberg str. 24393", "rank": "Strain"}, "500464": {"name": "Chlamydia psittaci Mat116", "rank": "Strain"}, "1158518": {"name": "Staphylococcus aureus M0250", "rank": "Strain"}, "1158514": {"name": "Staphylococcus aureus M0200", "rank": "Strain"}, "1158515": {"name": "Staphylococcus aureus M0212", "rank": "Strain"}, "1158516": {"name": "Staphylococcus aureus M0216", "rank": "Strain"}, "1158517": {"name": "Staphylococcus aureus M0235", "rank": "Strain"}, "1158510": {"name": "Staphylococcus aureus M0108", "rank": "Strain"}, "1158511": {"name": "Staphylococcus aureus M0144", "rank": "Strain"}, "1158512": {"name": "Staphylococcus aureus M0154", "rank": "Strain"}, "1158513": {"name": "Staphylococcus aureus M0177", "rank": "Strain"}, "45851": {"name": "Butyrivibrio crossotus", "rank": "Species"}, "1439321": {"name": "Enterobacter aerogenes MGH 62", "rank": "Strain"}, "1439320": {"name": "Enterobacter aerogenes MGH 61", "rank": "Strain"}, "1439323": {"name": "Enterobacter aerogenes MGH 78", "rank": "Strain"}, "1439322": {"name": "Enterobacter aerogenes MGH 77", "rank": "Strain"}, "1439325": {"name": "Enterobacter cloacae BIDMC 67", "rank": "Strain"}, "1439324": {"name": "Enterobacter cloacae BIDMC 66", "rank": "Strain"}, "1439326": {"name": "Enterobacter cloacae CHS 79", "rank": "Strain"}, "1439329": {"name": "Enterobacter cloacae MGH 53", "rank": "Strain"}, "1439328": {"name": "Enterobacter cloacae BWH 43", "rank": "Strain"}, "130048": {"name": "Halobiforma nitratireducens", "rank": "Species"}, "130049": {"name": "Paenibacillus dendritiformis", "rank": "Species"}, "311458": {"name": "Candidatus Caldiarchaeum subterraneum", "rank": "Species"}, "1338518": {"name": "Bacillus amyloliquefaciens subsp. plantarum UCMB5033", "rank": "Strain"}, "1338519": {"name": "Enterococcus faecalis 918", "rank": "Strain"}, "740709": {"name": "Idiomarina xiamenensis 10-D-4", "rank": "Strain"}, "40318": {"name": "Streptomyces nodosus", "rank": "Species"}, "930881": {"name": "Sweet potato virus C", "rank": "Species"}, "394036": {"name": "Narcissus degeneration virus", "rank": "Species"}, "64974": {"name": "Marinospirillum minutulum", "rank": "Species"}, "1314884": {"name": "Lactobacillus acidophilus La-14", "rank": "Strain"}, "1314885": {"name": "Salmonella enterica subsp. enterica serovar Cubana str. CVM42234", "rank": "Strain"}, "85013": {"name": "Frankineae", "rank": "Suborder"}, "85012": {"name": "Streptosporangineae", "rank": "Suborder"}, "85011": {"name": "Streptomycineae", "rank": "Suborder"}, "1315170": {"name": "Acinetobacter baumannii TG22336", "rank": "Strain"}, "85017": {"name": "Promicromonosporaceae", "rank": "Family"}, "85016": {"name": "Cellulomonadaceae", "rank": "Family"}, "1315175": {"name": "Acinetobacter baumannii TG27315", "rank": "Strain"}, "85014": {"name": "Glycomycineae", "rank": "Suborder"}, "317858": {"name": "Cyprinid herpesvirus 1", "rank": "Species"}, "85019": {"name": "Brevibacteriaceae", "rank": "Family"}, "85018": {"name": "Dermatophilaceae", "rank": "Family"}, "1487953": {"name": "Leptolyngbya sp. JSC-1", "rank": "Species"}, "77095": {"name": "Prevotella bryantii", "rank": "Species"}, "1487956": {"name": "Corynebacterium sp. ATCC 6931", "rank": "Species"}, "1487955": {"name": "Burkholderia sp. BGK", "rank": "Species"}, "1487954": {"name": "Burkholderia sp. BGJ", "rank": "Species"}, "992107": {"name": "Helicobacter pylori Hp P-13b", "rank": "Strain"}, "1120797": {"name": "Mycobacterium sp. 141", "rank": "Species"}, "316106": {"name": "Bitter gourd leaf curl betasatellite", "rank": "Species"}, "1120792": {"name": "Methylopila sp. 73B", "rank": "Species"}, "910473": {"name": "Burkholderia phage KS5", "rank": "Species"}, "244573": {"name": "Thiocapsa marina", "rank": "Species"}, "716545": {"name": "Saccharomyceta", "rank": "No rank"}, "716544": {"name": "Waddlia chondrophila WSU 86-1044", "rank": "Strain"}, "1151306": {"name": "Peptoclostridium difficile 342", "rank": "Strain"}, "1151304": {"name": "Peptoclostridium difficile CD211", "rank": "Strain"}, "1343740": {"name": "Streptomyces rapamycinicus NRRL 5491", "rank": "Strain"}, "1151303": {"name": "Peptoclostridium difficile CD206", "rank": "Strain"}, "1151300": {"name": "Peptoclostridium difficile CD200", "rank": "Strain"}, "1151301": {"name": "Peptoclostridium difficile CD201", "rank": "Strain"}, "687342": {"name": "Torque teno virus 3", "rank": "Species"}, "687343": {"name": "Torque teno virus 4", "rank": "Species"}, "687340": {"name": "Torque teno virus 1", "rank": "Species"}, "687341": {"name": "Torque teno virus 2", "rank": "Species"}, "687346": {"name": "Torque teno virus 7", "rank": "Species"}, "687347": {"name": "Torque teno virus 8", "rank": "Species"}, "1151308": {"name": "Peptoclostridium difficile 655", "rank": "Strain"}, "687345": {"name": "Torque teno virus 6", "rank": "Species"}, "1154969": {"name": "Streptococcus agalactiae GB00999", "rank": "Strain"}, "1154968": {"name": "Streptococcus agalactiae GB00992", "rank": "Strain"}, "95818": {"name": "Candidatus Saccharibacteria", "rank": "Phylum"}, "935543": {"name": "Burkholderia sp. WSM4176", "rank": "Species"}, "31508": {"name": "Agrotis segetum nucleopolyhedrovirus", "rank": "Species"}, "935546": {"name": "Mesorhizobium loti NZP2037", "rank": "Strain"}, "935547": {"name": "Mesorhizobium loti R7A", "rank": "Strain"}, "935548": {"name": "Mesorhizobium loti R88b", "rank": "Strain"}, "935549": {"name": "Rhizobium leguminosarum bv. trifolii SRDI565", "rank": "Strain"}, "1154963": {"name": "Streptococcus agalactiae GB00963", "rank": "Strain"}, "1154962": {"name": "Streptococcus agalactiae GB00959", "rank": "Strain"}, "1154965": {"name": "Streptococcus agalactiae GB00975", "rank": "Strain"}, "1154964": {"name": "Streptococcus agalactiae GB00965", "rank": "Strain"}, "1154967": {"name": "Streptococcus agalactiae GB00986", "rank": "Strain"}, "1154966": {"name": "Streptococcus agalactiae GB00984", "rank": "Strain"}, "994838": {"name": "Candidatus Parvarchaeum acidophilus ARMAN-5_'5-way FS'", "rank": "Strain"}, "92629": {"name": "Metarhizium album", "rank": "Species"}, "31504": {"name": "Tobacco ringspot virus satellite RNA", "rank": "Species"}, "438782": {"name": "Abaca bunchy top virus", "rank": "Species"}, "349681": {"name": "Phlebiopsis gigantea mycovirus dsRNA 1", "rank": "Species"}, "246200": {"name": "Ruegeria pomeroyi DSS-3", "rank": "Strain"}, "1160778": {"name": "Salmonella enterica subsp. salamae serovar 58:l,z13,z28:z6", "rank": "Strain"}, "58352": {"name": "Kitasatospora mediocidica", "rank": "Species"}, "55583": {"name": "Dehalobacter restrictus", "rank": "Species"}, "138595": {"name": "Olsenella profusa", "rank": "Species"}, "79929": {"name": "Methanothermobacter marburgensis str. Marburg", "rank": "Strain"}, "1388231": {"name": "Staphylococcus aureus M0348", "rank": "Strain"}, "1121479": {"name": "Donghicola xiamenensis DSM 18339", "rank": "Strain"}, "503170": {"name": "Salisaeta longa", "rank": "Species"}, "1121472": {"name": "Desulfurispora thermophila DSM 16022", "rank": "Strain"}, "1220028": {"name": "Xanthomonas citri pv. malvacearum X20", "rank": "Strain"}, "889338": {"name": "Salmonella phage PVP-SE1", "rank": "Species"}, "1521188": {"name": "Lymantria dispar iflavirus 1", "rank": "Species"}, "1239284": {"name": "Firmicutes bacterium JGI 0000112-J22", "rank": "Species"}, "1345637": {"name": "Human cyclovirus VS5700009", "rank": "Species"}, "46503": {"name": "Parabacteroides merdae", "rank": "Species"}, "1239288": {"name": "Firmicutes bacterium JGI 0000112-L22", "rank": "Species"}, "1239289": {"name": "Chloroflexi bacterium JGI 0000112-G22", "rank": "Species"}, "376470": {"name": "Olivibacter sitiensis", "rank": "Species"}, "479060": {"name": "Cocksfoot mild mosaic virus", "rank": "Species"}, "887326": {"name": "Mobiluncus curtisii ATCC 51333", "rank": "Strain"}, "887327": {"name": "Kingella kingae ATCC 23330", "rank": "Strain"}, "887324": {"name": "Actinobacillus ureae ATCC 25976", "rank": "Strain"}, "887325": {"name": "Lachnoanaerobaculum saburreum DSM 3986", "rank": "Strain"}, "1429889": {"name": "Brevibacillus borstelensis cifa_chp40", "rank": "Strain"}, "1429888": {"name": "Leuconostoc mesenteroides P45", "rank": "Strain"}, "887320": {"name": "Campylobacter coli 2692", "rank": "Strain"}, "887321": {"name": "Campylobacter coli 2698", "rank": "Strain"}, "319939": {"name": "Pseudomonas otitidis", "rank": "Species"}, "1429887": {"name": "Mycobacterium tuberculosis MTB-476", "rank": "Strain"}, "1429886": {"name": "Mycobacterium tuberculosis MTB-489", "rank": "Strain"}, "1429881": {"name": "Staphylococcus aureus SA11-LAU", "rank": "Strain"}, "1429882": {"name": "Staphylococcus aureus SA12-LAU", "rank": "Strain"}, "1249661": {"name": "Burkholderia thailandensis MSMB121", "rank": "Strain"}, "1249663": {"name": "Burkholderia thailandensis H0587", "rank": "Strain"}, "1249662": {"name": "Burkholderia thailandensis E444", "rank": "Strain"}, "1249665": {"name": "Burkholderia thailandensis E254", "rank": "Strain"}, "1249667": {"name": "Burkholderia thailandensis USAMRU Malaysia #20", "rank": "Strain"}, "939306": {"name": "Alpha proteobacterium SCGC AAA240-E13", "rank": "Species"}, "1423814": {"name": "Lactobacillus vaginalis DSM 5837 = ATCC 49540", "rank": "Strain"}, "1423815": {"name": "Lactobacillus versmoldensis DSM 14857 = KCTC 3814", "rank": "Strain"}, "1423816": {"name": "Lactobacillus zeae DSM 20178 = KCTC 3804", "rank": "Strain"}, "1503864": {"name": "Yam virus X", "rank": "Species"}, "1410780": {"name": "Staphylococcus aureus F52754", "rank": "Strain"}, "1328366": {"name": "Klebsiella pneumoniae MGH 21", "rank": "Strain"}, "1328367": {"name": "Klebsiella pneumoniae MGH 29", "rank": "Strain"}, "1328364": {"name": "Klebsiella pneumoniae MGH 19", "rank": "Strain"}, "1328365": {"name": "Klebsiella pneumoniae MGH 20", "rank": "Strain"}, "1328362": {"name": "Klebsiella pneumoniae MGH 17", "rank": "Strain"}, "1328363": {"name": "Klebsiella pneumoniae MGH 18", "rank": "Strain"}, "1328360": {"name": "Brucella abortus B10-0973", "rank": "Strain"}, "1328361": {"name": "Brucella abortus BC95", "rank": "Strain"}, "186458": {"name": "Bornavirus", "rank": "Genus"}, "1328368": {"name": "Klebsiella pneumoniae MGH 30", "rank": "Strain"}, "1328369": {"name": "Klebsiella pneumoniae MGH 31", "rank": "Strain"}, "745718": {"name": "Olleya sp. VCSM12", "rank": "Species"}, "1344987": {"name": "Staphylococcus epidermidis WI09", "rank": "Strain"}, "1344988": {"name": "Staphylococcus epidermidis WI05", "rank": "Strain"}, "1344989": {"name": "Staphylococcus epidermidis CIM28", "rank": "Strain"}, "745717": {"name": "Olleya sp. VCSA23", "rank": "Species"}, "127509": {"name": "Vibrio phage Vf33", "rank": "Species"}, "127508": {"name": "Vibrio phage VfO4K68", "rank": "Species"}, "208491": {"name": "Goose hemorrhagic polyomavirus", "rank": "Species"}, "412687": {"name": "Intrasporangium oryzae", "rank": "Species"}, "1284819": {"name": "Klebsiella pneumoniae UHKPC45", "rank": "Strain"}, "1284818": {"name": "Klebsiella pneumoniae UHKPC179", "rank": "Strain"}, "1284811": {"name": "Klebsiella pneumoniae UHKPC01", "rank": "Strain"}, "1284810": {"name": "Klebsiella pneumoniae UHKPC09", "rank": "Strain"}, "1284813": {"name": "Klebsiella pneumoniae UHKPC27", "rank": "Strain"}, "1284812": {"name": "Klebsiella pneumoniae UHKPC81", "rank": "Strain"}, "1284815": {"name": "Klebsiella pneumoniae UHKPC24", "rank": "Strain"}, "1284814": {"name": "Klebsiella pneumoniae UHKPC 52", "rank": "Strain"}, "1284817": {"name": "Klebsiella pneumoniae UHKPC57", "rank": "Strain"}, "1284816": {"name": "Klebsiella pneumoniae UHKPC26", "rank": "Strain"}, "1234368": {"name": "Chlamydia pecorum W73", "rank": "Strain"}, "1234369": {"name": "Chlamydia pecorum P787", "rank": "Strain"}, "1345588": {"name": "Helicobacter pylori SA194A", "rank": "Strain"}, "1345587": {"name": "Helicobacter pylori SA175C", "rank": "Strain"}, "1345586": {"name": "Helicobacter pylori SA175A", "rank": "Strain"}, "1345585": {"name": "Helicobacter pylori SA174A", "rank": "Strain"}, "1345584": {"name": "Helicobacter pylori SA173C", "rank": "Strain"}, "1345583": {"name": "Helicobacter pylori SA173A", "rank": "Strain"}, "1345582": {"name": "Helicobacter pylori SA172C", "rank": "Strain"}, "1345581": {"name": "Helicobacter pylori SA172A", "rank": "Strain"}, "1345580": {"name": "Helicobacter pylori SA171C", "rank": "Strain"}, "928293": {"name": "Yersinia phage Yep-phi", "rank": "Species"}, "284813": {"name": "Encephalitozoon cuniculi GB-M1", "rank": "Strain"}, "284811": {"name": "Ashbya gossypii ATCC 10895", "rank": "Strain"}, "1355530": {"name": "Helicobacter pylori UM084", "rank": "Strain"}, "1471516": {"name": "Prochlorococcus sp. scB245a_519O11", "rank": "Species"}, "1471517": {"name": "Prochlorococcus sp. scB245a_519O21", "rank": "Species"}, "1471514": {"name": "Prochlorococcus sp. scB245a_519G16", "rank": "Species"}, "879089": {"name": "Listeria monocytogenes SLCC2540", "rank": "Strain"}, "1471512": {"name": "Prochlorococcus sp. scB245a_519D13", "rank": "Species"}, "1471513": {"name": "Prochlorococcus sp. scB245a_519E23", "rank": "Species"}, "1471510": {"name": "Prochlorococcus sp. scB245a_519B7", "rank": "Species"}, "1471511": {"name": "Prochlorococcus sp. scB245a_519C7", "rank": "Species"}, "1244140": {"name": "Enterococcus faecalis LA3B-2", "rank": "Strain"}, "1471518": {"name": "Prochlorococcus sp. scB245a_520B18", "rank": "Species"}, "1471519": {"name": "Prochlorococcus sp. scB245a_520D2", "rank": "Species"}, "1444138": {"name": "Escherichia coli 3-073-06_S3_C1", "rank": "Strain"}, "1444139": {"name": "Escherichia coli 3-105-05_S3_C1", "rank": "Strain"}, "1409590": {"name": "Staphylococcus aureus OCMM6066", "rank": "Strain"}, "1444130": {"name": "Escherichia coli 7-233-03_S3_C1", "rank": "Strain"}, "1444131": {"name": "Escherichia coli 8-415-05_S3_C1", "rank": "Strain"}, "1444132": {"name": "Escherichia coli 1-110-08_S3_C1", "rank": "Strain"}, "1444133": {"name": "Escherichia coli 1-176-05_S3_C1", "rank": "Strain"}, "1444134": {"name": "Escherichia coli 1-182-04_S3_C1", "rank": "Strain"}, "1444135": {"name": "Escherichia coli 1-250-04_S3_C1", "rank": "Strain"}, "1444136": {"name": "Escherichia coli 1-392-07_S3_C1", "rank": "Strain"}, "1444137": {"name": "Escherichia coli 3-020-07_S3_C1", "rank": "Strain"}, "936549": {"name": "Actinomyces sp. ICM54", "rank": "Species"}, "862968": {"name": "Streptococcus constellatus subsp. pharyngis C818", "rank": "Strain"}, "1409594": {"name": "Staphylococcus aureus UCIM6069", "rank": "Strain"}, "1248915": {"name": "Escherichia coli O145:H28 str. RM13516", "rank": "Strain"}, "1248916": {"name": "Sandarakinorhabdus sp. AAP62", "rank": "Species"}, "1248917": {"name": "Porphyrobacter sp. AAP82", "rank": "Species"}, "1409597": {"name": "Staphylococcus aureus SJUD6118", "rank": "Strain"}, "1178528": {"name": "Enterococcus faecium LCT-EF128", "rank": "Strain"}, "986730": {"name": "Encephalitozoon cuniculi EC1", "rank": "Strain"}, "1409596": {"name": "Staphylococcus aureus SJOS6144", "rank": "Strain"}, "365533": {"name": "Belnapia moabensis", "rank": "Species"}, "308892": {"name": "Bacillus boroniphilus", "rank": "Species"}, "903923": {"name": "Acinetobacter baumannii Naval-21", "rank": "Strain"}, "903922": {"name": "Acinetobacter baumannii Naval-2", "rank": "Strain"}, "903921": {"name": "Acinetobacter baumannii Naval-82", "rank": "Strain"}, "903920": {"name": "Acinetobacter baumannii Naval-113", "rank": "Strain"}, "903927": {"name": "Acinetobacter baumannii Naval-57", "rank": "Strain"}, "903926": {"name": "Acinetobacter baumannii OIFC035", "rank": "Strain"}, "903925": {"name": "Acinetobacter baumannii WC-A-694", "rank": "Strain"}, "903924": {"name": "Acinetobacter baumannii Canada BC1", "rank": "Strain"}, "903929": {"name": "Acinetobacter baumannii OIFC087", "rank": "Strain"}, "1421998": {"name": "Mycobacterium tuberculosis TB_RSA82", "rank": "Strain"}, "50340": {"name": "Pseudomonas fuscovaginae", "rank": "Species"}, "497980": {"name": "Streptococcus pneumoniae 459-5", "rank": "Strain"}, "1421996": {"name": "Mycobacterium tuberculosis TB_RSA80", "rank": "Strain"}, "934802": {"name": "Phipapillomavirus", "rank": "Genus"}, "1203629": {"name": "Propionibacterium sp. KPL2000", "rank": "Species"}, "934803": {"name": "Dyozetapapillomavirus", "rank": "Genus"}, "1203622": {"name": "Corynebacterium sp. KPL1989", "rank": "Species"}, "1203627": {"name": "Corynebacterium sp. KPL1998", "rank": "Species"}, "984234": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. 648901 16-16", "rank": "Strain"}, "1203625": {"name": "Corynebacterium sp. KPL1996", "rank": "Species"}, "1203624": {"name": "Corynebacterium sp. KPL1995", "rank": "Species"}, "756278": {"name": "Synechococcus phage S-RIM8", "rank": "Species"}, "756277": {"name": "Synechococcus phage S-CBP2", "rank": "Species"}, "756276": {"name": "Synechococcus phage S-CBP3", "rank": "Species"}, "756275": {"name": "Synechococcus phage S-CBS4", "rank": "Species"}, "1410788": {"name": "Staphylococcus aureus W42932", "rank": "Strain"}, "381707": {"name": "Bovine viral diarrhea virus 3", "rank": "Species"}, "756272": {"name": "Planctomyces brasiliensis DSM 5305", "rank": "Strain"}, "984230": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. 648901 6-18", "rank": "Strain"}, "449216": {"name": "Rickettsia prowazekii str. Rp22", "rank": "Strain"}, "700512": {"name": "Vibrio phage SIO-2", "rank": "Species"}, "1297579": {"name": "Fusobacterium nucleatum CC53", "rank": "Strain"}, "1410789": {"name": "Staphylococcus aureus H18808", "rank": "Strain"}, "1136433": {"name": "Streptomyces sp. CNT371", "rank": "Species"}, "1136432": {"name": "Streptomyces sp. CNH189", "rank": "Species"}, "1136431": {"name": "Salinispora tropica CNB536", "rank": "Strain"}, "1136430": {"name": "Salinispora arenicola CNH964", "rank": "Strain"}, "387662": {"name": "Candidatus Carsonella ruddii PV", "rank": "Strain"}, "1203190": {"name": "Corynebacterium timonense 5401744", "rank": "Strain"}, "387661": {"name": "Parabacteroides johnsonii", "rank": "Species"}, "1203195": {"name": "Enterobacter cloacae subsp. cloacae 08XA1", "rank": "Strain"}, "1308982": {"name": "Escherichia coli HM46", "rank": "Strain"}, "1308983": {"name": "Escherichia coli HM65", "rank": "Strain"}, "561879": {"name": "Bacillus safensis", "rank": "Species"}, "1485002": {"name": "Acinetobacter sp. ETR1", "rank": "Species"}, "598467": {"name": "Brenneria sp. EniD312", "rank": "Species"}, "698967": {"name": "Corynebacterium diphtheriae HC01", "rank": "Strain"}, "12275": {"name": "Tomato black ring virus", "rank": "Species"}, "12274": {"name": "Grapevine fanleaf virus", "rank": "Species"}, "12273": {"name": "Grapevine chrome mosaic virus", "rank": "Species"}, "489722": {"name": "Mesorhizobium metallidurans", "rank": "Species"}, "12270": {"name": "Nepovirus", "rank": "Genus"}, "655811": {"name": "Anaerococcus vaginalis ATCC 51170", "rank": "Strain"}, "1422023": {"name": "Mycobacterium tuberculosis TB_RSA107", "rank": "Strain"}, "655813": {"name": "Streptococcus oralis ATCC 35037", "rank": "Strain"}, "655812": {"name": "Aerococcus viridans ATCC 11563", "rank": "Strain"}, "1422026": {"name": "Mycobacterium tuberculosis TB_RSA110", "rank": "Strain"}, "1422027": {"name": "Mycobacterium tuberculosis TB_RSA111", "rank": "Strain"}, "655817": {"name": "Escherichia coli ABU 83972", "rank": "Strain"}, "655816": {"name": "Bacillus subtilis subsp. spizizenii str. W23", "rank": "Strain"}, "655819": {"name": "Beauveria bassiana ARSEF 2860", "rank": "Strain"}, "1422029": {"name": "Mycobacterium tuberculosis TB_RSA113", "rank": "Strain"}, "66229": {"name": "Komagataeibacter intermedius", "rank": "Species"}, "66228": {"name": "Actinomyces europaeus", "rank": "Species"}, "1268318": {"name": "Ralstonia sp. JGI 0001001-C06", "rank": "Species"}, "573370": {"name": "Desulfovibrio magneticus RS-1", "rank": "Strain"}, "51034": {"name": "Sida golden mosaic virus", "rank": "Species"}, "698961": {"name": "Gardnerella vaginalis 6119V5", "rank": "Strain"}, "648017": {"name": "Staphylococcus phage phiPVL-CN125", "rank": "Species"}, "40834": {"name": "Borrelia duttonii", "rank": "Species"}, "40835": {"name": "Borrelia hispanica", "rank": "Species"}, "173087": {"name": "Human papillomavirus types", "rank": "No rank"}, "207559": {"name": "Desulfovibrio alaskensis G20", "rank": "Strain"}, "909827": {"name": "Pepper vein yellows virus", "rank": "Species"}, "209261": {"name": "Salmonella enterica subsp. enterica serovar Typhi str. Ty2", "rank": "Strain"}, "645169": {"name": "Brucella melitensis bv. 2", "rank": "Strain"}, "1438870": {"name": "Mycobacterium tuberculosis 2543MS", "rank": "Strain"}, "107633": {"name": "Methylocystis sp. LW5", "rank": "Species"}, "336063": {"name": "Unclassified Hepadnaviridae", "rank": "No rank"}, "582491": {"name": "Rubidibacter", "rank": "Genus"}, "644042": {"name": "Lactobacillus plantarum JDM1", "rank": "Strain"}, "913338": {"name": "Actinobacterium SCGC AAA027-L06", "rank": "Species"}, "1438874": {"name": "Mycobacterium tuberculosis 3499MM", "rank": "Strain"}, "913333": {"name": "Thaumarchaeota archaeon SCGC AAA007-O23", "rank": "Species"}, "269774": {"name": "Atopococcus tabaci", "rank": "Species"}, "269773": {"name": "Atopococcus", "rank": "Genus"}, "913336": {"name": "Marine Group III euryarchaeote SCGC AAA288-E19", "rank": "Species"}, "913335": {"name": "Marine Group III euryarchaeote SCGC AAA007-O11", "rank": "Species"}, "107635": {"name": "Methylosinus sp. LW3", "rank": "Species"}, "1036677": {"name": "Methanosarcina soligelidi", "rank": "Species"}, "1036674": {"name": "Idiomarina sp. A28L", "rank": "Species"}, "1268314": {"name": "Ralstonia sp. JGI 0001001-A05", "rank": "Species"}, "1036673": {"name": "Paenibacillus mucilaginosus KNP414", "rank": "Strain"}, "2085": {"name": "Mycoplasmatales", "rank": "Order"}, "1300143": {"name": "Chryseobacterium oranimense G311", "rank": "Strain"}, "1300145": {"name": "Vibrio harveyi VHJR7", "rank": "Strain"}, "1365008": {"name": "Pseudomonas aeruginosa B3-1811", "rank": "Strain"}, "104267": {"name": "Tenacibaculum", "rank": "Genus"}, "857288": {"name": "Arabis mosaic virus small satellite RNA barley/CHE/1991", "rank": "Species"}, "37928": {"name": "Arthrobacter crystallopoietes", "rank": "Species"}, "1303771": {"name": "Enterococcus faecium E1165", "rank": "Strain"}, "1268316": {"name": "Burkholderia sp. JGI 0001021-E08", "rank": "Species"}, "37926": {"name": "Thermocrispum municipale", "rank": "Species"}, "37924": {"name": "Thermocrispum", "rank": "Genus"}, "37925": {"name": "Thermocrispum agreste", "rank": "Species"}, "1055815": {"name": "Psychrobacter sp. TB67", "rank": "Species"}, "33018": {"name": "Sporolactobacillus laevolacticus", "rank": "Species"}, "204269": {"name": "Great Island virus", "rank": "Species"}, "157270": {"name": "Gooseberry vein banding associated virus", "rank": "Species"}, "33012": {"name": "Propionimicrobium lymphophilum", "rank": "Species"}, "83681": {"name": "Nonomuraea", "rank": "Genus"}, "33010": {"name": "Propionibacterium avidum", "rank": "Species"}, "83683": {"name": "Lactobacillus amylolyticus", "rank": "Species"}, "83684": {"name": "Lactobacillus delbrueckii subsp. delbrueckii", "rank": "Subspecies"}, "53707": {"name": "Pseudomonas syringae pv. lachrymans", "rank": "Strain"}, "290030": {"name": "Malvastrum yellow vein Yunnan virus", "rank": "Species"}, "1531961": {"name": "Peptococcaceae bacterium BICA1-7", "rank": "Species"}, "999": {"name": "Flexibacter litoralis", "rank": "Species"}, "211502": {"name": "Conchiformibius kuhniae", "rank": "Species"}, "390988": {"name": "Actinocatenispora", "rank": "Genus"}, "691159": {"name": "Peptoclostridium difficile 6466", "rank": "Strain"}, "877455": {"name": "Methanobacterium lacus", "rank": "Species"}, "1513224": {"name": "Decapod penstyldensovirus 1", "rank": "Species"}, "1513223": {"name": "Penstyldensovirus", "rank": "Genus"}, "373371": {"name": "Unclassified Phic3unalikevirus", "rank": "No rank"}, "1158170": {"name": "Thioalkalivibrio sp. ALE12", "rank": "Species"}, "1040638": {"name": "Escherichia coli O104:H4 str. LB226692", "rank": "Strain"}, "377463": {"name": "Malvastrum yellow mosaic virus satellite DNA beta", "rank": "Species"}, "377462": {"name": "Malvastrum yellow mosaic virus", "rank": "Species"}, "1380388": {"name": "Nocardioides sp. URHA0032", "rank": "Species"}, "1380389": {"name": "Sphingomonas sp. URHD0057", "rank": "Species"}, "1380386": {"name": "Mycobacterium sp. URHB0044", "rank": "Species"}, "1380387": {"name": "Alcanivorax sp. 43B_GOM-46m", "rank": "Species"}, "1380384": {"name": "Tenacibaculum sp. 47A_GOM-205m", "rank": "Species"}, "1380385": {"name": "Variovorax sp. URHB0020", "rank": "Species"}, "1380380": {"name": "Ahrensia sp. 13_GOM-1096m", "rank": "Species"}, "1380381": {"name": "Colwellia sp. 8_GOM-1096m", "rank": "Species"}, "1158488": {"name": "Staphylococcus aureus M1322", "rank": "Strain"}, "633147": {"name": "Olsenella uli DSM 7084", "rank": "Strain"}, "1158489": {"name": "Staphylococcus aureus M1359", "rank": "Strain"}, "995": {"name": "Solitalea canadensis", "rank": "Species"}, "1158484": {"name": "Staphylococcus aureus M1291", "rank": "Strain"}, "1158485": {"name": "Staphylococcus aureus M1311", "rank": "Strain"}, "9606": {"name": "Homo sapiens", "rank": "Species"}, "911008": {"name": "Leclercia adecarboxylata ATCC 23216 = NBRC 102595", "rank": "Strain"}, "1302421": {"name": "Clostridium botulinum A1 str. CFSAN002368", "rank": "Strain"}, "1302425": {"name": "Clostridium botulinum CFSAN002367", "rank": "Strain"}, "1302427": {"name": "Clostridium botulinum CFSAN002369", "rank": "Strain"}, "510690": {"name": "Sneathiella", "rank": "Genus"}, "169760": {"name": "Paenibacillus stellifer", "rank": "Species"}, "206350": {"name": "Methylophilales", "rank": "Order"}, "206351": {"name": "Neisseriales", "rank": "Order"}, "1173938": {"name": "Salmonella enterica subsp. enterica serovar Urbana str. ATCC 9261", "rank": "Strain"}, "1263082": {"name": "Lichtheimia corymbifera JMRC:FSU:9682", "rank": "Strain"}, "81684": {"name": "Unclassified Proteobacteria (miscellaneous)", "rank": "No rank"}, "1238428": {"name": "Halorubrum sp. J07HR59", "rank": "Species"}, "81682": {"name": "Methylovorus", "rank": "Genus"}, "111955": {"name": "Sulfolobus tokodaii", "rank": "Species"}, "1238425": {"name": "Haloquadratum walsbyi J07HQW2", "rank": "Strain"}, "1265669": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 35.H.08", "rank": "Strain"}, "1265668": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 19.F.03", "rank": "Strain"}, "1189619": {"name": "Psychroflexus gondwanensis ACAM 44", "rank": "Strain"}, "1189618": {"name": "Xanthomonas axonopodis pv. manihotis str. AFNC1360", "rank": "Strain"}, "1265663": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 55.U.08", "rank": "Strain"}, "279808": {"name": "Staphylococcus haemolyticus JCSC1435", "rank": "Strain"}, "1265661": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 30.H.04", "rank": "Strain"}, "1189616": {"name": "Xanthomonas axonopodis pv. manihotis str. AT6B", "rank": "Strain"}, "1189611": {"name": "Nitratireductor aquibiodomus RA22", "rank": "Strain"}, "1265666": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 62.H.72", "rank": "Strain"}, "1189613": {"name": "Staphylococcus massiliensis CCUG 55927", "rank": "Strain"}, "1189612": {"name": "Indibacter alkaliphilus LW1", "rank": "Strain"}, "1121116": {"name": "Brachymonas chironomi DSM 19884", "rank": "Strain"}, "1114179": {"name": "Pseudomonas phage tf", "rank": "Species"}, "1562063": {"name": "Unclassified Hunnivirus", "rank": "No rank"}, "1562065": {"name": "Norway rat pegivirus", "rank": "Species"}, "293284": {"name": "Corchorus yellow vein virus - Hoa Binh", "rank": "Strain"}, "1562066": {"name": "Norway rat pestivirus", "rank": "Species"}, "414004": {"name": "Cenarchaeum symbiosum A", "rank": "Strain"}, "478801": {"name": "Kytococcus sedentarius DSM 20547", "rank": "Strain"}, "1074186": {"name": "Streptococcus mutans TCI-298", "rank": "Strain"}, "1074184": {"name": "Streptococcus mutans TCI-292", "rank": "Strain"}, "1074185": {"name": "Streptococcus mutans TCI-294", "rank": "Strain"}, "1074182": {"name": "Streptococcus mutans TCI-280", "rank": "Strain"}, "33069": {"name": "Pseudomonas viridiflava", "rank": "Species"}, "1074180": {"name": "Streptococcus mutans TCI-278", "rank": "Strain"}, "1074181": {"name": "Streptococcus mutans TCI-279", "rank": "Strain"}, "213618": {"name": "Microcystis aeruginosa PCC 7941", "rank": "Strain"}, "477228": {"name": "Pseudomonas stutzeri TS44", "rank": "Strain"}, "992088": {"name": "Helicobacter pylori Hp P-41", "rank": "Strain"}, "992089": {"name": "Helicobacter pylori Hp P-62", "rank": "Strain"}, "992087": {"name": "Helicobacter pylori Hp P-30", "rank": "Strain"}, "992084": {"name": "Helicobacter pylori Hp P-25", "rank": "Strain"}, "992085": {"name": "Helicobacter pylori Hp P-26", "rank": "Strain"}, "992083": {"name": "Helicobacter pylori Hp P-23", "rank": "Strain"}, "992080": {"name": "Helicobacter pylori Hp P-15", "rank": "Strain"}, "992081": {"name": "Helicobacter pylori Hp P-16", "rank": "Strain"}, "1295010": {"name": "Campylobacter jejuni subsp. jejuni R14", "rank": "Strain"}, "1411123": {"name": "Rhizobiales bacterium YIM 77505", "rank": "Species"}, "1136176": {"name": "Vibrio cyclitrophicus ZF270", "rank": "Strain"}, "1136177": {"name": "Lactobacillus pentosus KCA1", "rank": "Strain"}, "1136174": {"name": "Vibrio cyclitrophicus ZF255", "rank": "Strain"}, "1136175": {"name": "Vibrio cyclitrophicus ZF264", "rank": "Strain"}, "1448686": {"name": "Mycobacterium tuberculosis M1439", "rank": "Strain"}, "1136173": {"name": "Vibrio cyclitrophicus ZF207", "rank": "Strain"}, "1405294": {"name": "Escherichia coli ATCC BAA-2215", "rank": "Strain"}, "1136171": {"name": "Vibrio cyclitrophicus ZF170", "rank": "Strain"}, "1157946": {"name": "Streptococcus salivarius PS4", "rank": "Strain"}, "1157947": {"name": "Thermotoga sp. Cell2", "rank": "Species"}, "1448688": {"name": "Mycobacterium tuberculosis M1444", "rank": "Strain"}, "1448689": {"name": "Mycobacterium tuberculosis M1448", "rank": "Strain"}, "1157943": {"name": "Mycobacterium sp. 155", "rank": "Species"}, "1136178": {"name": "Geobacillus thermoglucosidans TNO-09.020", "rank": "Strain"}, "1136179": {"name": "Rhodococcus erythropolis CCM2595", "rank": "Strain"}, "1072178": {"name": "Vernonia yellow vein Fujian virus alphasatellite", "rank": "Species"}, "1072177": {"name": "Vernonia yellow vein Fujian virus betasatellite", "rank": "Species"}, "1072176": {"name": "Bokeloh bat lyssavirus", "rank": "Species"}, "351495": {"name": "Raphanus sativus cryptic virus 2", "rank": "Species"}, "1449335": {"name": "Carnobacterium alterfunditum DSM 5972", "rank": "Strain"}, "1256993": {"name": "Providencia alcalifaciens PAL-3", "rank": "Strain"}, "1449337": {"name": "Carnobacterium funditum DSM 5970", "rank": "Strain"}, "1449336": {"name": "Carnobacterium divergens DSM 20623", "rank": "Strain"}, "1196647": {"name": "Canine picornavirus", "rank": "Species"}, "1449339": {"name": "Carnobacterium inhibens DSM 13024", "rank": "Strain"}, "1449338": {"name": "Carnobacterium gallinarum DSM 4847", "rank": "Strain"}, "147538": {"name": "Pezizomycotina", "rank": "Subphylum"}, "1131630": {"name": "Streptococcus pneumoniae GA62331", "rank": "Strain"}, "1388049": {"name": "Staphylococcus aureus M0087", "rank": "Strain"}, "1388048": {"name": "Staphylococcus aureus M0086", "rank": "Strain"}, "1388041": {"name": "Staphylococcus aureus M0079", "rank": "Strain"}, "1388040": {"name": "Staphylococcus aureus M0076", "rank": "Strain"}, "1388043": {"name": "Staphylococcus aureus M0081", "rank": "Strain"}, "1388042": {"name": "Staphylococcus aureus M0080", "rank": "Strain"}, "1388045": {"name": "Staphylococcus aureus M0083", "rank": "Strain"}, "1388044": {"name": "Staphylococcus aureus M0082", "rank": "Strain"}, "1388046": {"name": "Staphylococcus aureus M0084", "rank": "Strain"}, "1079479": {"name": "Bradyrhizobium elkanii USDA 3254", "rank": "Strain"}, "1079478": {"name": "Salmonella enterica subsp. enterica serovar Muenchen str. baa1674", "rank": "Strain"}, "1365187": {"name": "Vibrio parahaemolyticus CFSAN001595", "rank": "Strain"}, "1365186": {"name": "Klebsiella pneumoniae KP-1", "rank": "Strain"}, "1079471": {"name": "Salmonella enterica subsp. enterica serovar Pullorum str. 13036", "rank": "Strain"}, "1079470": {"name": "Salmonella enterica subsp. enterica serovar Pullorum str. 19945", "rank": "Strain"}, "1079473": {"name": "Salmonella enterica subsp. enterica serovar Montevideo str. 8387", "rank": "Strain"}, "397260": {"name": "Sphingomonas sanxanigenens", "rank": "Species"}, "1079475": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. 81-2625", "rank": "Strain"}, "1079474": {"name": "Salmonella enterica subsp. enterica serovar Javiana str. 10721", "rank": "Strain"}, "1079477": {"name": "Salmonella enterica subsp. enterica serovar Muenchen str. baa1594", "rank": "Strain"}, "1079476": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. 62-1976", "rank": "Strain"}, "927703": {"name": "Lactobacillus reuteri ATCC 53608", "rank": "Strain"}, "121039": {"name": "Ferrimicrobium acidiphilum", "rank": "Species"}, "121038": {"name": "Ferrimicrobium", "rank": "Genus"}, "760764": {"name": "Streptococcus pneumoniae GA11426", "rank": "Strain"}, "992098": {"name": "Helicobacter pylori Hp P-1b", "rank": "Strain"}, "1056820": {"name": "Teredinibacter turnerae T7902", "rank": "Strain"}, "1275976": {"name": "Salmonella enterica subsp. enterica serovar Newport str. JS09102", "rank": "Strain"}, "1310989": {"name": "Acinetobacter baumannii 44327_5", "rank": "Strain"}, "1310988": {"name": "Acinetobacter baumannii 44327_4", "rank": "Strain"}, "760769": {"name": "Streptococcus pneumoniae GA13338", "rank": "Strain"}, "1310985": {"name": "Acinetobacter baumannii 44327_1", "rank": "Strain"}, "1310984": {"name": "Acinetobacter baumannii 44467_10", "rank": "Strain"}, "1310986": {"name": "Acinetobacter baumannii 44327_2", "rank": "Strain"}, "1310981": {"name": "Acinetobacter baumannii 44467_7", "rank": "Strain"}, "1310980": {"name": "Acinetobacter baumannii 44467_6", "rank": "Strain"}, "139061": {"name": "Ascocoryne sarcoides", "rank": "Species"}, "139060": {"name": "Ascocoryne", "rank": "Genus"}, "1286828": {"name": "Amycolatopsis sp. JGI 0001006-E10", "rank": "Species"}, "1288909": {"name": "Staphylococcus aureus subsp. aureus S2396", "rank": "Strain"}, "1288908": {"name": "Staphylococcus aureus subsp. aureus S2395", "rank": "Strain"}, "1275971": {"name": "Haemophilus parasuis D74", "rank": "Strain"}, "1288907": {"name": "Staphylococcus aureus subsp. aureus S1805", "rank": "Strain"}, "1321391": {"name": "Rodent pegivirus", "rank": "Species"}, "1448930": {"name": "Unclassified Fervidibacteria", "rank": "No rank"}, "103690": {"name": "Nostoc sp. PCC 7120", "rank": "Species"}, "1408468": {"name": "Mycoplasma primatum ATCC 25948", "rank": "Strain"}, "1449089": {"name": "Enterobacter cloacae subsp. cloacae SY-70", "rank": "Strain"}, "1449088": {"name": "Bacillus amyloliquefaciens subsp. plantarum TrigoCor1448", "rank": "Strain"}, "1449087": {"name": "Thiomicrospira sp. MA2-6", "rank": "Species"}, "1194421": {"name": "Pseudomonas syringae pv. actinidiae ICMP 19099", "rank": "Strain"}, "1194422": {"name": "Pseudomonas syringae pv. actinidiae ICMP 19098", "rank": "Strain"}, "1408469": {"name": "Mycoplasma simbae ATCC 49888", "rank": "Strain"}, "1194424": {"name": "Zymomonas mobilis subsp. mobilis NRRL B-12526", "rank": "Strain"}, "315750": {"name": "Bacillus pumilus SAFR-032", "rank": "Strain"}, "141948": {"name": "Thermomonas", "rank": "Genus"}, "1388593": {"name": "Staphylococcus aureus M0807", "rank": "Strain"}, "1388592": {"name": "Staphylococcus aureus M0806", "rank": "Strain"}, "1388591": {"name": "Staphylococcus aureus M0805", "rank": "Strain"}, "1388590": {"name": "Staphylococcus aureus M0804", "rank": "Strain"}, "1388597": {"name": "Staphylococcus aureus M0811", "rank": "Strain"}, "1388596": {"name": "Staphylococcus aureus M0810", "rank": "Strain"}, "1388595": {"name": "Staphylococcus aureus M0809", "rank": "Strain"}, "95668": {"name": "Ureaplasma parvum serovar 14", "rank": "Strain"}, "1388599": {"name": "Staphylococcus aureus M0814", "rank": "Strain"}, "1388598": {"name": "Staphylococcus aureus M0812", "rank": "Strain"}, "39739": {"name": "Machlomovirus", "rank": "Genus"}, "39738": {"name": "Tombusviridae", "rank": "Family"}, "154834": {"name": "Panicum mosaic satellite virus", "rank": "Species"}, "39731": {"name": "Bymovirus", "rank": "Genus"}, "39730": {"name": "Rymovirus", "rank": "Genus"}, "39733": {"name": "Astroviridae", "rank": "Family"}, "1410881": {"name": "Staphylococcus aureus T45940", "rank": "Strain"}, "39734": {"name": "Umbravirus", "rank": "Genus"}, "11520": {"name": "Influenza B virus", "rank": "Species"}, "1214901": {"name": "Staphylococcus aureus M0646", "rank": "Strain"}, "1116149": {"name": "Escherichia coli P0298942.12", "rank": "Strain"}, "1116148": {"name": "Escherichia coli P0298942.11", "rank": "Strain"}, "543939": {"name": "Sputnik virophage", "rank": "Species"}, "1116141": {"name": "Escherichia coli P0298942.1", "rank": "Strain"}, "1116140": {"name": "Escherichia coli MP020940.1", "rank": "Strain"}, "1116143": {"name": "Escherichia coli P0298942.6", "rank": "Strain"}, "1116142": {"name": "Escherichia coli P0298942.2", "rank": "Strain"}, "1116145": {"name": "Escherichia coli P0298942.8", "rank": "Strain"}, "1116144": {"name": "Escherichia coli P0298942.7", "rank": "Strain"}, "1116147": {"name": "Escherichia coli P0298942.10", "rank": "Strain"}, "1116146": {"name": "Escherichia coli P0298942.9", "rank": "Strain"}, "180869": {"name": "Bacillus thuringiensis serovar pakistani", "rank": "Strain"}, "565654": {"name": "Enterococcus casseliflavus EC10", "rank": "Strain"}, "225588": {"name": "Streptomyces phage phiBT1", "rank": "Species"}, "180860": {"name": "Bacillus thuringiensis serovar tochigiensis", "rank": "Strain"}, "670898": {"name": "Escherichia coli E851/71", "rank": "Strain"}, "670899": {"name": "Escherichia coli RN587/1", "rank": "Strain"}, "183988": {"name": "Methanopyri", "rank": "Class"}, "670890": {"name": "Escherichia coli LT-68", "rank": "Strain"}, "670892": {"name": "Escherichia coli 3431", "rank": "Strain"}, "670893": {"name": "Escherichia coli EPECa14", "rank": "Strain"}, "670894": {"name": "Escherichia coli E128010", "rank": "Strain"}, "1282665": {"name": "Streptococcus tigurinus 1366", "rank": "Strain"}, "670896": {"name": "Escherichia coli EPECa12", "rank": "Strain"}, "670897": {"name": "Escherichia coli 2362-75", "rank": "Strain"}, "1206109": {"name": "Candidatus Portiera aleyrodidarum BT-B-HRs", "rank": "Strain"}, "1206108": {"name": "Escherichia coli J96", "rank": "Strain"}, "715340": {"name": "Pleosporineae", "rank": "Suborder"}, "1206101": {"name": "Streptomyces sp. CNR698", "rank": "Species"}, "1358423": {"name": "Sphingobacterium antarcticus 4BY", "rank": "Strain"}, "1206103": {"name": "Pedobacter arcticus A12", "rank": "Strain"}, "1206102": {"name": "Salinispora pacifica CNT796", "rank": "Strain"}, "1206105": {"name": "Enterococcus faecalis D32", "rank": "Strain"}, "1206104": {"name": "Paenibacillus polymyxa ATCC 12321", "rank": "Strain"}, "1206107": {"name": "Corynebacterium diphtheriae str. Aberdeen", "rank": "Strain"}, "1206106": {"name": "Corynebacterium diphtheriae DSM 43988", "rank": "Strain"}, "883118": {"name": "Klebsiella oxytoca 10-5243", "rank": "Strain"}, "883111": {"name": "Facklamia hominis CCUG 36813", "rank": "Strain"}, "883110": {"name": "Facklamia hominis ACS-120-V-Sch10", "rank": "Strain"}, "883113": {"name": "Facklamia languida CCUG 37842", "rank": "Strain"}, "883112": {"name": "Facklamia ignava CCUG 37419", "rank": "Strain"}, "883114": {"name": "Helcococcus kunzii ATCC 51366", "rank": "Strain"}, "883117": {"name": "Klebsiella oxytoca 10-5242", "rank": "Strain"}, "43947": {"name": "Tolumonas", "rank": "Genus"}, "1462": {"name": "Geobacillus kaustophilus", "rank": "Species"}, "1465": {"name": "Brevibacillus laterosporus", "rank": "Species"}, "1464": {"name": "Paenibacillus larvae", "rank": "Species"}, "28091": {"name": "Neisseria weaveri", "rank": "Species"}, "43948": {"name": "Tolumonas auensis", "rank": "Species"}, "1226332": {"name": "Lactobacillus helveticus CIRM-BIA 103", "rank": "Strain"}, "232259": {"name": "Belliella baltica", "rank": "Species"}, "1226333": {"name": "Lactobacillus helveticus CIRM-BIA 104", "rank": "Strain"}, "905055": {"name": "Tobacco leaf curl PUSA alphasatellite", "rank": "Species"}, "905054": {"name": "Tobacco leaf curl Pusa virus", "rank": "Species"}, "400121": {"name": "Gull circovirus", "rank": "Species"}, "1226335": {"name": "Lactobacillus helveticus CIRM-BIA 953", "rank": "Strain"}, "225324": {"name": "Enhydrobacter aerosaccus", "rank": "Species"}, "1226336": {"name": "Lactobacillus helveticus CIRM-BIA 101", "rank": "Strain"}, "225326": {"name": "Corynebacterium halotolerans", "rank": "Species"}, "1401256": {"name": "Xylella fastidiosa MUL0034", "rank": "Strain"}, "1095729": {"name": "Streptococcus anginosus subsp. whileyi CCUG 39159", "rank": "Strain"}, "1236974": {"name": "Paenibacillus sp. JCM 10914", "rank": "Species"}, "1236973": {"name": "Bacillus akibai JCM 9157", "rank": "Strain"}, "1236971": {"name": "Bacillus hemicellulosilyticus JCM 9152", "rank": "Strain"}, "1236970": {"name": "Bacillus wakoensis JCM 9140", "rank": "Strain"}, "1281118": {"name": "Escherichia coli HVH 191 (3-9341900)", "rank": "Strain"}, "573173": {"name": "Vibrio phage helene 12B3", "rank": "Species"}, "573171": {"name": "Vibrio phage douglas 12A4", "rank": "Species"}, "1609545": {"name": "Unclassified Mollicutes (miscellaneous)", "rank": "No rank"}, "573175": {"name": "Vibrio phage martha 12B12", "rank": "Species"}, "573174": {"name": "Vibrio phage henriette 12B8", "rank": "Species"}, "103730": {"name": "Actinokineospora inagensis", "rank": "Species"}, "1218564": {"name": "Leptospira alstonii serovar Pingchang str. 80-412", "rank": "Strain"}, "1218565": {"name": "Leptospira alstonii serovar Sichuan str. 79601", "rank": "Strain"}, "1218562": {"name": "Leptospira alstonii serovar Pingchang", "rank": "Strain"}, "1218563": {"name": "Leptospira alstonii serovar Sichuan", "rank": "Strain"}, "194802": {"name": "Vibrio phage VpV262", "rank": "Species"}, "1316911": {"name": "Bifidobacterium animalis subsp. lactis KLDS2.0603", "rank": "Strain"}, "701456": {"name": "Mycobacterium phage SkiPole", "rank": "Species"}, "221915": {"name": "Staphylococcus phage K", "rank": "Species"}, "44024": {"name": "Kokobera virus", "rank": "Species"}, "44026": {"name": "Sepik virus", "rank": "Species"}, "1219375": {"name": "Xanthomonas cassavae CFBP 4642", "rank": "Strain"}, "529929": {"name": "Salmonella phage phiSG-JL2", "rank": "Species"}, "125788": {"name": "Bombyx mori densovirus 5", "rank": "Strain"}, "49964": {"name": "Myxococcus phage Mx8", "rank": "Species"}, "1038858": {"name": "Azorhizobium doebereinerae UFLA1-100", "rank": "Strain"}, "1038859": {"name": "Bradyrhizobium elkanii WSM1741", "rank": "Strain"}, "1169397": {"name": "Escherichia coli KTE166", "rank": "Strain"}, "445688": {"name": "Prochlorococcus phage P-SSM7", "rank": "Species"}, "445686": {"name": "Synechococcus phage S-SSM7", "rank": "Species"}, "445685": {"name": "Synechococcus phage S-SSM5", "rank": "Species"}, "445684": {"name": "Synechococcus phage Syn19", "rank": "Species"}, "445683": {"name": "Synechococcus phage S-ShM2", "rank": "Species"}, "1409629": {"name": "Staphylococcus aureus SMMC6108", "rank": "Strain"}, "1444238": {"name": "Escherichia coli 2-474-04_S4_C2", "rank": "Strain"}, "1409627": {"name": "Staphylococcus aureus KINB6024", "rank": "Strain"}, "1409626": {"name": "Staphylococcus aureus UCIM6085", "rank": "Strain"}, "1444235": {"name": "Escherichia coli 2-316-03_S4_C2", "rank": "Strain"}, "1409624": {"name": "Staphylococcus aureus KINB6023", "rank": "Strain"}, "1444233": {"name": "Escherichia coli 2-210-07_S4_C2", "rank": "Strain"}, "1444232": {"name": "Escherichia coli 2-177-06_S4_C2", "rank": "Strain"}, "1444231": {"name": "Escherichia coli 2-156-04_S4_C2", "rank": "Strain"}, "1409620": {"name": "Staphylococcus aureus KINW6025", "rank": "Strain"}, "1422558": {"name": "Staphylococcus aureus VET0291R", "rank": "Strain"}, "1422559": {"name": "Staphylococcus aureus VET0292R", "rank": "Strain"}, "1084715": {"name": "Porcine bocavirus 3", "rank": "Strain"}, "1422552": {"name": "Staphylococcus aureus VET0284R", "rank": "Strain"}, "629725": {"name": "Candiru virus", "rank": "Species"}, "1422550": {"name": "Staphylococcus aureus VET0282R", "rank": "Strain"}, "1422551": {"name": "Staphylococcus aureus VET0283R", "rank": "Strain"}, "1422556": {"name": "Staphylococcus aureus VET0289R", "rank": "Strain"}, "1422557": {"name": "Staphylococcus aureus VET0290R", "rank": "Strain"}, "1422554": {"name": "Staphylococcus aureus VET0287R", "rank": "Strain"}, "1422555": {"name": "Staphylococcus aureus VET0288R", "rank": "Strain"}, "1185674": {"name": "Xanthomonas axonopodis pv. manihotis str. IBSBF 2346", "rank": "Strain"}, "63612": {"name": "Sodalis glossinidius", "rank": "Species"}, "44688": {"name": "Lactococcus lactis subsp. lactis bv. diacetylactis", "rank": "Strain"}, "1412698": {"name": "Staphylococcus aureus T89463", "rank": "Strain"}, "1412699": {"name": "Staphylococcus aureus T89467", "rank": "Strain"}, "1333579": {"name": "Streptococcus agalactiae 112469214-isolate1", "rank": "Strain"}, "1333578": {"name": "Streptococcus agalactiae MC634", "rank": "Strain"}, "1412692": {"name": "Staphylococcus aureus T30565", "rank": "Strain"}, "1412693": {"name": "Staphylococcus aureus T30569", "rank": "Strain"}, "1333575": {"name": "Streptococcus agalactiae MC631", "rank": "Strain"}, "1333574": {"name": "Streptococcus agalactiae MC629", "rank": "Strain"}, "1333573": {"name": "Streptococcus agalactiae MC628", "rank": "Strain"}, "1333572": {"name": "Streptococcus agalactiae MC627", "rank": "Strain"}, "1333571": {"name": "Streptococcus agalactiae MC626", "rank": "Strain"}, "354328": {"name": "Bell pepper endornavirus", "rank": "Species"}, "1054400": {"name": "Bacillus amyloliquefaciens subsp. plantarum", "rank": "Subspecies"}, "1122207": {"name": "Marinomonas ushuaiensis DSM 15871", "rank": "Strain"}, "1054405": {"name": "Bacillus amyloliquefaciens subsp. amyloliquefaciens", "rank": "Subspecies"}, "1122200": {"name": "Marinobacterium jannaschii DSM 6295", "rank": "Strain"}, "1122203": {"name": "Marinococcus halotolerans DSM 16375", "rank": "Strain"}, "1122202": {"name": "Marinobacterium rhizophilum DSM 18822", "rank": "Strain"}, "1178537": {"name": "Bacillus xiamenensis", "rank": "Species"}, "13034": {"name": "Dactylococcopsis", "rank": "Genus"}, "13035": {"name": "Dactylococcopsis salina PCC 8305", "rank": "Strain"}, "1081054": {"name": "Morelia spilota papillomavirus 1", "rank": "Strain"}, "1081055": {"name": "Canis familiaris papillomavirus 8", "rank": "Strain"}, "96241": {"name": "Bacillus subtilis subsp. spizizenii", "rank": "Subspecies"}, "270495": {"name": "Fangia hongkongensis", "rank": "Species"}, "270496": {"name": "Desulfovibrio putealis", "rank": "Species"}, "1237929": {"name": "Thioalkalivibrio sp. ALJ5", "rank": "Species"}, "1331043": {"name": "Salmonella enterica subsp. enterica serovar Gallinarum/pullorum str. FCAV198", "rank": "Strain"}, "1331042": {"name": "Pasteurella multocida subsp. multocida P1062", "rank": "Strain"}, "11867": {"name": "Avian myelocytomatosis virus", "rank": "Species"}, "11864": {"name": "Avian leukosis virus", "rank": "Species"}, "926": {"name": "Thiomonas intermedia", "rank": "Species"}, "927": {"name": "Halothiobacillus neapolitanus", "rank": "Species"}, "887825": {"name": "Chickpea chlorosis virus-A", "rank": "Strain"}, "920": {"name": "Acidithiobacillus ferrooxidans", "rank": "Species"}, "921": {"name": "Starkeya novella", "rank": "Species"}, "929": {"name": "Thermithiobacillus tepidarius", "rank": "Species"}, "100225": {"name": "Austwickia chelonae", "rank": "Species"}, "1276141": {"name": "Metarhizium brunneum ARSEF 3297", "rank": "Strain"}, "181487": {"name": "Actinomyces cardiffensis", "rank": "Species"}, "274495": {"name": "Lettuce ring necrosis virus", "rank": "Species"}, "391774": {"name": "Desulfovibrio vulgaris DP4", "rank": "Strain"}, "1310162": {"name": "Campylobacter jejuni BJ-CJD101", "rank": "Strain"}, "274493": {"name": "Chlorobium/Pelodictyon group", "rank": "No rank"}, "904698": {"name": "Arumowot virus", "rank": "Species"}, "12809": {"name": "Raspberry ringspot virus", "rank": "Species"}, "1235558": {"name": "Herbaspirillum huttiense subsp. putei IAM 15032", "rank": "Strain"}, "1122602": {"name": "Nesterenkonia alba DSM 19423", "rank": "Strain"}, "1235559": {"name": "Providencia phage Redjac", "rank": "Species"}, "266940": {"name": "Kineococcus radiotolerans SRS30216 = ATCC BAA-149", "rank": "Strain"}, "42684": {"name": "Streptomyces collinus", "rank": "Species"}, "1122604": {"name": "Nevskia soli DSM 19509", "rank": "Strain"}, "886888": {"name": "Acinetobacter baumannii 3990", "rank": "Strain"}, "886889": {"name": "Acinetobacter baumannii 3909", "rank": "Strain"}, "663276": {"name": "Sinorhizobium fredii group", "rank": "No rank"}, "132920": {"name": "Exiguobacterium antarcticum", "rank": "Species"}, "171441": {"name": "Photorhabdus temperata subsp. temperata", "rank": "Subspecies"}, "886882": {"name": "Paenibacillus polymyxa SC2", "rank": "Strain"}, "663278": {"name": "Ethanoligenens harbinense YUAN-3", "rank": "Strain"}, "886886": {"name": "Acinetobacter baumannii AB210", "rank": "Strain"}, "43080": {"name": "Sulfolobus islandicus", "rank": "Species"}, "341694": {"name": "Peptostreptococcus stomatis", "rank": "Species"}, "1388051": {"name": "Staphylococcus aureus M0092", "rank": "Strain"}, "75612": {"name": "Pseudomonas mandelii", "rank": "Species"}, "857042": {"name": "Candidatus Poribacteria sp. WGA-4G", "rank": "Species"}, "766139": {"name": "Shigella boydii 3594-74", "rank": "Strain"}, "766138": {"name": "Shigella boydii 965-58", "rank": "Strain"}, "1298610": {"name": "Psychrobacter sp. JCM 18903", "rank": "Species"}, "1158178": {"name": "Thioalkalivibrio sp. ALE27", "rank": "Species"}, "1230343": {"name": "Legionella anisa str. Linanisette", "rank": "Strain"}, "281120": {"name": "Candidatus Amoebophilus asiaticus", "rank": "Species"}, "1031711": {"name": "Ralstonia solanacearum Po82", "rank": "Strain"}, "1447456": {"name": "Mycobacterium tuberculosis MD16764", "rank": "Strain"}, "1447457": {"name": "Mycobacterium tuberculosis MD18096", "rank": "Strain"}, "1447454": {"name": "Mycobacterium tuberculosis MD19323", "rank": "Strain"}, "1447455": {"name": "Mycobacterium tuberculosis MD19051", "rank": "Strain"}, "1447452": {"name": "Mycobacterium tuberculosis MD19591", "rank": "Strain"}, "1447453": {"name": "Mycobacterium tuberculosis MD18472", "rank": "Strain"}, "1447450": {"name": "Mycobacterium tuberculosis MD17890", "rank": "Strain"}, "1447451": {"name": "Mycobacterium tuberculosis MD19339", "rank": "Strain"}, "1264737": {"name": "Cronobacter phage vB_CskP_GAP227", "rank": "Species"}, "1447458": {"name": "Mycobacterium tuberculosis MD17973", "rank": "Strain"}, "1447459": {"name": "Mycobacterium tuberculosis MD18112", "rank": "Strain"}, "1281197": {"name": "Escherichia coli UMEA 3159-1", "rank": "Strain"}, "1122939": {"name": "Patulibacter americanus DSM 16676", "rank": "Strain"}, "4959": {"name": "Debaryomyces hansenii", "rank": "Species"}, "10310": {"name": "Human herpesvirus 2", "rank": "Species"}, "1281196": {"name": "Escherichia coli UMEA 3155-1", "rank": "Strain"}, "1122933": {"name": "Paraoerskovia marina DSM 21750", "rank": "Strain"}, "4953": {"name": "Zygosaccharomyces", "rank": "Genus"}, "4950": {"name": "Torulaspora delbrueckii", "rank": "Species"}, "4951": {"name": "Yarrowia", "rank": "Genus"}, "4956": {"name": "Zygosaccharomyces rouxii", "rank": "Species"}, "5180": {"name": "Sclerotinia sclerotiorum", "rank": "Species"}, "4954": {"name": "Zygosaccharomyces bailii", "rank": "Species"}, "10319": {"name": "Varicellovirus", "rank": "Genus"}, "5181": {"name": "Helotiaceae", "rank": "Family"}, "331869": {"name": "Alpha proteobacterium BAL199", "rank": "Species"}, "1281192": {"name": "Escherichia coli UMEA 3148-1", "rank": "Strain"}, "243272": {"name": "Mycoplasma arthritidis 158L3-1", "rank": "Strain"}, "243273": {"name": "Mycoplasma genitalium G37", "rank": "Strain"}, "1281190": {"name": "Escherichia coli UMEA 3140-1", "rank": "Strain"}, "243276": {"name": "Treponema pallidum subsp. pallidum str. Nichols", "rank": "Strain"}, "243277": {"name": "Vibrio cholerae O1 biovar El Tor str. N16961", "rank": "Strain"}, "243274": {"name": "Thermotoga maritima MSB8", "rank": "Strain"}, "243275": {"name": "Treponema denticola ATCC 35405", "rank": "Strain"}, "212035": {"name": "Acanthamoeba polyphaga mimivirus", "rank": "Species"}, "1329200": {"name": "Fictibacillus", "rank": "Genus"}, "1088740": {"name": "Candidatus Nitrosoarchaeum koreensis", "rank": "Species"}, "573234": {"name": "Candidatus Hodgkinia cicadicola Dsem", "rank": "Strain"}, "573235": {"name": "Escherichia coli O26:H11 str. 11368", "rank": "Strain"}, "110932": {"name": "Leifsonia", "rank": "Genus"}, "573237": {"name": "Chlamydia trachomatis D(s)2923", "rank": "Strain"}, "1427195": {"name": "Mycobacterium tuberculosis XTB13-103", "rank": "Strain"}, "1427194": {"name": "Mycobacterium tuberculosis XTB13-102", "rank": "Strain"}, "1427197": {"name": "Mycobacterium tuberculosis XTB13-105", "rank": "Strain"}, "1526408": {"name": "Staphylococcus phage P108", "rank": "Species"}, "1427191": {"name": "Mycobacterium tuberculosis XTB13-097", "rank": "Strain"}, "1427190": {"name": "Mycobacterium tuberculosis XTB13-096", "rank": "Strain"}, "1427193": {"name": "Mycobacterium tuberculosis XTB13-100", "rank": "Strain"}, "1427192": {"name": "Mycobacterium tuberculosis XTB13-098", "rank": "Strain"}, "1006598": {"name": "Serratia plymuthica RVH1", "rank": "Strain"}, "1522312": {"name": "Kingella sp. Sch538", "rank": "Species"}, "1522311": {"name": "Tessaracoccus sp. SIT6", "rank": "Species"}, "1522310": {"name": "Mobilicoccus sp. SIT2", "rank": "Species"}, "1522317": {"name": "Bacterium SIT7", "rank": "Species"}, "779": {"name": "Ehrlichia ruminantium", "rank": "Species"}, "466038": {"name": "Candidatus Pelagibacter ubique HTCC8051", "rank": "Strain"}, "39681": {"name": "Asparagus virus 2", "rank": "Species"}, "1154834": {"name": "Streptococcus agalactiae BSU167", "rank": "Strain"}, "334858": {"name": "Goodfellowiella coeruleoviolacea", "rank": "Species"}, "523841": {"name": "Haloferax mediterranei ATCC 33500", "rank": "Strain"}, "948106": {"name": "Burkholderia dilworthii", "rank": "Species"}, "948107": {"name": "Burkholderia sprentiae", "rank": "Species"}, "1224164": {"name": "Corynebacterium vitaeruminis DSM 20294", "rank": "Strain"}, "913089": {"name": "Escherichia coli TW10828", "rank": "Strain"}, "913088": {"name": "Escherichia coli TW11681", "rank": "Strain"}, "1287094": {"name": "Mesorhizobium sp. L103C565B0", "rank": "Species"}, "913087": {"name": "Escherichia coli TW14425", "rank": "Strain"}, "694569": {"name": "Aggregatibacter actinomycetemcomitans D7S-1", "rank": "Strain"}, "11048": {"name": "Lactate dehydrogenase-elevating virus", "rank": "Species"}, "235266": {"name": "Acidianus filamentous virus 1", "rank": "Species"}, "11041": {"name": "Rubella virus", "rank": "Species"}, "11040": {"name": "Rubivirus", "rank": "Genus"}, "11047": {"name": "Equine arteritis virus", "rank": "Species"}, "29405": {"name": "Microlunatus phosphovorus", "rank": "Species"}, "681645": {"name": "Corynebacterium pseudotuberculosis C231", "rank": "Strain"}, "116056": {"name": "Pelargonium zonate spot virus", "rank": "Species"}, "198542": {"name": "Streptococcus pyogenes phage 315.5", "rank": "Species"}, "383407": {"name": "Xanthomonas oryzae pv. oryzicola BLS256", "rank": "Strain"}, "2121": {"name": "Mycoplasma orale", "rank": "Species"}, "2123": {"name": "Mycoplasma putrefaciens", "rank": "Species"}, "2122": {"name": "Mycoplasma pirum", "rank": "Species"}, "2124": {"name": "Mycoplasma salivarium", "rank": "Species"}, "2127": {"name": "Mycoplasma collis", "rank": "Species"}, "437506": {"name": "Robiginitomaculum", "rank": "Genus"}, "2129": {"name": "Ureaplasma", "rank": "Genus"}, "2128": {"name": "Mycoplasma flocculare", "rank": "Species"}, "439809": {"name": "Mycobacterium phage Tweety", "rank": "Species"}, "1204178": {"name": "Helicobacter phage KHP40", "rank": "Species"}, "1422211": {"name": "Staphylococcus aureus DAR966", "rank": "Strain"}, "1422210": {"name": "Staphylococcus aureus DAR951", "rank": "Strain"}, "1422213": {"name": "Staphylococcus aureus DAR1067", "rank": "Strain"}, "1422212": {"name": "Staphylococcus aureus DAR1065", "rank": "Strain"}, "1422215": {"name": "Staphylococcus aureus DAR1083", "rank": "Strain"}, "1422214": {"name": "Staphylococcus aureus DAR1082", "rank": "Strain"}, "1422217": {"name": "Staphylococcus aureus DAR1086", "rank": "Strain"}, "426368": {"name": "Methanococcus maripaludis C7", "rank": "Strain"}, "1422219": {"name": "Staphylococcus aureus DAR1157", "rank": "Strain"}, "1422218": {"name": "Staphylococcus aureus DAR1090", "rank": "Strain"}, "1422482": {"name": "Staphylococcus aureus VET0179R", "rank": "Strain"}, "1422483": {"name": "Staphylococcus aureus VET0180R", "rank": "Strain"}, "1438788": {"name": "Klebsiella pneumoniae MGH 65", "rank": "Strain"}, "1438789": {"name": "Klebsiella pneumoniae MGH 66", "rank": "Strain"}, "1438784": {"name": "Klebsiella pneumoniae MGH 59", "rank": "Strain"}, "1338015": {"name": "Elizabethkingia anophelis NUH4", "rank": "Strain"}, "1438786": {"name": "Klebsiella pneumoniae MGH 63", "rank": "Strain"}, "1438787": {"name": "Klebsiella pneumoniae MGH 64", "rank": "Strain"}, "1438780": {"name": "Klebsiella pneumoniae CHS 76", "rank": "Strain"}, "1438781": {"name": "Klebsiella pneumoniae CHS 80", "rank": "Strain"}, "1438782": {"name": "Klebsiella pneumoniae MGH 51", "rank": "Strain"}, "1422485": {"name": "Staphylococcus aureus VET0184R", "rank": "Strain"}, "498740": {"name": "Borrelia burgdorferi 64b", "rank": "Strain"}, "498741": {"name": "Borrelia sp. SV1", "rank": "Species"}, "498742": {"name": "Borrelia spielmanii A14S", "rank": "Strain"}, "1246459": {"name": "Rhizobium sp. 2MFCol3.1", "rank": "Species"}, "928723": {"name": "Sinorhizobium meliloti BO21CC", "rank": "Strain"}, "1448564": {"name": "Mycobacterium tuberculosis TKK_04_0095", "rank": "Strain"}, "877240": {"name": "Pseudoalteromonas phage H105/1", "rank": "Species"}, "1468172": {"name": "Gaillardia latent virus", "rank": "Species"}, "421531": {"name": "Chryseobacterium luteum", "rank": "Species"}, "1380110": {"name": "Bacillus sp. RP1137", "rank": "Species"}, "1538075": {"name": "Malasseziomycetes", "rank": "Class"}, "525318": {"name": "Lactobacillus buchneri ATCC 11577", "rank": "Strain"}, "172049": {"name": "Thermococcus sibiricus", "rank": "Species"}, "172045": {"name": "Elizabethkingia miricola", "rank": "Species"}, "525310": {"name": "Lactobacillus brevis subsp. gravesensis ATCC 27305", "rank": "Strain"}, "172042": {"name": "Rothia aeria", "rank": "Species"}, "172043": {"name": "Brevundimonas nasdae", "rank": "Species"}, "36820": {"name": "Gordonia aichiensis", "rank": "Species"}, "36821": {"name": "Gordonia amarae", "rank": "Species"}, "36822": {"name": "Gordonia rubripertincta", "rank": "Species"}, "36823": {"name": "Gordonia sputi", "rank": "Species"}, "36826": {"name": "Clostridium botulinum A", "rank": "Strain"}, "36827": {"name": "Clostridium botulinum B", "rank": "Strain"}, "36828": {"name": "Clostridium botulinum C", "rank": "Strain"}, "36829": {"name": "Clostridium botulinum D", "rank": "Strain"}, "1138938": {"name": "Enterococcus faecium EnGen0376", "rank": "Strain"}, "1138939": {"name": "Enterococcus faecium EnGen0377", "rank": "Strain"}, "1138934": {"name": "Enterococcus faecium EnGen0057", "rank": "Strain"}, "1138935": {"name": "Enterococcus faecium EnGen0045", "rank": "Strain"}, "1138936": {"name": "Enterococcus faecium EnGen0049", "rank": "Strain"}, "1138937": {"name": "Enterococcus faecium EnGen0375", "rank": "Strain"}, "1138930": {"name": "Enterococcus faecium EnGen0054", "rank": "Strain"}, "1138931": {"name": "Enterococcus faecium EnGen0051", "rank": "Strain"}, "1138932": {"name": "Enterococcus faecium EnGen0050", "rank": "Strain"}, "1138933": {"name": "Enterococcus faecium EnGen0046", "rank": "Strain"}, "1147149": {"name": "Enterobacteria phage mEp043 c-1", "rank": "Species"}, "1147148": {"name": "Enterobacteria phage HK629", "rank": "Species"}, "1147147": {"name": "Enterobacteria phage HK633", "rank": "Species"}, "1147146": {"name": "Enterobacteria phage HK630", "rank": "Species"}, "1147145": {"name": "Enterobacteria phage HK446", "rank": "Species"}, "1147144": {"name": "Enterobacteria phage HK225", "rank": "Species"}, "1147143": {"name": "Enterobacteria phage HK140", "rank": "Species"}, "1147142": {"name": "Enterobacteria phage HK578", "rank": "Species"}, "1147140": {"name": "Salmonella phage SPN3UB", "rank": "Species"}, "1300067": {"name": "Flammulina velutipes KACC42780", "rank": "Strain"}, "797210": {"name": "Halopiger xanaduensis SH-6", "rank": "Strain"}, "721123": {"name": "Microcystis aeruginosa PCC 9701", "rank": "Strain"}, "1417296": {"name": "Defluviimonas sp. 20V17", "rank": "Species"}, "875330": {"name": "Pseudomonas syringae pv. glycinea str. race 4", "rank": "Strain"}, "555793": {"name": "Novosphingobium sp. Rr 2-17", "rank": "Species"}, "34398": {"name": "Mitosporic Clavicipitaceae", "rank": "No rank"}, "290174": {"name": "Aquimarina", "rank": "Genus"}, "67297": {"name": "Streptomyces flaveolus", "rank": "Species"}, "34395": {"name": "Chaetothyriales", "rank": "Order"}, "34397": {"name": "Clavicipitaceae", "rank": "Family"}, "34392": {"name": "Microsporum", "rank": "Genus"}, "1439000": {"name": "Streptococcus pyogenes ABC020009156", "rank": "Strain"}, "211469": {"name": "Kineosphaera", "rank": "Genus"}, "1439001": {"name": "Streptococcus pyogenes ABC020010041", "rank": "Strain"}, "309805": {"name": "Persephonella marina", "rank": "Species"}, "309806": {"name": "Sulfurihydrogenibium azorense", "rank": "Species"}, "309807": {"name": "Salinibacter ruber DSM 13855", "rank": "Strain"}, "1352929": {"name": "Frankia sp. CcI6", "rank": "Species"}, "656190": {"name": "Carrot yellow leaf virus", "rank": "Species"}, "627611": {"name": "Vibrio parahaemolyticus K5030", "rank": "Strain"}, "204090": {"name": "Staphylococcus phage P68", "rank": "Species"}, "1227814": {"name": "Escherichia coli O08", "rank": "Strain"}, "1331269": {"name": "Bordetella pertussis STO1-SEAT-0004", "rank": "Strain"}, "1263836": {"name": "Thermotoga sp. TBGT1765", "rank": "Species"}, "1331268": {"name": "Bordetella pertussis H973", "rank": "Strain"}, "247333": {"name": "Serinicoccus marinus", "rank": "Species"}, "673860": {"name": "Aciduliprofundum sp. MAR08-339", "rank": "Species"}, "673862": {"name": "Candidatus Babela massiliensis", "rank": "Species"}, "985052": {"name": "Vulcanisaeta moutnovskia", "rank": "Species"}, "1126211": {"name": "Bacillus amyloliquefaciens Y2", "rank": "Strain"}, "1331265": {"name": "Bordetella pertussis H918", "rank": "Strain"}, "1331264": {"name": "Bordetella pertussis H897", "rank": "Strain"}, "1331267": {"name": "Bordetella pertussis H939", "rank": "Strain"}, "1331266": {"name": "Bordetella pertussis H921", "rank": "Strain"}, "999611": {"name": "Leisingera aquimarina DSM 24565", "rank": "Strain"}, "1331261": {"name": "Bordetella hinzii L60", "rank": "Strain"}, "1331260": {"name": "Bordetella bronchiseptica F-1", "rank": "Strain"}, "1331263": {"name": "Bordetella pertussis STO1-CHLA-0011", "rank": "Strain"}, "1182183": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN000954", "rank": "Strain"}, "45248": {"name": "Leucothrix mucor", "rank": "Species"}, "45247": {"name": "Leucothrix", "rank": "Genus"}, "45242": {"name": "Capnocytophaga granulosa", "rank": "Species"}, "293644": {"name": "Salmonella phage SS3e", "rank": "Species"}, "626962": {"name": "Olive latent virus 3", "rank": "Species"}, "1265507": {"name": "Succinimonas amylolytica DSM 2873", "rank": "Strain"}, "1265504": {"name": "Curvibacter lanceolatus ATCC 14669", "rank": "Strain"}, "1265505": {"name": "Desulfospira joergensenii DSM 10085", "rank": "Strain"}, "1265502": {"name": "Caldimonas manganoxidans ATCC BAA-369", "rank": "Strain"}, "1265503": {"name": "Colwellia piezophila ATCC BAA-637", "rank": "Strain"}, "1265501": {"name": "Firmicutes bacterium JGI 0000119-P10", "rank": "Species"}, "1144281": {"name": "Rickettsia sibirica subsp. sibirica", "rank": "Subspecies"}, "1144280": {"name": "Rickettsia sibirica subsp. mongolitimonae HA-91", "rank": "Strain"}, "1265508": {"name": "Candidatus Ancillula", "rank": "Genus"}, "1265509": {"name": "Candidatus Ancillula trichonymphae", "rank": "Species"}, "1197325": {"name": "Mycoplasma wenyonii str. Massachusetts", "rank": "Strain"}, "292208": {"name": "Dendrolimus punctatus densovirus", "rank": "Strain"}, "995022": {"name": "Simian adenovirus 49", "rank": "Strain"}, "84086": {"name": "Unclassified Firmicutes sensu stricto (miscellaneous)", "rank": "No rank"}, "940265": {"name": "Acetobacter pasteurianus subsp. pasteurianus LMG 1262 = NBRC 106471", "rank": "Strain"}, "1074061": {"name": "Streptococcus sobrinus TCI-77", "rank": "Strain"}, "1378072": {"name": "Serratia fonticola LMG 7882", "rank": "Strain"}, "1074063": {"name": "Streptococcus sobrinus TCI-80", "rank": "Strain"}, "1074062": {"name": "Streptococcus sobrinus TCI-79", "rank": "Strain"}, "1074064": {"name": "Streptococcus sobrinus TCI-89", "rank": "Strain"}, "1074067": {"name": "Streptococcus sobrinus TCI-119", "rank": "Strain"}, "1074066": {"name": "Streptococcus sobrinus TCI-107", "rank": "Strain"}, "1074069": {"name": "Streptococcus sobrinus TCI-124", "rank": "Strain"}, "573054": {"name": "Ampullavirus", "rank": "Genus"}, "313603": {"name": "Maribacter sp. HTCC2170", "rank": "Species"}, "665550": {"name": "Dietzia alimentaria", "rank": "Species"}, "578134": {"name": "Mouse parvovirus 4", "rank": "Species"}, "1269334": {"name": "Rickettsia monacensis IrR/Munich", "rank": "Strain"}, "1130332": {"name": "Calescamantes bacterium JGI 0000106-I5", "rank": "Species"}, "1130333": {"name": "Calescamantes bacterium JGI 0000106-J16", "rank": "Species"}, "1130330": {"name": "Calescamantes bacterium JGI 0000106-H18", "rank": "Species"}, "1130331": {"name": "Calescamantes bacterium JGI 0000106-I17", "rank": "Species"}, "1130336": {"name": "Calescamantes bacterium JGI 0000106-N7", "rank": "Species"}, "1130337": {"name": "Calescamantes bacterium JGI 0000106-P5", "rank": "Species"}, "1130334": {"name": "Calescamantes bacterium JGI 0000106-M22", "rank": "Species"}, "1130335": {"name": "Calescamantes bacterium JGI 0000106-N5", "rank": "Species"}, "1411600": {"name": "Staphylococcus aureus W85432", "rank": "Strain"}, "1411601": {"name": "Staphylococcus aureus W85440", "rank": "Strain"}, "1411602": {"name": "Staphylococcus aureus W88551", "rank": "Strain"}, "1411603": {"name": "Staphylococcus aureus W88555", "rank": "Strain"}, "1411604": {"name": "Staphylococcus aureus W91963", "rank": "Strain"}, "38313": {"name": "Shewanella algae", "rank": "Species"}, "1264675": {"name": "Ralstonia pickettii OR214", "rank": "Strain"}, "1145158": {"name": "Neisseria meningitidis 73704", "rank": "Strain"}, "1145159": {"name": "Neisseria meningitidis 81858", "rank": "Strain"}, "1145156": {"name": "Neisseria meningitidis NM1495", "rank": "Strain"}, "1145157": {"name": "Neisseria meningitidis 73696", "rank": "Strain"}, "1145154": {"name": "Neisseria meningitidis NM313", "rank": "Strain"}, "1145155": {"name": "Neisseria meningitidis NM1482", "rank": "Strain"}, "1145152": {"name": "Neisseria meningitidis NM94", "rank": "Strain"}, "1145153": {"name": "Neisseria meningitidis NM95", "rank": "Strain"}, "1145150": {"name": "Neisseria meningitidis NM43", "rank": "Strain"}, "1145151": {"name": "Neisseria meningitidis NM82", "rank": "Strain"}, "930945": {"name": "Sulfolobus islandicus REY15A", "rank": "Strain"}, "1388498": {"name": "Staphylococcus aureus M0737", "rank": "Strain"}, "1388499": {"name": "Staphylococcus aureus M0739", "rank": "Strain"}, "1388496": {"name": "Staphylococcus aureus M0734", "rank": "Strain"}, "1388497": {"name": "Staphylococcus aureus M0736", "rank": "Strain"}, "1388494": {"name": "Staphylococcus aureus M0732", "rank": "Strain"}, "1408418": {"name": "Acidiphilium angustum ATCC 35903", "rank": "Strain"}, "1388492": {"name": "Staphylococcus aureus M0730", "rank": "Strain"}, "1388493": {"name": "Staphylococcus aureus M0731", "rank": "Strain"}, "1388490": {"name": "Staphylococcus aureus M0728", "rank": "Strain"}, "1388491": {"name": "Staphylococcus aureus M0729", "rank": "Strain"}, "473783": {"name": "Unclassified Umbravirus", "rank": "No rank"}, "1114856": {"name": "Natronorubrum tibetense GA33", "rank": "Strain"}, "473788": {"name": "Nitrosococcus oceani AFC27", "rank": "Strain"}, "393029": {"name": "Desulfurispirillum", "rank": "Genus"}, "1388586": {"name": "Staphylococcus aureus M0798", "rank": "Strain"}, "1567404": {"name": "Fako virus", "rank": "Species"}, "1388587": {"name": "Staphylococcus aureus M0800", "rank": "Strain"}, "1567403": {"name": "Unclassified Dinovernavirus", "rank": "No rank"}, "1395586": {"name": "Paenibacillus sp. MAEPY1", "rank": "Species"}, "190811": {"name": "Bamboo mosaic virus satellite RNA", "rank": "Species"}, "115232": {"name": "Zea mosaic virus", "rank": "Species"}, "451373": {"name": "Rudanella", "rank": "Genus"}, "190818": {"name": "Geoglobus", "rank": "Genus"}, "932213": {"name": "Serratia sp. M24T3", "rank": "Species"}, "664683": {"name": "Halomonas titanicae", "rank": "Species"}, "1099853": {"name": "Coprobacter fastidiosus", "rank": "Species"}, "1438686": {"name": "Escherichia coli CHS 77", "rank": "Strain"}, "451374": {"name": "Rudanella lutea", "rank": "Species"}, "1288347": {"name": "Citrobacter freundii GTC 09479", "rank": "Strain"}, "421976": {"name": "Curvularia thermal tolerance virus", "rank": "Species"}, "1195071": {"name": "Staphylococcus phage StauST398-3", "rank": "Species"}, "1195072": {"name": "Bacillus phage vB_BceM-Bc431v3", "rank": "Species"}, "1195073": {"name": "Burkholderia phage BcepMigl", "rank": "Species"}, "183710": {"name": "Deinococcaceae", "rank": "Family"}, "1548": {"name": "Clostridium scatologenes", "rank": "Species"}, "1549": {"name": "Clostridium sporosphaeroides", "rank": "Species"}, "1547": {"name": "Erysipelatoclostridium ramosum", "rank": "Species"}, "1542": {"name": "Clostridium novyi", "rank": "Species"}, "2422": {"name": "Fervidobacterium", "rank": "Genus"}, "1540": {"name": "Clostridium mangenotii", "rank": "Species"}, "935296": {"name": "Enterobacter aerogenes EA1509E", "rank": "Strain"}, "935297": {"name": "Vibrio cholerae LMA3984-4", "rank": "Strain"}, "935298": {"name": "Corynebacterium pseudotuberculosis PAT10", "rank": "Strain"}, "561999": {"name": "Mycobacterium phage Troll4", "rank": "Species"}, "1029980": {"name": "Salmonella enterica subsp. enterica serovar Kentucky str. 5349", "rank": "Strain"}, "1029982": {"name": "Salmonella enterica subsp. enterica serovar Tallahassee str. 0012", "rank": "Strain"}, "1029983": {"name": "Salmonella enterica subsp. enterica serovar Abony str. 0014", "rank": "Strain"}, "1029984": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. SARB17", "rank": "Strain"}, "1239439": {"name": "Avastrovirus 3", "rank": "Species"}, "1029988": {"name": "Erwinia phage phiEaH2", "rank": "Species"}, "1029989": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 0292", "rank": "Strain"}, "48981": {"name": "Drosophila x virus", "rank": "Species"}, "1402531": {"name": "Pseudomonas aeruginosa BWHPSA039", "rank": "Strain"}, "118004": {"name": "Chrysiogenes", "rank": "Genus"}, "118005": {"name": "Chrysiogenes arsenatis DSM 11915", "rank": "Strain"}, "546184": {"name": "Mycobacterium phage Phaedrus", "rank": "Species"}, "546185": {"name": "Mycobacterium phage Porky", "rank": "Species"}, "118000": {"name": "Denitrovibrio acetiphilus", "rank": "Species"}, "546183": {"name": "Mycobacterium phage Kostya", "rank": "Species"}, "237609": {"name": "Pseudomonas alkylphenolia", "rank": "Species"}, "1569353": {"name": "Phaeobacter sp. S60", "rank": "Species"}, "1569354": {"name": "Phaeobacter sp. S26", "rank": "Species"}, "388051": {"name": "Cupriavidus sp. amp6", "rank": "Species"}, "1281143": {"name": "Escherichia coli HVH 216 (4-3042952)", "rank": "Strain"}, "72358": {"name": "Trachipleistophora", "rank": "Genus"}, "72359": {"name": "Trachipleistophora hominis", "rank": "Species"}, "457412": {"name": "Ruminococcus sp. 5_1_39BFAA", "rank": "Species"}, "457415": {"name": "Synergistes sp. 3_1_syn1", "rank": "Species"}, "46238": {"name": "Entomoplasma", "rank": "Genus"}, "543876": {"name": "Jatropha leaf curl virus", "rank": "Species"}, "307456": {"name": "Autographa californica multiple nucleopolyhedrovirus", "rank": "Species"}, "1406314": {"name": "Klebsiella pneumoniae subsp. pneumoniae PittNDM01", "rank": "Strain"}, "367737": {"name": "Arcobacter butzleri RM4018", "rank": "Strain"}, "1333570": {"name": "Streptococcus agalactiae MC625", "rank": "Strain"}, "714313": {"name": "Lactobacillus sanfranciscensis TMW 1.1304", "rank": "Strain"}, "714310": {"name": "Bean yellow mosaic Mexico virus", "rank": "Species"}, "356544": {"name": "Salmonella enterica subsp. enterica serovar Tallahassee", "rank": "Strain"}, "714315": {"name": "Leptotrichia goodfellowii DSM 19756", "rank": "Strain"}, "1534978": {"name": "Pseudomonas sp. YS-1p", "rank": "Species"}, "532078": {"name": "Yersinia phage Yepe2", "rank": "Species"}, "532075": {"name": "Enterobacteria phage EcoDS1", "rank": "Species"}, "532074": {"name": "Enterobacteria phage BA14", "rank": "Species"}, "532077": {"name": "Klebsiella phage K11", "rank": "Species"}, "532076": {"name": "Enterobacteria phage 13a", "rank": "Species"}, "1354149": {"name": "Mycobacterium tuberculosis MAL010105", "rank": "Strain"}, "1266765": {"name": "Geobacter sp. OR-1", "rank": "Species"}, "981426": {"name": "Frankia sp. Thr", "rank": "Species"}, "1354148": {"name": "Mycobacterium tuberculosis MAL010103", "rank": "Strain"}, "1476424": {"name": "Arenitalea", "rank": "Genus"}, "584": {"name": "Proteus mirabilis", "rank": "Species"}, "585": {"name": "Proteus vulgaris", "rank": "Species"}, "586": {"name": "Providencia", "rank": "Genus"}, "587": {"name": "Providencia rettgeri", "rank": "Species"}, "12138": {"name": "Maize chlorotic mottle virus", "rank": "Species"}, "12139": {"name": "Southern bean mosaic virus", "rank": "Species"}, "582": {"name": "Morganella morganii", "rank": "Species"}, "1041149": {"name": "Sinorhizobium medicae WSM1369", "rank": "Strain"}, "1097466": {"name": "Defluviimonas", "rank": "Genus"}, "1041147": {"name": "Rhizobium leucaenae USDA 9039", "rank": "Strain"}, "12136": {"name": "Cricket paralysis virus", "rank": "Species"}, "12137": {"name": "Sobemovirus", "rank": "Genus"}, "1041142": {"name": "Rhizobium leguminosarum bv. viciae GB30", "rank": "Strain"}, "1041143": {"name": "Rhizobium leguminosarum bv. viciae UPM1131", "rank": "Strain"}, "1041140": {"name": "Rhizobium leguminosarum bv. phaseoli FA23", "rank": "Strain"}, "1041141": {"name": "Rhizobium leguminosarum bv. viciae 128C53", "rank": "Strain"}, "1422343": {"name": "Staphylococcus aureus DAR5831", "rank": "Strain"}, "1422342": {"name": "Staphylococcus aureus DAR5832", "rank": "Strain"}, "59506": {"name": "Staphylococcus phage 85", "rank": "Strain"}, "1422340": {"name": "Staphylococcus aureus DAR5834", "rank": "Strain"}, "600332": {"name": "Zavarzinella", "rank": "Genus"}, "1422346": {"name": "Staphylococcus aureus DAR5828", "rank": "Strain"}, "1422345": {"name": "Staphylococcus aureus DAR5829", "rank": "Strain"}, "1422344": {"name": "Staphylococcus aureus DAR5830", "rank": "Strain"}, "1422349": {"name": "Staphylococcus aureus DAR5825", "rank": "Strain"}, "1422348": {"name": "Staphylococcus aureus DAR5826", "rank": "Strain"}, "59509": {"name": "Lumpy skin disease virus", "rank": "Species"}, "638632": {"name": "Komagataella pastoris DSMZ 70382", "rank": "Strain"}, "45764": {"name": "Mycobacterium phage DS6A", "rank": "Species"}, "695560": {"name": "Lactobacillus amylovorus GRL 1112", "rank": "Strain"}, "545431": {"name": "Yersinia pestis Pestoides A", "rank": "Strain"}, "695562": {"name": "Lactobacillus amylovorus GRL1118", "rank": "Strain"}, "1218489": {"name": "Lambdatorquevirus", "rank": "Genus"}, "1218488": {"name": "Torque teno sus virus k2", "rank": "Species"}, "1218487": {"name": "Kappatorquevirus", "rank": "Genus"}, "418136": {"name": "Francisella tularensis subsp. tularensis WY96-3418", "rank": "Strain"}, "224578": {"name": "Barley yellow dwarf virus-GAV", "rank": "Species"}, "1422779": {"name": "Staphylococcus aureus VET1103S", "rank": "Strain"}, "221126": {"name": "Algibacter lectus", "rank": "Species"}, "1158598": {"name": "Enterococcus mundtii ATCC 882", "rank": "Strain"}, "1280705": {"name": "Prevotella bryantii C21a", "rank": "Strain"}, "1280704": {"name": "Streptococcus equinus SN033", "rank": "Strain"}, "1280706": {"name": "Selenomonas ruminantium subsp. ruminantium ATCC 12561", "rank": "Strain"}, "1280701": {"name": "Bifidobacterium pseudolongum AGR2145", "rank": "Strain"}, "1280700": {"name": "Butyrivibrio fibrisolvens FE2007", "rank": "Strain"}, "1280703": {"name": "Butyrivibrio fibrisolvens MD2001", "rank": "Strain"}, "1280702": {"name": "Bifidobacterium longum AGR2137", "rank": "Strain"}, "504501": {"name": "Propionibacterium phage PAD20", "rank": "Species"}, "1246955": {"name": "Mycoplasma cynos C142", "rank": "Strain"}, "1076255": {"name": "Yoka poxvirus", "rank": "Species"}, "639030": {"name": "Acidobacteria bacterium KBS 146", "rank": "Species"}, "862259": {"name": "Mycoplasma mycoides subsp. capri LC str. 95010", "rank": "Strain"}, "1129895": {"name": "Brevibacillus brevis FJAT-0809-GLX", "rank": "Strain"}, "1129896": {"name": "Rhodococcus opacus M213", "rank": "Strain"}, "1331671": {"name": "Pseudomonas putida H8234", "rank": "Strain"}, "91359": {"name": "Enterovibrio calviensis", "rank": "Species"}, "1388029": {"name": "Staphylococcus aureus M0062", "rank": "Strain"}, "1388028": {"name": "Staphylococcus aureus M0061", "rank": "Strain"}, "1409548": {"name": "Staphylococcus aureus COAS6020", "rank": "Strain"}, "1409549": {"name": "Staphylococcus aureus HOAG6042", "rank": "Strain"}, "1255765": {"name": "Tomato yellow leaf curl China betasatellite", "rank": "Species"}, "1427374": {"name": "Streptococcus agalactiae CNCTC 10/84", "rank": "Strain"}, "1409542": {"name": "Staphylococcus aureus PLAC6004", "rank": "Strain"}, "1409543": {"name": "Staphylococcus aureus SCLE6011", "rank": "Strain"}, "1409540": {"name": "Staphylococcus aureus OCMM6017", "rank": "Strain"}, "1409541": {"name": "Staphylococcus aureus SCLE6012", "rank": "Strain"}, "1409546": {"name": "Staphylococcus aureus UCIM6034", "rank": "Strain"}, "1409547": {"name": "Staphylococcus aureus MISS6027", "rank": "Strain"}, "1409544": {"name": "Staphylococcus aureus SMMC6014", "rank": "Strain"}, "1409545": {"name": "Staphylococcus aureus SMMC6011", "rank": "Strain"}, "1422695": {"name": "Staphylococcus aureus VET1834R", "rank": "Strain"}, "1422694": {"name": "Staphylococcus aureus VET1833R", "rank": "Strain"}, "1422697": {"name": "Staphylococcus aureus VET1838R", "rank": "Strain"}, "1422696": {"name": "Staphylococcus aureus VET1835R", "rank": "Strain"}, "1422691": {"name": "Staphylococcus aureus VET0596R", "rank": "Strain"}, "1422690": {"name": "Staphylococcus aureus VET0489R", "rank": "Strain"}, "1422693": {"name": "Staphylococcus aureus VET1832R", "rank": "Strain"}, "1422692": {"name": "Staphylococcus aureus VET1831R", "rank": "Strain"}, "1388023": {"name": "Staphylococcus aureus M0052", "rank": "Strain"}, "311982": {"name": "Streptomyces hygroscopicus subsp. jinggangensis", "rank": "Subspecies"}, "1422699": {"name": "Staphylococcus aureus VET1842R", "rank": "Strain"}, "1422698": {"name": "Staphylococcus aureus VET1839R", "rank": "Strain"}, "1388022": {"name": "Staphylococcus aureus M0051", "rank": "Strain"}, "1095770": {"name": "Peptoniphilus timonensis JC401", "rank": "Strain"}, "173559": {"name": "Gordonia sihwensis", "rank": "Species"}, "1117645": {"name": "Elizabethkingia anophelis", "rank": "Species"}, "332054": {"name": "Trichoplusia ni single nucleopolyhedrovirus", "rank": "Species"}, "1117647": {"name": "Simiduia agarivorans SA1 = DSM 21679", "rank": "Strain"}, "1117646": {"name": "Elizabethkingia anophelis Ag1", "rank": "Strain"}, "67275": {"name": "Streptomyces aureocirculatus", "rank": "Species"}, "1346778": {"name": "Mycobacterium tuberculosis PanR0315", "rank": "Strain"}, "1302625": {"name": "Listeria monocytogenes SHL005", "rank": "Strain"}, "108150": {"name": "Thermoanaerobacter italicus", "rank": "Species"}, "1095771": {"name": "Ruminococcus sp. JC304", "rank": "Species"}, "1071783": {"name": "Chlamydia trachomatis L3/404/LN", "rank": "Strain"}, "1122125": {"name": "Inquilinus limosus DSM 16000", "rank": "Strain"}, "1071781": {"name": "Chlamydia trachomatis L2b/Ams4", "rank": "Strain"}, "1071780": {"name": "Chlamydia trachomatis L2b/Ams3", "rank": "Strain"}, "1122128": {"name": "Jeotgalicoccus marinus DSM 19772", "rank": "Strain"}, "1122129": {"name": "Jeotgalicoccus psychrophilus DSM 19085", "rank": "Strain"}, "1302629": {"name": "Listeria monocytogenes SHL009", "rank": "Strain"}, "392413": {"name": "Deinococcus misasensis", "rank": "Species"}, "1302628": {"name": "Listeria monocytogenes SHL008", "rank": "Strain"}, "1248420": {"name": "Streptococcus intermedius BA1", "rank": "Strain"}, "911241": {"name": "Pseudomonas sp. CF161", "rank": "Species"}, "1346770": {"name": "Mycobacterium tuberculosis PanR0407", "rank": "Strain"}, "122355": {"name": "Pseudomonas psychrophila", "rank": "Species"}, "223252": {"name": "Cotton leaf curl Multan virus", "rank": "Species"}, "1358411": {"name": "Pantoea dispersa EGD-AAK13", "rank": "Strain"}, "911242": {"name": "Pseudomonas sp. CFII64", "rank": "Species"}, "135461": {"name": "Bacillus subtilis subsp. subtilis", "rank": "Subspecies"}, "223259": {"name": "Cotton leaf curl Rajasthan virus", "rank": "Species"}, "1412803": {"name": "Staphylococcus aureus W33592", "rank": "Strain"}, "1412802": {"name": "Staphylococcus aureus W33578", "rank": "Strain"}, "1412801": {"name": "Staphylococcus aureus W33563", "rank": "Strain"}, "1412800": {"name": "Staphylococcus aureus W29651", "rank": "Strain"}, "1412807": {"name": "Staphylococcus aureus W39826", "rank": "Strain"}, "1412806": {"name": "Staphylococcus aureus W39821", "rank": "Strain"}, "1412805": {"name": "Staphylococcus aureus W36570", "rank": "Strain"}, "1412804": {"name": "Staphylococcus aureus W36553", "rank": "Strain"}, "1412809": {"name": "Staphylococcus aureus W46883", "rank": "Strain"}, "1042326": {"name": "Rhizobium sp. IBUN", "rank": "Species"}, "1286631": {"name": "Sphaerotilus natans subsp. natans DSM 6575", "rank": "Strain"}, "1286630": {"name": "Brucella melitensis M5", "rank": "Strain"}, "1042322": {"name": "Demequinaceae", "rank": "Family"}, "13373": {"name": "Burkholderia mallei", "rank": "Species"}, "76859": {"name": "Fusobacterium nucleatum subsp. animalis", "rank": "Subspecies"}, "1089120": {"name": "Mycobacterium phage DeadP", "rank": "Species"}, "748671": {"name": "Lactobacillus crispatus ST1", "rank": "Strain"}, "1328863": {"name": "Lactobacillus crispatus EM-LC1", "rank": "Strain"}, "1154865": {"name": "Streptococcus agalactiae MRI Z1-023", "rank": "Strain"}, "1328869": {"name": "Enterococcus faecium UC7267", "rank": "Strain"}, "1089129": {"name": "Mycobacterium phage LHTSCC", "rank": "Species"}, "1154866": {"name": "Streptococcus agalactiae MRI Z1-024", "rank": "Strain"}, "1423524": {"name": "Mycobacterium tuberculosis BTB10-305", "rank": "Strain"}, "1423525": {"name": "Mycobacterium tuberculosis BTB10-308", "rank": "Strain"}, "1423526": {"name": "Mycobacterium tuberculosis BTB10-357", "rank": "Strain"}, "1423527": {"name": "Mycobacterium tuberculosis BTB10-367", "rank": "Strain"}, "1423520": {"name": "Mycobacterium tuberculosis BTB10-257", "rank": "Strain"}, "55505": {"name": "Thermonema rossianum", "rank": "Species"}, "1423522": {"name": "Mycobacterium tuberculosis BTB10-277", "rank": "Strain"}, "1423523": {"name": "Mycobacterium tuberculosis BTB10-295", "rank": "Strain"}, "55508": {"name": "Janthinobacterium agaricidamnosum", "rank": "Species"}, "1281144": {"name": "Escherichia coli HVH 217 (4-1022806)", "rank": "Strain"}, "1423528": {"name": "Mycobacterium tuberculosis BTB10-406", "rank": "Strain"}, "1423529": {"name": "Mycobacterium tuberculosis BTB10-422", "rank": "Strain"}, "1281145": {"name": "Escherichia coli HVH 218 (4-4500903)", "rank": "Strain"}, "1345507": {"name": "Helicobacter pylori SA30C", "rank": "Strain"}, "1345506": {"name": "Helicobacter pylori SA30A", "rank": "Strain"}, "1345505": {"name": "Helicobacter pylori SA29C", "rank": "Strain"}, "591206": {"name": "Roseivivax isoporae", "rank": "Species"}, "1154862": {"name": "Streptococcus agalactiae CCUG 34230", "rank": "Strain"}, "1281147": {"name": "Escherichia coli HVH 221 (4-3136817)", "rank": "Strain"}, "1345509": {"name": "Helicobacter pylori SA221C", "rank": "Strain"}, "1345508": {"name": "Helicobacter pylori SA221A", "rank": "Strain"}, "1001229": {"name": "Bacillus thuringiensis serovar chinensis", "rank": "Strain"}, "1410638": {"name": "Ruminococcaceae bacterium AB4001", "rank": "Species"}, "202954": {"name": "Acinetobacter tandoii", "rank": "Species"}, "202955": {"name": "Acinetobacter tjernbergiae", "rank": "Species"}, "1287276": {"name": "Mesorhizobium sp. LNJC398B00", "rank": "Species"}, "155978": {"name": "Acaryochloris marina", "rank": "Species"}, "202950": {"name": "Acinetobacter baylyi", "rank": "Species"}, "202951": {"name": "Acinetobacter bouvetii", "rank": "Species"}, "202952": {"name": "Acinetobacter gerneri", "rank": "Species"}, "1287273": {"name": "Mesorhizobium sp. LNJC391B00", "rank": "Species"}, "391038": {"name": "Burkholderia phymatum STM815", "rank": "Strain"}, "155977": {"name": "Acaryochloris", "rank": "Genus"}, "155975": {"name": "Actinokineospora enzanensis", "rank": "Species"}, "485362": {"name": "Francolinus leucoscepus papillomavirus 1", "rank": "Strain"}, "12960": {"name": "Azoarcus", "rank": "Genus"}, "1134787": {"name": "Enterococcus faecalis ERV129", "rank": "Strain"}, "1398952": {"name": "Acinetobacter baumannii UH12308", "rank": "Strain"}, "1134785": {"name": "Enterococcus faecalis ERV103", "rank": "Strain"}, "1134784": {"name": "Enterococcus faecalis 599", "rank": "Strain"}, "1134782": {"name": "Escherichia coli O104:H4 str. 2009EL-2050", "rank": "Strain"}, "1158155": {"name": "Thioalkalivibrio sp. AKL7", "rank": "Species"}, "43773": {"name": "Syntrophus", "rank": "Genus"}, "1134789": {"name": "Enterococcus faecalis ERV31", "rank": "Strain"}, "1134788": {"name": "Enterococcus faecalis ERV25", "rank": "Strain"}, "402777": {"name": "Kamptonema formosum PCC 6407", "rank": "Strain"}, "1177758": {"name": "Chipapillomavirus 1", "rank": "Species"}, "1158153": {"name": "Thioalkalivibrio sp. AKL3", "rank": "Species"}, "380669": {"name": "Dracaena mottle virus", "rank": "Species"}, "186931": {"name": "Thioalkalivibrio nitratireducens", "rank": "Species"}, "1409765": {"name": "Staphylococcus aureus DAR5844", "rank": "Strain"}, "1409762": {"name": "Staphylococcus aureus DAR5876", "rank": "Strain"}, "1158159": {"name": "Thioalkalivibrio sp. AKL12", "rank": "Species"}, "29292": {"name": "Pyrococcus abyssi", "rank": "Species"}, "29291": {"name": "Methanococcoides burtonii", "rank": "Species"}, "1409760": {"name": "Staphylococcus aureus DAR5882", "rank": "Strain"}, "29294": {"name": "Unclassified Archaea", "rank": "No rank"}, "745022": {"name": "Salmonella enterica subsp. enterica serovar Montevideo str. 531954", "rank": "Strain"}, "745023": {"name": "Vibrio parahaemolyticus 10329", "rank": "Strain"}, "745020": {"name": "Salmonella enterica subsp. enterica serovar Montevideo str. 515920-1", "rank": "Strain"}, "745021": {"name": "Salmonella enterica subsp. enterica serovar Montevideo str. 515920-2", "rank": "Strain"}, "451834": {"name": "Early diverging fungal lineages", "rank": "No rank"}, "439855": {"name": "Escherichia coli SMS-3-5", "rank": "Strain"}, "246343": {"name": "Turkey astrovirus 2", "rank": "Strain"}, "643453": {"name": "Xanthomonas citri group", "rank": "Species group"}, "1422438": {"name": "Staphylococcus aureus VET0110R", "rank": "Strain"}, "1295359": {"name": "Pyrenochaeta sp. UM 256", "rank": "Species"}, "364710": {"name": "Endocarpon", "rank": "Genus"}, "232721": {"name": "Acidovorax sp. JS42", "rank": "Species"}, "1415763": {"name": "Streptococcus pneumoniae 1719", "rank": "Strain"}, "1415762": {"name": "Streptococcus pneumoniae 13856", "rank": "Strain"}, "1415761": {"name": "Streptococcus pseudopneumoniae 5247", "rank": "Strain"}, "1415760": {"name": "Streptococcus pseudopneumoniae 1321", "rank": "Strain"}, "1447715": {"name": "Bifidobacterium pseudolongum PV8-2", "rank": "Strain"}, "1415766": {"name": "Streptococcus mitis 27/7", "rank": "Strain"}, "1415765": {"name": "Streptococcus mitis 21/39", "rank": "Strain"}, "1447716": {"name": "Bifidobacterium kashiwanohense PV20-2", "rank": "Strain"}, "570935": {"name": "Salmonella enterica subsp. enterica serovar Pomona", "rank": "Strain"}, "10455": {"name": "Spodoptera frugiperda multiple nucleopolyhedrovirus", "rank": "Species"}, "10454": {"name": "Spodoptera exigua multiple nucleopolyhedrovirus", "rank": "Species"}, "451705": {"name": "Enterobacteria phage phiEcoM-GJ1", "rank": "Species"}, "1413383": {"name": "Staphylococcus aureus BG407", "rank": "Strain"}, "1413382": {"name": "Staphylococcus aureus Sau 194", "rank": "Strain"}, "1413381": {"name": "Staphylococcus aureus Sau 99", "rank": "Strain"}, "1413380": {"name": "Staphylococcus aureus Sau 98", "rank": "Strain"}, "1413387": {"name": "Staphylococcus aureus 18754-2", "rank": "Strain"}, "1173761": {"name": "Salmonella phage FSL SP-058", "rank": "Species"}, "1413385": {"name": "Staphylococcus aureus 6665-5", "rank": "Strain"}, "1413384": {"name": "Staphylococcus aureus 5670-1", "rank": "Strain"}, "1182544": {"name": "Cladophialophora yegresii CBS 114405", "rank": "Strain"}, "1182545": {"name": "Exophiala aquamarina CBS 119918", "rank": "Strain"}, "1413389": {"name": "Staphylococcus aureus 87807-1", "rank": "Strain"}, "1413388": {"name": "Staphylococcus aureus 53180-1", "rank": "Strain"}, "1182540": {"name": "Candida albicans A203", "rank": "Strain"}, "1182541": {"name": "Capronia coronata CBS 617.96", "rank": "Strain"}, "1182543": {"name": "Cladophialophora psammophila CBS 110553", "rank": "Strain"}, "938143": {"name": "Salmonella enterica subsp. enterica serovar Rubislaw str. ATCC 10717", "rank": "Strain"}, "938142": {"name": "Salmonella enterica subsp. enterica serovar Choleraesuis str. ATCC 10708", "rank": "Strain"}, "938141": {"name": "Salmonella enterica subsp. enterica serovar Sloterdijk str. ATCC 15791", "rank": "Strain"}, "436145": {"name": "Leptospira interrogans serovar Muenchen", "rank": "Strain"}, "938147": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. 638970-15", "rank": "Strain"}, "42255": {"name": "Rubrobacter", "rank": "Genus"}, "42256": {"name": "Rubrobacter radiotolerans", "rank": "Species"}, "1121381": {"name": "Deinococcus marmoris DSM 12784", "rank": "Strain"}, "1121380": {"name": "Deinococcus frigens DSM 12807", "rank": "Strain"}, "1121383": {"name": "Deinococcus murrayi DSM 11303", "rank": "Strain"}, "295405": {"name": "Bacteroides fragilis YCH46", "rank": "Strain"}, "551115": {"name": "'Nostoc azollae' 0708", "rank": "Strain"}, "1121384": {"name": "Deinococcus radiodurans DSM 20539", "rank": "Strain"}, "1121387": {"name": "Dermatophilus congolensis DSM 44180 = NBRC 105199", "rank": "Strain"}, "1049936": {"name": "Leptospira interrogans str. UI 09600", "rank": "Strain"}, "1049933": {"name": "Leptospira interrogans str. L1207", "rank": "Strain"}, "1049931": {"name": "Leptospira interrogans str. FPW2026", "rank": "Strain"}, "116090": {"name": "Caloranaerobacter azorensis", "rank": "Species"}, "586416": {"name": "Terribacillus aidingensis", "rank": "Species"}, "150340": {"name": "Vibrio sp. Ex25", "rank": "Species"}, "333045": {"name": "Luffa begomovirus associated DNA beta", "rank": "Species"}, "333046": {"name": "Unclassified Bacteroidales", "rank": "No rank"}, "556259": {"name": "Bacteroides sp. D2", "rank": "Species"}, "1227459": {"name": "Haloferax gibbonsii ATCC 33959", "rank": "Strain"}, "166953": {"name": "Kaistia", "rank": "Genus"}, "326298": {"name": "Sulfurimonas denitrificans DSM 1251", "rank": "Strain"}, "11723": {"name": "Simian immunodeficiency virus", "rank": "Species"}, "29521": {"name": "Brachyspira", "rank": "Genus"}, "29520": {"name": "Borrelia crocidurae", "rank": "Species"}, "326297": {"name": "Shewanella amazonensis SB2B", "rank": "Strain"}, "29526": {"name": "Syntrophobacter", "rank": "Genus"}, "375548": {"name": "Unclassified Flexiviridae", "rank": "No rank"}, "1077464": {"name": "Streptococcus tigurinus", "rank": "Species"}, "27292": {"name": "Saccharomyces pastorianus", "rank": "Species"}, "37296": {"name": "Human herpesvirus 8", "rank": "Species"}, "1159062": {"name": "Helicobacter pylori GAMchJs124i", "rank": "Strain"}, "499174": {"name": "Peptoclostridium difficile QCD-23m63", "rank": "Strain"}, "499175": {"name": "Peptoclostridium difficile ATCC 43255", "rank": "Strain"}, "499176": {"name": "Peptoclostridium difficile CIP 107932", "rank": "Strain"}, "2006": {"name": "Thermobispora bispora", "rank": "Species"}, "2004": {"name": "Streptosporangiaceae", "rank": "Family"}, "2005": {"name": "Microbispora", "rank": "Genus"}, "2002": {"name": "Streptosporangium amethystogenes", "rank": "Species"}, "2000": {"name": "Streptosporangium", "rank": "Genus"}, "2001": {"name": "Streptosporangium roseum", "rank": "Species"}, "1548147": {"name": "Helicobacter sp. MIT 03-1614", "rank": "Species"}, "1548148": {"name": "Helicobacter sp. MIT 03-1616", "rank": "Species"}, "1548149": {"name": "Helicobacter sp. MIT 05-5293", "rank": "Species"}, "1115478": {"name": "Salmonella phage SE2", "rank": "Species"}, "269484": {"name": "Ehrlichia canis str. Jake", "rank": "Strain"}, "469602": {"name": "Fusobacterium nucleatum subsp. vincentii 3_1_27", "rank": "Strain"}, "159896": {"name": "Microbacterium gubbeenense", "rank": "Species"}, "269482": {"name": "Burkholderia vietnamiensis G4", "rank": "Strain"}, "1388658": {"name": "Staphylococcus aureus M0884", "rank": "Strain"}, "1388659": {"name": "Staphylococcus aureus M0885", "rank": "Strain"}, "1266371": {"name": "Candidatus Tremblaya phenacola PAVE", "rank": "Strain"}, "1388654": {"name": "Staphylococcus aureus M0879", "rank": "Strain"}, "1388655": {"name": "Staphylococcus aureus M0880", "rank": "Strain"}, "1388656": {"name": "Staphylococcus aureus M0882", "rank": "Strain"}, "1388657": {"name": "Staphylococcus aureus M0883", "rank": "Strain"}, "1388650": {"name": "Staphylococcus aureus M0874", "rank": "Strain"}, "1388651": {"name": "Staphylococcus aureus M0875", "rank": "Strain"}, "1388652": {"name": "Staphylococcus aureus M0876", "rank": "Strain"}, "1388653": {"name": "Staphylococcus aureus M0878", "rank": "Strain"}, "162013": {"name": "Tioman virus", "rank": "Species"}, "204722": {"name": "Brucella suis 1330", "rank": "Strain"}, "1299309": {"name": "Alphanecrovirus", "rank": "Genus"}, "174157": {"name": "Leptospira interrogans serovar Autumnalis", "rank": "Strain"}, "1299307": {"name": "Betafusellovirus", "rank": "Genus"}, "1299306": {"name": "Tibrovirus", "rank": "Genus"}, "28274": {"name": "Avian paramyxovirus 4", "rank": "Species"}, "35519": {"name": "Mogibacterium timidum", "rank": "Species"}, "1439294": {"name": "Streptococcus pyogenes ABC020060220", "rank": "Strain"}, "166954": {"name": "Kaistia adipata", "rank": "Species"}, "660122": {"name": "Nectria haematococca mpVI 77-13-4", "rank": "Strain"}, "1439299": {"name": "Streptococcus pyogenes ABC020060777", "rank": "Strain"}, "192203": {"name": "Tobacco vein distorting virus", "rank": "Species"}, "269261": {"name": "Nitratifractor salsuginis", "rank": "Species"}, "269260": {"name": "Nitratifractor", "rank": "Genus"}, "1703": {"name": "Brevibacterium linens", "rank": "Species"}, "353207": {"name": "Replication defective viruses", "rank": "No rank"}, "1707": {"name": "Cellulomonas", "rank": "Genus"}, "1708": {"name": "Cellulomonas fimi", "rank": "Species"}, "1388265": {"name": "Staphylococcus aureus M0400", "rank": "Strain"}, "1463821": {"name": "Glycomyces sp. NRRL B-16210", "rank": "Species"}, "1463820": {"name": "Actinosporangium sp. NRRL B-3428", "rank": "Species"}, "1463823": {"name": "Microbispora sp. NRRL B-24597", "rank": "Species"}, "1463822": {"name": "Kitasatospora sp. NRRL B-11411", "rank": "Species"}, "1463825": {"name": "Saccharothrix sp. NRRL B-16314", "rank": "Species"}, "1463824": {"name": "Nocardia sp. NRRL WC-3656", "rank": "Species"}, "1463827": {"name": "Streptomyces sp. NRRL B-12105", "rank": "Species"}, "1463826": {"name": "Streptomyces sp. NRRL B-11253", "rank": "Species"}, "1463829": {"name": "Streptomyces sp. NRRL B-1381", "rank": "Species"}, "89966": {"name": "Hymenobacter", "rank": "Genus"}, "991968": {"name": "Vibrio cholerae HC-50A2", "rank": "Strain"}, "991969": {"name": "Vibrio cholerae HC-52A1", "rank": "Strain"}, "991965": {"name": "Vibrio cholerae HC-48A1", "rank": "Strain"}, "991966": {"name": "Vibrio cholerae HC-48B2", "rank": "Strain"}, "991967": {"name": "Vibrio cholerae HC-50A1", "rank": "Strain"}, "991960": {"name": "Vibrio cholerae HC-39A1", "rank": "Strain"}, "991961": {"name": "Vibrio cholerae HC-40A1", "rank": "Strain"}, "991962": {"name": "Vibrio cholerae HC-41A1", "rank": "Strain"}, "991963": {"name": "Vibrio cholerae HC-42A1", "rank": "Strain"}, "1281029": {"name": "Escherichia coli HVH 92 (4-5930790)", "rank": "Strain"}, "53961": {"name": "Salmonella enterica subsp. enterica serovar Abortusovis", "rank": "Strain"}, "1499683": {"name": "Clostridium sp. CL-6", "rank": "Species"}, "1138871": {"name": "Mycobacterium yongonense 05-1390", "rank": "Strain"}, "1138874": {"name": "Streptococcus pyogenes NS88.2", "rank": "Strain"}, "1138877": {"name": "Mycobacterium tuberculosis 7199-99", "rank": "Strain"}, "471223": {"name": "Geobacillus sp. WCH70", "rank": "Species"}, "224372": {"name": "Alcanivoracaceae", "rank": "Family"}, "996650": {"name": "Camelus dromedarius papillomavirus type 1", "rank": "Strain"}, "224379": {"name": "Hahellaceae", "rank": "Family"}, "358403": {"name": "Unclassified Prymnesiovirus", "rank": "No rank"}, "290309": {"name": "Comamonas granuli", "rank": "Species"}, "674982": {"name": "Ceratocystis resinifera virus 1", "rank": "Species"}, "674983": {"name": "Pleurotus ostreatus virus 1", "rank": "Species"}, "674980": {"name": "Chaetoceros salsugineum DNA virus", "rank": "Species"}, "674981": {"name": "Victorivirus", "rank": "Genus"}, "622438": {"name": "Duck astrovirus C-NGB", "rank": "Strain"}, "674984": {"name": "Rosellinia necatrix virus 1", "rank": "Species"}, "1221289": {"name": "Acinetobacter sp. TG27347", "rank": "Species"}, "1221288": {"name": "Acinetobacter baumannii AB_TG27343", "rank": "Strain"}, "1221281": {"name": "Acinetobacter baumannii AB_TG2032", "rank": "Strain"}, "1221280": {"name": "Acinetobacter baumannii AB_TG2031", "rank": "Strain"}, "1221283": {"name": "Acinetobacter baumannii AB_TG27323", "rank": "Strain"}, "1221282": {"name": "Acinetobacter baumannii AB_TG2631", "rank": "Strain"}, "1221285": {"name": "Acinetobacter baumannii AB_TG27331", "rank": "Strain"}, "1221284": {"name": "Acinetobacter baumannii AB_TG27327", "rank": "Strain"}, "1221287": {"name": "Acinetobacter baumannii AB_TG27339", "rank": "Strain"}, "1221286": {"name": "Acinetobacter baumannii AB_TG27335", "rank": "Strain"}, "320388": {"name": "Burkholderia mallei SAVP1", "rank": "Strain"}, "320389": {"name": "Burkholderia mallei NCTC 10247", "rank": "Strain"}, "1353246": {"name": "Thaumarchaeota archaeon MY2", "rank": "Species"}, "1185876": {"name": "Fibrisoma limi BUZ 3", "rank": "Strain"}, "1353243": {"name": "Streptococcus anginosus subsp. whileyi MAS624", "rank": "Strain"}, "1353241": {"name": "Fur seal faeces associated circular DNA virus", "rank": "Species"}, "1412634": {"name": "Staphylococcus aureus F29982", "rank": "Strain"}, "1296646": {"name": "Mycobacterium phage Butters", "rank": "Species"}, "1115511": {"name": "Escherichia albertii NBRC 107761", "rank": "Strain"}, "888833": {"name": "Streptococcus australis ATCC 700641", "rank": "Strain"}, "888832": {"name": "Prevotella salivae DSM 15606", "rank": "Strain"}, "47850": {"name": "Micromonospora aurantiaca", "rank": "Species"}, "1455696": {"name": "Yersinia pestis EV NIIEG", "rank": "Strain"}, "999407": {"name": "Clostridium clostridioforme 90A7", "rank": "Strain"}, "999406": {"name": "Clostridium clostridioforme 90A6", "rank": "Strain"}, "999405": {"name": "Clostridium clostridioforme 90A4", "rank": "Strain"}, "999404": {"name": "Clostridium clostridioforme 90A3", "rank": "Strain"}, "999403": {"name": "Clostridium clostridioforme 90A1", "rank": "Strain"}, "1268254": {"name": "Peptoniphilus timonensis", "rank": "Species"}, "1078764": {"name": "Corynebacterium sp. HFH0082", "rank": "Species"}, "999409": {"name": "Clostridium clostridioforme 90B1", "rank": "Strain"}, "999408": {"name": "Clostridium clostridioforme 90A8", "rank": "Strain"}, "409322": {"name": "Treponema pedis", "rank": "Species"}, "1123384": {"name": "Thermotoga hypogea DSM 11164", "rank": "Strain"}, "1160": {"name": "Planktothrix agardhii", "rank": "Species"}, "1076522": {"name": "Sediminibacterium sp. OR43", "rank": "Species"}, "1117409": {"name": "Methyloversatilis sp. NVD", "rank": "Species"}, "197701": {"name": "Aeromonas veronii bv. veronii", "rank": "Strain"}, "78276": {"name": "Crucifer tobamovirus", "rank": "Species"}, "1281022": {"name": "Escherichia coli HVH 85 (4-0792144)", "rank": "Strain"}, "1165907": {"name": "Porcine bocavirus", "rank": "Species"}, "1165908": {"name": "Simian adenovirus B", "rank": "Species"}, "1161": {"name": "Nostocales", "rank": "Order"}, "1159080": {"name": "Helicobacter pylori HP260Bi", "rank": "Strain"}, "908137": {"name": "Cotton leaf curl Allahabad virus India:Karnal:OY77:2005", "rank": "Strain"}, "1105380": {"name": "Posavirus 1", "rank": "Species"}, "36659": {"name": "Volvariella volvacea", "rank": "Species"}, "908133": {"name": "Cotton leaf curl Allahabad virus", "rank": "Species"}, "1400880": {"name": "Mycobacterium tuberculosis KT-0015", "rank": "Strain"}, "1400881": {"name": "Mycobacterium tuberculosis KT-0016", "rank": "Strain"}, "1400882": {"name": "Mycobacterium tuberculosis KT-0017", "rank": "Strain"}, "1400883": {"name": "Mycobacterium tuberculosis KT-0019", "rank": "Strain"}, "1400884": {"name": "Mycobacterium tuberculosis KT-0022", "rank": "Strain"}, "1400885": {"name": "Mycobacterium tuberculosis KT-0023", "rank": "Strain"}, "1400886": {"name": "Mycobacterium tuberculosis KT-0024", "rank": "Strain"}, "1400887": {"name": "Mycobacterium tuberculosis KT-0026", "rank": "Strain"}, "1400888": {"name": "Mycobacterium tuberculosis KT-0027", "rank": "Strain"}, "1400889": {"name": "Mycobacterium tuberculosis KT-0028", "rank": "Strain"}, "1291334": {"name": "Leptospira interrogans serovar Copenhageni str. Fiocruz LV2816", "rank": "Strain"}, "1291335": {"name": "Leptospira interrogans serovar Copenhageni str. Fiocruz LV2841", "rank": "Strain"}, "1291332": {"name": "Leptospira interrogans serovar Copenhageni str. Fiocruz LV2766", "rank": "Strain"}, "1291333": {"name": "Leptospira interrogans serovar Copenhageni str. Fiocruz LV2807", "rank": "Strain"}, "1291330": {"name": "Leptospira interrogans serovar Copenhageni str. Fiocruz LV4160", "rank": "Strain"}, "1291331": {"name": "Leptospira interrogans serovar Copenhageni str. Fiocruz LV2750", "rank": "Strain"}, "215690": {"name": "Thermomonas fusca", "rank": "Species"}, "762210": {"name": "Bifidobacterium saguini", "rank": "Species"}, "1310577": {"name": "Acinetobacter baumannii 532413", "rank": "Strain"}, "1442604": {"name": "Enterococcus faecium VRE0576", "rank": "Strain"}, "1442605": {"name": "Enterococcus faecium VSE1036", "rank": "Strain"}, "1442606": {"name": "Enterococcus faecium VRE1044", "rank": "Strain"}, "1442607": {"name": "Enterococcus faecium VRE1261", "rank": "Strain"}, "1442601": {"name": "Helicobacter pylori HLJ039", "rank": "Strain"}, "1442602": {"name": "Enterobacter asburiae C1", "rank": "Strain"}, "350894": {"name": "Flavobacterium suncheonense", "rank": "Species"}, "1161102": {"name": "Pasteurella multocida subsp. multocida VTCCBAA264", "rank": "Strain"}, "350893": {"name": "Flavobacterium daejeonense", "rank": "Species"}, "1150948": {"name": "Wolbachia endosymbiont of Glossina morsitans morsitans", "rank": "Species"}, "1310747": {"name": "Acinetobacter baumannii 1095464", "rank": "Strain"}, "1310746": {"name": "Acinetobacter baumannii 1287985", "rank": "Strain"}, "1310745": {"name": "Acinetobacter baumannii 480175", "rank": "Strain"}, "1310744": {"name": "Acinetobacter baumannii 1237893", "rank": "Strain"}, "1169338": {"name": "Escherichia coli KTE19", "rank": "Strain"}, "1310742": {"name": "Acinetobacter baumannii 1188188", "rank": "Strain"}, "1310741": {"name": "Acinetobacter baumannii 73736", "rank": "Strain"}, "1310740": {"name": "Acinetobacter baumannii 457946", "rank": "Strain"}, "1169334": {"name": "Escherichia coli KTE15", "rank": "Strain"}, "1169335": {"name": "Escherichia coli KTE16", "rank": "Strain"}, "1169336": {"name": "Escherichia coli KTE17", "rank": "Strain"}, "1169337": {"name": "Escherichia coli KTE18", "rank": "Strain"}, "1169330": {"name": "Escherichia coli KTE10", "rank": "Strain"}, "1169331": {"name": "Escherichia sp. KTE11", "rank": "Species"}, "1310749": {"name": "Acinetobacter baumannii 10519", "rank": "Strain"}, "1310748": {"name": "Acinetobacter baumannii 846928", "rank": "Strain"}, "91623": {"name": "Clostridium akagii", "rank": "Species"}, "265975": {"name": "Oribacterium", "rank": "Genus"}, "1408969": {"name": "Mycobacterium tuberculosis UT0113", "rank": "Strain"}, "1408968": {"name": "Mycobacterium tuberculosis UT0112", "rank": "Strain"}, "1408967": {"name": "Mycobacterium tuberculosis UT0110", "rank": "Strain"}, "585147": {"name": "Staphylococcus aureus subsp. aureus A017934/97", "rank": "Strain"}, "1408965": {"name": "Mycobacterium tuberculosis UT0106", "rank": "Strain"}, "1408964": {"name": "Mycobacterium tuberculosis UT0105", "rank": "Strain"}, "1408963": {"name": "Mycobacterium tuberculosis UT0104", "rank": "Strain"}, "1408962": {"name": "Mycobacterium tuberculosis UT0100", "rank": "Strain"}, "1408960": {"name": "Mycobacterium tuberculosis UT0097", "rank": "Strain"}, "1211642": {"name": "Caulobacter phage CcrMagneto", "rank": "Species"}, "1211643": {"name": "Caulobacter phage CcrRogue", "rank": "Species"}, "1211640": {"name": "Caulobacter phage CcrColossus", "rank": "Species"}, "1211641": {"name": "Caulobacter phage CcrKarma", "rank": "Species"}, "572479": {"name": "Halanaerobium praevalens DSM 2228", "rank": "Strain"}, "146939": {"name": "Azospira oryzae", "rank": "Species"}, "1211644": {"name": "Caulobacter phage CcrSwift", "rank": "Species"}, "572477": {"name": "Allochromatium vinosum DSM 180", "rank": "Strain"}, "1448667": {"name": "Mycobacterium tuberculosis M1384", "rank": "Strain"}, "1115805": {"name": "Staphylococcus epidermidis E13A", "rank": "Strain"}, "146937": {"name": "Azospira", "rank": "Genus"}, "1527514": {"name": "Enterobacteria phage EK99P-1", "rank": "Species"}, "1527515": {"name": "Idiomarinaceae phage Phi1M2-2", "rank": "Species"}, "1115803": {"name": "Actinomyces naeslundii str. Howell 279", "rank": "Strain"}, "146936": {"name": "Azonexus", "rank": "Genus"}, "1115809": {"name": "Prevotella baroniae F0067", "rank": "Strain"}, "585149": {"name": "Staphylococcus aureus subsp. aureus C101", "rank": "Strain"}, "992006": {"name": "Vibrio cholerae HC-62A1", "rank": "Strain"}, "992007": {"name": "Vibrio cholerae HC-62B1", "rank": "Strain"}, "992004": {"name": "Vibrio cholerae HC-51A1", "rank": "Strain"}, "992005": {"name": "Vibrio cholerae HC-60A1", "rank": "Strain"}, "992002": {"name": "Vibrio cholerae HC-44C1", "rank": "Strain"}, "1049789": {"name": "Leptospira broomii serovar Hurstbridge str. 5399", "rank": "Strain"}, "992000": {"name": "Vibrio cholerae HE-40", "rank": "Strain"}, "992001": {"name": "Vibrio cholerae HE-46", "rank": "Strain"}, "1049786": {"name": "Leptospira borgpetersenii str. Brem 307", "rank": "Strain"}, "1049780": {"name": "Leptospira borgpetersenii str. Brem 328", "rank": "Strain"}, "1049781": {"name": "Leptospira borgpetersenii str. Noumea 25", "rank": "Strain"}, "992008": {"name": "Vibrio cholerae HC-69A1", "rank": "Strain"}, "992009": {"name": "Vibrio cholerae HC-78A1", "rank": "Strain"}, "288456": {"name": "Bombyx mori Macula-like virus", "rank": "Species"}, "103618": {"name": "Actinomyces coleocanis", "rank": "Species"}, "1395513": {"name": "Sporolactobacillus laevolacticus DSM 442", "rank": "Strain"}, "1395516": {"name": "Pseudomonas moraviensis R28-S", "rank": "Strain"}, "1388519": {"name": "Staphylococcus aureus M0594", "rank": "Strain"}, "1388518": {"name": "Staphylococcus aureus M0570", "rank": "Strain"}, "1388513": {"name": "Staphylococcus aureus M0511", "rank": "Strain"}, "1388512": {"name": "Staphylococcus aureus M0498", "rank": "Strain"}, "1388511": {"name": "Staphylococcus aureus M0735", "rank": "Strain"}, "1388510": {"name": "Staphylococcus aureus M0726", "rank": "Strain"}, "1388517": {"name": "Staphylococcus aureus M0561", "rank": "Strain"}, "1388516": {"name": "Staphylococcus aureus M0551", "rank": "Strain"}, "1388515": {"name": "Staphylococcus aureus M0538", "rank": "Strain"}, "1388514": {"name": "Staphylococcus aureus M0524", "rank": "Strain"}, "1203599": {"name": "Mycobacterium yongonense", "rank": "Species"}, "1112273": {"name": "Methylophilus sp. 1", "rank": "Species"}, "1210519": {"name": "Francisella tularensis subsp. tularensis 80700103", "rank": "Strain"}, "1210518": {"name": "Francisella tularensis subsp. tularensis 70102010", "rank": "Strain"}, "1112272": {"name": "Hyphomicrobium sp. 802", "rank": "Species"}, "1157027": {"name": "Staphylococcus aureus M0391", "rank": "Strain"}, "1157026": {"name": "Staphylococcus aureus M0364", "rank": "Strain"}, "1412639": {"name": "Staphylococcus aureus F77942", "rank": "Strain"}, "1157029": {"name": "Staphylococcus aureus M0427", "rank": "Strain"}, "1365108": {"name": "Burkholderia sp. A9", "rank": "Species"}, "1394644": {"name": "Vibrio parahaemolyticus S109", "rank": "Strain"}, "1116157": {"name": "Escherichia coli P0302308.5", "rank": "Strain"}, "1562571": {"name": "Acidobacteria subdivision 23", "rank": "No rank"}, "341938": {"name": "Bacillus phage Bam35", "rank": "Species"}, "10616": {"name": "Human papillomavirus type 49", "rank": "Strain"}, "1234659": {"name": "Yersinia pestis subsp. microtus", "rank": "Subspecies"}, "1608298": {"name": "Thiolapillus", "rank": "Genus"}, "203557": {"name": "Verrucomicrobiaceae", "rank": "Family"}, "1439860": {"name": "Burkholderia pseudomallei TSV28", "rank": "Strain"}, "341937": {"name": "Unclassified Tectivirus", "rank": "No rank"}, "230143": {"name": "Scardovia wiggsiae", "rank": "Species"}, "1439861": {"name": "Burkholderia pseudomallei TSV5", "rank": "Strain"}, "101764": {"name": "Aconitum latent virus", "rank": "Species"}, "47021": {"name": "Orbiliaceae", "rank": "Family"}, "39956": {"name": "Methylobacterium mesophilicum", "rank": "Species"}, "938709": {"name": "Bacteroidetes bacterium SCGC AAA027-N21", "rank": "Species"}, "223903": {"name": "Hymenobacter norwichensis", "rank": "Species"}, "223900": {"name": "Chromohalobacter japonicus", "rank": "Species"}, "543310": {"name": "Clostridiales Family XI. Incertae Sedis", "rank": "Family"}, "543311": {"name": "Parvimonas", "rank": "Genus"}, "1169848": {"name": "Xanthomonas arboricola pv. juglandis str. NCPPB 1447", "rank": "Strain"}, "543314": {"name": "Clostridiales Family XIII. Incertae Sedis", "rank": "Family"}, "62320": {"name": "Haloterrigena turkmenica", "rank": "Species"}, "1157678": {"name": "Oxalobacteraceae bacterium JGI 0001004-J12", "rank": "Species"}, "80842": {"name": "Herbaspirillum rubrisubalbicans", "rank": "Species"}, "80841": {"name": "Unclassified Burkholderiales (miscellaneous)", "rank": "No rank"}, "80840": {"name": "Burkholderiales", "rank": "Order"}, "1402135": {"name": "Sulfitobacter sp. H3", "rank": "Species"}, "80849": {"name": "Wolbachia endosymbiont of Brugia malayi", "rank": "Species"}, "1446600": {"name": "Escherichia coli O15:H18", "rank": "Strain"}, "1446601": {"name": "Escherichia coli O15:H18 str. K1516", "rank": "Strain"}, "1446602": {"name": "Escherichia coli O153:H2", "rank": "Strain"}, "1446603": {"name": "Escherichia coli O153:H2 str. 2010C-5034", "rank": "Strain"}, "1446604": {"name": "Escherichia coli O156:H25", "rank": "Strain"}, "1446605": {"name": "Escherichia coli O156:H25 str. 2011C-3602", "rank": "Strain"}, "1446606": {"name": "Escherichia coli O157: str. 2010EL-2044", "rank": "Strain"}, "1446607": {"name": "Escherichia coli O157: str. 2010EL-2045", "rank": "Strain"}, "1446608": {"name": "Escherichia coli O157:H16 str. 98-3133", "rank": "Strain"}, "1446609": {"name": "Escherichia coli O157:H7 str. 06-3745", "rank": "Strain"}, "1287074": {"name": "Mesorhizobium sp. L103C105A0", "rank": "Species"}, "1046117": {"name": "Oceaniovalibus guishaninsula", "rank": "Species"}, "933390": {"name": "Penicillium oxalicum JU-A10-T", "rank": "Strain"}, "444461": {"name": "Bacillus acidiproducens DSM 23148", "rank": "Strain"}, "102231": {"name": "Gloeocapsa", "rank": "Genus"}, "102232": {"name": "Gloeocapsa sp. PCC 73106", "rank": "Species"}, "102234": {"name": "Cyanobacterium", "rank": "Genus"}, "102235": {"name": "Cyanobacterium stanieri", "rank": "Species"}, "1472649": {"name": "Dielma", "rank": "Genus"}, "320831": {"name": "Staphylococcus phage PT1028", "rank": "Species"}, "10784": {"name": "Bovine parvovirus", "rank": "Strain"}, "12618": {"name": "Chicken anemia virus", "rank": "Species"}, "28236": {"name": "Petrotoga", "rank": "Genus"}, "1": {"name": "Root", "rank": "no rank"}, "28232": {"name": "Geobacter metallireducens", "rank": "Species"}, "28230": {"name": "Carnobacterium alterfunditum", "rank": "Species"}, "28231": {"name": "Geobacter", "rank": "Genus"}, "230494": {"name": "Reinekea", "rank": "Genus"}, "1198630": {"name": "Thermoanaerobacter thermohydrosulfuricus WC1", "rank": "Strain"}, "1434142": {"name": "Shigella flexneri Shi06GS37", "rank": "Strain"}, "1434143": {"name": "Shigella flexneri 2003055", "rank": "Strain"}, "1434140": {"name": "Shigella flexneri Shi06AH028", "rank": "Strain"}, "1434141": {"name": "Shigella flexneri Shi06HN244", "rank": "Strain"}, "1434146": {"name": "Shigella flexneri Shi06SX36", "rank": "Strain"}, "1434147": {"name": "Shigella flexneri 2002103", "rank": "Strain"}, "258533": {"name": "Mycobacterium cosmeticum", "rank": "Species"}, "1434145": {"name": "Shigella flexneri Shi06GS55", "rank": "Strain"}, "1434148": {"name": "Shigella flexneri Shi05SX04", "rank": "Strain"}, "1434149": {"name": "Shigella flexneri Shi06SX53", "rank": "Strain"}, "388463": {"name": "Edaphobacter", "rank": "Genus"}, "671144": {"name": "Wallemia sebi CBS 633.66", "rank": "Strain"}, "561367": {"name": "Salinimicrobium", "rank": "Genus"}, "671143": {"name": "Candidatus Methylomirabilis oxyfera", "rank": "Species"}, "1444228": {"name": "Escherichia coli 2-005-03_S4_C2", "rank": "Strain"}, "332159": {"name": "Solibacteres", "rank": "Class"}, "1504319": {"name": "Actinobacterium acAMD-5", "rank": "Species"}, "320834": {"name": "Staphylococcus phage 69", "rank": "Strain"}, "1422040": {"name": "Mycobacterium tuberculosis TB_RSA124", "rank": "Strain"}, "1409634": {"name": "Staphylococcus aureus FVRH6040", "rank": "Strain"}, "1443898": {"name": "Rhodococcus fascians A78", "rank": "Strain"}, "1443899": {"name": "Rhodococcus fascians GIC26", "rank": "Strain"}, "252966": {"name": "Mahella australiensis", "rank": "Species"}, "1476583": {"name": "Deinococcus phoenicis", "rank": "Species"}, "1443892": {"name": "Rhodococcus fascians 05-561-1", "rank": "Strain"}, "1443893": {"name": "Rhodococcus fascians A21d2", "rank": "Strain"}, "1443890": {"name": "Rhodococcus fascians 04-516", "rank": "Strain"}, "1443891": {"name": "Rhodococcus fascians 05-339-1", "rank": "Strain"}, "1443896": {"name": "Rhodococcus fascians A73a", "rank": "Strain"}, "1409636": {"name": "Staphylococcus aureus UCIM6081", "rank": "Strain"}, "1443894": {"name": "Rhodococcus fascians A25f", "rank": "Strain"}, "1443895": {"name": "Rhodococcus fascians A3b", "rank": "Strain"}, "1409637": {"name": "Staphylococcus aureus LAMC6078", "rank": "Strain"}, "1078846": {"name": "Methylovulum miyakonense HT12", "rank": "Strain"}, "1409630": {"name": "Staphylococcus aureus AMMC6111", "rank": "Strain"}, "1409631": {"name": "Staphylococcus aureus OCMM6075", "rank": "Strain"}, "1409632": {"name": "Staphylococcus aureus FVRH6035", "rank": "Strain"}, "1409633": {"name": "Staphylococcus aureus WAMC6030", "rank": "Strain"}, "233784": {"name": "Grapevine deformation virus", "rank": "Species"}, "927658": {"name": "Alkaliflexus imshenetskii DSM 15055", "rank": "Strain"}, "463360": {"name": "Chickpea chlorotic dwarf virus", "rank": "Species"}, "1425338": {"name": "Listeria monocytogenes Lm_1824", "rank": "Strain"}, "1392231": {"name": "Streptococcus phage 20617", "rank": "Species"}, "5498": {"name": "Cladosporium", "rank": "Genus"}, "168275": {"name": "Psychromonas arctica", "rank": "Species"}, "1423687": {"name": "Bacillus subtilis GB03", "rank": "Strain"}, "1423686": {"name": "Bacillus tequilensis KCTC 13622", "rank": "Strain"}, "1423688": {"name": "Bacillus pumilus INR7", "rank": "Strain"}, "412022": {"name": "Burkholderia mallei NCTC 10229", "rank": "Strain"}, "412021": {"name": "Burkholderia mallei ATCC 10399", "rank": "Strain"}, "382273": {"name": "Prochlorococcus phage P-SSP3", "rank": "Species"}, "644282": {"name": "Desulfarculus baarsii DSM 2075", "rank": "Strain"}, "644283": {"name": "Micromonospora aurantiaca ATCC 27029", "rank": "Strain"}, "208958": {"name": "Aeromonas hydrophila subsp. ranae", "rank": "Subspecies"}, "644281": {"name": "Methanocaldococcus sp. FS406-22", "rank": "Species"}, "644284": {"name": "Arcanobacterium haemolyticum DSM 20595", "rank": "Strain"}, "626086": {"name": "Aliivibrio logei 5S-186", "rank": "Strain"}, "1247189": {"name": "Streptococcus dysgalactiae subsp. equisimilis 167", "rank": "Strain"}, "1157388": {"name": "Enterococcus faecalis EnGen0204", "rank": "Strain"}, "2242": {"name": "Halobacterium salinarum", "rank": "Species"}, "2246": {"name": "Haloferax volcanii", "rank": "Species"}, "2247": {"name": "Halorubrum lacusprofundi", "rank": "Species"}, "2248": {"name": "Halorubrum saccharovorum", "rank": "Species"}, "2249": {"name": "Halococcus", "rank": "Genus"}, "1458269": {"name": "Bordetella bronchiseptica D756", "rank": "Strain"}, "1217706": {"name": "Acinetobacter sp. NIPH 2168", "rank": "Species"}, "445600": {"name": "Streptomyces sulphureus L180", "rank": "Strain"}, "1458261": {"name": "Bordetella bronchiseptica E012", "rank": "Strain"}, "1458260": {"name": "Bordetella bronchiseptica D993", "rank": "Strain"}, "1458263": {"name": "Bordetella bronchiseptica C4", "rank": "Strain"}, "1458262": {"name": "Bordetella bronchiseptica E014", "rank": "Strain"}, "1458265": {"name": "Bordetella bronchiseptica E010", "rank": "Strain"}, "1473205": {"name": "Senegalimassilia", "rank": "Genus"}, "1208587": {"name": "Streptococcus phage SP-QS1", "rank": "Species"}, "1281048": {"name": "Escherichia coli HVH 112 (4-5987253)", "rank": "Strain"}, "1208583": {"name": "Commensalibacter sp. MX01", "rank": "Species"}, "1217703": {"name": "Acinetobacter sp. ANC 4105", "rank": "Species"}, "5270": {"name": "Ustilago maydis", "rank": "Species"}, "1281040": {"name": "Escherichia coli HVH 104 (4-6977960)", "rank": "Strain"}, "1281043": {"name": "Escherichia coli HVH 107 (4-5860571)", "rank": "Strain"}, "1281042": {"name": "Escherichia coli HVH 106 (4-6881831)", "rank": "Strain"}, "1080365": {"name": "Pediococcus acidilactici MA18/5M", "rank": "Strain"}, "1281044": {"name": "Escherichia coli HVH 108 (4-6924867)", "rank": "Strain"}, "1281047": {"name": "Escherichia coli HVH 111 (4-7039018)", "rank": "Strain"}, "735332": {"name": "Leptothrix ochracea L12", "rank": "Strain"}, "929769": {"name": "Sida golden mosaic Buckup virus-Jamaica:St. Elizabeth:2004", "rank": "Strain"}, "1127672": {"name": "Glaciecola chathamensis S18K6", "rank": "Strain"}, "929766": {"name": "Sida golden yellow vein virus-Jamaica:Liguanea2:2008", "rank": "Strain"}, "343509": {"name": "Sodalis glossinidius str. 'morsitans'", "rank": "Strain"}, "1157383": {"name": "Enterococcus faecalis EnGen0199", "rank": "Strain"}, "1217709": {"name": "Acinetobacter sp. NIPH 713", "rank": "Species"}, "1217708": {"name": "Acinetobacter sp. NIPH 2100", "rank": "Species"}, "1412612": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20120774", "rank": "Strain"}, "1412613": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20120917", "rank": "Strain"}, "1412610": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20120738", "rank": "Strain"}, "1412611": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20120773", "rank": "Strain"}, "1412616": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20121689", "rank": "Strain"}, "1412617": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20120927", "rank": "Strain"}, "1412614": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20120918", "rank": "Strain"}, "1412615": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20120925", "rank": "Strain"}, "34053": {"name": "Yersinia enterocolitica (type O:5)", "rank": "Strain"}, "207246": {"name": "Avian paramyxovirus 3", "rank": "Species"}, "34051": {"name": "Yersinia enterocolitica (type O:3)", "rank": "Strain"}, "207244": {"name": "Anaerostipes", "rank": "Genus"}, "981224": {"name": "Acinetobacter sp. NCTC 10304", "rank": "Species"}, "207240": {"name": "Luffa yellow mosaic virus", "rank": "Species"}, "1240767": {"name": "Escherichia coli O104:H4 str. Ec11-6006", "rank": "Strain"}, "1240766": {"name": "Escherichia coli O104:H4 str. Ec11-5604", "rank": "Strain"}, "981222": {"name": "Candidatus Chloracidobacterium thermophilum B", "rank": "Strain"}, "1240765": {"name": "Escherichia coli O104:H4 str. Ec11-5603", "rank": "Strain"}, "1388435": {"name": "Staphylococcus aureus M0654", "rank": "Strain"}, "568766": {"name": "Dickeya sp. NCPPB 3274", "rank": "Species"}, "1417028": {"name": "Mycobacterium tuberculosis KT-0081", "rank": "Strain"}, "1417029": {"name": "Mycobacterium tuberculosis KT-0082", "rank": "Strain"}, "981220": {"name": "Helicobacter pylori NQ1671", "rank": "Strain"}, "425067": {"name": "Burkholderia pseudomallei 305", "rank": "Strain"}, "1417023": {"name": "Mycobacterium tuberculosis KT-0060", "rank": "Strain"}, "1417020": {"name": "Mycobacterium tuberculosis KT-0040", "rank": "Strain"}, "1417021": {"name": "Mycobacterium tuberculosis KT-0042", "rank": "Strain"}, "1417026": {"name": "Mycobacterium tuberculosis KT-0067", "rank": "Strain"}, "1417027": {"name": "Mycobacterium tuberculosis KT-0069", "rank": "Strain"}, "568768": {"name": "Dickeya sp. NCPPB 569", "rank": "Species"}, "1384054": {"name": "Arenimonas malthae CC-JY-1", "rank": "Strain"}, "1240760": {"name": "Escherichia coli O104:H4 str. Ec11-9990", "rank": "Strain"}, "553633": {"name": "Wolbachia endosymbiont of Drosophila suzukii", "rank": "Species"}, "1123487": {"name": "Uliginosibacterium gangwonense DSM 18521", "rank": "Strain"}, "1123488": {"name": "Varibaculum cambriense DSM 15806", "rank": "Strain"}, "1123489": {"name": "Veillonella magna DSM 19857", "rank": "Strain"}, "56460": {"name": "Xanthomonas vesicatoria", "rank": "Species"}, "1413546": {"name": "Staphylococcus aureus 44(2608)", "rank": "Strain"}, "1240769": {"name": "Escherichia coli O104:H4 str. 11-02033-1", "rank": "Strain"}, "1413548": {"name": "Staphylococcus aureus Chi-4", "rank": "Strain"}, "1240768": {"name": "Escherichia coli O104:H4 str. 11-02030", "rank": "Strain"}, "1510041": {"name": "Rhizobium sp. H41", "rank": "Species"}, "875454": {"name": "Peptoniphilus rhinitidis 1-13", "rank": "Strain"}, "398261": {"name": "Methylobacterium sp. WSM2598", "rank": "Species"}, "1340493": {"name": "Bryobacter aggregatus MPL3", "rank": "Strain"}, "191026": {"name": "Desulfovibrio hydrothermalis", "rank": "Species"}, "1340497": {"name": "Streptococcus pneumoniae 1779n23_04", "rank": "Strain"}, "1340495": {"name": "Lactobacillus reuteri I5007", "rank": "Strain"}, "191028": {"name": "Leisingera", "rank": "Genus"}, "1287334": {"name": "Mesorhizobium sp. LSJC277A00", "rank": "Species"}, "232237": {"name": "Xanthomonas phage Xp10", "rank": "Species"}, "561229": {"name": "Dickeya zeae Ech1591", "rank": "Strain"}, "1055524": {"name": "Burkholderia cenocepacia H111", "rank": "Strain"}, "1055527": {"name": "Helicobacter pylori ELS37", "rank": "Strain"}, "1055526": {"name": "Candidatus Burkholderia kirkii UZHbot1", "rank": "Strain"}, "1055529": {"name": "Helicobacter pylori Puno135", "rank": "Strain"}, "1055528": {"name": "Helicobacter pylori Puno120", "rank": "Strain"}, "1335638": {"name": "Phaeocystis globosa virus virophage", "rank": "Species"}, "956483": {"name": "Mycoplasma bovis Hubei-1", "rank": "Strain"}, "101570": {"name": "Enterobacteria phage ES18", "rank": "Species"}, "1335631": {"name": "Frischella", "rank": "Genus"}, "1513531": {"name": "Tomato yellow leaf curl Indonesia virus", "rank": "Species"}, "1513530": {"name": "Tomato leaf curl Nigeria virus", "rank": "Species"}, "1410720": {"name": "Staphylococcus aureus W35356", "rank": "Strain"}, "1410721": {"name": "Staphylococcus aureus W41918", "rank": "Strain"}, "1410723": {"name": "Staphylococcus aureus H19520", "rank": "Strain"}, "1410724": {"name": "Staphylococcus aureus M41648", "rank": "Strain"}, "1410725": {"name": "Staphylococcus aureus F54452", "rank": "Strain"}, "1410726": {"name": "Staphylococcus aureus F54461", "rank": "Strain"}, "1410727": {"name": "Staphylococcus aureus F54467", "rank": "Strain"}, "1410728": {"name": "Staphylococcus aureus F54471", "rank": "Strain"}, "1410729": {"name": "Staphylococcus aureus F54494", "rank": "Strain"}, "559292": {"name": "Saccharomyces cerevisiae S288c", "rank": "Strain"}, "559295": {"name": "Lachancea thermotolerans CBS 6340", "rank": "Strain"}, "198822": {"name": "Candidatus Burkholderia kirkii", "rank": "Species"}, "1421914": {"name": "Staphylococcus aureus W82239", "rank": "Strain"}, "500635": {"name": "Mitsuokella multacida DSM 20544", "rank": "Strain"}, "1348337": {"name": "Serratia marcescens LCT-SM262", "rank": "Strain"}, "1348336": {"name": "Serratia marcescens LCT-SM166", "rank": "Strain"}, "1348335": {"name": "Staphylococcus aureus LCT-SA67", "rank": "Strain"}, "1348334": {"name": "Lyngbya aestuarii BL J", "rank": "Strain"}, "1229514": {"name": "Ralstonia sp. GA3-3", "rank": "Species"}, "1348331": {"name": "Thermotoga sp. A7A", "rank": "Species"}, "1229516": {"name": "Mycobacterium marinum str. Europe", "rank": "Strain"}, "1229518": {"name": "Lactococcus garvieae Tac2", "rank": "Strain"}, "1348339": {"name": "Pseudomonas aeruginosa LCT-PA41", "rank": "Strain"}, "1348338": {"name": "Leifsonia rubra CMS 76R", "rank": "Strain"}, "1382315": {"name": "Geobacillus vulcani PSS1", "rank": "Strain"}, "1382313": {"name": "Thermus scotoductus KI2", "rank": "Strain"}, "1173441": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN000217", "rank": "Strain"}, "1173440": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN000215", "rank": "Strain"}, "1173443": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN000220", "rank": "Strain"}, "1173442": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN000219", "rank": "Strain"}, "1173445": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN000224", "rank": "Strain"}, "1173444": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN000223", "rank": "Strain"}, "1173447": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN000227", "rank": "Strain"}, "1173446": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN000225", "rank": "Strain"}, "1173449": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN000233", "rank": "Strain"}, "1173448": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN000230", "rank": "Strain"}, "1074210": {"name": "Mouse astrovirus M-52/USA/2008", "rank": "Species"}, "1125764": {"name": "Cassava mosaic Madagascar virus", "rank": "Species"}, "387905": {"name": "Staphylococcus phage phiNM", "rank": "Species"}, "387909": {"name": "Staphylococcus phage phiNM3", "rank": "Species"}, "1305837": {"name": "Streptomyces sp. CNS606", "rank": "Species"}, "1305836": {"name": "Sporosarcina sp. EUR3 2.2.2", "rank": "Species"}, "1305835": {"name": "Rhodococcus sp. JG-3", "rank": "Species"}, "1305839": {"name": "Streptomyces sp. KhCrAH-337", "rank": "Species"}, "1388381": {"name": "Staphylococcus aureus M0577", "rank": "Strain"}, "1410931": {"name": "Salmonella enterica subsp. enterica serovar Cerro str. CFSAN001697", "rank": "Strain"}, "146825": {"name": "Halorhabdus", "rank": "Genus"}, "146826": {"name": "Halorhabdus utahensis", "rank": "Species"}, "322505": {"name": "Sharpea azabuensis", "rank": "Species"}, "302409": {"name": "Ehrlichia ruminantium str. Gardel", "rank": "Strain"}, "62913": {"name": "Georgefischeriales", "rank": "Order"}, "62919": {"name": "Tilletiariaceae", "rank": "Family"}, "302406": {"name": "Advenella mimigardefordensis", "rank": "Species"}, "333760": {"name": "Human papillomavirus type 16", "rank": "Strain"}, "333762": {"name": "Human papillomavirus type 26", "rank": "Strain"}, "333763": {"name": "Human papillomavirus type 32", "rank": "Strain"}, "333764": {"name": "Human papillomavirus type 34", "rank": "Strain"}, "333765": {"name": "Human papillomavirus type 53", "rank": "Strain"}, "333766": {"name": "Alphapapillomavirus 13", "rank": "Species"}, "333767": {"name": "Alphapapillomavirus 3", "rank": "Species"}, "333769": {"name": "Human papillomavirus type 90", "rank": "Strain"}, "1525753": {"name": "Streptomyces sp. JS01", "rank": "Species"}, "1094946": {"name": "Sphingomonas sp. JGI 0001003-C6", "rank": "Species"}, "450": {"name": "Legionella longbeachae", "rank": "Species"}, "1418110": {"name": "Aeromonas hydrophila AL09-71", "rank": "Strain"}, "1072517": {"name": "Blue squill virus A", "rank": "Species"}, "1225199": {"name": "Streptococcus mutans B06Sm2", "rank": "Strain"}, "412965": {"name": "Candidatus Vesicomyosocius okutanii HA", "rank": "Strain"}, "1225198": {"name": "Streptococcus mutans B082SM-A", "rank": "Strain"}, "421000": {"name": "Sulfitobacter donghicola", "rank": "Species"}, "1104996": {"name": "Gluconobacter frateurii NBRC 101659", "rank": "Strain"}, "1220589": {"name": "Lysinibacillus odysseyi 34hs-1 = NBRC 100172", "rank": "Strain"}, "1157478": {"name": "Enterococcus faecium EnGen0183", "rank": "Strain"}, "1157479": {"name": "Enterococcus faecium EnGen0184", "rank": "Strain"}, "1157476": {"name": "Enterococcus faecium EnGen0181", "rank": "Strain"}, "1157477": {"name": "Enterococcus faecium EnGen0182", "rank": "Strain"}, "1157474": {"name": "Enterococcus faecium EnGen0179", "rank": "Strain"}, "1157475": {"name": "Enterococcus faecium EnGen0180", "rank": "Strain"}, "1220581": {"name": "Rhizobium rhizogenes NBRC 13257", "rank": "Strain"}, "1157473": {"name": "Enterococcus faecium EnGen0178", "rank": "Strain"}, "1220583": {"name": "Gordonia aichiensis NBRC 108223", "rank": "Strain"}, "1220582": {"name": "Rhizobium rubi NBRC 13261", "rank": "Strain"}, "999544": {"name": "Salinispora pacifica DSM 45548", "rank": "Strain"}, "1169162": {"name": "Salinispora arenicola CNY011", "rank": "Strain"}, "327280": {"name": "Okra yellow mosaic Mexico virus", "rank": "Species"}, "1225190": {"name": "Streptococcus mutans B084SM-A", "rank": "Strain"}, "1225193": {"name": "Streptococcus mutans B09Sm1", "rank": "Strain"}, "1115539": {"name": "Yam bean mosaic virus", "rank": "Species"}, "1225192": {"name": "Streptococcus mutans B07Sm2", "rank": "Strain"}, "69929": {"name": "Xanthomonas arboricola pv. pruni", "rank": "Strain"}, "1268336": {"name": "Rhizobium sp. JGI 0001014-F05", "rank": "Species"}, "1225194": {"name": "Streptococcus mutans B24Sm2", "rank": "Strain"}, "1438704": {"name": "Klebsiella pneumoniae BWH 46", "rank": "Strain"}, "1388758": {"name": "Dehalococcoides mccartyi GY50", "rank": "Strain"}, "1438706": {"name": "Klebsiella pneumoniae BWH 48", "rank": "Strain"}, "1438700": {"name": "Klebsiella pneumoniae BIDMC 61", "rank": "Strain"}, "1268334": {"name": "Bradyrhizobium sp. JGI 0001019-M21", "rank": "Species"}, "1438702": {"name": "Klebsiella pneumoniae BIDMC 69", "rank": "Strain"}, "1438703": {"name": "Klebsiella pneumoniae BWH 45", "rank": "Strain"}, "1388751": {"name": "Campylobacter subantarcticus LMG 24374", "rank": "Strain"}, "1388750": {"name": "Campylobacter lari CCUG 22395", "rank": "Strain"}, "1388753": {"name": "Campylobacter peloridis LMG 23910", "rank": "Strain"}, "1388752": {"name": "Campylobacter subantarcticus LMG 24377", "rank": "Strain"}, "1438708": {"name": "Klebsiella pneumoniae CHS 02", "rank": "Strain"}, "1438709": {"name": "Klebsiella pneumoniae CHS 03", "rank": "Strain"}, "1411538": {"name": "Staphylococcus aureus H64299", "rank": "Strain"}, "1008": {"name": "Saprospira grandis", "rank": "Species"}, "1007": {"name": "Saprospira", "rank": "Genus"}, "1006": {"name": "Marivirga tractuosa", "rank": "Species"}, "1411534": {"name": "Staphylococcus aureus H57821", "rank": "Strain"}, "1411535": {"name": "Staphylococcus aureus H57822", "rank": "Strain"}, "1411532": {"name": "Staphylococcus aureus H40575", "rank": "Strain"}, "1411533": {"name": "Staphylococcus aureus H40583", "rank": "Strain"}, "1411530": {"name": "Staphylococcus aureus H37235", "rank": "Strain"}, "1411531": {"name": "Staphylococcus aureus H40569", "rank": "Strain"}, "52959": {"name": "Polaribacter", "rank": "Genus"}, "1094943": {"name": "Sphingomonas sp. JGI 0001002-I20", "rank": "Species"}, "1384459": {"name": "Methyloceanibacter caenitepidi", "rank": "Species"}, "1522060": {"name": "Pantoea sp. 3.5.1", "rank": "Species"}, "1911": {"name": "Streptomyces griseus", "rank": "Species"}, "1912": {"name": "Streptomyces hygroscopicus", "rank": "Species"}, "1914": {"name": "Streptomyces lavendulae", "rank": "Species"}, "1916": {"name": "Streptomyces lividans", "rank": "Species"}, "172314": {"name": "Ljungan virus", "rank": "Species"}, "1216928": {"name": "Heartland virus", "rank": "Species"}, "1216926": {"name": "Escherichia phage ADB-2", "rank": "Species"}, "411855": {"name": "Unclassified Phytoreovirus", "rank": "No rank"}, "411854": {"name": "Homalodisca vitripennis reovirus", "rank": "Species"}, "1245469": {"name": "Bradyrhizobium oligotrophicum S58", "rank": "Strain"}, "60520": {"name": "Lactobacillus paraplantarum", "rank": "Species"}, "1304874": {"name": "Aminiphilus circumscriptus DSM 16581", "rank": "Strain"}, "1304875": {"name": "Aminobacterium mobile DSM 12262", "rank": "Strain"}, "437671": {"name": "Brucella sp. F96/2", "rank": "Species"}, "437670": {"name": "Brucella sp. F23/97", "rank": "Species"}, "267849": {"name": "Nitrincola", "rank": "Genus"}, "1304878": {"name": "Bradyrhizobium japonicum in8p8", "rank": "Strain"}, "1304879": {"name": "Bradyrhizobium japonicum is5", "rank": "Strain"}, "1267535": {"name": "Acidobacteriaceae bacterium KBS 96", "rank": "Species"}, "1267534": {"name": "Acidobacteriaceae bacterium KBS 89", "rank": "Species"}, "64186": {"name": "Streptococcus phage Sfi21", "rank": "Species"}, "64187": {"name": "Xanthomonas oryzae pv. oryzae", "rank": "Strain"}, "1267533": {"name": "Acidobacteriaceae bacterium KBS 83", "rank": "Species"}, "1306023": {"name": "Bacillus thuringiensis serovar tolworthi NA205-3", "rank": "Strain"}, "1214564": {"name": "Caldicellulosiruptor sp. F32", "rank": "Species"}, "320483": {"name": "Anaplasma marginale str. Florida", "rank": "Strain"}, "88138": {"name": "Modestobacter", "rank": "Genus"}, "88132": {"name": "Eremococcus coleocola", "rank": "Species"}, "701347": {"name": "Enterobacter lignolyticus SCF1", "rank": "Strain"}, "1150600": {"name": "Arcticibacter svalbardensis MN12-7", "rank": "Strain"}, "1078003": {"name": "Mycobacterium avium subsp. paratuberculosis 4B", "rank": "Strain"}, "872294": {"name": "Staphylococcus phage SAP-26", "rank": "Species"}, "1348853": {"name": "Novosphingobium malaysiense", "rank": "Species"}, "1093099": {"name": "Campylobacter fetus subsp. venerealis 97/608", "rank": "Strain"}, "42475": {"name": "Rice ragged stunt virus", "rank": "Species"}, "1396510": {"name": "Gallibacterium anatis 4895", "rank": "Strain"}, "1396511": {"name": "Gallibacterium anatis 7990", "rank": "Strain"}, "1396512": {"name": "Gallibacterium anatis str. Avicor", "rank": "Strain"}, "1396513": {"name": "Gallibacterium anatis CCM5995", "rank": "Strain"}, "1396514": {"name": "Gallibacterium anatis IPDH697-78", "rank": "Strain"}, "1396515": {"name": "Gallibacterium anatis 10672-6", "rank": "Strain"}, "46607": {"name": "Andes virus", "rank": "Species"}, "1324223": {"name": "Mycobacterium tuberculosis TKK-01-0006", "rank": "Strain"}, "1324222": {"name": "Mycobacterium tuberculosis TKK-01-0005", "rank": "Strain"}, "1324221": {"name": "Mycobacterium tuberculosis TKK-01-0004", "rank": "Strain"}, "1324220": {"name": "Mycobacterium tuberculosis TKK-01-0003", "rank": "Strain"}, "1324227": {"name": "Mycobacterium tuberculosis TKK-01-0011", "rank": "Strain"}, "1324226": {"name": "Mycobacterium tuberculosis TKK-01-0010", "rank": "Strain"}, "1324225": {"name": "Mycobacterium tuberculosis TKK-01-0009", "rank": "Strain"}, "1324224": {"name": "Mycobacterium tuberculosis TKK-01-0007", "rank": "Strain"}, "910040": {"name": "Aminicenantes bacterium SCGC AAA252-O03", "rank": "Species"}, "910041": {"name": "Aminicenantes bacterium SCGC AAA252-G05", "rank": "Species"}, "1324229": {"name": "Mycobacterium tuberculosis TKK-01-0013", "rank": "Strain"}, "1324228": {"name": "Mycobacterium tuberculosis TKK-01-0012", "rank": "Strain"}, "1221328": {"name": "Bacillus subtilis subsp. subtilis str. AG1839", "rank": "Strain"}, "910047": {"name": "Candidatus Latescibacter anaerobius SCGC AAA252-E07", "rank": "Strain"}, "163665": {"name": "Dysgonomonas mossii", "rank": "Species"}, "1191061": {"name": "Klebsiella oxytoca E718", "rank": "Strain"}, "1134831": {"name": "Enterococcus faecium P1140", "rank": "Strain"}, "1134830": {"name": "Enterococcus faecium P1139", "rank": "Strain"}, "1134833": {"name": "Enterococcus faecium P1986", "rank": "Strain"}, "1134832": {"name": "Enterococcus faecium P1190", "rank": "Strain"}, "1134835": {"name": "Enterococcus faecium R494", "rank": "Strain"}, "1134834": {"name": "Enterococcus faecium R446", "rank": "Strain"}, "1134837": {"name": "Enterococcus faecium R497", "rank": "Strain"}, "1169293": {"name": "Enterococcus faecalis EnGen0336", "rank": "Strain"}, "1134839": {"name": "Enterococcus faecium R501", "rank": "Strain"}, "1134838": {"name": "Enterococcus faecium R499", "rank": "Strain"}, "77037": {"name": "Wolbachia endosymbiont of Muscidifurax uniraptor", "rank": "Species"}, "77038": {"name": "Wolbachia endosymbiont of Drosophila simulans", "rank": "Species"}, "754762": {"name": "Rhizobium leguminosarum bv. trifolii WSM2297", "rank": "Strain"}, "580050": {"name": "Bifidobacterium animalis subsp. lactis Bl-04", "rank": "Strain"}, "754764": {"name": "Rhizobium leguminosarum bv. trifolii WSM597", "rank": "Strain"}, "363331": {"name": "Chryseobacterium taiwanense", "rank": "Species"}, "216465": {"name": "Polaromonas naphthalenivorans", "rank": "Species"}, "216466": {"name": "Streptococcus agalactiae serogroup V", "rank": "Strain"}, "48736": {"name": "Ralstonia", "rank": "Genus"}, "40127": {"name": "Neurospora tetrasperma", "rank": "Species"}, "40120": {"name": "Densovirinae", "rank": "Subfamily"}, "40121": {"name": "Erythroparvovirus", "rank": "Genus"}, "40122": {"name": "Iteradensovirus", "rank": "Genus"}, "325462": {"name": "Lambdapapillomavirus", "rank": "Genus"}, "290512": {"name": "Prosthecochloris aestuarii DSM 271", "rank": "Strain"}, "1221996": {"name": "Bacillus thermotolerans", "rank": "Species"}, "76343": {"name": "Beet soil-borne mosaic virus", "rank": "Species"}, "908070": {"name": "Bhendi yellow vein mosaic betasatellite", "rank": "Species"}, "908072": {"name": "Bhendi yellow vein mosaic betasatellite India:Coimbator:OYCO1:2005", "rank": "Strain"}, "260552": {"name": "Microbulbifer agarilyticus", "rank": "Species"}, "379899": {"name": "Niabella", "rank": "Genus"}, "394503": {"name": "Clostridium cellulolyticum H10", "rank": "Strain"}, "1295746": {"name": "Mycobacterium tuberculosis TKK_02_0030", "rank": "Strain"}, "475879": {"name": "Paralichthys olivaceus birnavirus", "rank": "Species"}, "1295745": {"name": "Mycobacterium tuberculosis TKK_02_0029", "rank": "Strain"}, "1169279": {"name": "Enterococcus faecium EnGen0371", "rank": "Strain"}, "1169278": {"name": "Enterococcus faecium EnGen0372", "rank": "Strain"}, "1295744": {"name": "Mycobacterium tuberculosis TKK_02_0028", "rank": "Strain"}, "641892": {"name": "Candidatus Sulcia muelleri DMIN", "rank": "Strain"}, "1169271": {"name": "Staphylococcus aureus M1256", "rank": "Strain"}, "1169270": {"name": "Staphylococcus aureus M1244", "rank": "Strain"}, "1169273": {"name": "Staphylococcus aureus M1286", "rank": "Strain"}, "1169272": {"name": "Staphylococcus aureus M1275", "rank": "Strain"}, "1169275": {"name": "Staphylococcus aureus M1374", "rank": "Strain"}, "1345000": {"name": "Staphylococcus epidermidis APO27", "rank": "Strain"}, "1169277": {"name": "Staphylococcus aureus M1510", "rank": "Strain"}, "1169276": {"name": "Staphylococcus aureus M1405", "rank": "Strain"}, "1403896": {"name": "Staphylococcus aureus M1514", "rank": "Strain"}, "31977": {"name": "Veillonellaceae", "rank": "Family"}, "1403894": {"name": "Staphylococcus aureus M1512", "rank": "Strain"}, "1403895": {"name": "Staphylococcus aureus M1513", "rank": "Strain"}, "1403892": {"name": "Staphylococcus aureus M1509", "rank": "Strain"}, "1403893": {"name": "Staphylococcus aureus M1511", "rank": "Strain"}, "1403890": {"name": "Staphylococcus aureus M1507", "rank": "Strain"}, "1403891": {"name": "Staphylococcus aureus M1508", "rank": "Strain"}, "349163": {"name": "Acidiphilium cryptum JF-5", "rank": "Strain"}, "349161": {"name": "Desulfotomaculum reducens MI-1", "rank": "Strain"}, "1295792": {"name": "Mycobacterium tuberculosis TKK_02_0076", "rank": "Strain"}, "349165": {"name": "Almpiwar group", "rank": "No rank"}, "1403899": {"name": "Staphylococcus aureus M1518", "rank": "Strain"}, "676234": {"name": "Furcraea necrotic streak virus", "rank": "Species"}, "316606": {"name": "Segniliparaceae", "rank": "Family"}, "1293907": {"name": "Bartonella bacilliformis CAR600-02", "rank": "Strain"}, "685950": {"name": "Fervidicoccus", "rank": "Genus"}, "487311": {"name": "Anopheles gambiae densovirus", "rank": "Strain"}, "1295797": {"name": "Mycobacterium tuberculosis OFXR-2", "rank": "Strain"}, "585396": {"name": "Escherichia coli O111:H- str. 11128", "rank": "Strain"}, "585397": {"name": "Escherichia coli ED1a", "rank": "Strain"}, "1049821": {"name": "Leptospira interrogans serovar Copenhageni str. R103", "rank": "Strain"}, "1049820": {"name": "Leptospira interrogans serovar Copenhageni str. P2518", "rank": "Strain"}, "585395": {"name": "Escherichia coli O103:H2 str. 12009", "rank": "Strain"}, "1328399": {"name": "Klebsiella pneumoniae BIDMC 2A", "rank": "Strain"}, "1402650": {"name": "Staphylococcus aureus M1137", "rank": "Strain"}, "1388416": {"name": "Staphylococcus aureus M0626", "rank": "Strain"}, "1388417": {"name": "Staphylococcus aureus M0627", "rank": "Strain"}, "1388414": {"name": "Staphylococcus aureus M0623", "rank": "Strain"}, "1388415": {"name": "Staphylococcus aureus M0624", "rank": "Strain"}, "1388412": {"name": "Staphylococcus aureus M0619", "rank": "Strain"}, "1388413": {"name": "Staphylococcus aureus M0621", "rank": "Strain"}, "1388410": {"name": "Staphylococcus aureus M0617", "rank": "Strain"}, "1388411": {"name": "Staphylococcus aureus M0618", "rank": "Strain"}, "1388418": {"name": "Staphylococcus aureus M0630", "rank": "Strain"}, "1388419": {"name": "Staphylococcus aureus M0631", "rank": "Strain"}, "1435008": {"name": "Citrus endogenous pararetrovirus", "rank": "Species"}, "1160137": {"name": "Nocardia sp. BMG111209", "rank": "Species"}, "188913": {"name": "Cetobacterium somerae", "rank": "Species"}, "569360": {"name": "Fusarium sambucinum species complex", "rank": "No rank"}, "188910": {"name": "Microchaete", "rank": "Genus"}, "569365": {"name": "Cladophialophora immunda", "rank": "Species"}, "1328391": {"name": "Klebsiella pneumoniae UCICRE 4", "rank": "Strain"}, "1328390": {"name": "Klebsiella pneumoniae UCICRE 2", "rank": "Strain"}, "234621": {"name": "Rhodococcus erythropolis PR4", "rank": "Strain"}, "1457153": {"name": "Chlamydia gallinacea", "rank": "Species"}, "1567486": {"name": "Enterobacteria phage P88", "rank": "Species"}, "648": {"name": "Aeromonas caviae", "rank": "Species"}, "1457154": {"name": "Candidatus Accumulibacter sp. SK-01", "rank": "Species"}, "1457158": {"name": "Bacillus amyloliquefaciens EBL11", "rank": "Strain"}, "1448493": {"name": "Mycobacterium tuberculosis TKK_05MA_0012", "rank": "Strain"}, "1448492": {"name": "Mycobacterium tuberculosis TKK_05MA_0011", "rank": "Strain"}, "1448491": {"name": "Mycobacterium tuberculosis TKK_05MA_0010", "rank": "Strain"}, "1448490": {"name": "Mycobacterium tuberculosis TKK_05MA_0009", "rank": "Strain"}, "1448497": {"name": "Mycobacterium tuberculosis TKK_05MA_0018", "rank": "Strain"}, "1448496": {"name": "Mycobacterium tuberculosis TKK_05MA_0017", "rank": "Strain"}, "1448495": {"name": "Mycobacterium tuberculosis TKK_05MA_0016", "rank": "Strain"}, "1448498": {"name": "Mycobacterium tuberculosis TKK_05MA_0020", "rank": "Strain"}, "547467": {"name": "Diascia yellow mottle virus", "rank": "Species"}, "10710": {"name": "Enterobacteria phage lambda", "rank": "Species"}, "203697": {"name": "Derxia", "rank": "Genus"}, "10717": {"name": "Bacillus phage phi105", "rank": "Species"}, "203692": {"name": "Spirochaetia", "rank": "Class"}, "203693": {"name": "Nitrospira", "rank": "Class"}, "131081": {"name": "Corynebacterium capitovis", "rank": "Species"}, "10719": {"name": "Streptomyces phage phiC31", "rank": "Species"}, "203699": {"name": "Derxia gummosa", "rank": "Species"}, "1051974": {"name": "Granulibacter bethesdensis CGDNIH2", "rank": "Strain"}, "646294": {"name": "St-Valerien swine virus", "rank": "Species"}, "1051972": {"name": "Neisseria weaveri ATCC 51223", "rank": "Strain"}, "1051973": {"name": "Rhodococcus fascians D188", "rank": "Strain"}, "1219465": {"name": "Lone Star virus", "rank": "Species"}, "1163398": {"name": "Pseudomonas sp. HYS", "rank": "Species"}, "938623": {"name": "Alpha proteobacterium SCGC AAA024-N17", "rank": "Species"}, "238030": {"name": "Pasteuria nishizawae str. North American", "rank": "Strain"}, "938624": {"name": "Alpha proteobacterium SCGC AAA027-C06", "rank": "Species"}, "1163390": {"name": "Escherichia coli O111:H11", "rank": "Strain"}, "183795": {"name": "Pseudomonas mediterranea", "rank": "Species"}, "1163392": {"name": "Pseudomonas aeruginosa ATCC 14886", "rank": "Strain"}, "1163395": {"name": "Pseudomonas aeruginosa E2", "rank": "Strain"}, "1163396": {"name": "Pseudomonas aeruginosa CI27", "rank": "Strain"}, "347834": {"name": "Rhizobium etli CFN 42", "rank": "Strain"}, "679189": {"name": "Prevotella timonensis CRIS 5C-B1", "rank": "Strain"}, "679188": {"name": "Lactobacillus crispatus 214-1", "rank": "Strain"}, "105559": {"name": "Nitrosococcus watsonii C-113", "rank": "Strain"}, "882104": {"name": "Methanoregula formicica", "rank": "Species"}, "1162668": {"name": "Leptospirillum ferrooxidans C2-3", "rank": "Strain"}, "882101": {"name": "Sinorhizobium fredii GR64", "rank": "Strain"}, "882100": {"name": "Mycobacterium tuberculosis BTB05-559", "rank": "Strain"}, "882102": {"name": "Vibrio anguillarum 775", "rank": "Strain"}, "1402682": {"name": "Staphylococcus aureus M1172", "rank": "Strain"}, "1160283": {"name": "Microcystis aeruginosa PCC 9807", "rank": "Strain"}, "1160282": {"name": "Microcystis aeruginosa PCC 9806", "rank": "Strain"}, "1160281": {"name": "Microcystis aeruginosa PCC 9443", "rank": "Strain"}, "1160280": {"name": "Microcystis aeruginosa PCC 9432", "rank": "Strain"}, "1160286": {"name": "Microcystis aeruginosa PCC 9717", "rank": "Strain"}, "1160285": {"name": "Microcystis aeruginosa PCC 9809", "rank": "Strain"}, "1160284": {"name": "Microcystis aeruginosa PCC 9808", "rank": "Strain"}, "357278": {"name": "Lactobacillus parabrevis", "rank": "Species"}, "278096": {"name": "Unclassified Lentisphaerae", "rank": "No rank"}, "709797": {"name": "Bradyrhizobiaceae bacterium SG-6C", "rank": "Species"}, "1446723": {"name": "Escherichia coli O26:H11 str. 2010C-4430", "rank": "Strain"}, "1446722": {"name": "Escherichia coli O26:H11 str. 2010C-4244", "rank": "Strain"}, "1446721": {"name": "Escherichia coli O26:H11 str. 2010C-3902", "rank": "Strain"}, "1446720": {"name": "Escherichia coli O26:H11 str. 2010C-3871", "rank": "Strain"}, "1402679": {"name": "Staphylococcus aureus M1168", "rank": "Strain"}, "1402678": {"name": "Staphylococcus aureus M1166", "rank": "Strain"}, "1446725": {"name": "Escherichia coli O26:H11 str. 2010C-4834", "rank": "Strain"}, "1446724": {"name": "Escherichia coli O26:H11 str. 2010C-4819", "rank": "Strain"}, "1402675": {"name": "Staphylococcus aureus M1163", "rank": "Strain"}, "1402674": {"name": "Staphylococcus aureus M1162", "rank": "Strain"}, "1402677": {"name": "Staphylococcus aureus M1165", "rank": "Strain"}, "1402676": {"name": "Staphylococcus aureus M1164", "rank": "Strain"}, "1402671": {"name": "Staphylococcus aureus M1159", "rank": "Strain"}, "1402670": {"name": "Staphylococcus aureus M1158", "rank": "Strain"}, "1402673": {"name": "Staphylococcus aureus M1161", "rank": "Strain"}, "1402672": {"name": "Staphylococcus aureus M1160", "rank": "Strain"}, "208444": {"name": "Amycolatopsis vancoresmycina", "rank": "Species"}, "208447": {"name": "Oceanithermus", "rank": "Genus"}, "1339307": {"name": "Bacteroides fragilis str. 3719 A10", "rank": "Strain"}, "208441": {"name": "Amycolatopsis decaplanina", "rank": "Species"}, "208443": {"name": "Amycolatopsis balhimycina", "rank": "Species"}, "279058": {"name": "Collimonas arenae", "rank": "Species"}, "1096930": {"name": "Novosphingobium lindaniclasticum LE124", "rank": "Strain"}, "28175": {"name": "Vibrio orientalis", "rank": "Species"}, "28174": {"name": "Vibrio ordalii", "rank": "Species"}, "28176": {"name": "Candidatus Photodesmus katoptron", "rank": "Species"}, "28173": {"name": "Vibrio nigripulchritudo", "rank": "Species"}, "28172": {"name": "Vibrio metschnikovii", "rank": "Species"}, "185793": {"name": "Tomato yellow leaf curl China virus", "rank": "Species"}, "1396141": {"name": "Haloferula sp. BvORR071", "rank": "Species"}, "380358": {"name": "Xanthomonas albilineans GPE PC73", "rank": "Strain"}, "1402687": {"name": "Staphylococcus aureus M1178", "rank": "Strain"}, "1315308": {"name": "Streptococcus pneumoniae MNZ14", "rank": "Strain"}, "1315309": {"name": "Streptococcus pneumoniae MNZ37", "rank": "Strain"}, "1315307": {"name": "Streptococcus pneumoniae MNZ11b", "rank": "Strain"}, "671065": {"name": "Metallosphaera yellowstonensis MK1", "rank": "Strain"}, "1391647": {"name": "Clostridium sp. Ade.TY", "rank": "Species"}, "1391646": {"name": "Clostridium bifermentans WYM", "rank": "Strain"}, "1284208": {"name": "Fusarium graminearum hypovirus 1", "rank": "Species"}, "1422619": {"name": "Staphylococcus aureus VET0382R", "rank": "Strain"}, "1422618": {"name": "Staphylococcus aureus VET0376R", "rank": "Strain"}, "1422615": {"name": "Staphylococcus aureus VET0368R", "rank": "Strain"}, "1422614": {"name": "Staphylococcus aureus VET0367R", "rank": "Strain"}, "1422617": {"name": "Staphylococcus aureus VET0373R", "rank": "Strain"}, "1422616": {"name": "Staphylococcus aureus VET0369R", "rank": "Strain"}, "1422611": {"name": "Staphylococcus aureus VET0363R", "rank": "Strain"}, "1422610": {"name": "Staphylococcus aureus VET0361R", "rank": "Strain"}, "1422613": {"name": "Staphylococcus aureus VET0366R", "rank": "Strain"}, "1445506": {"name": "Yarrowia lipolytica PO1f", "rank": "Strain"}, "1246339": {"name": "Staphylococcus aureus subsp. aureus ST2249", "rank": "Strain"}, "504": {"name": "Kingella kingae", "rank": "Species"}, "505": {"name": "Kingella oralis", "rank": "Species"}, "506": {"name": "Alcaligenaceae", "rank": "Family"}, "507": {"name": "Alcaligenes", "rank": "Genus"}, "500": {"name": "Thermomicrobium roseum", "rank": "Species"}, "680287": {"name": "Ahjdlikevirus", "rank": "Genus"}, "502": {"name": "Kingella denitrificans", "rank": "Species"}, "40571": {"name": "Lentzea albidocapillata", "rank": "Species"}, "40576": {"name": "Xenorhabdus bovienii", "rank": "Species"}, "981221": {"name": "Helicobacter pylori NQ4191", "rank": "Strain"}, "1441928": {"name": "Pseudomonas aeruginosa RB-48", "rank": "Strain"}, "1169157": {"name": "Streptomyces sp. CNQ766", "rank": "Species"}, "1192034": {"name": "Chondromyces apiculatus DSM 436", "rank": "Strain"}, "1336752": {"name": "Vibrio fluvialis PG41", "rank": "Strain"}, "1336753": {"name": "Vibrio fluvialis I21563", "rank": "Strain"}, "333367": {"name": "Clostridium asparagiforme", "rank": "Species"}, "333361": {"name": "Corchorus yellow vein virus", "rank": "Species"}, "5592": {"name": "Microascales", "rank": "Order"}, "2697": {"name": "Heliobacterium", "rank": "Genus"}, "196164": {"name": "Corynebacterium efficiens YS-314", "rank": "Strain"}, "553481": {"name": "Mycobacterium avium subsp. avium ATCC 25291", "rank": "Strain"}, "891412": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. 607308-9", "rank": "Strain"}, "891411": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. 77-0424", "rank": "Strain"}, "553482": {"name": "Streptococcus equi subsp. equi 4047", "rank": "Strain"}, "891414": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. 629163", "rank": "Strain"}, "228578": {"name": "Youcai mosaic virus", "rank": "Species"}, "56636": {"name": "Aeropyrum pernix", "rank": "Species"}, "56635": {"name": "Aeropyrum", "rank": "Genus"}, "754083": {"name": "Escherichia coli STEC_94C", "rank": "Strain"}, "228574": {"name": "Paenibacillus lactis", "rank": "Species"}, "1200386": {"name": "Neisseria meningitidis alpha704", "rank": "Strain"}, "1301915": {"name": "Methanocaldococcus sp. JH146", "rank": "Species"}, "529884": {"name": "Candidatus Rhodoluna lacicola", "rank": "Species"}, "529885": {"name": "Enterococcus faecium E980", "rank": "Strain"}, "373058": {"name": "Tomato bushy stunt virus satellite RNA", "rank": "Species"}, "529881": {"name": "Candidatus Aquiluna", "rank": "Genus"}, "529883": {"name": "Candidatus Rhodoluna", "rank": "Genus"}, "448176": {"name": "Granulicoccus", "rank": "Genus"}, "1502488": {"name": "Alpha proteobacterium QL1", "rank": "Species"}, "5334": {"name": "Schizophyllum commune", "rank": "Species"}, "1340847": {"name": "Streptococcus suis T15", "rank": "Strain"}, "5333": {"name": "Schizophyllum", "rank": "Genus"}, "5332": {"name": "Schizophyllaceae", "rank": "Family"}, "5339": {"name": "Agaricaceae", "rank": "Family"}, "5338": {"name": "Agaricales", "rank": "Order"}, "758828": {"name": "Succinivibrionaceae bacterium WG-1", "rank": "Species"}, "96901": {"name": "Pseudomonas synxantha BG33R", "rank": "Strain"}, "655225": {"name": "Oenococcus oeni AWRIB429", "rank": "Strain"}, "281915": {"name": "Curvibacter", "rank": "Genus"}, "273075": {"name": "Thermoplasma acidophilum DSM 1728", "rank": "Strain"}, "1005528": {"name": "Escherichia coli EC4422", "rank": "Strain"}, "1005529": {"name": "Escherichia coli EC4013", "rank": "Strain"}, "1224136": {"name": "Enterobacteriaceae bacterium LSJC7", "rank": "Species"}, "1401325": {"name": "Ornithobacterium rhinotracheale ORT-UMN 88", "rank": "Strain"}, "1005520": {"name": "Escherichia coli TW09109", "rank": "Strain"}, "1005522": {"name": "Escherichia coli TW10119", "rank": "Strain"}, "1005523": {"name": "Escherichia coli EC4203", "rank": "Strain"}, "1005526": {"name": "Escherichia coli TW14301", "rank": "Strain"}, "1005527": {"name": "Escherichia coli EC4421", "rank": "Strain"}, "693216": {"name": "Cronobacter turicensis z3032", "rank": "Strain"}, "57037": {"name": "Lactobacillus zeae", "rank": "Species"}, "1412559": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20120677", "rank": "Strain"}, "1412558": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20120968", "rank": "Strain"}, "1412555": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20121765", "rank": "Strain"}, "1412554": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20121744", "rank": "Strain"}, "1412557": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20121542", "rank": "Strain"}, "1412556": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20120496", "rank": "Strain"}, "1412551": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20121753", "rank": "Strain"}, "1412550": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20120722", "rank": "Strain"}, "1412553": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20120697", "rank": "Strain"}, "1412552": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20120469", "rank": "Strain"}, "1417105": {"name": "Staphylococcus aureus T89906", "rank": "Strain"}, "1417104": {"name": "Staphylococcus aureus M42496", "rank": "Strain"}, "1417107": {"name": "Staphylococcus aureus W70590", "rank": "Strain"}, "92713": {"name": "Parachlamydiaceae", "rank": "Family"}, "35829": {"name": "Acetivibrio", "rank": "Genus"}, "1417100": {"name": "Staphylococcus aureus M42485", "rank": "Strain"}, "425104": {"name": "Shewanella sediminis HAW-EB3", "rank": "Strain"}, "1417102": {"name": "Staphylococcus aureus H43996", "rank": "Strain"}, "35825": {"name": "Pseudobacteroides cellulosolvens", "rank": "Species"}, "1248760": {"name": "Blastomonas sp. AAP53", "rank": "Species"}, "1286141": {"name": "Meno virus", "rank": "Species"}, "1417108": {"name": "Staphylococcus aureus W70599", "rank": "Strain"}, "35823": {"name": "Arthrospira", "rank": "Genus"}, "1286142": {"name": "Nse virus", "rank": "Species"}, "1462527": {"name": "Oceanobacillus sp. S5", "rank": "Species"}, "1462526": {"name": "Virgibacillus sp. Vm-5", "rank": "Species"}, "340680": {"name": "Amorphus coralli", "rank": "Species"}, "1137931": {"name": "Astrovirus wild boar/WBAstV-1/2011/HUN", "rank": "Species"}, "44474": {"name": "Pleurocapsa", "rank": "Genus"}, "44470": {"name": "Natronococcus amylolyticus", "rank": "Species"}, "44471": {"name": "Microcoleus", "rank": "Genus"}, "651457": {"name": "Kosmotoga olearia", "rank": "Species"}, "651456": {"name": "Kosmotoga", "rank": "Genus"}, "184917": {"name": "Desulfovibrio magneticus", "rank": "Species"}, "956149": {"name": "Cronobacter sakazakii SP291", "rank": "Strain"}, "663954": {"name": "Streptococcus dysgalactiae subsp. equisimilis ATCC 12394", "rank": "Strain"}, "1076727": {"name": "Candidatus Photodesmus", "rank": "Genus"}, "663951": {"name": "Staphylococcus aureus subsp. aureus TW20", "rank": "Strain"}, "663952": {"name": "Streptococcus dysgalactiae subsp. dysgalactiae ATCC 27957", "rank": "Strain"}, "1306951": {"name": "Dickeya zeae DZ2Q", "rank": "Strain"}, "292629": {"name": "Anaerolineales", "rank": "Order"}, "292628": {"name": "Anaerolineaceae", "rank": "Family"}, "674954": {"name": "Trichomonas vaginalis virus 2", "rank": "Species"}, "292627": {"name": "Cowpea severe leaf curl-associated DNA beta", "rank": "Species"}, "292626": {"name": "Luffa puckering and leaf distortion-associated DNA beta", "rank": "Species"}, "292625": {"name": "Anaerolineae", "rank": "Class"}, "1221257": {"name": "Acinetobacter baumannii AB_2008-15-52", "rank": "Strain"}, "1357269": {"name": "Staphylococcus sp. EGD-HP3", "rank": "Species"}, "1357268": {"name": "Enterobacter sp. EGD-HP1", "rank": "Species"}, "1221255": {"name": "Acinetobacter baumannii AB_2008-15-34-7", "rank": "Strain"}, "1281128": {"name": "Escherichia coli HVH 201 (4-4459431)", "rank": "Strain"}, "1221258": {"name": "Acinetobacter baumannii AB_2008-15-69", "rank": "Strain"}, "1221259": {"name": "Acinetobacter baumannii AB_2008-15-70", "rank": "Strain"}, "1438823": {"name": "Mycobacterium bovis Bz 31150", "rank": "Strain"}, "516704": {"name": "Pontibacillus halophilus", "rank": "Species"}, "1387197": {"name": "Candidatus Schmidhempelia bombi str. Bimp", "rank": "Strain"}, "240865": {"name": "Honeysuckle yellow vein virus", "rank": "Species"}, "110500": {"name": "Pelotomaculum thermopropionicum", "rank": "Species"}, "124225": {"name": "Brackiella oedipodis", "rank": "Species"}, "124224": {"name": "Brackiella", "rank": "Genus"}, "1430331": {"name": "Geobacillus sp. G1w1", "rank": "Species"}, "1279033": {"name": "Rhizobium sp. JGI 0001012-J08", "rank": "Species"}, "1438803": {"name": "Klebsiella pneumoniae UCI 56", "rank": "Strain"}, "1438802": {"name": "Klebsiella pneumoniae UCI 55", "rank": "Strain"}, "1383062": {"name": "Mannheimia haemolytica serotype A1/A6", "rank": "Strain"}, "1438801": {"name": "Klebsiella pneumoniae MGH 80", "rank": "Strain"}, "1353978": {"name": "Shigella sonnei 1DT-1", "rank": "Strain"}, "1438800": {"name": "Klebsiella pneumoniae MGH 79", "rank": "Strain"}, "1438807": {"name": "Klebsiella pneumoniae UCI 62", "rank": "Strain"}, "1438805": {"name": "Klebsiella pneumoniae UCI 60", "rank": "Strain"}, "1283279": {"name": "Saccharopolyspora rectivirgula DSM 43747", "rank": "Strain"}, "1265690": {"name": "Nafulsella turpanensis", "rank": "Species"}, "1223543": {"name": "Gordonia paraffinivorans NBRC 108238", "rank": "Strain"}, "1223544": {"name": "Gordonia sihwensis NBRC 108236", "rank": "Strain"}, "1223545": {"name": "Gordonia soli NBRC 108243", "rank": "Strain"}, "673375": {"name": "Sodalis phage SO-1", "rank": "Species"}, "673376": {"name": "Clostridium phage phiCP26F", "rank": "Species"}, "1278298": {"name": "Actinomyces slackii ATCC 49928", "rank": "Strain"}, "1278299": {"name": "Acholeplasma multilocale ATCC 49900", "rank": "Strain"}, "542838": {"name": "Unassigned Autographivirinae", "rank": "No rank"}, "542836": {"name": "Picovirinae", "rank": "Subfamily"}, "542837": {"name": "Sp6likevirus", "rank": "Genus"}, "542835": {"name": "Autographivirinae", "rank": "Subfamily"}, "1438827": {"name": "Mycobacterium tuberculosis Mr 4387", "rank": "Strain"}, "1120984": {"name": "Amycolatopsis taiwanensis DSM 45107", "rank": "Strain"}, "1281129": {"name": "Escherichia coli HVH 202 (4-3163997)", "rank": "Strain"}, "1438808": {"name": "Klebsiella pneumoniae UCI 63", "rank": "Strain"}, "1120985": {"name": "Anaeroarcus burkinensis DSM 6283", "rank": "Strain"}, "527012": {"name": "Yersinia kristensenii ATCC 33638", "rank": "Strain"}, "527019": {"name": "Bacillus thuringiensis IBL 200", "rank": "Strain"}, "1120980": {"name": "Alysiella crassa DSM 2578", "rank": "Strain"}, "1438826": {"name": "Mycobacterium tuberculosis Kc 9614", "rank": "Strain"}, "1074155": {"name": "Streptococcus mutans TCI-204", "rank": "Strain"}, "1074154": {"name": "Streptococcus mutans TCI-202", "rank": "Strain"}, "1500265": {"name": "Methylibium sp. YR605", "rank": "Species"}, "1074156": {"name": "Streptococcus mutans TCI-210", "rank": "Strain"}, "1074151": {"name": "Streptococcus mutans TCI-196", "rank": "Strain"}, "1500262": {"name": "Methylibium sp. CF468", "rank": "Species"}, "1074153": {"name": "Streptococcus mutans TCI-201", "rank": "Strain"}, "1074152": {"name": "Streptococcus sobrinus TCI-200", "rank": "Strain"}, "1120983": {"name": "Amorphus coralli DSM 19760", "rank": "Strain"}, "1074159": {"name": "Streptococcus mutans TCI-218", "rank": "Strain"}, "1074158": {"name": "Streptococcus sobrinus TCI-215", "rank": "Strain"}, "35350": {"name": "Apple stem pitting virus", "rank": "Species"}, "1121303": {"name": "Clostridium cellobioparum DSM 1351 = ATCC 15832", "rank": "Strain"}, "1296619": {"name": "Staphylococcus capitis CR01", "rank": "Strain"}, "1121308": {"name": "Peptoclostridium difficile ATCC 9689 = DSM 1296", "rank": "Strain"}, "210016": {"name": "Myzus persicae densovirus", "rank": "Species"}, "703339": {"name": "Staphylococcus aureus 04-02981", "rank": "Strain"}, "1382920": {"name": "Helicobacter pylori oki102", "rank": "Strain"}, "1382921": {"name": "Helicobacter pylori oki112", "rank": "Strain"}, "1382922": {"name": "Helicobacter pylori oki128", "rank": "Strain"}, "1382923": {"name": "Helicobacter pylori oki154", "rank": "Strain"}, "1382924": {"name": "Helicobacter pylori oki422", "rank": "Strain"}, "1382925": {"name": "Helicobacter pylori oki673", "rank": "Strain"}, "1382926": {"name": "Helicobacter pylori oki828", "rank": "Strain"}, "1382927": {"name": "Helicobacter pylori oki898", "rank": "Strain"}, "762962": {"name": "Staphylococcus aureus subsp. aureus ATCC 51811", "rank": "Strain"}, "762963": {"name": "Actinomyces sp. oral taxon 170 str. F0386", "rank": "Strain"}, "762964": {"name": "Haemophilus sp. oral taxon 851", "rank": "Species"}, "762965": {"name": "Haemophilus sp. oral taxon 851 str. F0397", "rank": "Strain"}, "762966": {"name": "Parasutterella excrementihominis YIT 11859", "rank": "Strain"}, "762967": {"name": "Sutterella parvirubra YIT 11816", "rank": "Strain"}, "762968": {"name": "Paraprevotella clara YIT 11840", "rank": "Strain"}, "1094972": {"name": "Beta proteobacterium JGI 0001003-N18", "rank": "Species"}, "1400176": {"name": "Klebsiella pneumoniae UCI 25", "rank": "Strain"}, "1047005": {"name": "Unclassified Omnitrophica", "rank": "No rank"}, "1438999": {"name": "Streptococcus pyogenes ABC020007794", "rank": "Strain"}, "154334": {"name": "Macacine herpesvirus 5", "rank": "Species"}, "1438995": {"name": "Streptococcus pyogenes ABC020006309", "rank": "Strain"}, "1438994": {"name": "Streptococcus pyogenes ABC020006298", "rank": "Strain"}, "1438997": {"name": "Streptococcus pyogenes ABC020006715", "rank": "Strain"}, "154339": {"name": "Little cherry virus 2", "rank": "Species"}, "1400022": {"name": "Escherichia coli D6-113.11", "rank": "Strain"}, "1438990": {"name": "Streptococcus pyogenes ABC020005773", "rank": "Strain"}, "1438993": {"name": "Streptococcus pyogenes ABC020006103", "rank": "Strain"}, "1217100": {"name": "Jiangellaceae", "rank": "Family"}, "182269": {"name": "Aurantimonas", "rank": "Genus"}, "182262": {"name": "Agarivorans albus", "rank": "Species"}, "411475": {"name": "Flavonifractor plautii ATCC 29863", "rank": "Strain"}, "411474": {"name": "Coprococcus eutactus ATCC 27759", "rank": "Strain"}, "411477": {"name": "Parabacteroides merdae ATCC 43184", "rank": "Strain"}, "411476": {"name": "Bacteroides ovatus ATCC 8483", "rank": "Strain"}, "411471": {"name": "Subdoligranulum variabile DSM 15176", "rank": "Strain"}, "411470": {"name": "Ruminococcus gnavus ATCC 29149", "rank": "Strain"}, "411473": {"name": "Ruminococcus callidus ATCC 27760", "rank": "Strain"}, "411472": {"name": "Clostridium symbiosum ATCC 14940", "rank": "Strain"}, "411479": {"name": "Bacteroides uniformis ATCC 8492", "rank": "Strain"}, "605": {"name": "Salmonella enterica subsp. enterica serovar Pullorum", "rank": "Strain"}, "604": {"name": "Salmonella enterica subsp. enterica serovar Gallinarum/pullorum", "rank": "Strain"}, "600": {"name": "Salmonella enterica subsp. enterica serovar Thompson", "rank": "Strain"}, "1181782": {"name": "Escherichia coli KTE240", "rank": "Strain"}, "1181781": {"name": "Escherichia coli KTE237", "rank": "Strain"}, "1181780": {"name": "Escherichia coli KTE236", "rank": "Strain"}, "1130827": {"name": "Rickettsia sibirica subsp. sibirica BJ-90", "rank": "Strain"}, "869694": {"name": "Escherichia coli B41", "rank": "Strain"}, "1295609": {"name": "Thermodesulfobacterium geofontis", "rank": "Species"}, "144549": {"name": "Mycobacterium fortuitum subsp. fortuitum", "rank": "Subspecies"}, "222556": {"name": "Unclassified Nodaviridae", "rank": "No rank"}, "990070": {"name": "Lebetimonas sp. JS032", "rank": "Species"}, "990073": {"name": "Lebetimonas sp. JS170", "rank": "Species"}, "990072": {"name": "Lebetimonas sp. JS138", "rank": "Species"}, "426716": {"name": "Nocardia rhamnosiphila", "rank": "Species"}, "1352356": {"name": "Helicobacter pylori SouthAfrica20", "rank": "Strain"}, "1151277": {"name": "Peptoclostridium difficile CD88", "rank": "Strain"}, "1197719": {"name": "Salmonella bongori N268-08", "rank": "Strain"}, "1197718": {"name": "Aspergillus oryzae 100-8", "rank": "Strain"}, "1352354": {"name": "Pseudomonas aeruginosa PAO581", "rank": "Strain"}, "1151275": {"name": "Peptoclostridium difficile CD70", "rank": "Strain"}, "585890": {"name": "Chitiniphilus", "rank": "Genus"}, "297249": {"name": "Tomato yellow leaf curl Guangdong virus", "rank": "Species"}, "297246": {"name": "Legionella pneumophila str. Paris", "rank": "Strain"}, "925409": {"name": "Sediminibacterium sp. OR53", "rank": "Species"}, "297245": {"name": "Legionella pneumophila str. Lens", "rank": "Strain"}, "1310938": {"name": "Acinetobacter baumannii 25935_4", "rank": "Strain"}, "1310939": {"name": "Acinetobacter baumannii 25935_5", "rank": "Strain"}, "1310934": {"name": "Acinetobacter baumannii 25691_10", "rank": "Strain"}, "1310935": {"name": "Acinetobacter baumannii 25935_1", "rank": "Strain"}, "1310936": {"name": "Acinetobacter baumannii 25935_2", "rank": "Strain"}, "1310930": {"name": "Acinetobacter baumannii 25691_6", "rank": "Strain"}, "1310933": {"name": "Acinetobacter baumannii 25691_9", "rank": "Strain"}, "1410786": {"name": "Staphylococcus aureus H87658", "rank": "Strain"}, "712888": {"name": "Actinobaculum sp. oral taxon 183", "rank": "Species"}, "564": {"name": "Escherichia fergusonii", "rank": "Species"}, "565": {"name": "Escherichia hermannii", "rank": "Species"}, "358104": {"name": "Unclassified Hypovirus", "rank": "No rank"}, "358100": {"name": "Microbacterium indicum", "rank": "Species"}, "1129": {"name": "Synechococcus", "rank": "Genus"}, "353825": {"name": "Unclassified Alpharetrovirus", "rank": "No rank"}, "1125": {"name": "Microcystis", "rank": "Genus"}, "1126": {"name": "Microcystis aeruginosa", "rank": "Species"}, "1410781": {"name": "Staphylococcus aureus F52748", "rank": "Strain"}, "1123": {"name": "Chlorogloeopsis", "rank": "Genus"}, "103807": {"name": "Enterobacteria phage phiP27", "rank": "Species"}, "1311073": {"name": "Acinetobacter baumannii 26016_6", "rank": "Strain"}, "1482601": {"name": "Streptomyces microflavus subgroup", "rank": "No rank"}, "1482603": {"name": "Streptomyces puniceus subgroup", "rank": "No rank"}, "1311070": {"name": "Acinetobacter baumannii 26016_3", "rank": "Strain"}, "569": {"name": "Hafnia alvei", "rank": "Species"}, "649760": {"name": "Prevotella oris F0302", "rank": "Strain"}, "1291515": {"name": "Acheta domesticus volvovirus", "rank": "Species"}, "1107544": {"name": "Agrobacterium tumefaciens 5A", "rank": "Strain"}, "195253": {"name": "Synechococcus sp. PCC 6312", "rank": "Species"}, "195250": {"name": "Synechococcus sp. PCC 7336", "rank": "Species"}, "671266": {"name": "Enterorhabdus caecimuris", "rank": "Species"}, "671267": {"name": "Bacteroides sartorii", "rank": "Species"}, "1439219": {"name": "Streptococcus pyogenes ABC020052553", "rank": "Strain"}, "1439218": {"name": "Streptococcus pyogenes ABC020052543", "rank": "Strain"}, "1439215": {"name": "Streptococcus pyogenes ABC020052420", "rank": "Strain"}, "1439214": {"name": "Streptococcus pyogenes ABC020052378", "rank": "Strain"}, "1439217": {"name": "Streptococcus pyogenes ABC020052519", "rank": "Strain"}, "1439216": {"name": "Streptococcus pyogenes ABC020052497", "rank": "Strain"}, "1439211": {"name": "Streptococcus pyogenes ABC020052309", "rank": "Strain"}, "1245787": {"name": "Mycobacterium tuberculosis GuangZ0019", "rank": "Strain"}, "1439213": {"name": "Streptococcus pyogenes ABC020052375", "rank": "Strain"}, "1439212": {"name": "Streptococcus pyogenes ABC020052313", "rank": "Strain"}, "134606": {"name": "Trichoplusia ni cypovirus 15", "rank": "Strain"}, "1352510": {"name": "Unclassified Panicovirus", "rank": "No rank"}, "1789": {"name": "Mycobacterium xenopi", "rank": "Species"}, "1781": {"name": "Mycobacterium marinum", "rank": "Species"}, "1784": {"name": "Mycobacterium simiae", "rank": "Species"}, "1027371": {"name": "Gordonia alkanivorans NBRC 16433", "rank": "Strain"}, "1027373": {"name": "Nitrosopumilus sp. AR", "rank": "Species"}, "1027372": {"name": "Enterococcus faecalis OG1X", "rank": "Strain"}, "1027374": {"name": "Nitrosopumilus sp. SJ", "rank": "Species"}, "68911": {"name": "Natrialba chahannaoensis", "rank": "Species"}, "68910": {"name": "Deinococcus murrayi", "rank": "Species"}, "455363": {"name": "Unclassified Phycodnaviridae", "rank": "No rank"}, "11018": {"name": "Togaviridae", "rank": "Family"}, "1131813": {"name": "Methylobacterium sp. 88A", "rank": "Species"}, "442430": {"name": "Coraliomargarita", "rank": "Genus"}, "1193499": {"name": "Pseudomonas putida SJTE-1", "rank": "Strain"}, "1400808": {"name": "Enterococcus faecalis NY9", "rank": "Strain"}, "1400800": {"name": "Enterococcus faecalis GA2", "rank": "Strain"}, "1400801": {"name": "Enterococcus faecalis GAN13", "rank": "Strain"}, "1400802": {"name": "Enterococcus faecalis KS19", "rank": "Strain"}, "1400803": {"name": "Enterococcus faecalis MD6", "rank": "Strain"}, "1400804": {"name": "Enterococcus faecalis MN16", "rank": "Strain"}, "1400805": {"name": "Enterococcus faecalis MTUP9", "rank": "Strain"}, "1400806": {"name": "Enterococcus faecalis MTmid8", "rank": "Strain"}, "1400807": {"name": "Enterococcus faecalis NJ44", "rank": "Strain"}, "1234128": {"name": "Vibrio parahaemolyticus SNUVpS-1", "rank": "Strain"}, "432201": {"name": "Enterobacteria phage HK544", "rank": "Species"}, "768710": {"name": "Desulfosporosinus youngiae DSM 17734", "rank": "Strain"}, "768713": {"name": "Finegoldia magna ACS-171-V-Col3", "rank": "Strain"}, "1193729": {"name": "Candidatus Endolissoclinum faulkneri L2", "rank": "Strain"}, "627480": {"name": "Pseudomonas phage phikF77", "rank": "Species"}, "49185": {"name": "Kineosporia aurantiaca", "rank": "Species"}, "49184": {"name": "Kineosporia", "rank": "Genus"}, "49186": {"name": "Marinobacterium stanieri", "rank": "Species"}, "1221206": {"name": "Soybean chlorotic spot virus", "rank": "Species"}, "1221209": {"name": "Methylomarinum", "rank": "Genus"}, "1221208": {"name": "Papilio polyxenes densovirus", "rank": "Strain"}, "1609594": {"name": "Aydin virus", "rank": "Species"}, "1194154": {"name": "Salmonella enterica subsp. enterica serovar Bredeney str. CFSAN001080", "rank": "Strain"}, "1194156": {"name": "Salmonella enterica subsp. enterica serovar Havana str. CFSAN001082", "rank": "Strain"}, "1194150": {"name": "Salmonella enterica subsp. enterica serovar Litchfield str. CFSAN001076", "rank": "Strain"}, "1194151": {"name": "Salmonella enterica subsp. enterica serovar Norwich str. CFSAN001077", "rank": "Strain"}, "1194153": {"name": "Salmonella enterica subsp. enterica serovar Ohio str. CFSAN001079", "rank": "Strain"}, "1194158": {"name": "Salmonella enterica subsp. enterica serovar Eastbourne str. CFSAN001084", "rank": "Strain"}, "1194159": {"name": "Salmonella enterica subsp. enterica serovar Stanleyville str. CFSAN000624", "rank": "Strain"}, "669368": {"name": "Coleofasciculus", "rank": "Genus"}, "1284775": {"name": "Prevotella sp. S7-1-8", "rank": "Species"}, "88387": {"name": "Ophiostoma mitovirus 4", "rank": "Species"}, "1117958": {"name": "Pseudomonas extremaustralis 14-3 substr. 14-3b", "rank": "Strain"}, "1117955": {"name": "Pseudomonas extremaustralis 14-3", "rank": "Strain"}, "478550": {"name": "Ligustrum necrotic ringspot virus", "rank": "Species"}, "1216363": {"name": "Staphylococcus aureus subsp. aureus 06BA18369", "rank": "Strain"}, "1127131": {"name": "Weissella confusa LBAE C39-2", "rank": "Strain"}, "444878": {"name": "Prochlorococcus phage Syn33", "rank": "Species"}, "1127134": {"name": "Nocardia cyriacigeorgica GUH-2", "rank": "Strain"}, "1189079": {"name": "Pseudomonas syringae pv. actinidiae ICMP 19072", "rank": "Strain"}, "181070": {"name": "Proteocatella sphenisci", "rank": "Species"}, "262698": {"name": "Brucella abortus bv. 1 str. 9-941", "rank": "Strain"}, "558415": {"name": "Marinilabiliaceae", "rank": "Family"}, "1037256": {"name": "Salmonella enterica subsp. enterica serovar Heidelberg str. RI-11-013312", "rank": "Strain"}, "45075": {"name": "Legionella shakespearei", "rank": "Species"}, "40005": {"name": "Yellow fever virus group", "rank": "Subgenus"}, "40004": {"name": "Tyuleniy virus", "rank": "Species"}, "1290393": {"name": "Pasteurella multocida 671/90", "rank": "Strain"}, "1290392": {"name": "Shigella flexneri II:(3)4,7(8)", "rank": "Strain"}, "1290391": {"name": "Botrytis cinerea BcDW1", "rank": "Strain"}, "1311111": {"name": "Acinetobacter baumannii 25569_4", "rank": "Strain"}, "1311110": {"name": "Acinetobacter baumannii 25569_3", "rank": "Strain"}, "1311113": {"name": "Acinetobacter baumannii 25569_6", "rank": "Strain"}, "1311112": {"name": "Acinetobacter baumannii 25569_5", "rank": "Strain"}, "1311115": {"name": "Acinetobacter baumannii 25569_8", "rank": "Strain"}, "1311114": {"name": "Acinetobacter baumannii 25569_7", "rank": "Strain"}, "1311117": {"name": "Acinetobacter baumannii 25569_10", "rank": "Strain"}, "1311116": {"name": "Acinetobacter baumannii 25569_9", "rank": "Strain"}, "1311118": {"name": "Acinetobacter baumannii 25442_1", "rank": "Strain"}, "1448774": {"name": "Mycobacterium tuberculosis M2192", "rank": "Strain"}, "474942": {"name": "Ophiocordycipitaceae", "rank": "Family"}, "474943": {"name": "Cordycipitaceae", "rank": "Family"}, "985665": {"name": "Paenibacillus terrae HPL-003", "rank": "Strain"}, "1236544": {"name": "Shewanella algae JCM 21037 = NBRC 103173", "rank": "Strain"}, "1236542": {"name": "Shewanella marina JCM 15074", "rank": "Strain"}, "1236543": {"name": "Shewanella putrefaciens JCM 20190 = NBRC 3908", "rank": "Strain"}, "1236540": {"name": "Prolixibacter bellariivorans JCM 13498", "rank": "Strain"}, "1236541": {"name": "Shewanella haliotis JCM 14758", "rank": "Strain"}, "1438726": {"name": "Klebsiella pneumoniae CHS 20", "rank": "Strain"}, "44674": {"name": "Sulfurospirillum barnesii", "rank": "Species"}, "44675": {"name": "Geothrix", "rank": "Genus"}, "44676": {"name": "Geothrix fermentans", "rank": "Species"}, "1236549": {"name": "Vibrio cholerae 4260B", "rank": "Strain"}, "73498": {"name": "Sphaeropsis sapinea RNA virus 2", "rank": "Species"}, "73497": {"name": "Sphaeropsis sapinea RNA virus 1", "rank": "Species"}, "368407": {"name": "Methanoculleus marisnigri JR1", "rank": "Strain"}, "10872": {"name": "Pseudomonas phage Pf3", "rank": "Species"}, "1398071": {"name": "Staphylococcus aureus M1461", "rank": "Strain"}, "1398070": {"name": "Staphylococcus aureus M1460", "rank": "Strain"}, "1398073": {"name": "Staphylococcus aureus M1465", "rank": "Strain"}, "1398072": {"name": "Staphylococcus aureus M1464", "rank": "Strain"}, "1398075": {"name": "Staphylococcus aureus M1468", "rank": "Strain"}, "1398074": {"name": "Staphylococcus aureus M1467", "rank": "Strain"}, "1398077": {"name": "Staphylococcus aureus M1470", "rank": "Strain"}, "1398076": {"name": "Staphylococcus aureus M1469", "rank": "Strain"}, "1398079": {"name": "Staphylococcus aureus M1472", "rank": "Strain"}, "1398078": {"name": "Staphylococcus aureus M1471", "rank": "Strain"}, "1417216": {"name": "Staphylococcus aureus W79968", "rank": "Strain"}, "224455": {"name": "Hyalangium", "rank": "Genus"}, "546270": {"name": "Gemella haemolysans ATCC 10379", "rank": "Strain"}, "546271": {"name": "Selenomonas sputigena ATCC 35185", "rank": "Strain"}, "546272": {"name": "Brucella melitensis ATCC 23457", "rank": "Strain"}, "546273": {"name": "Veillonella dispar ATCC 17748", "rank": "Strain"}, "546274": {"name": "Eikenella corrodens ATCC 23834", "rank": "Strain"}, "1208660": {"name": "Bordetella parapertussis Bpp5", "rank": "Strain"}, "531844": {"name": "Flavobacteriaceae bacterium 3519-10", "rank": "Species"}, "903814": {"name": "Eubacterium limosum KIST612", "rank": "Strain"}, "505292": {"name": "Pseudomonas phage MP38", "rank": "Species"}, "505291": {"name": "Pseudomonas phage MP29", "rank": "Species"}, "92938": {"name": "Fischerella muscicola", "rank": "Species"}, "1111709": {"name": "Unclassified Iflaviridae", "rank": "No rank"}, "1244120": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20111095", "rank": "Strain"}, "1428624": {"name": "Streptomyces sp. MUSC 125", "rank": "Species"}, "1306165": {"name": "Pseudomonas aeruginosa MH27", "rank": "Strain"}, "1446688": {"name": "Escherichia coli O157:H7 str. K5467", "rank": "Strain"}, "1446689": {"name": "Escherichia coli O157:H7 str. K5602", "rank": "Strain"}, "1234873": {"name": "Lactococcus lactis subsp. cremoris TIFN3", "rank": "Strain"}, "1423547": {"name": "Mycobacterium tuberculosis BTB11-289", "rank": "Strain"}, "1446680": {"name": "Escherichia coli O157:H7 str. K4405", "rank": "Strain"}, "1446681": {"name": "Escherichia coli O157:H7 str. K4406", "rank": "Strain"}, "1446682": {"name": "Escherichia coli O157:H7 str. K4527", "rank": "Strain"}, "1446683": {"name": "Escherichia coli O157:H7 str. K5418", "rank": "Strain"}, "1446684": {"name": "Escherichia coli O157:H7 str. K5448", "rank": "Strain"}, "1446685": {"name": "Escherichia coli O157:H7 str. K5449", "rank": "Strain"}, "1446686": {"name": "Escherichia coli O157:H7 str. K5453", "rank": "Strain"}, "1446687": {"name": "Escherichia coli O157:H7 str. K5460", "rank": "Strain"}, "263906": {"name": "Methanolinea tarda", "rank": "Species"}, "1370094": {"name": "Rangifer tarandus papillomavirus 2", "rank": "Species"}, "263908": {"name": "Gordonia effusa", "rank": "Species"}, "263909": {"name": "Gordonia araii", "rank": "Species"}, "1423540": {"name": "Mycobacterium tuberculosis BTB11-192", "rank": "Strain"}, "1423541": {"name": "Mycobacterium tuberculosis BTB11-195", "rank": "Strain"}, "168657": {"name": "Hydrogenobaculum", "rank": "Genus"}, "1244099": {"name": "Streptococcus agalactiae SGBS020", "rank": "Strain"}, "1337888": {"name": "Geobacillus kaustophilus GBlys", "rank": "Strain"}, "1337887": {"name": "Ochrobactrum intermedium 229E", "rank": "Strain"}, "1053167": {"name": "Bacillus cereus BAG1O-1", "rank": "Strain"}, "1053166": {"name": "Bacillus cereus AND1407", "rank": "Strain"}, "68239": {"name": "Streptomyces mirabilis", "rank": "Species"}, "931209": {"name": "Human papillomavirus type 128", "rank": "Strain"}, "508677": {"name": "Unclassified Synergistetes", "rank": "No rank"}, "551531": {"name": "Tomato leaf curl Kerala virus", "rank": "Species"}, "68237": {"name": "Streptomyces mediolani", "rank": "Species"}, "1053169": {"name": "Bacillus cereus BAG1O-3", "rank": "Strain"}, "1053168": {"name": "Bacillus cereus BAG1O-2", "rank": "Strain"}, "485255": {"name": "Natranaerobiaceae", "rank": "Family"}, "485256": {"name": "Natranaerobiales", "rank": "Order"}, "1129034": {"name": "Macroptilium yellow spot virus", "rank": "Species"}, "1129033": {"name": "Macroptilium yellow net virus", "rank": "Species"}, "1129032": {"name": "Centrosema yellow spot virus", "rank": "Species"}, "1472344": {"name": "Basilea", "rank": "Genus"}, "1472345": {"name": "Basilea psittacipulmonis", "rank": "Species"}, "1189303": {"name": "Candidatus Sulcia muelleri PSPU", "rank": "Strain"}, "42631": {"name": "Brome streak mosaic virus", "rank": "Species"}, "1286307": {"name": "Staphylococcus pseudintermedius K7", "rank": "Strain"}, "889206": {"name": "Streptococcus vestibularis ATCC 49124", "rank": "Strain"}, "889205": {"name": "Streptococcus pseudopneumoniae ATCC BAA-960", "rank": "Strain"}, "1286308": {"name": "Lysobacter antibioticus HS124", "rank": "Strain"}, "889201": {"name": "Streptococcus cristatus ATCC 51100", "rank": "Strain"}, "887929": {"name": "Pseudoramibacter alactolyticus ATCC 23263", "rank": "Strain"}, "491921": {"name": "Megamonas rupellensis", "rank": "Species"}, "1194719": {"name": "Sinorhizobium meliloti H1", "rank": "Strain"}, "1242970": {"name": "Staphylococcus aureus CN79", "rank": "Strain"}, "10699": {"name": "Siphoviridae", "rank": "Family"}, "1001534": {"name": "Francisella tularensis subsp. tularensis TI0902", "rank": "Strain"}, "1001533": {"name": "Bos taurus papillomavirus 7", "rank": "Strain"}, "1001530": {"name": "Photobacterium leiognathi subsp. mandapamensis svers.1.1.", "rank": "Strain"}, "1446572": {"name": "Escherichia coli O121:H19 str. 2011C-3500", "rank": "Strain"}, "1446573": {"name": "Escherichia coli O121:H19 str. 2011C-3537", "rank": "Strain"}, "1446570": {"name": "Escherichia coli O121:H19 str. 2011C-3108", "rank": "Strain"}, "1446571": {"name": "Escherichia coli O121:H19 str. 2011C-3216", "rank": "Strain"}, "1446576": {"name": "Escherichia coli O121:H19 str. K5269", "rank": "Strain"}, "1446577": {"name": "Escherichia coli O121:H7", "rank": "Strain"}, "1446574": {"name": "Escherichia coli O121:H19 str. 2011C-3609", "rank": "Strain"}, "1446575": {"name": "Escherichia coli O121:H19 str. K5198", "rank": "Strain"}, "1033837": {"name": "Lactobacillus kefiranofaciens ZW3", "rank": "Strain"}, "1446578": {"name": "Escherichia coli O121:H7 str. 2009C-3299", "rank": "Strain"}, "1446579": {"name": "Escherichia coli O123:H11", "rank": "Strain"}, "366616": {"name": "Haematobacter missouriensis", "rank": "Species"}, "366617": {"name": "Unclassified Alphacoronavirus", "rank": "No rank"}, "366614": {"name": "Haematobacter", "rank": "Genus"}, "938781": {"name": "Beta proteobacterium SCGC AAA027-I06", "rank": "Species"}, "938785": {"name": "Beta proteobacterium SCGC AAA027-K21", "rank": "Species"}, "42094": {"name": "Ureaplasma diversum", "rank": "Species"}, "1447485": {"name": "Mycobacterium tuberculosis MD16553", "rank": "Strain"}, "1447484": {"name": "Mycobacterium tuberculosis MD16277", "rank": "Strain"}, "1447487": {"name": "Mycobacterium tuberculosis MD15974", "rank": "Strain"}, "1447486": {"name": "Mycobacterium tuberculosis MD15766", "rank": "Strain"}, "1447480": {"name": "Mycobacterium tuberculosis MD17888", "rank": "Strain"}, "1447483": {"name": "Mycobacterium tuberculosis MD16577", "rank": "Strain"}, "1447482": {"name": "Mycobacterium tuberculosis MD17901", "rank": "Strain"}, "1447489": {"name": "Mycobacterium tuberculosis MD16265", "rank": "Strain"}, "1447488": {"name": "Mycobacterium tuberculosis MD15958", "rank": "Strain"}, "1158666": {"name": "Enterococcus faecalis EnGen0281", "rank": "Strain"}, "1158667": {"name": "Enterococcus faecalis EnGen0287", "rank": "Strain"}, "1158664": {"name": "Enterococcus faecalis EnGen0279", "rank": "Strain"}, "1158665": {"name": "Enterococcus faecalis EnGen0304", "rank": "Strain"}, "1158662": {"name": "Enterococcus faecalis EnGen0291", "rank": "Strain"}, "93378": {"name": "Edwardsiella hoshinae", "rank": "Species"}, "1158660": {"name": "Enterococcus faecalis EnGen0302", "rank": "Strain"}, "1158661": {"name": "Enterococcus faecalis EnGen0306", "rank": "Strain"}, "328061": {"name": "Radish mosaic virus", "rank": "Species"}, "1088542": {"name": "Leptospira weilii str. UI 13098", "rank": "Strain"}, "1158669": {"name": "Enterococcus faecalis EnGen0295", "rank": "Strain"}, "1005090": {"name": "Buchnera aphidicola str. Ak (Acyrthosiphon kondoi)", "rank": "Strain"}, "745407": {"name": "Dacryopinax sp. DJM-731 SS1", "rank": "Species"}, "115713": {"name": "Chlamydophila pneumoniae CWL029", "rank": "Strain"}, "115711": {"name": "Chlamydophila pneumoniae AR39", "rank": "Strain"}, "745408": {"name": "Rhodococcus sp. JVH1", "rank": "Species"}, "1154789": {"name": "Streptococcus agalactiae FSL S3-603", "rank": "Strain"}, "1154788": {"name": "Streptococcus agalactiae FSL S3-501", "rank": "Strain"}, "1574623": {"name": "Lyngbya confervoides BDU141951", "rank": "Strain"}, "1244096": {"name": "Streptococcus agalactiae SGBS014", "rank": "Strain"}, "1154781": {"name": "Streptococcus agalactiae FSL S3-277", "rank": "Strain"}, "1154780": {"name": "Streptococcus agalactiae FSL S3-222", "rank": "Strain"}, "1154783": {"name": "Streptococcus agalactiae FSL C1-494", "rank": "Strain"}, "1541205": {"name": "Bat Hp-betacoronavirus/Zhejiang2013", "rank": "Species"}, "1154785": {"name": "Streptococcus agalactiae FSL S3-027", "rank": "Strain"}, "1154784": {"name": "Streptococcus agalactiae FSL S3-229", "rank": "Strain"}, "1154787": {"name": "Streptococcus agalactiae FSL S3-043", "rank": "Strain"}, "1154786": {"name": "Streptococcus agalactiae FSL S3-251", "rank": "Strain"}, "1095631": {"name": "Saccharomyces cerevisiae x Saccharomyces kudriavzevii VIN7", "rank": "Strain"}, "339671": {"name": "Actinobacillus succinogenes 130Z", "rank": "Strain"}, "936140": {"name": "Lactobacillus farciminis KCTC 3681 = DSM 20184", "rank": "Strain"}, "224325": {"name": "Archaeoglobus fulgidus DSM 4304", "rank": "Strain"}, "570952": {"name": "Fodinicurvata sediminis DSM 21159", "rank": "Strain"}, "1233383": {"name": "Human cosavirus", "rank": "Species"}, "51101": {"name": "Brevibacillus agri", "rank": "Species"}, "1033846": {"name": "Marinobacter adhaerens", "rank": "Species"}, "649764": {"name": "Slackia exigua ATCC 700122", "rank": "Strain"}, "388399": {"name": "Sagittula stellata E-37", "rank": "Strain"}, "388396": {"name": "Vibrio fischeri MJ11", "rank": "Strain"}, "1006543": {"name": "Staphylococcus aureus subsp. aureus T0131", "rank": "Strain"}, "1471462": {"name": "Prochlorococcus sp. scB241_529B19", "rank": "Species"}, "1471463": {"name": "Prochlorococcus sp. scB241_529C4", "rank": "Species"}, "150059": {"name": "Halonatronum", "rank": "Genus"}, "1471461": {"name": "Prochlorococcus sp. scB241_528P18", "rank": "Species"}, "1471466": {"name": "Prochlorococcus sp. scB241_529J15", "rank": "Species"}, "1471467": {"name": "Prochlorococcus sp. scB241_529J16", "rank": "Species"}, "1471464": {"name": "Prochlorococcus sp. scB241_529D18", "rank": "Species"}, "1471465": {"name": "Prochlorococcus sp. scB241_529J11", "rank": "Species"}, "150053": {"name": "Yersinia enterocolitica subsp. palearctica", "rank": "Subspecies"}, "150052": {"name": "Yersinia enterocolitica subsp. enterocolitica", "rank": "Subspecies"}, "498845": {"name": "Candidatus Korarchaeum", "rank": "Genus"}, "1471469": {"name": "Prochlorococcus sp. scB243_495D8", "rank": "Species"}, "150055": {"name": "Streptococcus lutetiensis", "rank": "Species"}, "150054": {"name": "Streptococcus infantarius subsp. infantarius", "rank": "Subspecies"}, "1444044": {"name": "Escherichia coli 2-460-02_S1_C1", "rank": "Strain"}, "1444045": {"name": "Escherichia coli 2-474-04_S1_C1", "rank": "Strain"}, "1444046": {"name": "Escherichia coli 5-172-05_S1_C1", "rank": "Strain"}, "1444047": {"name": "Escherichia coli 5-366-08_S1_C1", "rank": "Strain"}, "1444040": {"name": "Escherichia coli 2-177-06_S1_C1", "rank": "Strain"}, "1444041": {"name": "Escherichia coli 2-222-05_S1_C1", "rank": "Strain"}, "1444042": {"name": "Escherichia coli 2-316-03_S1_C1", "rank": "Strain"}, "1444043": {"name": "Escherichia coli 2-427-07_S1_C1", "rank": "Strain"}, "131226": {"name": "Cherry mottle leaf virus", "rank": "Species"}, "1444048": {"name": "Escherichia coli 8-415-05_S1_C1", "rank": "Strain"}, "1444049": {"name": "Escherichia coli 1-110-08_S1_C1", "rank": "Strain"}, "906888": {"name": "Nonlabens ulvanivorans", "rank": "Species"}, "334771": {"name": "Ignisphaera aggregans", "rank": "Species"}, "1169404": {"name": "Escherichia coli KTE180", "rank": "Strain"}, "1385658": {"name": "Marine gokushovirus", "rank": "Species"}, "374928": {"name": "Haemophilus influenzae PittAA", "rank": "Strain"}, "374927": {"name": "Haemophilus influenzae 22.1-21", "rank": "Strain"}, "348058": {"name": "Salmonella phage epsilon34", "rank": "Species"}, "463676": {"name": "Rhinovirus C", "rank": "Species"}, "318854": {"name": "Wongabel virus", "rank": "Species"}, "337052": {"name": "Deltapapillomavirus 4", "rank": "Species"}, "337050": {"name": "Alphapapillomavirus 6", "rank": "Species"}, "337051": {"name": "Betapapillomavirus 1", "rank": "Species"}, "337054": {"name": "Human papillomavirus type 88", "rank": "Strain"}, "864686": {"name": "Bocavirus gorilla/GBoV1/2009", "rank": "Strain"}, "453847": {"name": "Haladaptatus cibarius", "rank": "Species"}, "54289": {"name": "Vicia cryptic virus", "rank": "Species"}, "1516081": {"name": "MSSI2.225 virus", "rank": "Species"}, "177400": {"name": "Anaerophaga thermohalophila", "rank": "Species"}, "1232381": {"name": "Corynebacterium glutamicum SCgG1", "rank": "Strain"}, "1232383": {"name": "Corynebacterium glutamicum SCgG2", "rank": "Strain"}, "1274374": {"name": "Paenibacillus sp. GD11", "rank": "Species"}, "1077152": {"name": "Escherichia phage Cba120", "rank": "Species"}, "1398022": {"name": "Staphylococcus aureus M1402", "rank": "Strain"}, "1398026": {"name": "Staphylococcus aureus M1408", "rank": "Strain"}, "1398027": {"name": "Staphylococcus aureus M1409", "rank": "Strain"}, "1413569": {"name": "Staphylococcus aureus GD2010-102", "rank": "Strain"}, "1413568": {"name": "Staphylococcus aureus GD2010-061", "rank": "Strain"}, "2718": {"name": "Cardiobacterium hominis", "rank": "Species"}, "1413563": {"name": "Staphylococcus aureus Rd.545", "rank": "Strain"}, "2717": {"name": "Cardiobacterium", "rank": "Genus"}, "1413561": {"name": "Staphylococcus aureus 2(04HN_17-03-52-05)", "rank": "Strain"}, "1413560": {"name": "Staphylococcus aureus 1(04GN_04-02-52-07)", "rank": "Strain"}, "1413567": {"name": "Staphylococcus aureus GD2010-052", "rank": "Strain"}, "2713": {"name": "Aquifex", "rank": "Genus"}, "1413565": {"name": "Staphylococcus aureus Rd.290", "rank": "Strain"}, "1413564": {"name": "Staphylococcus aureus Rd.614", "rank": "Strain"}, "1339326": {"name": "Bacteroides fragilis str. S36L5", "rank": "Strain"}, "1398029": {"name": "Staphylococcus aureus M1411", "rank": "Strain"}, "167132": {"name": "Tulip virus X", "rank": "Species"}, "488255": {"name": "Malachra yellow vein mosaic virus-associated satellite DNA beta", "rank": "Species"}, "990271": {"name": "Vibrio variabilis", "rank": "Species"}, "757342": {"name": "Pseudomonas phage JG004", "rank": "Species"}, "760939": {"name": "Acinetobacter phage Acj9", "rank": "Species"}, "863372": {"name": "Herbaspirillum huttiense", "rank": "Species"}, "4930": {"name": "Saccharomyces", "rank": "Genus"}, "1122997": {"name": "Propionibacterium jensenii DSM 20535", "rank": "Strain"}, "1105239": {"name": "Streptococcus agalactiae str. Gottschalk 2864", "rank": "Strain"}, "1105238": {"name": "Streptococcus agalactiae str. Gottschalk 13227", "rank": "Strain"}, "1105236": {"name": "Streptococcus agalactiae str. Gottschalk 1002A", "rank": "Strain"}, "1105235": {"name": "Streptococcus agalactiae str. Gottschalk 19247", "rank": "Strain"}, "1105234": {"name": "Streptococcus agalactiae BSU174", "rank": "Strain"}, "1105233": {"name": "Streptococcus agalactiae BSU133", "rank": "Strain"}, "1105232": {"name": "Streptococcus agalactiae BSU451", "rank": "Strain"}, "1105231": {"name": "Streptococcus agalactiae BSU260", "rank": "Strain"}, "5315": {"name": "Ganoderma lucidum", "rank": "Species"}, "1249477": {"name": "Burkholderia pseudomallei NAU35A-3", "rank": "Strain"}, "293431": {"name": "Haloquadratum", "rank": "Genus"}, "281310": {"name": "Haemophilus influenzae 86-028NP", "rank": "Strain"}, "283785": {"name": "Bizionia", "rank": "Genus"}, "277944": {"name": "Human coronavirus NL63", "rank": "Species"}, "1418381": {"name": "Staphylococcus aureus F48420", "rank": "Strain"}, "925769": {"name": "Vibrio cholerae O1 str. 2010EL-1792", "rank": "Strain"}, "925768": {"name": "Vibrio cholerae O1 str. 2010EL-1798", "rank": "Strain"}, "1388159": {"name": "Staphylococcus aureus M0244", "rank": "Strain"}, "1410830": {"name": "Staphylococcus aureus T78544", "rank": "Strain"}, "1410831": {"name": "Staphylococcus aureus F77005", "rank": "Strain"}, "1410832": {"name": "Staphylococcus aureus F77047", "rank": "Strain"}, "1388158": {"name": "Staphylococcus aureus M0242", "rank": "Strain"}, "1410834": {"name": "Staphylococcus aureus F76996", "rank": "Strain"}, "1410835": {"name": "Staphylococcus aureus F68118", "rank": "Strain"}, "1410836": {"name": "Staphylococcus aureus M36077", "rank": "Strain"}, "1410837": {"name": "Staphylococcus aureus H42737", "rank": "Strain"}, "1410838": {"name": "Staphylococcus aureus H42759", "rank": "Strain"}, "1410839": {"name": "Staphylococcus aureus F80349", "rank": "Strain"}, "1460424": {"name": "Staphylococcus aureus SA0077", "rank": "Strain"}, "393133": {"name": "Listeria monocytogenes 10403S", "rank": "Strain"}, "53412": {"name": "Pseudomonas resinovorans", "rank": "Species"}, "1460427": {"name": "Helicobacter pylori wls-5-9", "rank": "Strain"}, "1460422": {"name": "Klebsiella pneumoniae subsp. pneumoniae ST258", "rank": "Strain"}, "1460423": {"name": "Helicobacter pylori wls-5-5", "rank": "Strain"}, "1123400": {"name": "Thiothrix flexilis DSM 14609", "rank": "Strain"}, "1123401": {"name": "Thiothrix lacustris DSM 21227", "rank": "Strain"}, "651553": {"name": "Haloglycomyces", "rank": "Genus"}, "1460428": {"name": "Helicobacter pylori wls-5-10", "rank": "Strain"}, "1460429": {"name": "Helicobacter pylori wls-5-11", "rank": "Strain"}, "151043": {"name": "Tulare apple mosaic virus", "rank": "Species"}, "1177759": {"name": "Chipapillomavirus 2", "rank": "Species"}, "1593425": {"name": "Sewage-associated gemycircularvirus 10", "rank": "Species"}, "1593424": {"name": "Sewage-associated gemycircularvirus 7", "rank": "Species"}, "1196236": {"name": "Paspalum dilatatum striate mosaic virus", "rank": "Species"}, "217615": {"name": "Grapevine leafroll-associated virus 7", "rank": "Species"}, "357809": {"name": "Lachnoclostridium phytofermentans ISDg", "rank": "Strain"}, "1452730": {"name": "Staphylococcus aureus SA10", "rank": "Strain"}, "716540": {"name": "Erwinia amylovora ATCC 49946", "rank": "Strain"}, "1122211": {"name": "Marinospirillum insulare DSM 21763", "rank": "Strain"}, "1412607": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20120686", "rank": "Strain"}, "1281270": {"name": "Escherichia coli UMEA 3805-1", "rank": "Strain"}, "64471": {"name": "Synechococcus sp. CC9311", "rank": "Species"}, "947561": {"name": "Yersinia enterocolitica IP2222", "rank": "Strain"}, "947560": {"name": "Yersinia enterocolitica (type O:36)", "rank": "Strain"}, "523791": {"name": "Kangiella koreensis DSM 16069", "rank": "Strain"}, "1341679": {"name": "Acinetobacter indicus CIP 110367", "rank": "Strain"}, "1281271": {"name": "Escherichia coli UMEA 3821-1", "rank": "Strain"}, "1341675": {"name": "Brucella abortus 99-9971-135", "rank": "Strain"}, "1341674": {"name": "Brucella abortus 90-12178", "rank": "Strain"}, "914147": {"name": "Streptococcus pneumoniae 2082239", "rank": "Strain"}, "1341676": {"name": "Brucella abortus 99-9971-159", "rank": "Strain"}, "1341671": {"name": "Brucella abortus 03-4923-239-D", "rank": "Strain"}, "1341670": {"name": "Brucella abortus 03-2770-11", "rank": "Strain"}, "271257": {"name": "Magnaporthe oryzae virus 1", "rank": "Species"}, "1341672": {"name": "Brucella abortus 07-0994-2411", "rank": "Strain"}, "1310708": {"name": "Acinetobacter baumannii 923118", "rank": "Strain"}, "1151250": {"name": "Escherichia coli B113", "rank": "Strain"}, "1151251": {"name": "Escherichia coli B114", "rank": "Strain"}, "1072595": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 400095 18", "rank": "Strain"}, "1072594": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 400095 17", "rank": "Strain"}, "1151254": {"name": "Peptoclostridium difficile CD9", "rank": "Strain"}, "1072592": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 400095 13", "rank": "Strain"}, "1072591": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 400095 11", "rank": "Strain"}, "1072590": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 392869-2", "rank": "Strain"}, "1521187": {"name": "Chloroflexus sp. MS-G", "rank": "Species"}, "1151259": {"name": "Peptoclostridium difficile CD22", "rank": "Strain"}, "1186058": {"name": "Trichosporon asahii var. asahii CBS 2479", "rank": "Strain"}, "361101": {"name": "Streptococcus pseudoporcinus", "rank": "Species"}, "361100": {"name": "Bacillus cereus Q1", "rank": "Strain"}, "1131290": {"name": "Zeta proteobacterium SCGC AB-604-O16", "rank": "Species"}, "1131291": {"name": "Gallionella sp. SCGC AAA018-N21", "rank": "Species"}, "1249501": {"name": "Pig stool associated circular ssDNA virus", "rank": "Species"}, "1421841": {"name": "Staphylococcus aureus F64894", "rank": "Strain"}, "1421840": {"name": "Staphylococcus aureus F64891", "rank": "Strain"}, "1397858": {"name": "Mycobacterium tuberculosis TKK_02_0013", "rank": "Strain"}, "1421842": {"name": "Staphylococcus aureus F64896", "rank": "Strain"}, "1421845": {"name": "Staphylococcus aureus F91084", "rank": "Strain"}, "1421844": {"name": "Staphylococcus aureus F71592", "rank": "Strain"}, "1421847": {"name": "Staphylococcus aureus H31084", "rank": "Strain"}, "1421846": {"name": "Staphylococcus aureus H22656", "rank": "Strain"}, "1397852": {"name": "Xenorhabdus bovienii str. feltiae Florida", "rank": "Strain"}, "1421848": {"name": "Staphylococcus aureus H31085", "rank": "Strain"}, "1397850": {"name": "Mycoplasma californicum HAZ160_1", "rank": "Strain"}, "1397851": {"name": "Xenorhabdus bovienii str. feltiae France", "rank": "Strain"}, "1397856": {"name": "Mycobacterium tuberculosis TKK_02_0006", "rank": "Strain"}, "1397857": {"name": "Mycobacterium tuberculosis TKK_02_0012", "rank": "Strain"}, "1397854": {"name": "Mycobacterium tuberculosis TKK_02_0002", "rank": "Strain"}, "1397855": {"name": "Mycobacterium tuberculosis TKK_02_0003", "rank": "Strain"}, "1389420": {"name": "Escherichia coli LAU-EC9", "rank": "Strain"}, "1389422": {"name": "Klebsiella pneumoniae LAU-KP1", "rank": "Strain"}, "1389423": {"name": "Escherichia coli LAU-EC2", "rank": "Strain"}, "292414": {"name": "Ruegeria sp. TM1040", "rank": "Species"}, "292415": {"name": "Thiobacillus denitrificans ATCC 25259", "rank": "Strain"}, "585893": {"name": "Picobirnaviridae", "rank": "Family"}, "525909": {"name": "Acidimicrobium ferrooxidans DSM 10331", "rank": "Strain"}, "525903": {"name": "Thermanaerovibrio acidaminovorans DSM 6589", "rank": "Strain"}, "525904": {"name": "Thermobaculum terrenum ATCC BAA-798", "rank": "Strain"}, "47885": {"name": "Pseudomonas oryzihabitans", "rank": "Species"}, "754409": {"name": "Winogradskyella sp. PG-2", "rank": "Species"}, "880591": {"name": "Ketogulonicigenium vulgare Y25", "rank": "Strain"}, "880592": {"name": "Lactobacillus rhamnosus R0011", "rank": "Strain"}, "1114958": {"name": "Bacillus amyloliquefaciens subsp. plantarum CAU B946", "rank": "Strain"}, "1114959": {"name": "Saccharomonospora azurea SZMC 14600", "rank": "Strain"}, "68033": {"name": "Carrot mottle virus", "rank": "Species"}, "1261124": {"name": "Mannheimia haemolytica serotype 6", "rank": "Strain"}, "1261125": {"name": "Mannheimia haemolytica serotype 6 str. H23", "rank": "Strain"}, "1261126": {"name": "Mannheimia haemolytica D153", "rank": "Strain"}, "1261128": {"name": "Pantoea agglomerans 299R", "rank": "Strain"}, "1261129": {"name": "Bacillus thuringiensis serovar kurstaki str. HD-1", "rank": "Strain"}, "249403": {"name": "Deinococcus frigens", "rank": "Species"}, "249402": {"name": "Cardinium endosymbiont of Encarsia pergandiella", "rank": "Species"}, "1221835": {"name": "Acinetobacter phage Bphi-B1251", "rank": "Species"}, "196600": {"name": "Vibrio vulnificus YJ016", "rank": "Strain"}, "1388289": {"name": "Staphylococcus aureus M0434", "rank": "Strain"}, "1388288": {"name": "Staphylococcus aureus M0433", "rank": "Strain"}, "1388287": {"name": "Staphylococcus aureus M0431", "rank": "Strain"}, "1388286": {"name": "Staphylococcus aureus M0430", "rank": "Strain"}, "1388285": {"name": "Staphylococcus aureus M0429", "rank": "Strain"}, "1388284": {"name": "Staphylococcus aureus M0428", "rank": "Strain"}, "1388283": {"name": "Staphylococcus aureus M0426", "rank": "Strain"}, "1388282": {"name": "Staphylococcus aureus M0425", "rank": "Strain"}, "1388281": {"name": "Staphylococcus aureus M0423", "rank": "Strain"}, "1388280": {"name": "Staphylococcus aureus M0421", "rank": "Strain"}, "246602": {"name": "Pseudoduganella violaceinigra", "rank": "Species"}, "1453991": {"name": "Pseudomonas aeruginosa BK1", "rank": "Strain"}, "144752": {"name": "Allpahuayo virus", "rank": "Species"}, "1453999": {"name": "Candidatus Accumulibacter sp. SK-02", "rank": "Species"}, "31899": {"name": "Caldicellulosiruptor bescii", "rank": "Species"}, "1310701": {"name": "Acinetobacter baumannii 268680", "rank": "Strain"}, "1418269": {"name": "Staphylococcus aureus F91077", "rank": "Strain"}, "1418268": {"name": "Staphylococcus aureus F91072", "rank": "Strain"}, "323450": {"name": "Pontibacter actiniarum", "rank": "Species"}, "1418265": {"name": "Staphylococcus aureus F12753", "rank": "Strain"}, "1219035": {"name": "Novosphingobium tardaugens NBRC 16725", "rank": "Strain"}, "1418267": {"name": "Staphylococcus aureus F87602", "rank": "Strain"}, "1418266": {"name": "Staphylococcus aureus F19955", "rank": "Strain"}, "1418261": {"name": "Staphylococcus aureus F45749", "rank": "Strain"}, "1418263": {"name": "Staphylococcus aureus W45755_111412", "rank": "Strain"}, "1418262": {"name": "Staphylococcus aureus W31983", "rank": "Strain"}, "797114": {"name": "Halosimplex carlsbadense 2-9-1", "rank": "Strain"}, "257758": {"name": "Streptococcus pseudopneumoniae", "rank": "Species"}, "159139": {"name": "Manzanilla virus", "rank": "Species"}, "767100": {"name": "Parvimonas sp. oral taxon 110 str. F0139", "rank": "Strain"}, "1388135": {"name": "Staphylococcus aureus M0204", "rank": "Strain"}, "1388134": {"name": "Staphylococcus aureus M0203", "rank": "Strain"}, "1388137": {"name": "Staphylococcus aureus M0207", "rank": "Strain"}, "1388136": {"name": "Staphylococcus aureus M0205", "rank": "Strain"}, "1388131": {"name": "Staphylococcus aureus M0199", "rank": "Strain"}, "1090946": {"name": "Rhizobium leguminosarum bv. viciae Vc2", "rank": "Strain"}, "1388133": {"name": "Staphylococcus aureus M0202", "rank": "Strain"}, "1388132": {"name": "Staphylococcus aureus M0201", "rank": "Strain"}, "45662": {"name": "Desulfohalobium", "rank": "Genus"}, "1217676": {"name": "Acinetobacter soli CIP 110264", "rank": "Strain"}, "1388139": {"name": "Staphylococcus aureus M0209", "rank": "Strain"}, "1388138": {"name": "Staphylococcus aureus M0208", "rank": "Strain"}, "143786": {"name": "Brachyspiraceae", "rank": "Family"}, "371042": {"name": "Erwinia typographi", "rank": "Species"}, "1310892": {"name": "Acinetobacter baumannii 44895_8", "rank": "Strain"}, "1217653": {"name": "Acinetobacter calcoaceticus ANC 3680", "rank": "Strain"}, "1217652": {"name": "Acinetobacter brisouii ANC 4119", "rank": "Strain"}, "1217651": {"name": "Acinetobacter bereziniae NIPH 3", "rank": "Strain"}, "1217650": {"name": "Acinetobacter bereziniae CIP 70.12", "rank": "Strain"}, "1217657": {"name": "Acinetobacter gyllenbergii CIP 110306", "rank": "Strain"}, "1217656": {"name": "Acinetobacter guillouiae NIPH 991", "rank": "Strain"}, "142786": {"name": "Norovirus", "rank": "Genus"}, "1217654": {"name": "Acinetobacter calcoaceticus NIPH 13", "rank": "Strain"}, "1217659": {"name": "Acinetobacter haemolyticus CIP 64.3", "rank": "Strain"}, "1217658": {"name": "Acinetobacter gyllenbergii NIPH 230", "rank": "Strain"}, "1232680": {"name": "Unassigned Spounavirinae", "rank": "No rank"}, "1104917": {"name": "Crocuta crocuta papillomavirus 1", "rank": "Strain"}, "1104916": {"name": "Unclassified Lambdapapillomavirus", "rank": "No rank"}, "1535231": {"name": "Altibacter", "rank": "Genus"}, "162289": {"name": "Peptoniphilus", "rank": "Genus"}, "1310879": {"name": "Acinetobacter baumannii 25253_5", "rank": "Strain"}, "1310878": {"name": "Acinetobacter baumannii 25253_4", "rank": "Strain"}, "1137799": {"name": "Endozoicomonas numazuensis", "rank": "Species"}, "1310870": {"name": "Acinetobacter baumannii 25307_6", "rank": "Strain"}, "1310872": {"name": "Acinetobacter baumannii 25307_8", "rank": "Strain"}, "1310875": {"name": "Acinetobacter baumannii 25253_1", "rank": "Strain"}, "1310877": {"name": "Acinetobacter baumannii 25253_3", "rank": "Strain"}, "240125": {"name": "Mycobacterium parascrofulaceum", "rank": "Species"}, "1501433": {"name": "Kamptonema", "rank": "Genus"}, "686439": {"name": "Clavibacter phage CMP1", "rank": "Species"}, "1227500": {"name": "Natronorubrum bangense JCM 10635", "rank": "Strain"}, "114424": {"name": "Ovine mastadenovirus A", "rank": "Species"}, "1078505": {"name": "Paenibacillus sp. HGH0039", "rank": "Species"}, "1293539": {"name": "Choristoneura rosaceana entomopoxvirus 'L'", "rank": "Species"}, "189479": {"name": "Orbiliales", "rank": "Order"}, "765913": {"name": "Thiorhodococcus drewsii AZ1", "rank": "Strain"}, "254250": {"name": "Isoptericola", "rank": "Genus"}, "291990": {"name": "Thermosediminibacter oceani", "rank": "Species"}, "291995": {"name": "Pseudomonas azotifigens", "rank": "Species"}, "1087": {"name": "Rhodovibrio salinarum", "rank": "Species"}, "1085": {"name": "Rhodospirillum rubrum", "rank": "Species"}, "1084": {"name": "Rhodospirillum photometricum", "rank": "Species"}, "1083": {"name": "Phaeospirillum molischianum", "rank": "Species"}, "1082": {"name": "Phaeospirillum fulvum", "rank": "Species"}, "1081": {"name": "Rhodospirillum", "rank": "Genus"}, "104766": {"name": "Nanovirus", "rank": "Genus"}, "100887": {"name": "Soil-borne cereal mosaic virus", "rank": "Species"}, "100886": {"name": "Catenibacterium mitsuokai", "rank": "Species"}, "100880": {"name": "Northern cereal mosaic virus", "rank": "Species"}, "100883": {"name": "Coprobacillus", "rank": "Genus"}, "475088": {"name": "Methanosphaerula palustris", "rank": "Species"}, "1280938": {"name": "Pseudomonas aeruginosa B136-33", "rank": "Strain"}, "1280936": {"name": "Candidatus Liberibacter americanus PW_SP", "rank": "Strain"}, "1280937": {"name": "Escherichia coli EC096/10", "rank": "Strain"}, "701521": {"name": "Pediococcus claussenii ATCC BAA-344", "rank": "Strain"}, "475087": {"name": "Methanosphaerula", "rank": "Genus"}, "39420": {"name": "Feldmannia species virus", "rank": "Species"}, "1267600": {"name": "Pantoea sp. IMH", "rank": "Species"}, "317047": {"name": "Kuraishia capsulata", "rank": "Species"}, "1536769": {"name": "Paenibacillus sp. FSL P4-0081", "rank": "Species"}, "320771": {"name": "Pedosphaera parvula Ellin514", "rank": "Strain"}, "1148491": {"name": "Rosellinia necatrix victorivirus 1", "rank": "Species"}, "1116035": {"name": "Escherichia coli 2875000", "rank": "Strain"}, "1116034": {"name": "Escherichia coli 2872800", "rank": "Strain"}, "72149": {"name": "Aichivirus A", "rank": "Species"}, "1116036": {"name": "Escherichia coli 2875150", "rank": "Strain"}, "1116031": {"name": "Escherichia coli 2867750", "rank": "Strain"}, "1116030": {"name": "Escherichia coli 2866750", "rank": "Strain"}, "1116033": {"name": "Escherichia coli 2872000", "rank": "Strain"}, "1116032": {"name": "Escherichia coli 2871950", "rank": "Strain"}, "254878": {"name": "Penicillium chrysogenum complex", "rank": "No rank"}, "1116039": {"name": "Escherichia coli P0299438.4", "rank": "Strain"}, "1116038": {"name": "Escherichia coli P0299438.3", "rank": "Strain"}, "454958": {"name": "Xanthomonas campestris pv. musacearum", "rank": "Strain"}, "454957": {"name": "Xanthomonas arboricola pv. celebensis", "rank": "Strain"}, "885379": {"name": "Tomato leaf curl Bangladesh betasatellite", "rank": "Species"}, "1432331": {"name": "Candidatus Altimarinus pacificus", "rank": "Species"}, "1432330": {"name": "Candidatus Altimarinus", "rank": "Genus"}, "453851": {"name": "Henriciella marina", "rank": "Species"}, "1193515": {"name": "Snodgrassella", "rank": "Genus"}, "632112": {"name": "Lactobacillus phage Lb338-1", "rank": "Species"}, "1078089": {"name": "Bacteroides sp. HPS0048", "rank": "Species"}, "938429": {"name": "Actinobacterium SCGC AAA027-D23", "rank": "Species"}, "1078083": {"name": "Staphylococcus sp. HGB0015", "rank": "Species"}, "1078086": {"name": "Streptomyces sp. HGB0020", "rank": "Species"}, "1078085": {"name": "Paenisporosarcina sp. HGH0030", "rank": "Species"}, "46680": {"name": "Pseudomonas nitroreducens", "rank": "Species"}, "319225": {"name": "Chlorobium luteolum DSM 273", "rank": "Strain"}, "319224": {"name": "Shewanella putrefaciens CN-32", "rank": "Strain"}, "1402503": {"name": "Pseudomonas aeruginosa BWHPSA003", "rank": "Strain"}, "1402502": {"name": "Pseudomonas aeruginosa BWHPSA002", "rank": "Strain"}, "1402501": {"name": "Pseudomonas aeruginosa BWHPSA001", "rank": "Strain"}, "1402500": {"name": "Pseudomonas aeruginosa X13273", "rank": "Strain"}, "1402507": {"name": "Pseudomonas aeruginosa BWHPSA007", "rank": "Strain"}, "1402506": {"name": "Pseudomonas aeruginosa BWHPSA006", "rank": "Strain"}, "1402505": {"name": "Pseudomonas aeruginosa BWHPSA005", "rank": "Strain"}, "1402504": {"name": "Pseudomonas aeruginosa BWHPSA004", "rank": "Strain"}, "638847": {"name": "Pyramidobacter", "rank": "Genus"}, "1402509": {"name": "Pseudomonas aeruginosa BWHPSA009", "rank": "Strain"}, "1402508": {"name": "Pseudomonas aeruginosa BWHPSA008", "rank": "Strain"}, "345690": {"name": "Unclassified Lymphocystivirus", "rank": "No rank"}, "1187846": {"name": "Vibrio genomosp. F10 str. 9ZD137", "rank": "Strain"}, "1187847": {"name": "Vibrio genomosp. F10 str. 9ZC157", "rank": "Strain"}, "1095659": {"name": "Vibrio cholerae O1 str. 87395", "rank": "Strain"}, "1187845": {"name": "Vibrio genomosp. F10 str. 9ZB36", "rank": "Strain"}, "1051055": {"name": "Brucella abortus bv. 1 str. NI435a", "rank": "Strain"}, "1095656": {"name": "Vibrio cholerae O1 str. NHCC-006C", "rank": "Strain"}, "1187848": {"name": "Vibrio genomosp. F10 str. ZF-129", "rank": "Strain"}, "1051056": {"name": "Brucella abortus bv. 1 str. NI474", "rank": "Strain"}, "1095653": {"name": "Vibrio cholerae O1 str. EC-0027", "rank": "Strain"}, "1150461": {"name": "Bifidobacterium scardovii JCM 12489 = DSM 13734", "rank": "Strain"}, "1095651": {"name": "Vibrio cholerae O1 str. EC-0009", "rank": "Strain"}, "1095650": {"name": "Vibrio cholerae O1 str. EM-1727", "rank": "Strain"}, "359961": {"name": "Bacillus phage WBeta", "rank": "Species"}, "264641": {"name": "Desulfitibacter alkalitolerans", "rank": "Species"}, "1286404": {"name": "Bacillus thuringiensis serovar thuringiensis str. IS5056", "rank": "Strain"}, "1286405": {"name": "Lactobacillus rhamnosus CRL1505", "rank": "Strain"}, "1481452": {"name": "Mosavirus A", "rank": "Species"}, "40216": {"name": "Acinetobacter radioresistens", "rank": "Species"}, "1544378": {"name": "Synedrella leaf curl alphasatellite", "rank": "Species"}, "40214": {"name": "Acinetobacter johnsonii", "rank": "Species"}, "40215": {"name": "Acinetobacter junii", "rank": "Species"}, "1423775": {"name": "Lactobacillus nodensis DSM 19682 = JCM 14932 = NBRC 107160", "rank": "Strain"}, "702976": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. 22704", "rank": "Strain"}, "702979": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. CHS44", "rank": "Strain"}, "859058": {"name": "Caenispirillum salinarum", "rank": "Species"}, "1256221": {"name": "Lactobacillus paracasei subsp. paracasei Lpp22", "rank": "Strain"}, "1256220": {"name": "Lactobacillus paracasei subsp. paracasei Lpp17", "rank": "Strain"}, "1256223": {"name": "Lactobacillus paracasei subsp. paracasei Lpp120", "rank": "Strain"}, "1256222": {"name": "Lactobacillus paracasei subsp. paracasei Lpp46", "rank": "Strain"}, "1256225": {"name": "Lactobacillus paracasei subsp. paracasei Lpp225", "rank": "Strain"}, "1256224": {"name": "Lactobacillus paracasei subsp. paracasei Lpp223", "rank": "Strain"}, "62672": {"name": "SAR86 cluster", "rank": "No rank"}, "1256226": {"name": "Lactobacillus paracasei subsp. paracasei Lpp226", "rank": "Strain"}, "1256229": {"name": "Lactobacillus paracasei subsp. tolerans Lpl14", "rank": "Strain"}, "1052802": {"name": "Crenarchaeota archaeon SCGC AAA471-B23", "rank": "Species"}, "1052801": {"name": "Crenarchaeota archaeon SCGC AAA471-B05", "rank": "Species"}, "644335": {"name": "Brucella abortus bv. 4", "rank": "Strain"}, "1048668": {"name": "Cotton leaf curl Multan alphasatellite", "rank": "Species"}, "1052806": {"name": "Crenarchaeota archaeon SCGC AAA471-O08", "rank": "Species"}, "1052805": {"name": "Crenarchaeota archaeon SCGC AAA471-L14", "rank": "Species"}, "1052804": {"name": "Crenarchaeota archaeon SCGC AAA471-L13", "rank": "Species"}, "1255043": {"name": "Thioalkalivibrio nitratireducens DSM 14787", "rank": "Strain"}, "908340": {"name": "Clostridium sp. HGF2", "rank": "Species"}, "908341": {"name": "Paenibacillus sp. HGF5", "rank": "Species"}, "765068": {"name": "Propionibacterium acnes HL045PA1", "rank": "Strain"}, "765069": {"name": "Propionibacterium acnes HL013PA1", "rank": "Strain"}, "228748": {"name": "Desulfurococcus fermentans", "rank": "Species"}, "228745": {"name": "Thermovibrio ammonificans", "rank": "Species"}, "765061": {"name": "Propionibacterium acnes HL103PA1", "rank": "Strain"}, "765063": {"name": "Propionibacterium acnes HL099PA1", "rank": "Strain"}, "765064": {"name": "Propionibacterium acnes HL097PA1", "rank": "Strain"}, "765065": {"name": "Propionibacterium acnes HL020PA1", "rank": "Strain"}, "765066": {"name": "Propionibacterium acnes HL053PA1", "rank": "Strain"}, "765067": {"name": "Propionibacterium acnes HL053PA2", "rank": "Strain"}, "1408260": {"name": "Lactococcus lactis subsp. lactis bv. diacetylactis str. LD61", "rank": "Strain"}, "749545": {"name": "Escherichia coli MS 182-1", "rank": "Strain"}, "971271": {"name": "Tomato leaf curl Hanoi virus", "rank": "Species"}, "1408264": {"name": "Burkholderia pseudomallei MSHR6137", "rank": "Strain"}, "1345560": {"name": "Helicobacter pylori SA160A", "rank": "Strain"}, "971279": {"name": "Palaeococcus pacificus", "rank": "Species"}, "749547": {"name": "Escherichia coli MS 187-1", "rank": "Strain"}, "1455266": {"name": "Mycobacterium tuberculosis NRITLD47", "rank": "Strain"}, "1398990": {"name": "Acinetobacter baumannii UH9707", "rank": "Strain"}, "749546": {"name": "Escherichia coli MS 185-1", "rank": "Strain"}, "1455263": {"name": "Mycobacterium tuberculosis NRITLD44", "rank": "Strain"}, "1225651": {"name": "Thalassobacter sp. 16PALIMAR09", "rank": "Species"}, "1345565": {"name": "Helicobacter pylori SA162C", "rank": "Strain"}, "1455268": {"name": "Mycobacterium tuberculosis NRITLD49", "rank": "Strain"}, "749540": {"name": "Escherichia coli MS 146-1", "rank": "Strain"}, "1071069": {"name": "Bacillus sp. MSP5.4", "rank": "Species"}, "1234380": {"name": "Propionibacterium acnes C1", "rank": "Strain"}, "1169143": {"name": "Burkholderia bryophila 376MFSha3.1", "rank": "Strain"}, "749542": {"name": "Escherichia coli MS 16-3", "rank": "Strain"}, "1169146": {"name": "Microbacterium sp. 11MF", "rank": "Species"}, "1169145": {"name": "Cryocola sp. 340MFSha3.1", "rank": "Species"}, "1169144": {"name": "Bacillus sp. 123MFChir2", "rank": "Species"}, "1235428": {"name": "Equus ferus caballus papillomavirus type 4", "rank": "Species"}, "1235429": {"name": "Equus ferus caballus papillomavirus type 5", "rank": "Species"}, "1225204": {"name": "Streptococcus mutans B114SM-A", "rank": "Strain"}, "1560351": {"name": "Goutanap virus", "rank": "Species"}, "1235427": {"name": "Equine papillomavirus type 6", "rank": "Species"}, "273068": {"name": "Caldanaerobacter subterraneus subsp. tengcongensis MB4", "rank": "Strain"}, "1225201": {"name": "Streptococcus mutans B88SM-A", "rank": "Strain"}, "138949": {"name": "Enterovirus B", "rank": "Species"}, "273063": {"name": "Sulfolobus tokodaii str. 7", "rank": "Strain"}, "1225200": {"name": "Streptococcus mutans B85SM-B", "rank": "Strain"}, "887284": {"name": "Campylobacter coli 67-8", "rank": "Strain"}, "887287": {"name": "Campylobacter coli 84-2", "rank": "Strain"}, "1428419": {"name": "Oenococcus oeni IOEB_9803", "rank": "Strain"}, "1428418": {"name": "Oenococcus oeni IOEB_9517", "rank": "Strain"}, "227507": {"name": "Strawberry pallidosis-associated virus", "rank": "Species"}, "1428411": {"name": "Oenococcus oeni IOEB_0501", "rank": "Strain"}, "1428410": {"name": "Oenococcus oeni IOEB_0205", "rank": "Strain"}, "1428413": {"name": "Oenococcus oeni IOEB_0607", "rank": "Strain"}, "1428412": {"name": "Oenococcus oeni IOEB_0502", "rank": "Strain"}, "1428415": {"name": "Oenococcus oeni IOEB_1491", "rank": "Strain"}, "1428414": {"name": "Oenococcus oeni IOEB_0608", "rank": "Strain"}, "1428417": {"name": "Oenococcus oeni IOEB_9304", "rank": "Strain"}, "1428416": {"name": "Oenococcus oeni IOEB_8417", "rank": "Strain"}, "1218115": {"name": "Burkholderia caledonica NBRC 102488", "rank": "Strain"}, "459291": {"name": "Sulfolobus spindle-shaped virus 5", "rank": "Species"}, "459290": {"name": "Sulfolobus spindle-shaped virus 4", "rank": "Species"}, "1394634": {"name": "Vibrio parahaemolyticus S095", "rank": "Strain"}, "147067": {"name": "Thermobispora", "rank": "Genus"}, "445337": {"name": "Clostridium botulinum C str. Eklund", "rank": "Strain"}, "445336": {"name": "Clostridium botulinum Bf", "rank": "Strain"}, "445335": {"name": "Clostridium botulinum NCTC 2916", "rank": "Strain"}, "445334": {"name": "Clostridium perfringens C str. JGS1495", "rank": "Strain"}, "445971": {"name": "Anaerofustis stercorihominis DSM 17244", "rank": "Strain"}, "335963": {"name": "Hippeastrum latent virus", "rank": "Species"}, "742159": {"name": "Achromobacter piechaudii ATCC 43553", "rank": "Strain"}, "742152": {"name": "Wolfiporia cocos MD-104 SS10", "rank": "Strain"}, "129052": {"name": "Catelliglobosispora koreensis", "rank": "Species"}, "1218800": {"name": "Sulfurovum sp. SCGC AAA036-F05", "rank": "Species"}, "412418": {"name": "Borrelia recurrentis A1", "rank": "Strain"}, "412419": {"name": "Borrelia duttonii Ly", "rank": "Strain"}, "134676": {"name": "Actinoplanes sp. SE50/110", "rank": "Species"}, "1273754": {"name": "Halovirus HRTV-7", "rank": "Species"}, "1273755": {"name": "Halovirus HRTV-8", "rank": "Species"}, "1273750": {"name": "Halovirus HHTV-1", "rank": "Species"}, "1273751": {"name": "Halovirus HHTV-2", "rank": "Species"}, "1273752": {"name": "Halovirus HRTV-4", "rank": "Species"}, "1273753": {"name": "Halovirus HRTV-5", "rank": "Species"}, "911131": {"name": "Methanobrevibacter smithii TS95C", "rank": "Strain"}, "1120961": {"name": "Ahrensia kielensis DSM 5890", "rank": "Strain"}, "379501": {"name": "Staphylococcus phage phiMR11", "rank": "Species"}, "1122599": {"name": "Neptunomonas japonica DSM 18939", "rank": "Strain"}, "38402": {"name": "Erysipelothrix tonsillarum", "rank": "Species"}, "371731": {"name": "Rhodobacter sp. SW2", "rank": "Species"}, "371730": {"name": "N4likevirus", "rank": "Genus"}, "489829": {"name": "Enterobacteria phage ID18 sensu lato", "rank": "Species"}, "489828": {"name": "Enterobacteria phage WA13 sensu lato", "rank": "Species"}, "489825": {"name": "Moorea producens 3L", "rank": "Strain"}, "35794": {"name": "Rickettsia slovaca", "rank": "Species"}, "313627": {"name": "Bacillus sp. NRRL B-14911", "rank": "Species"}, "313625": {"name": "Synechococcus sp. BL107", "rank": "Species"}, "313624": {"name": "Nodularia spumigena CCY9414", "rank": "Strain"}, "1081904": {"name": "Prevotella pleuritidis F0068", "rank": "Strain"}, "313629": {"name": "Chlamydia phage 4", "rank": "Species"}, "313628": {"name": "Lentisphaera araneosa HTCC2155", "rank": "Strain"}, "649757": {"name": "Anaerostipes hadrus DSM 3319", "rank": "Strain"}, "649756": {"name": "Anaerostipes hadrus", "rank": "Species"}, "649755": {"name": "Faecalitalea cylindroides ATCC 27803", "rank": "Strain"}, "649754": {"name": "Corynebacterium ammoniagenes DSM 20306", "rank": "Strain"}, "520999": {"name": "Providencia alcalifaciens DSM 30120", "rank": "Strain"}, "1310718": {"name": "Acinetobacter baumannii 1475764", "rank": "Strain"}, "1158668": {"name": "Enterococcus faecalis EnGen0300", "rank": "Strain"}, "879309": {"name": "Veillonella sp. oral taxon 158 str. F0412", "rank": "Strain"}, "879308": {"name": "Peptoniphilus sp. oral taxon 375 str. F0436", "rank": "Strain"}, "879301": {"name": "Lactobacillus iners LEAF 2053A-b", "rank": "Strain"}, "879300": {"name": "Lactobacillus iners LactinV 11V1-d", "rank": "Strain"}, "879303": {"name": "Lactobacillus iners LEAF 2062A-h1", "rank": "Strain"}, "879302": {"name": "Lactobacillus iners LEAF 2052A-d", "rank": "Strain"}, "879305": {"name": "Anaerococcus prevotii ACS-065-V-Col13", "rank": "Strain"}, "879304": {"name": "Lactobacillus iners LEAF 3008A-a", "rank": "Strain"}, "879307": {"name": "Gardnerella vaginalis 315-A", "rank": "Strain"}, "879306": {"name": "Anaerococcus hydrogenalis ACS-025-V-Sch4", "rank": "Strain"}, "1233488": {"name": "Vibrio phage VPMS1", "rank": "Species"}, "225937": {"name": "Marinobacter adhaerens HP15", "rank": "Strain"}, "1310710": {"name": "Acinetobacter baumannii 3390", "rank": "Strain"}, "1118963": {"name": "Arthrobacter sp. Rue61a", "rank": "Species"}, "1118965": {"name": "Xanthomonas axonopodis pv. malvacearum str. GSPB1386", "rank": "Strain"}, "1279007": {"name": "Pseudomonas aeruginosa PA1", "rank": "Strain"}, "1279005": {"name": "Escherichia sp. KTE172", "rank": "Species"}, "614034": {"name": "Tomato leaf curl Nigeria virus-Nigeria:2006", "rank": "Strain"}, "1279008": {"name": "Pseudomonas aeruginosa PA1R", "rank": "Strain"}, "1279009": {"name": "Cesiribacter andamanensis AMV16", "rank": "Strain"}, "614033": {"name": "Tomato leaf curl Togo virus-Togo:2006", "rank": "Strain"}, "1447522": {"name": "Mycobacterium tuberculosis MD14437", "rank": "Strain"}, "1447523": {"name": "Mycobacterium tuberculosis MD16573", "rank": "Strain"}, "1124472": {"name": "Vibrio cholerae O1 str. 3500-05", "rank": "Strain"}, "1124473": {"name": "Vibrio cholerae O1 str. 3546-06", "rank": "Strain"}, "1124474": {"name": "Vibrio cholerae O1 str. 2009V-1046", "rank": "Strain"}, "1124475": {"name": "Vibrio cholerae O1 str. 2009V-1116", "rank": "Strain"}, "1124476": {"name": "Vibrio cholerae O1 str. 2010V-1014", "rank": "Strain"}, "1447525": {"name": "Mycobacterium tuberculosis MD15758", "rank": "Strain"}, "886718": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. CDC_2010K_1559", "rank": "Strain"}, "1124479": {"name": "Vibrio cholerae O1 str. 3569-08", "rank": "Strain"}, "1447528": {"name": "Pseudomonas aeruginosa 3573", "rank": "Strain"}, "1447529": {"name": "Pseudomonas aeruginosa 3574", "rank": "Strain"}, "1321820": {"name": "Gemella bergeriae ATCC 700627", "rank": "Strain"}, "1120999": {"name": "Andreprevotia chitinilytica DSM 18519", "rank": "Strain"}, "1120998": {"name": "Anaerovorax odorimutans DSM 5092", "rank": "Strain"}, "1047070": {"name": "Cloacimonetes bacterium JGI 0000039-G13", "rank": "Species"}, "1047071": {"name": "Cloacimonetes bacterium JGI 0000039-I07", "rank": "Species"}, "1047072": {"name": "Cloacimonetes bacterium JGI 0000039-I11", "rank": "Species"}, "1321821": {"name": "Porphyromonas gingivalis F0185", "rank": "Strain"}, "1047075": {"name": "Cloacimonetes bacterium JGI 0000039-L21", "rank": "Species"}, "1047076": {"name": "Cloacimonetes bacterium JGI 0000039-M09", "rank": "Species"}, "1047077": {"name": "Cloacimonetes bacterium JGI 0000039-P09", "rank": "Species"}, "1047078": {"name": "Cloacimonetes bacterium JGI 0000059-F17", "rank": "Species"}, "1116057": {"name": "Escherichia coli MP021017.1", "rank": "Strain"}, "261386": {"name": "Leptospirillum sp. Group III", "rank": "Species group"}, "156586": {"name": "Flavobacteria bacterium BBFL7", "rank": "Species"}, "261385": {"name": "Leptospirillum sp. Group II", "rank": "Species group"}, "1355477": {"name": "Bradyrhizobium diazoefficiens", "rank": "Species"}, "28049": {"name": "Acidothermus cellulolyticus", "rank": "Species"}, "28048": {"name": "Acidothermus", "rank": "Genus"}, "12480": {"name": "African green monkey polyomavirus", "rank": "Species"}, "1159211": {"name": "Streptococcus pneumoniae SPAR55", "rank": "Strain"}, "1159212": {"name": "Streptococcus pneumoniae SPAR95", "rank": "Strain"}, "1232427": {"name": "Corynebacterium sp. GD7", "rank": "Species"}, "28042": {"name": "Saccharopolyspora rectivirgula", "rank": "Species"}, "33708": {"name": "Murid herpesvirus 4", "rank": "Species"}, "303379": {"name": "Herminiimonas", "rank": "Genus"}, "1478175": {"name": "Neochlamydia sp. EPS4", "rank": "Species"}, "1478174": {"name": "Neochlamydia sp. TUME1", "rank": "Species"}, "1235813": {"name": "Bacteroides pyogenes JCM 10003", "rank": "Strain"}, "326319": {"name": "Dokdonia", "rank": "Genus"}, "329161": {"name": "Unclassified P2-like viruses", "rank": "No rank"}, "329164": {"name": "Potato Virus P", "rank": "Species"}, "122960": {"name": "Alicyclobacillus herbarius", "rank": "Species"}, "184020": {"name": "Tobacco bushy top virus", "rank": "Species"}, "520449": {"name": "Brucella sp. 83/13", "rank": "Species"}, "520448": {"name": "Brucella sp. NVSL 07-0026", "rank": "Species"}, "1432856": {"name": "Formica exsecta virus 1", "rank": "Species"}, "1432857": {"name": "Formica exsecta virus 2", "rank": "Species"}, "1444769": {"name": "Kitasatospora sp. MBT66", "rank": "Species"}, "339860": {"name": "Methanosphaera stadtmanae DSM 3091", "rank": "Strain"}, "339862": {"name": "Desulfosporosinus youngiae", "rank": "Species"}, "948077": {"name": "Arenimonas metalli", "rank": "Species"}, "948071": {"name": "Puniceispirillum phage HMO-2011", "rank": "Species"}, "496396": {"name": "Pseudomonas phage PT2", "rank": "Species"}, "251221": {"name": "Gloeobacter violaceus PCC 7421", "rank": "Strain"}, "52242": {"name": "Lactobacillus gallinarum", "rank": "Species"}, "251229": {"name": "Chroococcidiopsis thermalis PCC 7203", "rank": "Strain"}, "381666": {"name": "Ralstonia eutropha H16", "rank": "Strain"}, "198599": {"name": "Saccharomyces 23S RNA narnavirus", "rank": "Species"}, "1388025": {"name": "Staphylococcus aureus M0056", "rank": "Strain"}, "1227747": {"name": "Bacillus subtilis Miyagi-4", "rank": "Strain"}, "1227742": {"name": "Saccharomyces cerevisiae ZTW1", "rank": "Strain"}, "198597": {"name": "Ophiostoma mitovirus 3a", "rank": "Species"}, "1005541": {"name": "Escherichia coli EC1846", "rank": "Strain"}, "558017": {"name": "Betabaculovirus", "rank": "Genus"}, "558016": {"name": "Alphabaculovirus", "rank": "Genus"}, "558019": {"name": "Deltabaculovirus", "rank": "Genus"}, "558018": {"name": "Gammabaculovirus", "rank": "Genus"}, "1209072": {"name": "Cellvibrio mixtus subsp. mixtus J3-8", "rank": "Strain"}, "1005544": {"name": "Escherichia coli EC1849", "rank": "Strain"}, "232115": {"name": "Mesonia", "rank": "Genus"}, "196490": {"name": "Bradyrhizobium sp. Ai1a-2", "rank": "Species"}, "1499499": {"name": "Prochlorococcus sp. MIT 0602", "rank": "Species"}, "1499498": {"name": "Prochlorococcus sp. MIT 0601", "rank": "Species"}, "12333": {"name": "Unclassified phages", "rank": "No rank"}, "1037660": {"name": "Tilletiaria anomala UBC 951", "rank": "Strain"}, "12331": {"name": "Rice stripe virus", "rank": "Species"}, "12336": {"name": "Clostridium phage c-st", "rank": "Species"}, "355315": {"name": "Streptococcus agalactiae serogroup Ia", "rank": "Strain"}, "454231": {"name": "Salmonella enterica subsp. enterica serovar Kentucky str. CDC 191", "rank": "Strain"}, "641487": {"name": "Lactococcus phage P087", "rank": "Species"}, "1422109": {"name": "Mycobacterium tuberculosis TB_RSA195", "rank": "Strain"}, "1422108": {"name": "Mycobacterium tuberculosis TB_RSA194", "rank": "Strain"}, "1170653": {"name": "Cassava associated cicular DNA virus", "rank": "Species"}, "1422105": {"name": "Mycobacterium tuberculosis TB_RSA191", "rank": "Strain"}, "1422104": {"name": "Mycobacterium tuberculosis TB_RSA190", "rank": "Strain"}, "1422107": {"name": "Mycobacterium tuberculosis TB_RSA193", "rank": "Strain"}, "43140": {"name": "Mapuera virus", "rank": "Species"}, "1422100": {"name": "Mycobacterium tuberculosis TB_RSA184", "rank": "Strain"}, "1422103": {"name": "Mycobacterium tuberculosis TB_RSA189", "rank": "Strain"}, "589861": {"name": "Thermoanaerobacter ethanolicus CCSD1", "rank": "Strain"}, "290008": {"name": "Isfahan virus", "rank": "Species"}, "67585": {"name": "Milk vetch dwarf virus", "rank": "Species"}, "517722": {"name": "Citromicrobium sp. JLT1363", "rank": "Species"}, "67581": {"name": "Streptomyces viridosporus", "rank": "Species"}, "1347369": {"name": "Bacillus sp. FF4", "rank": "Species"}, "1347368": {"name": "Bacillus sp. FF3", "rank": "Species"}, "652721": {"name": "Prevotella sp. oral taxon 317", "rank": "Species"}, "1413606": {"name": "Staphylococcus aureus USA_9", "rank": "Strain"}, "1413607": {"name": "Staphylococcus aureus USA_11", "rank": "Strain"}, "1413604": {"name": "Staphylococcus aureus USA7", "rank": "Strain"}, "1413605": {"name": "Staphylococcus aureus USA_8", "rank": "Strain"}, "1413602": {"name": "Staphylococcus aureus USA_1", "rank": "Strain"}, "1413603": {"name": "Staphylococcus aureus USA_6", "rank": "Strain"}, "1413600": {"name": "Staphylococcus aureus 08143-5", "rank": "Strain"}, "1413608": {"name": "Staphylococcus aureus USA_12", "rank": "Strain"}, "1413609": {"name": "Staphylococcus aureus USA_15", "rank": "Strain"}, "1123290": {"name": "Sporosarcina ureae DSM 2281", "rank": "Strain"}, "1123294": {"name": "Stappia stellulata DSM 5886", "rank": "Strain"}, "1582477": {"name": "Pan troglodytes verus polyomavirus 2", "rank": "Species"}, "1123299": {"name": "Streptococcus castoreus DSM 17536", "rank": "Strain"}, "1123298": {"name": "Streptococcus caballi DSM 19004", "rank": "Strain"}, "377431": {"name": "Chlorobium ferrooxidans DSM 13031", "rank": "Strain"}, "1200300": {"name": "Thermogladius cellulolyticus", "rank": "Species"}, "1200302": {"name": "Photobacterium damselae subsp. piscicida DI21", "rank": "Strain"}, "301452": {"name": "Streptococcus pyogenes serotype M49", "rank": "Strain"}, "301451": {"name": "Streptococcus pyogenes serotype M18", "rank": "Strain"}, "1463890": {"name": "Streptomyces sp. NRRL S-1831", "rank": "Species"}, "1463891": {"name": "Streptomyces sp. NRRL S-1833", "rank": "Species"}, "1463892": {"name": "Streptomyces sp. NRRL S-1868", "rank": "Species"}, "301450": {"name": "Streptococcus pyogenes serotype M6", "rank": "Strain"}, "1463894": {"name": "Streptomyces sp. NRRL S-20", "rank": "Species"}, "1463895": {"name": "Streptomyces sp. NRRL S-237", "rank": "Species"}, "1463896": {"name": "Streptomyces sp. NRRL S-241", "rank": "Species"}, "1463897": {"name": "Streptomyces sp. NRRL S-244", "rank": "Species"}, "1463898": {"name": "Streptomyces sp. NRRL S-31", "rank": "Species"}, "1463899": {"name": "Streptomyces sp. NRRL S-325", "rank": "Species"}, "1223521": {"name": "Comamonas granuli NBRC 101663", "rank": "Strain"}, "1105378": {"name": "Porcine astrovirus 2", "rank": "Species"}, "1105379": {"name": "Porcine astrovirus 4", "rank": "Species"}, "103621": {"name": "Actinomyces urogenitalis", "rank": "Species"}, "321023": {"name": "Aeromonas phage 31", "rank": "Species"}, "500148": {"name": "Metarhizium brunneum", "rank": "Species"}, "285109": {"name": "Thioclava pacifica", "rank": "Species"}, "577675": {"name": "Escherichia coli O91:H21", "rank": "Strain"}, "861450": {"name": "Anaeroglobus geminatus F0357", "rank": "Strain"}, "861452": {"name": "Fusobacterium sp. oral taxon 370 str. F0437", "rank": "Strain"}, "1421055": {"name": "Yam spherical virus", "rank": "Species"}, "861454": {"name": "Lachnospiraceae bacterium oral taxon 082 str. F0431", "rank": "Strain"}, "861455": {"name": "Streptococcus sp. oral taxon 058 str. F0407", "rank": "Strain"}, "165432": {"name": "Cucumber leaf spot virus", "rank": "Species"}, "1225804": {"name": "Escherichia phage KBNP135", "rank": "Species"}, "1225803": {"name": "Escherichia phage KBNP21", "rank": "Species"}, "1310633": {"name": "Acinetobacter baumannii 940793", "rank": "Strain"}, "1225800": {"name": "Listeria phage P70", "rank": "Species"}, "256035": {"name": "Glycomyces arizonensis", "rank": "Species"}, "82076": {"name": "Picrophilus torridus", "rank": "Species"}, "1300113": {"name": "Anguillid rhabdovirus", "rank": "Species"}, "66987": {"name": "Legionella pneumophila serogroup 12", "rank": "Strain"}, "668336": {"name": "Aggregatibacter actinomycetemcomitans D11S-1", "rank": "Strain"}, "1417189": {"name": "Staphylococcus aureus S29036", "rank": "Strain"}, "668331": {"name": "Raphidiopsis brookii", "rank": "Species"}, "385964": {"name": "Yersinia pestis subsp. pestis", "rank": "Subspecies"}, "1417185": {"name": "Staphylococcus aureus M62794", "rank": "Strain"}, "1417184": {"name": "Staphylococcus aureus M59257", "rank": "Strain"}, "1417187": {"name": "Staphylococcus aureus M70006", "rank": "Strain"}, "1417186": {"name": "Staphylococcus aureus M66468", "rank": "Strain"}, "1417181": {"name": "Staphylococcus aureus M55902", "rank": "Strain"}, "1417180": {"name": "Staphylococcus aureus M55890", "rank": "Strain"}, "1417183": {"name": "Staphylococcus aureus M59255", "rank": "Strain"}, "1417182": {"name": "Staphylococcus aureus M59248", "rank": "Strain"}, "33045": {"name": "Bartonella grahamii", "rank": "Species"}, "33044": {"name": "Bartonella doshiae", "rank": "Species"}, "33047": {"name": "Bartonella vinsonii", "rank": "Species"}, "33046": {"name": "Bartonella taylorii", "rank": "Species"}, "33043": {"name": "Coprococcus eutactus", "rank": "Species"}, "33042": {"name": "Coprococcus", "rank": "Genus"}, "88688": {"name": "Caulobacter segnis", "rank": "Species"}, "1228987": {"name": "Cyanobacterium endosymbiont of Epithemia turgida isolate EtSB Lake Yunoko", "rank": "Strain"}, "1123523": {"name": "Staphylococcus aureus subsp. aureus 11819-97", "rank": "Strain"}, "320372": {"name": "Burkholderia pseudomallei 1710b", "rank": "Strain"}, "320371": {"name": "Burkholderia pseudomallei 1710a", "rank": "Strain"}, "1123520": {"name": "Neisseria meningitidis DE9686", "rank": "Strain"}, "1422446": {"name": "Staphylococcus aureus VET0119R", "rank": "Strain"}, "1123524": {"name": "Pseudomonas monteilii QM", "rank": "Strain"}, "81037": {"name": "Pseudoalteromonas elyakovii", "rank": "Species"}, "81031": {"name": "Hyphomonas johnsonii", "rank": "Species"}, "81030": {"name": "Hyphomonas hirschiana", "rank": "Species"}, "81033": {"name": "Hyphomonas oceanitis", "rank": "Species"}, "81032": {"name": "Hyphomonas neptunium", "rank": "Species"}, "1422440": {"name": "Staphylococcus aureus VET0112R", "rank": "Strain"}, "1422441": {"name": "Staphylococcus aureus VET0113R", "rank": "Strain"}, "471473": {"name": "Chlamydia trachomatis L2b/UCH-1/proctitis", "rank": "Strain"}, "471472": {"name": "Chlamydia trachomatis 434/Bu", "rank": "Strain"}, "760748": {"name": "Streptococcus pneumoniae GA05245", "rank": "Strain"}, "760749": {"name": "Streptococcus pneumoniae GA05248", "rank": "Strain"}, "1422442": {"name": "Staphylococcus aureus VET0114R", "rank": "Strain"}, "217159": {"name": "Clostridium carboxidivorans", "rank": "Species"}, "760742": {"name": "Streptococcus pneumoniae GA02254", "rank": "Strain"}, "760743": {"name": "Streptococcus pneumoniae GA02270", "rank": "Strain"}, "1422443": {"name": "Staphylococcus aureus VET0115R", "rank": "Strain"}, "760746": {"name": "Streptococcus pneumoniae GA04375", "rank": "Strain"}, "760747": {"name": "Streptococcus pneumoniae GA13499", "rank": "Strain"}, "760744": {"name": "Streptococcus pneumoniae GA02714", "rank": "Strain"}, "760745": {"name": "Streptococcus pneumoniae GA04175", "rank": "Strain"}, "188905": {"name": "Jannaschia", "rank": "Genus"}, "1281225": {"name": "Escherichia coli UMEA 3230-1", "rank": "Strain"}, "653388": {"name": "Bacillus mojavensis subgroup", "rank": "Species subgroup"}, "699192": {"name": "Megasphaera genomosp. type_1", "rank": "Species"}, "85620": {"name": "Candidatus Phytoplasma asteris", "rank": "Species group"}, "85621": {"name": "16SrII (Peanut WB group)", "rank": "Species group"}, "85623": {"name": "16SrIII (X-disease group)", "rank": "Species group"}, "1084722": {"name": "Mycobacterium phage BarrelRoll", "rank": "Species"}, "755896": {"name": "Yersinia pestis 9", "rank": "Strain"}, "1547580": {"name": "Botryosphaeria dothidea victorivirus 1", "rank": "Species"}, "189330": {"name": "Dorea", "rank": "Genus"}, "688": {"name": "Aliivibrio logei", "rank": "Species"}, "687": {"name": "Vibrio gazogenes", "rank": "Species"}, "686": {"name": "Vibrio cholerae O1 biovar El Tor", "rank": "Strain"}, "685": {"name": "Vibrio diazotrophicus", "rank": "Species"}, "680": {"name": "Vibrio campbellii", "rank": "Species"}, "1418096": {"name": "Xanthomonas arboricola pv. pruni MAFF 301427", "rank": "Strain"}, "1306406": {"name": "Streptomyces thermolilacinus SPC6", "rank": "Strain"}, "1418095": {"name": "Xanthomonas arboricola pv. pruni MAFF 301420", "rank": "Strain"}, "1410706": {"name": "Staphylococcus aureus F84093", "rank": "Strain"}, "1306400": {"name": "Mycobacterium tuberculosis str. Beijing/NITR203", "rank": "Strain"}, "1355020": {"name": "Mycobacterium tuberculosis Mtb562", "rank": "Strain"}, "1306409": {"name": "Clostridium butyricum DKU-01", "rank": "Strain"}, "1355022": {"name": "Bacillus safensis VK", "rank": "Strain"}, "1410649": {"name": "Blautia schinkii DSM 10518", "rank": "Strain"}, "1410648": {"name": "Bifidobacterium thermophilum DSM 20212", "rank": "Strain"}, "1410647": {"name": "Bifidobacterium ruminantium DSM 6489", "rank": "Strain"}, "1410646": {"name": "Bifidobacterium merycicum DSM 6492", "rank": "Strain"}, "1410645": {"name": "Bifidobacterium boum DSM 20432", "rank": "Strain"}, "1410644": {"name": "Bifidobacterium adolescentis DSM 20087", "rank": "Strain"}, "1144379": {"name": "Trichechus manatus latirostris papillomavirus 2", "rank": "Species"}, "1265613": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 17.H.06", "rank": "Strain"}, "436113": {"name": "Mycoplasma mycoides subsp. capri str. GM12", "rank": "Strain"}, "1265611": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 07.O.05", "rank": "Strain"}, "481720": {"name": "Lactobacillus otakiensis", "rank": "Species"}, "1189621": {"name": "Nitritalea halalkaliphila LW7", "rank": "Strain"}, "1265614": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 20.H.06", "rank": "Strain"}, "1265615": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 28.O.08", "rank": "Strain"}, "712117": {"name": "Actinomyces sp. oral taxon 170", "rank": "Species"}, "1265618": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 22.H.04", "rank": "Strain"}, "1265619": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 63.H.87", "rank": "Strain"}, "1294331": {"name": "Saccharomyces cerevisiae YJM993", "rank": "Strain"}, "1438766": {"name": "Klebsiella pneumoniae CHS 60", "rank": "Strain"}, "64972": {"name": "Oceanobacter kriegii", "rank": "Species"}, "540746": {"name": "Rudaea cellulosilytica", "rank": "Species"}, "327987": {"name": "Unclassified Ranavirus", "rank": "No rank"}, "666686": {"name": "Bacillus sp. 1NLA3E", "rank": "Species"}, "1465826": {"name": "Anaerococcus pacaensis", "rank": "Species"}, "1465825": {"name": "Timonella senegalensis", "rank": "Species"}, "1465824": {"name": "Timonella", "rank": "Genus"}, "1465823": {"name": "Herbaspirillum massiliense", "rank": "Species"}, "666681": {"name": "Methylotenera versatilis 301", "rank": "Strain"}, "1001731": {"name": "Mycobacterium abscessus 5S-0422", "rank": "Strain"}, "1073362": {"name": "Eikenella corrodens CC92I", "rank": "Strain"}, "1001733": {"name": "Mycobacterium abscessus 5S-1212", "rank": "Strain"}, "1001732": {"name": "Mycobacterium abscessus 5S-0921", "rank": "Strain"}, "1073367": {"name": "Prevotella oralis CC98A", "rank": "Strain"}, "1073366": {"name": "Prevotella nigrescens CC14M", "rank": "Strain"}, "1001737": {"name": "Mycobacterium abscessus 6G-0728-R", "rank": "Strain"}, "1001736": {"name": "Mycobacterium abscessus 6G-0728-S", "rank": "Strain"}, "1001739": {"name": "Mycobacterium abscessus 6G-0212", "rank": "Strain"}, "1001738": {"name": "Mycobacterium abscessus 6G-1108", "rank": "Strain"}, "1116369": {"name": "Hoeflea sp. 108", "rank": "Species"}, "414050": {"name": "Lysobacter dokdonensis", "rank": "Species"}, "414051": {"name": "Caenispirillum", "rank": "Genus"}, "869269": {"name": "Streptococcus pneumoniae INV104", "rank": "Strain"}, "1250278": {"name": "Salegentibacter sp. Hel_I_6", "rank": "Species"}, "11642": {"name": "Simian foamy virus", "rank": "Species"}, "1424334": {"name": "Advenella kashmirensis W13003", "rank": "Strain"}, "347253": {"name": "Streptococcus salivarius JIM8777", "rank": "Strain"}, "1214225": {"name": "Acidocella sp. MX-AZ02", "rank": "Species"}, "1214224": {"name": "Streptococcus pyogenes HLJGAS12011", "rank": "Strain"}, "1214223": {"name": "Helicobacter pylori HLJHP253", "rank": "Strain"}, "1214222": {"name": "Helicobacter pylori HLJHP271", "rank": "Strain"}, "1214221": {"name": "Helicobacter pylori HLJHP256", "rank": "Strain"}, "1463927": {"name": "Streptomyces sp. NRRL WC-3641", "rank": "Species"}, "179636": {"name": "Alicycliphilus denitrificans", "rank": "Species"}, "209529": {"name": "Aphid lethal paralysis virus", "rank": "Species"}, "1448659": {"name": "Mycobacterium tuberculosis M1317", "rank": "Strain"}, "1448658": {"name": "Mycobacterium tuberculosis M1315", "rank": "Strain"}, "1095674": {"name": "Neisseria meningitidis 61103", "rank": "Strain"}, "1448651": {"name": "Mycobacterium tuberculosis M1294", "rank": "Strain"}, "1448650": {"name": "Mycobacterium tuberculosis M1292", "rank": "Strain"}, "1448653": {"name": "Mycobacterium tuberculosis M1300", "rank": "Strain"}, "1448652": {"name": "Mycobacterium tuberculosis M1295", "rank": "Strain"}, "1448655": {"name": "Mycobacterium tuberculosis M1307", "rank": "Strain"}, "1448654": {"name": "Mycobacterium tuberculosis M1304", "rank": "Strain"}, "1448657": {"name": "Mycobacterium tuberculosis M1310", "rank": "Strain"}, "1448656": {"name": "Mycobacterium tuberculosis M1309", "rank": "Strain"}, "119045": {"name": "Methylobacteriaceae", "rank": "Family"}, "119043": {"name": "Rhodobiaceae", "rank": "Family"}, "119042": {"name": "Unclassified Rhizobiales", "rank": "No rank"}, "1095671": {"name": "Neisseria meningitidis NM3652", "rank": "Strain"}, "683150": {"name": "Arthrobacter sp. SJCon", "rank": "Species"}, "1095670": {"name": "Neisseria meningitidis NM3642", "rank": "Strain"}, "179": {"name": "Leptospirillum", "rank": "Genus"}, "59739": {"name": "Flammeovirga", "rank": "Genus"}, "174": {"name": "Leptospira borgpetersenii", "rank": "Species"}, "59738": {"name": "Marinilabilia", "rank": "Genus"}, "171": {"name": "Leptospira", "rank": "Genus"}, "170": {"name": "Leptospiraceae", "rank": "Family"}, "173": {"name": "Leptospira interrogans", "rank": "Species"}, "172": {"name": "Leptospira biflexa", "rank": "Species"}, "1388070": {"name": "Staphylococcus aureus M0118", "rank": "Strain"}, "1388071": {"name": "Staphylococcus aureus M0119", "rank": "Strain"}, "1427324": {"name": "Mycobacterium tuberculosis XTB13-262", "rank": "Strain"}, "1388073": {"name": "Staphylococcus aureus M0122", "rank": "Strain"}, "1427322": {"name": "Mycobacterium tuberculosis XTB13-255", "rank": "Strain"}, "1427323": {"name": "Mycobacterium tuberculosis XTB13-256", "rank": "Strain"}, "1388076": {"name": "Staphylococcus aureus M0125", "rank": "Strain"}, "1388077": {"name": "Staphylococcus aureus M0126", "rank": "Strain"}, "1388078": {"name": "Staphylococcus aureus M0127", "rank": "Strain"}, "1388079": {"name": "Staphylococcus aureus M0128", "rank": "Strain"}, "1500283": {"name": "Chryseobacterium sp. CF356", "rank": "Species"}, "1427329": {"name": "Mycobacterium tuberculosis XTB13-290", "rank": "Strain"}, "59734": {"name": "Empedobacter", "rank": "Genus"}, "139389": {"name": "Plicaturopsis", "rank": "Genus"}, "1095679": {"name": "Neisseria meningitidis 4119", "rank": "Strain"}, "1095678": {"name": "Neisseria meningitidis 63049", "rank": "Strain"}, "1213458": {"name": "Streptococcus pyogenes BJCYGAS15", "rank": "Strain"}, "1500287": {"name": "Chryseobacterium sp. OV715", "rank": "Species"}, "1241933": {"name": "Rousettus bat coronavirus HKU10", "rank": "Strain"}, "1500286": {"name": "Chryseobacterium sp. OV259", "rank": "Species"}, "1241935": {"name": "Sulfolobus islandicus LAL14/1", "rank": "Strain"}, "1213457": {"name": "Helicobacter pylori HLJHP193", "rank": "Strain"}, "1262532": {"name": "Mycobacterium phage BTCU-1", "rank": "Species"}, "1262533": {"name": "Lactococcus phage 340", "rank": "Species"}, "1262530": {"name": "Halovirus HSTV-1", "rank": "Species"}, "1262536": {"name": "Lactococcus phage jm3", "rank": "Species"}, "1262537": {"name": "Lactococcus phage P680", "rank": "Species"}, "1262535": {"name": "Lactococcus phage jm2", "rank": "Species"}, "1457250": {"name": "Halapricum salinum", "rank": "Species"}, "1262538": {"name": "Lactococcus phage phi7", "rank": "Species"}, "1262539": {"name": "Vibrio phage VH7D", "rank": "Species"}, "1056816": {"name": "Nocardia sp. BMG51109", "rank": "Species"}, "1056817": {"name": "Teredinibacter turnerae T8602", "rank": "Strain"}, "75906": {"name": "Thermocrinis ruber", "rank": "Species"}, "327565": {"name": "Aphanocapsa montana", "rank": "Species"}, "75905": {"name": "Thermocrinis", "rank": "Genus"}, "1056818": {"name": "Teredinibacter turnerae T8415", "rank": "Strain"}, "1056819": {"name": "Teredinibacter turnerae T8412", "rank": "Strain"}, "42897": {"name": "Shigella flexneri 2a", "rank": "Strain"}, "139034": {"name": "Penaeus merguiensis densovirus", "rank": "Species"}, "1474867": {"name": "Aureococcus anophagefferens virus", "rank": "Species"}, "64160": {"name": "Desulfurobacterium thermolithotrophum", "rank": "Species"}, "94695": {"name": "Methanosarcinales", "rank": "Order"}, "1391224": {"name": "Escherichia phage vB_EcoM_PhAPEC2", "rank": "Species"}, "1391223": {"name": "Escherichia phage vB_EcoP_PhAPEC7", "rank": "Species"}, "1288971": {"name": "Clostridium ultunense Esp", "rank": "Strain"}, "329886": {"name": "Vibriophage VP4", "rank": "Species"}, "146499": {"name": "Cucumber fruit mottle mosaic virus", "rank": "Species"}, "1413362": {"name": "Staphylococcus aureus 11S01420", "rank": "Strain"}, "1016998": {"name": "Salmonella enterica subsp. enterica serovar Paratyphi B str. SPB7", "rank": "Strain"}, "1199150": {"name": "Klebsiella pneumoniae subsp. pneumoniae KP5-1", "rank": "Strain"}, "545501": {"name": "Oceanobacillus oncorhynchi", "rank": "Species"}, "240237": {"name": "Woodsholea maritima", "rank": "Species"}, "103881": {"name": "Potato yellow vein virus", "rank": "Species"}, "39740": {"name": "Bromoviridae", "rank": "Family"}, "265488": {"name": "Rhodopirellula", "rank": "Genus"}, "39742": {"name": "Barnavirus", "rank": "Genus"}, "39743": {"name": "Asfivirus", "rank": "Genus"}, "39744": {"name": "Rubulavirus", "rank": "Genus"}, "39745": {"name": "Unclassified Paramyxovirinae", "rank": "No rank"}, "39747": {"name": "Unclassified Entomopoxvirinae", "rank": "No rank"}, "39748": {"name": "Hypoviridae", "rank": "Family"}, "39749": {"name": "Hypovirus", "rank": "Genus"}, "1267169": {"name": "Streptococcus phage phiBHN167", "rank": "Species"}, "265487": {"name": "Blastopirellula", "rank": "Genus"}, "1391489": {"name": "Enterococcus faecalis EnGen0419", "rank": "Strain"}, "1391488": {"name": "Enterococcus faecalis EnGen0418", "rank": "Strain"}, "293653": {"name": "Streptococcus pyogenes MGAS5005", "rank": "Strain"}, "1391483": {"name": "Enterococcus faecalis EnGen0413", "rank": "Strain"}, "1391482": {"name": "Enterococcus faecalis EnGen0412", "rank": "Strain"}, "1391481": {"name": "Enterococcus faecalis EnGen0411", "rank": "Strain"}, "1391480": {"name": "Enterococcus faecalis EnGen0410", "rank": "Strain"}, "1391487": {"name": "Enterococcus faecalis EnGen0417", "rank": "Strain"}, "1391486": {"name": "Enterococcus faecalis EnGen0416", "rank": "Strain"}, "1391485": {"name": "Enterococcus faecalis EnGen0415", "rank": "Strain"}, "1391484": {"name": "Enterococcus faecalis EnGen0414", "rank": "Strain"}, "1116170": {"name": "Escherichia coli P0304777.9", "rank": "Strain"}, "1116171": {"name": "Escherichia coli P0304777.10", "rank": "Strain"}, "1116172": {"name": "Escherichia coli P0304777.11", "rank": "Strain"}, "1116173": {"name": "Escherichia coli P0304777.12", "rank": "Strain"}, "1116174": {"name": "Escherichia coli P0304777.13", "rank": "Strain"}, "1116175": {"name": "Escherichia coli P0304777.14", "rank": "Strain"}, "1116176": {"name": "Escherichia coli P0304777.15", "rank": "Strain"}, "983919": {"name": "Pseudomonas aeruginosa HB15", "rank": "Strain"}, "1214955": {"name": "Gyrovirus 4", "rank": "Species"}, "1116179": {"name": "Escherichia coli P0304816.3", "rank": "Strain"}, "1434131": {"name": "Shigella flexneri Shi06GS07", "rank": "Strain"}, "1239989": {"name": "Morganella morganii SC01", "rank": "Strain"}, "1157009": {"name": "Staphylococcus aureus M0066", "rank": "Strain"}, "1157008": {"name": "Staphylococcus aureus M0060", "rank": "Strain"}, "1157003": {"name": "Staphylococcus aureus HI013", "rank": "Strain"}, "1157002": {"name": "Staphylococcus aureus HI111", "rank": "Strain"}, "1157001": {"name": "Staphylococcus aureus HI168", "rank": "Strain"}, "1157000": {"name": "Staphylococcus aureus HI049C", "rank": "Strain"}, "1157007": {"name": "Staphylococcus aureus M0045", "rank": "Strain"}, "1157006": {"name": "Staphylococcus aureus M0035", "rank": "Strain"}, "1157005": {"name": "Staphylococcus aureus M0029", "rank": "Strain"}, "1157004": {"name": "Staphylococcus aureus M0001", "rank": "Strain"}, "1198680": {"name": "Brucella melitensis CNGB 1120", "rank": "Strain"}, "1198681": {"name": "Brucella melitensis CNGB 290", "rank": "Strain"}, "1198682": {"name": "Brucella suis CNGB 786", "rank": "Strain"}, "1198683": {"name": "Brucella suis CNGB 247", "rank": "Strain"}, "1198684": {"name": "Brucella canis CNGB 1324", "rank": "Strain"}, "1198685": {"name": "Brucella canis CNGB 513", "rank": "Strain"}, "1198686": {"name": "Brucella canis CNGB 1172", "rank": "Strain"}, "1198687": {"name": "Brucella abortus CNGB 436", "rank": "Strain"}, "1198688": {"name": "Brucella abortus CNGB 308", "rank": "Strain"}, "1198689": {"name": "Brucella abortus CNGB 752", "rank": "Strain"}, "404974": {"name": "Vibrio cholerae AM-19226", "rank": "Strain"}, "131550": {"name": "Fibrobacteres/Acidobacteria group", "rank": "Superphylum"}, "1352594": {"name": "Mycobacterium tuberculosis PanR0906", "rank": "Strain"}, "1352595": {"name": "Mycobacterium tuberculosis PanR0907", "rank": "Strain"}, "1352596": {"name": "Mycobacterium tuberculosis PanR0908", "rank": "Strain"}, "1352597": {"name": "Mycobacterium tuberculosis PanR0909", "rank": "Strain"}, "1097668": {"name": "Burkholderia sp. YI23", "rank": "Species"}, "1097669": {"name": "Mycobacterium tuberculosis UT205", "rank": "Strain"}, "1234664": {"name": "Geobacillus caldoxylosilyticus CIC9", "rank": "Strain"}, "5281": {"name": "Tilletiaria anomala", "rank": "Species"}, "5280": {"name": "Tilletiaria", "rank": "Genus"}, "1097667": {"name": "Patulibacter medicamentivorans", "rank": "Species"}, "5285": {"name": "Rhodosporidium", "rank": "Genus"}, "5286": {"name": "Rhodosporidium toruloides", "rank": "Species"}, "180169": {"name": "Unclassified Iridoviridae", "rank": "No rank"}, "180162": {"name": "Cetobacterium", "rank": "Genus"}, "180164": {"name": "Blautia schinkii", "rank": "Species"}, "515619": {"name": "Eubacterium rectale ATCC 33656", "rank": "Strain"}, "910417": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. 629164-37", "rank": "Strain"}, "910416": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. 629164-26", "rank": "Strain"}, "910415": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. 596866-70", "rank": "Strain"}, "910414": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. 596866-22", "rank": "Strain"}, "910413": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. 485549-17", "rank": "Strain"}, "1444272": {"name": "Escherichia coli 1-110-08_S4_C3", "rank": "Strain"}, "910419": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. 639672-50", "rank": "Strain"}, "910418": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. 639672-46", "rank": "Strain"}, "77551": {"name": "Wolbachia endosymbiont of Onchocerca volvulus", "rank": "Species"}, "28449": {"name": "Neisseria subflava", "rank": "Species"}, "28448": {"name": "Komagataeibacter xylinus", "rank": "Species"}, "1181747": {"name": "Escherichia coli KTE201", "rank": "Strain"}, "28444": {"name": "Herbidospora cretacea", "rank": "Species"}, "28447": {"name": "Clavibacter michiganensis", "rank": "Species"}, "28443": {"name": "Herbidospora", "rank": "Genus"}, "28442": {"name": "Haloarcula vallismortis", "rank": "Species"}, "1105031": {"name": "Clostridium sp. MSTE9", "rank": "Species"}, "1105030": {"name": "Atopobium sp. ICM58", "rank": "Species"}, "1242253": {"name": "Lactobacillus pobuzihii E100301 = KCTC 13174", "rank": "Strain"}, "1105032": {"name": "Streptococcus sp. BS35b", "rank": "Species"}, "59617": {"name": "Helicobacter rodentium", "rank": "Species"}, "45617": {"name": "Human endogenous retrovirus K", "rank": "Species"}, "1095752": {"name": "Prevotella sp. oral taxon 306 str. F0472", "rank": "Strain"}, "1095750": {"name": "Lachnoanaerobaculum saburreum F0468", "rank": "Strain"}, "1291048": {"name": "Thermoanaerobacter thermocopriae JCM 7501", "rank": "Strain"}, "1191303": {"name": "Vibrio crassostreae ZF-91", "rank": "Strain"}, "1191300": {"name": "Vibrio crassostreae 9CS106", "rank": "Strain"}, "1191301": {"name": "Vibrio crassostreae 9ZC13", "rank": "Strain"}, "1191304": {"name": "Vibrio crassostreae 9ZC88", "rank": "Strain"}, "1191305": {"name": "Vibrio splendidus 12E03", "rank": "Strain"}, "1191309": {"name": "Vibrio splendidus FF-500", "rank": "Strain"}, "1397702": {"name": "Candidatus Rickettsia gravesii BWI-1", "rank": "Strain"}, "1397700": {"name": "Exiguobacterium antarcticum DSM 14480", "rank": "Strain"}, "1397701": {"name": "Brucella abortus S99", "rank": "Strain"}, "1130338": {"name": "EM3 bacterium JGI 0000106-B10", "rank": "Species"}, "1088721": {"name": "Novosphingobium pentaromativorans US6-1", "rank": "Strain"}, "1088720": {"name": "Lactobacillus rhamnosus ATCC 8530", "rank": "Strain"}, "1370107": {"name": "Escherichia coli O6:H16:CFA/II str. B2C", "rank": "Strain"}, "1370106": {"name": "Escherichia coli O6:H16:CFA/II", "rank": "Strain"}, "11856": {"name": "Squirrel monkey retrovirus", "rank": "Species"}, "1286528": {"name": "Neorickettsia helminthoeca str. Oregon", "rank": "Strain"}, "1444276": {"name": "Escherichia coli 3-020-07_S4_C3", "rank": "Strain"}, "591159": {"name": "Streptomyces viridochromogenes DSM 40736", "rank": "Strain"}, "644279": {"name": "Staphylococcus aureus subsp. aureus 132", "rank": "Strain"}, "1446583": {"name": "Escherichia coli O145:H25 str. 07-3858", "rank": "Strain"}, "259390": {"name": "Nocardia takedensis", "rank": "Species"}, "1446582": {"name": "Escherichia coli O145:H25", "rank": "Strain"}, "504474": {"name": "Corynebacterium urealyticum DSM 7109", "rank": "Strain"}, "1052826": {"name": "Aigarchaeota archaeon SCGC AAA471-D15", "rank": "Species"}, "1121112": {"name": "Bifidobacterium tsurumiense DSM 17777", "rank": "Strain"}, "504472": {"name": "Spirosoma linguale DSM 74", "rank": "Strain"}, "1121114": {"name": "Blautia producta ATCC 27340 = DSM 2950", "rank": "Strain"}, "74223": {"name": "Candidate division WS1", "rank": "No rank"}, "1121115": {"name": "Blautia wexlerae DSM 19850", "rank": "Strain"}, "1408303": {"name": "Bacillus sp. MB2021", "rank": "Species"}, "98360": {"name": "Salmonella enterica subsp. enterica serovar Dublin", "rank": "Strain"}, "1408306": {"name": "Butyrivibrio sp. MC2021", "rank": "Species"}, "1408305": {"name": "Butyrivibrio sp. LB2008", "rank": "Species"}, "1408304": {"name": "Butyrivibrio sp. FCS014", "rank": "Species"}, "1408309": {"name": "Prevotella sp. FD3004", "rank": "Species"}, "139808": {"name": "Shimazuella kribbensis", "rank": "Species"}, "459770": {"name": "Diplodia scrobiculata RNA virus 1", "rank": "Species"}, "263437": {"name": "Wolbachia endosymbiont of Culex quinquefasciatus", "rank": "Species"}, "1169623": {"name": "Unclassified Densovirus", "rank": "No rank"}, "663241": {"name": "Enterococcus phage phiEf11", "rank": "Species"}, "565639": {"name": "Enterococcus faecalis T8", "rank": "Strain"}, "565638": {"name": "Enterococcus faecalis T3", "rank": "Strain"}, "565637": {"name": "Enterococcus faecalis T2", "rank": "Strain"}, "565636": {"name": "Enterococcus faecalis T1", "rank": "Strain"}, "644897": {"name": "Desulfovibrio termitidis HI1", "rank": "Strain"}, "440266": {"name": "WU Polyomavirus", "rank": "Species"}, "766164": {"name": "Shigella sonnei 4822-66", "rank": "Strain"}, "1287657": {"name": "Bacillus massiliosenegalensis", "rank": "Species"}, "766166": {"name": "Escherichia coli EPEC C342-62", "rank": "Strain"}, "766160": {"name": "Shigella flexneri 4343-70", "rank": "Strain"}, "766161": {"name": "Shigella flexneri 6603-63", "rank": "Strain"}, "766162": {"name": "Shigella sonnei 3226-85", "rank": "Strain"}, "766163": {"name": "Shigella sonnei 3233-85", "rank": "Strain"}, "1123721": {"name": "Weissella koreensis KCTC 3621", "rank": "Strain"}, "347495": {"name": "Bacillus cereus F837/76", "rank": "Strain"}, "1248732": {"name": "Neisseria meningitidis 992008", "rank": "Strain"}, "1122238": {"name": "Microbacterium indicum DSM 19969", "rank": "Strain"}, "1122239": {"name": "Microbacterium luticocti DSM 19459", "rank": "Strain"}, "1405296": {"name": "Chlamydia suis MD56", "rank": "Strain"}, "1122236": {"name": "Methylophilus methylotrophus DSM 46235 = ATCC 53528", "rank": "Strain"}, "1122237": {"name": "Microbacterium gubbeenense DSM 15944", "rank": "Strain"}, "1122230": {"name": "Methanocorpusculum bavaricum DSM 4179", "rank": "Strain"}, "1122233": {"name": "Methermicoccus shengliensis DSM 18856", "rank": "Strain"}, "75574": {"name": "Jatropha mosaic virus", "rank": "Species"}, "633699": {"name": "Lactobacillus johnsonii FI9785", "rank": "Strain"}, "633697": {"name": "Eubacterium cellulosolvens 6", "rank": "Strain"}, "129394": {"name": "Xanthomonas oryzae pv. oryzicola", "rank": "Strain"}, "129395": {"name": "Botrytis virus F", "rank": "Species"}, "1163749": {"name": "Staphylococcus aureus subsp. aureus LCT-SA112", "rank": "Strain"}, "1163748": {"name": "Marinobacter hydrocarbonoclasticus ATCC 49840", "rank": "Strain"}, "1163743": {"name": "Helicobacter pylori HUP-B14", "rank": "Strain"}, "1163742": {"name": "Helicobacter pylori PeCan18", "rank": "Strain"}, "1163741": {"name": "Helicobacter pylori Shi169", "rank": "Strain"}, "1163740": {"name": "Helicobacter pylori Shi112", "rank": "Strain"}, "1163747": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. 2780", "rank": "Strain"}, "1163745": {"name": "Helicobacter cetorum MIT 99-5656", "rank": "Strain"}, "134533": {"name": "Acinetobacter parvus", "rank": "Species"}, "134536": {"name": "Burkholderia caledonica", "rank": "Species"}, "134537": {"name": "Burkholderia fungorum", "rank": "Species"}, "134534": {"name": "Acinetobacter gyllenbergii", "rank": "Species"}, "536084": {"name": "Tomato common mosaic virus", "rank": "Species"}, "536086": {"name": "Tomato mild mosaic virus", "rank": "Species"}, "536081": {"name": "Blainvillea yellow spot virus", "rank": "Species"}, "1405295": {"name": "Escherichia coli ATCC BAA-2219", "rank": "Strain"}, "446549": {"name": "Lucky bamboo bacilliform virus", "rank": "Species"}, "446548": {"name": "Unclassified Caulimoviridae", "rank": "No rank"}, "113604": {"name": "Tetrapisispora", "rank": "Genus"}, "1501332": {"name": "Oribacterium asaccharolyticum", "rank": "Species"}, "1329250": {"name": "Weissella oryzae SG25", "rank": "Strain"}, "1229831": {"name": "Chlamydia avium 10DC88", "rank": "Strain"}, "661": {"name": "Photobacterium angustum", "rank": "Species"}, "185283": {"name": "Unclassified Propionibacteriaceae", "rank": "No rank"}, "1432652": {"name": "Francisella tularensis subsp. holarctica PHIT-FT049", "rank": "Strain"}, "1446716": {"name": "Escherichia coli O26:H11 str. 2009C-4760", "rank": "Strain"}, "1232894": {"name": "Unassigned Tymoviridae", "rank": "No rank"}, "931281": {"name": "Pseudomonas putida BIRD-1", "rank": "Strain"}, "1506574": {"name": "Protoparvovirus", "rank": "Genus"}, "574521": {"name": "Escherichia coli O127:H6 str. E2348/69", "rank": "Strain"}, "1506577": {"name": "Tyzzerella", "rank": "Genus"}, "1151189": {"name": "Enterococcus faecalis EnGen0064", "rank": "Strain"}, "489909": {"name": "Nosocomiicoccus", "rank": "Genus"}, "32603": {"name": "Human herpesvirus 6A", "rank": "Species"}, "1446713": {"name": "Escherichia coli O26:H11 str. 2009C-3689", "rank": "Strain"}, "1241616": {"name": "Staphylococcus aureus subsp. aureus DSM 20231", "rank": "Strain"}, "171412": {"name": "Eremococcus", "rank": "Genus"}, "11033": {"name": "Semliki forest virus", "rank": "Species"}, "11034": {"name": "Sindbis virus", "rank": "Species"}, "29450": {"name": "Rhizobium leucaenae", "rank": "Species"}, "11036": {"name": "Venezuelan equine encephalitis virus", "rank": "Species"}, "11039": {"name": "Western equine encephalitis virus", "rank": "Species"}, "497742": {"name": "Desulfatirhabdium", "rank": "Genus"}, "29459": {"name": "Brucella melitensis", "rank": "Species"}, "302100": {"name": "Tomato leaf curl Mayotte virus", "rank": "Species"}, "372461": {"name": "Buchnera aphidicola BCc", "rank": "Strain"}, "1185709": {"name": "Xanthomonas axonopodis pv. manihotis str. UG27", "rank": "Strain"}, "1185708": {"name": "Xanthomonas axonopodis pv. manihotis str. UG24", "rank": "Strain"}, "1185707": {"name": "Xanthomonas axonopodis pv. manihotis str. UG23", "rank": "Strain"}, "1185706": {"name": "Xanthomonas axonopodis pv. manihotis str. UG21", "rank": "Strain"}, "1185705": {"name": "Xanthomonas axonopodis pv. manihotis str. ThaiXam", "rank": "Strain"}, "1185704": {"name": "Xanthomonas axonopodis pv. manihotis str. ORST X27", "rank": "Strain"}, "1185702": {"name": "Xanthomonas axonopodis pv. manihotis str. ORST17", "rank": "Strain"}, "1185700": {"name": "Xanthomonas axonopodis pv. manihotis str. NCPPB 1159", "rank": "Strain"}, "1172194": {"name": "Hydrocarboniphaga effusa AP103", "rank": "Strain"}, "1172190": {"name": "Sulfurimonas sp. AST-10", "rank": "Species"}, "1172191": {"name": "Catenovulum", "rank": "Genus"}, "1172192": {"name": "Catenovulum agarivorans", "rank": "Species"}, "1172193": {"name": "Betapapillomavirus 6", "rank": "Species"}, "1386083": {"name": "Helicobacter pylori X47-2AL", "rank": "Strain"}, "1386087": {"name": "Neisseria meningitidis LNP21362", "rank": "Strain"}, "1386084": {"name": "Neisseria meningitidis LNP27256", "rank": "Strain"}, "1177117": {"name": "Halomonas stevensii S18214", "rank": "Strain"}, "1386089": {"name": "Intrasporangium oryzae NRRL B-24470", "rank": "Strain"}, "1130305": {"name": "Crenarchaeote SCGC AAA261-N23", "rank": "Species"}, "1145160": {"name": "Neisseria meningitidis 2002020", "rank": "Strain"}, "281119": {"name": "Candidatus Amoebophilus", "rank": "Genus"}, "1145167": {"name": "Neisseria meningitidis 2001001", "rank": "Strain"}, "1214189": {"name": "Streptococcus suis YS16", "rank": "Strain"}, "1432657": {"name": "Borrelia duttonii CR2A", "rank": "Strain"}, "1412494": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. SA19943269", "rank": "Strain"}, "1412495": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. SA20123395", "rank": "Strain"}, "1412496": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. SA19971331", "rank": "Strain"}, "1412497": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. SA19961622", "rank": "Strain"}, "1412490": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. SA20083636", "rank": "Strain"}, "1130301": {"name": "Crenarchaeote SCGC AAA261-G18", "rank": "Species"}, "1412492": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. SA20095440", "rank": "Strain"}, "1412493": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. SA19942384", "rank": "Strain"}, "1145164": {"name": "Neisseria meningitidis 2001072", "rank": "Strain"}, "1412498": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. SA19983126", "rank": "Strain"}, "1412499": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. SA19994216", "rank": "Strain"}, "1122943": {"name": "Pedobacter oryzae", "rank": "Species"}, "1122940": {"name": "Paucisalibacillus globulus DSM 18846", "rank": "Strain"}, "1122941": {"name": "Pedobacter glucosidilyticus", "rank": "Species"}, "1122946": {"name": "Pelobacter seleniigenes DSM 18267", "rank": "Strain"}, "1122947": {"name": "Pelosinus fermentans DSM 17108", "rank": "Strain"}, "1122949": {"name": "Peptoniphilus lacrimalis DSM 7455", "rank": "Strain"}, "1145169": {"name": "Neisseria meningitidis 2001213", "rank": "Strain"}, "1169160": {"name": "Streptomyces sp. CNS335", "rank": "Species"}, "521011": {"name": "Methanosphaerula palustris E1-9c", "rank": "Strain"}, "521010": {"name": "Borrelia bissettii DN127", "rank": "Strain"}, "204434": {"name": "Acidobacteriaceae", "rank": "Family"}, "1159554": {"name": "Cronobacter dublinensis subsp. dublinensis LMG 23823", "rank": "Strain"}, "1380908": {"name": "Klebsiella pneumoniae JM45", "rank": "Strain"}, "204430": {"name": "Fibrobacteria", "rank": "Class"}, "204433": {"name": "Acidobacteriales", "rank": "Order"}, "204432": {"name": "Acidobacteriia", "rank": "Class"}, "1343920": {"name": "Apricot vein clearing associated virus", "rank": "Species"}, "35296": {"name": "Unclassified Picornaviridae", "rank": "No rank"}, "35297": {"name": "Striped Jack nervous necrosis virus", "rank": "Species"}, "35291": {"name": "Pelargonium flower break virus", "rank": "Species"}, "174683": {"name": "Ordosporidae", "rank": "Family"}, "174684": {"name": "Ordospora", "rank": "Genus"}, "174685": {"name": "Ordospora colligata", "rank": "Species"}, "1056833": {"name": "Mycobacterium phage Wile", "rank": "Species"}, "94132": {"name": "Ramlibacter tataouinensis", "rank": "Species"}, "94136": {"name": "Alkalibacillus haloalkaliphilus", "rank": "Species"}, "1522368": {"name": "Modestobacter sp. KNN45-2b", "rank": "Species"}, "334802": {"name": "Burkholderia mallei FMH", "rank": "Strain"}, "334803": {"name": "Burkholderia mallei JHU", "rank": "Strain"}, "1159089": {"name": "Streptococcus pneumoniae PNI0007", "rank": "Strain"}, "1159088": {"name": "Streptococcus pneumoniae PNI0006", "rank": "Strain"}, "1159085": {"name": "Streptococcus pneumoniae PCS70012", "rank": "Strain"}, "33996": {"name": "Gluconacetobacter diazotrophicus", "rank": "Species"}, "33995": {"name": "Komagataeibacter europaeus", "rank": "Species"}, "33994": {"name": "Neorickettsia helminthoeca", "rank": "Species"}, "33993": {"name": "Neorickettsia", "rank": "Genus"}, "33992": {"name": "Rickettsia rhipicephali", "rank": "Species"}, "33991": {"name": "Rickettsia montanensis", "rank": "Species"}, "33990": {"name": "Rickettsia bellii", "rank": "Species"}, "331975": {"name": "Heterocapsa circularisquama RNA virus", "rank": "Species"}, "331971": {"name": "Thalassobacillus", "rank": "Genus"}, "1463915": {"name": "Streptomyces sp. NRRL S-575", "rank": "Species"}, "1463917": {"name": "Streptomyces sp. NRRL S-646", "rank": "Species"}, "1463916": {"name": "Streptomyces sp. NRRL S-623", "rank": "Species"}, "1463911": {"name": "Streptomyces sp. NRRL S-481", "rank": "Species"}, "1463910": {"name": "Streptomyces sp. NRRL S-475", "rank": "Species"}, "64159": {"name": "Desulfurobacterium", "rank": "Genus"}, "1463912": {"name": "Streptomyces sp. NRRL S-50", "rank": "Species"}, "866778": {"name": "Veillonella atypica ACS-134-V-Col7a", "rank": "Strain"}, "866779": {"name": "Finegoldia magna SY403409CC001050417", "rank": "Strain"}, "88189": {"name": "Thermus igniterrae", "rank": "Species"}, "866774": {"name": "Atopobium vaginae PB189-T1-4", "rank": "Strain"}, "866775": {"name": "Aerococcus urinae ACS-120-V-Col10a", "rank": "Strain"}, "866776": {"name": "Veillonella atypica ACS-049-V-Sch6", "rank": "Strain"}, "866777": {"name": "Bifidobacterium breve ACS-071-V-Sch8b", "rank": "Strain"}, "866770": {"name": "Mobiluncus mulieris FB024-16", "rank": "Strain"}, "866771": {"name": "Prevotella disiens FB035-09AN", "rank": "Strain"}, "866773": {"name": "Finegoldia magna BVS033A4", "rank": "Strain"}, "1161935": {"name": "Salinivibrio phage CW02", "rank": "Species"}, "661182": {"name": "Perlucidibaca", "rank": "Genus"}, "1220534": {"name": "Methanobacterium sp. Maddingley MBC34", "rank": "Species"}, "1220535": {"name": "Alpha proteobacterium IMCC14465", "rank": "Species"}, "1220533": {"name": "Bacillus subtilis QB928", "rank": "Strain"}, "157837": {"name": "Oat mosaic virus", "rank": "Species"}, "1330065": {"name": "Aquamavirus", "rank": "Genus"}, "1330066": {"name": "Aquamavirus A", "rank": "Species"}, "1330067": {"name": "Dicipivirus", "rank": "Genus"}, "66429": {"name": "Streptomyces roseoverticillatus", "rank": "Species"}, "1330068": {"name": "Cadicivirus A", "rank": "Species"}, "1330069": {"name": "Megrivirus", "rank": "Genus"}, "1422228": {"name": "Staphylococcus aureus DAR1278", "rank": "Strain"}, "1422229": {"name": "Staphylococcus aureus DAR1291", "rank": "Strain"}, "1327777": {"name": "Mycobacterium phage SiSi", "rank": "Species"}, "336982": {"name": "Mycobacterium tuberculosis F11", "rank": "Strain"}, "645664": {"name": "Shigella phage SP18", "rank": "Species"}, "1422220": {"name": "Staphylococcus aureus DAR1158", "rank": "Strain"}, "1344113": {"name": "American bat vesiculovirus TFFN-2013", "rank": "Species"}, "1422222": {"name": "Staphylococcus aureus DAR1174", "rank": "Strain"}, "1422223": {"name": "Staphylococcus aureus DAR1176", "rank": "Strain"}, "1422224": {"name": "Staphylococcus aureus DAR1183", "rank": "Strain"}, "1422225": {"name": "Staphylococcus aureus DAR1200", "rank": "Strain"}, "1422226": {"name": "Staphylococcus aureus DAR1275", "rank": "Strain"}, "336988": {"name": "Oenococcus kitaharae", "rank": "Species"}, "31757": {"name": "Mycobacterium phage L5", "rank": "Species"}, "31754": {"name": "Lactococcus phage BK5-T", "rank": "Species"}, "31750": {"name": "Pepper ringspot virus", "rank": "Species"}, "871590": {"name": "Salmonella enterica subsp. enterica serovar Montevideo str. MB111609-0052", "rank": "Strain"}, "871591": {"name": "Salmonella enterica subsp. enterica serovar Montevideo str. 2009083312", "rank": "Strain"}, "871592": {"name": "Salmonella enterica subsp. enterica serovar Montevideo str. 2009085258", "rank": "Strain"}, "871593": {"name": "Salmonella enterica subsp. enterica serovar Montevideo str. 315731156", "rank": "Strain"}, "767456": {"name": "Lactobacillus helveticus H9", "rank": "Strain"}, "767455": {"name": "Lactobacillus delbrueckii subsp. bulgaricus ND02", "rank": "Strain"}, "1026882": {"name": "Methylophaga aminisulfidivorans MP", "rank": "Strain"}, "1354180": {"name": "Mycobacterium africanum MAL010129", "rank": "Strain"}, "228": {"name": "Pseudoalteromonas haloplanktis", "rank": "Species"}, "222": {"name": "Achromobacter", "rank": "Genus"}, "226": {"name": "Alteromonas", "rank": "Genus"}, "1504316": {"name": "Actinobacterium acMicro-1", "rank": "Species"}, "143067": {"name": "Methanosaetaceae", "rank": "Family"}, "163164": {"name": "Wolbachia endosymbiont of Drosophila melanogaster", "rank": "Species"}, "904339": {"name": "Staphylococcus hominis VCU122", "rank": "Strain"}, "1335422": {"name": "Mycobacterium intracellulare MIN_061107_1834", "rank": "Strain"}, "1335421": {"name": "Mycobacterium intracellulare MIN_052511_1280", "rank": "Strain"}, "1335420": {"name": "Mycobacterium avium MAV_120809_2495", "rank": "Strain"}, "858893": {"name": "Exophiala dermatitidis NIH/UT8656", "rank": "Strain"}, "1638": {"name": "Listeria ivanovii", "rank": "Species"}, "1639": {"name": "Listeria monocytogenes", "rank": "Species"}, "300275": {"name": "Lachancea", "rank": "Genus"}, "1637": {"name": "Listeria", "rank": "Genus"}, "1630": {"name": "Kandleria vitulina", "rank": "Species"}, "1331736": {"name": "Ruaniaceae", "rank": "Family"}, "1632": {"name": "Lactobacillus oris", "rank": "Species"}, "1633": {"name": "Lactobacillus vaginalis", "rank": "Species"}, "610116": {"name": "Aliihoeflea", "rank": "Genus"}, "1508419": {"name": "Thermotoga caldifontis", "rank": "Species"}, "431040": {"name": "Unclassified Tobacco necrosis satellite virus-like", "rank": "No rank"}, "431041": {"name": "Candidatus Synechococcus spongiarum", "rank": "Species"}, "1412788": {"name": "Staphylococcus aureus T57402", "rank": "Strain"}, "1504318": {"name": "Actinobacterium acAMD-2", "rank": "Species"}, "1412789": {"name": "Staphylococcus aureus T57415", "rank": "Strain"}, "1471492": {"name": "Prochlorococcus sp. scB243_498G3", "rank": "Species"}, "1291206": {"name": "Leptospira borgpetersenii serovar Hardjo-bovis str. Lely 607", "rank": "Strain"}, "1291207": {"name": "Leptospira borgpetersenii serovar Javanica str. L0066", "rank": "Strain"}, "290231": {"name": "Nocardia exalbida", "rank": "Species"}, "1468418": {"name": "Bartonella senegalensis", "rank": "Species"}, "65700": {"name": "Erwinia tracheiphila", "rank": "Species"}, "1412783": {"name": "Staphylococcus aureus T51022", "rank": "Strain"}, "1267360": {"name": "Mycobacterium tuberculosis TKK-01-0026", "rank": "Strain"}, "1267361": {"name": "Mycobacterium tuberculosis TKK-01-0032", "rank": "Strain"}, "1267362": {"name": "Mycobacterium tuberculosis TKK-01-0069", "rank": "Strain"}, "1267363": {"name": "Mycobacterium tuberculosis TKK-01-0072", "rank": "Strain"}, "1267364": {"name": "Mycobacterium tuberculosis TKK-01-0080", "rank": "Strain"}, "1388318": {"name": "Staphylococcus sp. M0480", "rank": "Species"}, "1527469": {"name": "Bacillus phage Bobb", "rank": "Species"}, "992133": {"name": "Yersinia pestis PY-07", "rank": "Strain"}, "1388722": {"name": "Staphylococcus aureus M0961", "rank": "Strain"}, "992131": {"name": "Yersinia pestis PY-05", "rank": "Strain"}, "1051659": {"name": "Lactobacillus casei UCD174", "rank": "Strain"}, "1051658": {"name": "Lactobacillus casei T71499", "rank": "Strain"}, "1051657": {"name": "Lactobacillus casei M36", "rank": "Strain"}, "1051656": {"name": "Lactobacillus casei Lpc-37", "rank": "Strain"}, "992138": {"name": "Yersinia pestis PY-12", "rank": "Strain"}, "1051654": {"name": "Lactobacillus casei CRF28", "rank": "Strain"}, "1051653": {"name": "Lactobacillus casei A2-362", "rank": "Strain"}, "1051652": {"name": "Lactobacillus casei 32G", "rank": "Strain"}, "1051651": {"name": "Lactobacillus casei 21/1", "rank": "Strain"}, "1051650": {"name": "Lactobacillus casei 12A", "rank": "Strain"}, "1411095": {"name": "Clostridium phage CDMH1", "rank": "Species"}, "85413": {"name": "Bosea", "rank": "Genus"}, "64968": {"name": "Marinospirillum", "rank": "Genus"}, "873533": {"name": "Prevotella oralis ATCC 33269", "rank": "Strain"}, "45361": {"name": "Mycoplasma conjunctivae", "rank": "Species"}, "45363": {"name": "Mycoplasma alkalescens", "rank": "Species"}, "45362": {"name": "Mycoplasma bovoculi", "rank": "Species"}, "1515746": {"name": "Shewanella sp. YQH10", "rank": "Species"}, "984225": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. 648902 6-8", "rank": "Strain"}, "984224": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. 648901 39-2", "rank": "Strain"}, "984227": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. 648904 3-6", "rank": "Strain"}, "984226": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. 648903 1-6", "rank": "Strain"}, "984221": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. 648899 3-17", "rank": "Strain"}, "984220": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. 648898 4-5", "rank": "Strain"}, "984223": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. 648901 1-17", "rank": "Strain"}, "984222": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. 648900 1-16", "rank": "Strain"}, "984229": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. 653049 13-19", "rank": "Strain"}, "984228": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. 648905 5-18", "rank": "Strain"}, "102897": {"name": "Frankia sp. EUN1f", "rank": "Species"}, "146786": {"name": "Thermosynechococcus elongatus", "rank": "Species"}, "1208919": {"name": "Candidatus Kinetoplastibacterium desouzaii TCC079E", "rank": "Strain"}, "119492": {"name": "Pecluvirus", "rank": "Genus"}, "194195": {"name": "Alysiella", "rank": "Genus"}, "130328": {"name": "Duck adenovirus A", "rank": "Species"}, "537973": {"name": "Lactobacillus paracasei subsp. paracasei 8700:2", "rank": "Strain"}, "537972": {"name": "Helicobacter pullorum MIT 98-5489", "rank": "Strain"}, "537971": {"name": "Helicobacter cinaedi CCUG 18818", "rank": "Strain"}, "537970": {"name": "Helicobacter canadensis MIT 98-5491", "rank": "Strain"}, "756883": {"name": "Halophilic archaeon DL31", "rank": "Species"}, "360580": {"name": "Mesta yellow vein mosaic virus-associated DNA beta", "rank": "Species"}, "1269275": {"name": "Anaplasma phagocytophilum str. CRT38", "rank": "Strain"}, "1403845": {"name": "Staphylococcus aureus M1349", "rank": "Strain"}, "1403844": {"name": "Staphylococcus aureus M1348", "rank": "Strain"}, "1403847": {"name": "Staphylococcus aureus M1351", "rank": "Strain"}, "1403846": {"name": "Staphylococcus aureus M1350", "rank": "Strain"}, "1403841": {"name": "Staphylococcus aureus M1345", "rank": "Strain"}, "1403840": {"name": "Staphylococcus aureus M1344", "rank": "Strain"}, "1403843": {"name": "Staphylococcus aureus M1347", "rank": "Strain"}, "1403842": {"name": "Staphylococcus aureus M1346", "rank": "Strain"}, "1403849": {"name": "Staphylococcus aureus M1353", "rank": "Strain"}, "1403848": {"name": "Staphylococcus aureus M1352", "rank": "Strain"}, "213034": {"name": "Sclerotinia sclerotiorum debilitation-associated RNA virus", "rank": "Species"}, "91753": {"name": "Cucurbit aphid-borne yellows virus", "rank": "Species"}, "443598": {"name": "Bradyrhizobium sp. Cp5.3", "rank": "Species"}, "1158976": {"name": "Enterococcus faecalis EnGen0235", "rank": "Strain"}, "1448848": {"name": "Staphylococcus aureus 1801-2 2010", "rank": "Strain"}, "1448849": {"name": "Staphylococcus warneri Lyso 1 2011", "rank": "Strain"}, "1240980": {"name": "Campylobacter fetus subsp. fetus 04/554", "rank": "Strain"}, "1390386": {"name": "Lactobacillus rhamnosus L31", "rank": "Strain"}, "1448842": {"name": "Staphylococcus aureus Lyso 2 2010", "rank": "Strain"}, "1390384": {"name": "Lactobacillus rhamnosus L34", "rank": "Strain"}, "1390383": {"name": "Lactobacillus rhamnosus L35", "rank": "Strain"}, "1448845": {"name": "Staphylococcus aureus 1101-1 2010", "rank": "Strain"}, "1448846": {"name": "Staphylococcus aureus 1101-2 2010", "rank": "Strain"}, "1390380": {"name": "Cronobacter turicensis z610", "rank": "Strain"}, "1087483": {"name": "Mycobacterium abscessus 47J26", "rank": "Strain"}, "87626": {"name": "Pseudoalteromonas tunicata D2", "rank": "Strain"}, "977927": {"name": "Enterobacteria phage SPC35", "rank": "Species"}, "1052671": {"name": "Mycobacterium phage Oline", "rank": "Species"}, "1052673": {"name": "Mycobacterium phage Thibault", "rank": "Species"}, "1052677": {"name": "Escherichia coli O104:H4 str. H112180282", "rank": "Strain"}, "1388207": {"name": "Staphylococcus aureus M0314", "rank": "Strain"}, "1388206": {"name": "Staphylococcus aureus M0313", "rank": "Strain"}, "1388205": {"name": "Staphylococcus aureus M0310", "rank": "Strain"}, "1388204": {"name": "Staphylococcus aureus M0309", "rank": "Strain"}, "1388203": {"name": "Staphylococcus aureus M0307", "rank": "Strain"}, "1388202": {"name": "Staphylococcus aureus M0305", "rank": "Strain"}, "1388201": {"name": "Staphylococcus aureus M0304", "rank": "Strain"}, "1388200": {"name": "Staphylococcus aureus M0303", "rank": "Strain"}, "1388209": {"name": "Staphylococcus aureus M0317", "rank": "Strain"}, "1388208": {"name": "Staphylococcus aureus M0316", "rank": "Strain"}, "1234364": {"name": "Dyella ginsengisoli LA-4", "rank": "Strain"}, "369400": {"name": "Flaviramulus", "rank": "Genus"}, "1244154": {"name": "Enterococcus faecium SD2A-2", "rank": "Strain"}, "1316739": {"name": "Pseudoalteromonas phage RIO-1", "rank": "Species"}, "188708": {"name": "Thermotogae", "rank": "Class"}, "188709": {"name": "Thermotogaceae", "rank": "Family"}, "1244150": {"name": "Enterococcus faecium LA4B-2", "rank": "Strain"}, "1244151": {"name": "Enterococcus faecium OC2A-1", "rank": "Strain"}, "1244152": {"name": "Enterococcus faecium SB2C-2", "rank": "Strain"}, "1244153": {"name": "Enterococcus faecium SD1C-2", "rank": "Strain"}, "365528": {"name": "Frankia sp. BCU110501", "rank": "Species"}, "365521": {"name": "Unclassified Double-stranded satellite RNAs", "rank": "No rank"}, "365523": {"name": "Tomato yellow spot virus", "rank": "Species"}, "1291539": {"name": "Candidatus Methanomethylophilus", "rank": "Genus"}, "1417143": {"name": "Staphylococcus aureus F85609", "rank": "Strain"}, "745310": {"name": "Sphingomonas sp. MM-1", "rank": "Species"}, "631362": {"name": "Thiorhodovibrio sp. 970", "rank": "Species"}, "115808": {"name": "Bradyrhizobium sp. ORS 285", "rank": "Species"}, "81942": {"name": "Kitasatospora cheerisanensis", "rank": "Species"}, "71032": {"name": "Grapevine leafroll-associated virus 5", "rank": "Species"}, "1433289": {"name": "Streptococcus thermophilus M17PTZA496", "rank": "Strain"}, "71030": {"name": "Chayote mosaic virus", "rank": "Species"}, "546552": {"name": "Barfin flounder virus BF93Hok", "rank": "Species"}, "1433287": {"name": "Mannheimia varigena USDA-ARS-USMARC-1296", "rank": "Strain"}, "1234367": {"name": "Chlamydia pecorum PV3056/3", "rank": "Strain"}, "189963": {"name": "Trichosporon asahii var. asahii", "rank": "Varietas"}, "1239577": {"name": "Mamastrovirus 13", "rank": "Species"}, "1239574": {"name": "Mamastrovirus 10", "rank": "Species"}, "595501": {"name": "Streptococcus pneumoniae BS455", "rank": "Strain"}, "1375": {"name": "Aerococcus", "rank": "Genus"}, "71421": {"name": "Haemophilus influenzae Rd KW20", "rank": "Strain"}, "1377": {"name": "Aerococcus viridans", "rank": "Species"}, "1376": {"name": "Aerococcus urinae", "rank": "Species"}, "1370": {"name": "Marinococcus", "rank": "Genus"}, "1372": {"name": "Planococcus", "rank": "Genus"}, "227137": {"name": "Okra yellow vein mosaic virus", "rank": "Species"}, "1337395": {"name": "Helicobacter pylori PZ5086", "rank": "Strain"}, "1337394": {"name": "Helicobacter pylori PZ5080", "rank": "Strain"}, "1337393": {"name": "Helicobacter pylori PZ5056", "rank": "Strain"}, "1337392": {"name": "Helicobacter pylori PZ5026", "rank": "Strain"}, "1337391": {"name": "Helicobacter pylori PZ5024", "rank": "Strain"}, "1337390": {"name": "Helicobacter pylori PZ5004", "rank": "Strain"}, "935261": {"name": "Aminobacter sp. J41", "rank": "Species"}, "1213731": {"name": "Staphylococcus epidermidis M0881", "rank": "Strain"}, "679190": {"name": "Prevotella buccalis ATCC 35310", "rank": "Strain"}, "118323": {"name": "Oscillatoria acuminata", "rank": "Species"}, "118322": {"name": "Lyngbya aestuarii", "rank": "Species"}, "1261657": {"name": "Murid herpesvirus 8", "rank": "Species"}, "186886": {"name": "Pomovirus", "rank": "Genus"}, "1579316": {"name": "Halocynthiibacter sp. PAMC 20958", "rank": "Species"}, "1579315": {"name": "Halocynthiibacter", "rank": "Genus"}, "1537658": {"name": "Unclassified Schizot4likevirus", "rank": "No rank"}, "1256987": {"name": "Providencia alcalifaciens F90-2004", "rank": "Strain"}, "1256988": {"name": "Providencia alcalifaciens 205/92", "rank": "Strain"}, "1256989": {"name": "Providencia alcalifaciens R90-1475", "rank": "Strain"}, "171164": {"name": "Halosimplex carlsbadense", "rank": "Species"}, "171163": {"name": "Halosimplex", "rank": "Genus"}, "42879": {"name": "Methanococcus aeolicus", "rank": "Species"}, "1409655": {"name": "Staphylococcus aureus OCMM6096", "rank": "Strain"}, "46170": {"name": "Staphylococcus aureus subsp. aureus", "rank": "Subspecies"}, "1388377": {"name": "Staphylococcus aureus M0568", "rank": "Strain"}, "1366052": {"name": "Lactobacillus fermentum MTCC 8711", "rank": "Strain"}, "1366053": {"name": "Mannheimia haemolytica USMARC_2286", "rank": "Strain"}, "1366050": {"name": "Ralstonia pickettii DTP0602", "rank": "Strain"}, "209639": {"name": "Marinobacter lipolyticus", "rank": "Species"}, "1470353": {"name": "Candidatus Soleaferrea", "rank": "Genus"}, "1470350": {"name": "Candidatus Stoquefichus massiliensis", "rank": "Species"}, "1328450": {"name": "Escherichia coli BIDMC 39", "rank": "Strain"}, "1470356": {"name": "Candidatus Clostridium anorexicamassiliense", "rank": "Species"}, "1470354": {"name": "Candidatus Soleaferrea massiliensis", "rank": "Species"}, "468556": {"name": "Gordonia kroppenstedtii DSM 45133", "rank": "Strain"}, "1470358": {"name": "Candidatus Blastococcus massiliensis", "rank": "Species"}, "255616": {"name": "Haloferax sulfurifontis", "rank": "Species"}, "202771": {"name": "Zooshikella", "rank": "Genus"}, "202772": {"name": "Zooshikella ganghwensis", "rank": "Species"}, "1238221": {"name": "Vibrio parahaemolyticus VPTS-2009", "rank": "Strain"}, "1238220": {"name": "Vibrio parahaemolyticus VPTS-2010_2", "rank": "Strain"}, "1238223": {"name": "Vibrio parahaemolyticus VPCR-2009", "rank": "Strain"}, "1238222": {"name": "Vibrio parahaemolyticus VPTS-2010", "rank": "Strain"}, "1238224": {"name": "Vibrio parahaemolyticus VPCR-2010", "rank": "Strain"}, "1233231": {"name": "Scytonema tolypothrichoides VB-61278", "rank": "Strain"}, "1233230": {"name": "Scytonema tolypothrichoides", "rank": "Species"}, "1310688": {"name": "Acinetobacter baumannii 144107", "rank": "Strain"}, "1310689": {"name": "Acinetobacter baumannii 1578804", "rank": "Strain"}, "1481960": {"name": "Peptoclostridium", "rank": "Genus"}, "908127": {"name": "Okra enation leaf curl virus India:Munthal EL37:2006", "rank": "Strain"}, "1388374": {"name": "Staphylococcus aureus M0564", "rank": "Strain"}, "445517": {"name": "Staphylococcus phage tp310-3", "rank": "Species"}, "445516": {"name": "Staphylococcus phage tp310-2", "rank": "Species"}, "445515": {"name": "Staphylococcus phage tp310-1", "rank": "Species"}, "1160895": {"name": "Candidatus Acidianus copahuensis", "rank": "Species"}, "1281135": {"name": "Escherichia coli HVH 208 (4-3112292)", "rank": "Strain"}, "1409752": {"name": "Staphylococcus aureus DAR5898", "rank": "Strain"}, "1281137": {"name": "Escherichia coli HVH 210 (4-3042480)", "rank": "Strain"}, "1409750": {"name": "Staphylococcus aureus DAR3172", "rank": "Strain"}, "1409757": {"name": "Staphylococcus aureus DAR5893", "rank": "Strain"}, "1409651": {"name": "Staphylococcus aureus KINW6036", "rank": "Strain"}, "1409755": {"name": "Staphylococcus aureus DAR5895", "rank": "Strain"}, "1409754": {"name": "Staphylococcus aureus DAR5896", "rank": "Strain"}, "1154891": {"name": "Streptococcus agalactiae GB00002", "rank": "Strain"}, "1154890": {"name": "Streptococcus agalactiae str. Gottschalk 992B", "rank": "Strain"}, "1409759": {"name": "Staphylococcus aureus DAR5891", "rank": "Strain"}, "1409758": {"name": "Staphylococcus aureus DAR5892", "rank": "Strain"}, "1154895": {"name": "Streptococcus agalactiae GB00018", "rank": "Strain"}, "1203590": {"name": "Streptococcus sp. HPH0090", "rank": "Species"}, "1203593": {"name": "Veillonella sp. HPA0037", "rank": "Species"}, "1203592": {"name": "Streptomyces sp. HPH0547", "rank": "Species"}, "1548018": {"name": "Helicobacter sanguini", "rank": "Species"}, "98671": {"name": "Arthrobacter albus", "rank": "Species"}, "645463": {"name": "Peptoclostridium difficile R20291", "rank": "Strain"}, "645462": {"name": "Peptoclostridium difficile CD196", "rank": "Strain"}, "352211": {"name": "Streptomyces sp. AcH 505", "rank": "Species"}, "45401": {"name": "Hyphomicrobiaceae", "rank": "Family"}, "1422428": {"name": "Staphylococcus aureus VET0095R", "rank": "Strain"}, "1422429": {"name": "Staphylococcus aureus VET0097R", "rank": "Strain"}, "1422426": {"name": "Staphylococcus aureus VET0093R", "rank": "Strain"}, "1422427": {"name": "Staphylococcus aureus VET0094R", "rank": "Strain"}, "1422424": {"name": "Staphylococcus aureus VET0091R", "rank": "Strain"}, "1422425": {"name": "Staphylococcus aureus VET0092R", "rank": "Strain"}, "1422422": {"name": "Staphylococcus aureus VET0089R", "rank": "Strain"}, "1422423": {"name": "Staphylococcus aureus VET0090R", "rank": "Strain"}, "1422420": {"name": "Staphylococcus aureus VET0087R", "rank": "Strain"}, "1422421": {"name": "Staphylococcus aureus VET0088R", "rank": "Strain"}, "1336746": {"name": "Streptococcus pyogenes HSC5", "rank": "Strain"}, "1239383": {"name": "Staphylococcus phage JD007", "rank": "Species"}, "683837": {"name": "Listeria seeligeri serovar 1/2b str. SLCC3954", "rank": "Strain"}, "1207036": {"name": "Escherichia coli Tx3800", "rank": "Strain"}, "1207037": {"name": "Escherichia coli Tx1686", "rank": "Strain"}, "1207035": {"name": "Escherichia coli 14A", "rank": "Strain"}, "138647": {"name": "Poinsettia branch-inducing phytoplasma", "rank": "Species"}, "1207038": {"name": "Escherichia coli 2886-75", "rank": "Strain"}, "1207039": {"name": "Gallaecimonas xiamenensis", "rank": "Species"}, "1402589": {"name": "Mycobacterium tuberculosis OFXR-19", "rank": "Strain"}, "1402588": {"name": "Mycobacterium tuberculosis OFXR-18", "rank": "Strain"}, "147553": {"name": "Pneumocystidomycetes", "rank": "Class"}, "147550": {"name": "Sordariomycetes", "rank": "Class"}, "1402583": {"name": "Mycobacterium tuberculosis OFXR-1", "rank": "Strain"}, "1402582": {"name": "Pseudomonas aeruginosa PS50", "rank": "Strain"}, "1402581": {"name": "Pseudomonas aeruginosa PS42", "rank": "Strain"}, "1402580": {"name": "Pseudomonas aeruginosa CF614", "rank": "Strain"}, "1402587": {"name": "Mycobacterium tuberculosis OFXR-17", "rank": "Strain"}, "1402586": {"name": "Mycobacterium tuberculosis OFXR-9", "rank": "Strain"}, "1402585": {"name": "Mycobacterium tuberculosis OFXR-8", "rank": "Strain"}, "268739": {"name": "Natronomonas moolapensis 8.8.11", "rank": "Strain"}, "400947": {"name": "Deefgea", "rank": "Genus"}, "400946": {"name": "Wohlfahrtiimonas chitiniclastica", "rank": "Species"}, "400948": {"name": "Deefgea rivuli", "rank": "Species"}, "123812": {"name": "Pasteurella multocida subsp. gallicida", "rank": "Subspecies"}, "1123399": {"name": "Thiothrix disciformis DSM 14473", "rank": "Strain"}, "1123390": {"name": "Thermus oshimai DSM 12092", "rank": "Strain"}, "1123391": {"name": "Thermus scotoductus DSM 8553", "rank": "Strain"}, "1123392": {"name": "Thiobacillus denitrificans DSM 12475", "rank": "Strain"}, "1123393": {"name": "Thiobacillus thioparus DSM 505", "rank": "Strain"}, "1247744": {"name": "Campylobacter coli BIGS0021", "rank": "Strain"}, "1247745": {"name": "Campylobacter coli BIGS0023", "rank": "Strain"}, "261685": {"name": "Thermosinus carboxydivorans", "rank": "Species"}, "1247747": {"name": "Mycobacterium avium subsp. paratuberculosis S5", "rank": "Strain"}, "1247740": {"name": "Campylobacter coli BIGS0017", "rank": "Strain"}, "1247741": {"name": "Campylobacter coli BIGS0018", "rank": "Strain"}, "1247742": {"name": "Campylobacter coli BIGS0019", "rank": "Strain"}, "393087": {"name": "Gracilibacillus lacisalsi", "rank": "Species"}, "74015": {"name": "Latescibacteria", "rank": "Phylum"}, "1151413": {"name": "Peptoclostridium difficile P31", "rank": "Strain"}, "1367846": {"name": "Francisella tularensis 99A-2628", "rank": "Strain"}, "1352575": {"name": "Mycobacterium tuberculosis PanR0603", "rank": "Strain"}, "1413499": {"name": "Staphylococcus aureus N1343", "rank": "Strain"}, "1413498": {"name": "Staphylococcus aureus N0426", "rank": "Strain"}, "1458467": {"name": "Enterococcus faecalis 68A", "rank": "Strain"}, "1458466": {"name": "Pectobacterium wasabiae CFIA1002", "rank": "Strain"}, "1413495": {"name": "Staphylococcus aureus MRSA-118", "rank": "Strain"}, "1458464": {"name": "Komagataeibacter intermedius AF2", "rank": "Strain"}, "1458463": {"name": "Butyrivibrio sp. AE2032", "rank": "Species"}, "1458462": {"name": "Lachnospiraceae bacterium AC2029", "rank": "Species"}, "1458461": {"name": "Candidatus Phaeomarinobacter ectocarpi", "rank": "Species"}, "1413490": {"name": "Staphylococcus aureus PA57", "rank": "Strain"}, "1123023": {"name": "Pseudonocardia acaciae DSM 45401", "rank": "Strain"}, "1123020": {"name": "Pseudomonas resinovorans DSM 21078", "rank": "Strain"}, "1123021": {"name": "Pseudomonas thermotolerans DSM 14292", "rank": "Strain"}, "1281283": {"name": "Xanthomonas campestris pv. campestris str. CN15", "rank": "Strain"}, "1123027": {"name": "Pseudorhodobacter ferrugineus DSM 5888", "rank": "Strain"}, "1123024": {"name": "Pseudonocardia asaccharolytica DSM 44247 = NBRC 16224", "rank": "Strain"}, "1123025": {"name": "Pseudonocardia spinosispora DSM 44797", "rank": "Strain"}, "1422790": {"name": "Staphylococcus aureus VET1468S", "rank": "Strain"}, "1422791": {"name": "Staphylococcus aureus VET1495S", "rank": "Strain"}, "1422792": {"name": "Staphylococcus aureus VET1499S", "rank": "Strain"}, "1422793": {"name": "Staphylococcus aureus VET1515S", "rank": "Strain"}, "984962": {"name": "Heterobasidion irregulare", "rank": "Species"}, "1422795": {"name": "Staphylococcus aureus VET1519S", "rank": "Strain"}, "1422796": {"name": "Staphylococcus aureus VET1526S", "rank": "Strain"}, "481851": {"name": "Unclassified N4likevirus", "rank": "No rank"}, "1422798": {"name": "Staphylococcus aureus VET1653S", "rank": "Strain"}, "1422799": {"name": "Staphylococcus aureus VET1727S", "rank": "Strain"}, "227321": {"name": "Aspergillus nidulans FGSC A4", "rank": "Strain"}, "1298653": {"name": "Perhabdovirus", "rank": "Genus"}, "341721": {"name": "Aedes pseudoscutellaris reovirus", "rank": "Species"}, "341722": {"name": "Agrococcus lahaulensis", "rank": "Species"}, "762660": {"name": "Acinetobacter phage Ac42", "rank": "Species"}, "229980": {"name": "Aeropyrum camini", "rank": "Species"}, "1230456": {"name": "Halorubrum kocurii JCM 14978", "rank": "Strain"}, "1230457": {"name": "Haloterrigena limicola JCM 13563", "rank": "Strain"}, "1230454": {"name": "Halorubrum aidingense JCM 13560", "rank": "Strain"}, "1230455": {"name": "Halorubrum arcis JCM 13916", "rank": "Strain"}, "1230452": {"name": "Haloferax lucentense DSM 14919", "rank": "Strain"}, "1230453": {"name": "Haloferax elongans ATCC BAA-1513", "rank": "Strain"}, "1230451": {"name": "Haloarcula argentinensis DSM 12282", "rank": "Strain"}, "903503": {"name": "Candidatus Moranella endobia PCIT", "rank": "Strain"}, "697331": {"name": "Basfia", "rank": "Genus"}, "903507": {"name": "Bacillus subtilis gtP20b", "rank": "Strain"}, "1230459": {"name": "Natrinema gari JCM 14663", "rank": "Strain"}, "1240774": {"name": "Escherichia coli O104:H4 str. 11-02913", "rank": "Strain"}, "223352": {"name": "Tomato leaf curl Sri Lanka virus", "rank": "Species"}, "1240776": {"name": "Escherichia coli O104:H4 str. 11-04080", "rank": "Strain"}, "1240777": {"name": "Escherichia coli O104:H4 str. 11-03943", "rank": "Strain"}, "226185": {"name": "Enterococcus faecalis V583", "rank": "Strain"}, "223356": {"name": "Tomato mosaic Havana virus", "rank": "Species"}, "1240772": {"name": "Escherichia coli O104:H4 str. 11-02281", "rank": "Strain"}, "226186": {"name": "Bacteroides thetaiotaomicron VPI-5482", "rank": "Strain"}, "1238208": {"name": "Vibrio parahaemolyticus VP250", "rank": "Strain"}, "223358": {"name": "Tomato mottle Taino virus", "rank": "Species"}, "1240778": {"name": "Escherichia coli O104:H4 str. Ec12-0465", "rank": "Strain"}, "1240779": {"name": "Escherichia coli O104:H4 str. Ec12-0466", "rank": "Strain"}, "578305": {"name": "Gayfeather mild mottle virus", "rank": "Species"}, "1477515": {"name": "Chicken megrivirus", "rank": "Species"}, "1477516": {"name": "Turkey megrivirus", "rank": "Species"}, "1331283": {"name": "Bordetella pertussis CHLA-20", "rank": "Strain"}, "490110": {"name": "Curionopolis virus", "rank": "Species"}, "1331281": {"name": "Bordetella pertussis CHLA-13", "rank": "Strain"}, "1331280": {"name": "Bordetella pertussis STO1-CHOC-0021", "rank": "Strain"}, "272621": {"name": "Lactobacillus acidophilus NCFM", "rank": "Strain"}, "272620": {"name": "Klebsiella pneumoniae subsp. pneumoniae MGH 78578", "rank": "Strain"}, "1331285": {"name": "Bordetella pertussis STO1-CHLA-0006", "rank": "Strain"}, "1331284": {"name": "Bordetella pertussis CHLA-26", "rank": "Strain"}, "272629": {"name": "Mannheimia haemolytica PHL213", "rank": "Strain"}, "1423447": {"name": "Mycobacterium tuberculosis BTB05-348", "rank": "Strain"}, "1423446": {"name": "Mycobacterium tuberculosis BTB05-285", "rank": "Strain"}, "1423445": {"name": "Mycobacterium tuberculosis BTB05-013", "rank": "Strain"}, "1423444": {"name": "Mycobacterium tuberculosis BTB05-001", "rank": "Strain"}, "1423443": {"name": "Mycobacterium tuberculosis BTB04-452", "rank": "Strain"}, "1423442": {"name": "Mycobacterium tuberculosis BTB04-416", "rank": "Strain"}, "1423441": {"name": "Mycobacterium tuberculosis BTB04-388", "rank": "Strain"}, "1423440": {"name": "Mycobacterium tuberculosis BTB04-172", "rank": "Strain"}, "911243": {"name": "Pseudomonas sp. CFII68", "rank": "Species"}, "1423449": {"name": "Mycobacterium tuberculosis BTB03-143", "rank": "Strain"}, "1423448": {"name": "Mycobacterium tuberculosis BTB05-371", "rank": "Strain"}, "999550": {"name": "Pseudophaeobacter arcticus DSM 23566", "rank": "Strain"}, "1141132": {"name": "Aeromonas phage phiAS7", "rank": "Species"}, "1141133": {"name": "Bacillus phage B4", "rank": "Species"}, "1141134": {"name": "Salmonella phage SPN19", "rank": "Species"}, "1141135": {"name": "Cronobacter phage vB_CsaM_GAP31", "rank": "Species"}, "1141136": {"name": "Cronobacter phage vB_CsaM_GAP32", "rank": "Species"}, "1141137": {"name": "Cronobacter phage vB_CsaP_GAP52", "rank": "Species"}, "1141138": {"name": "Cronobacter phage vB_CsaM_GAP161", "rank": "Species"}, "1141139": {"name": "Enterobacteria phage vB_EcoP_ACG-C91", "rank": "Species"}, "1225184": {"name": "Pantoea sp. A4", "rank": "Species"}, "1268303": {"name": "Rhodococcus sp. AW25M09", "rank": "Species"}, "1268301": {"name": "Delta proteobacterium JGI 0002000-E07", "rank": "Species"}, "1225181": {"name": "Klebsiella pneumoniae subsp. pneumoniae KPNIH24", "rank": "Strain"}, "1422084": {"name": "Mycobacterium tuberculosis TB_RSA168", "rank": "Strain"}, "1125693": {"name": "Proteus mirabilis WGLW4", "rank": "Strain"}, "864069": {"name": "Microvirga lotononidis", "rank": "Species"}, "1125697": {"name": "Pseudomonas aeruginosa str. Stone 130", "rank": "Strain"}, "1125694": {"name": "Proteus mirabilis WGLW6", "rank": "Strain"}, "1422080": {"name": "Mycobacterium tuberculosis TB_RSA164", "rank": "Strain"}, "1125699": {"name": "Treponema maltophilum ATCC 51939", "rank": "Strain"}, "1125698": {"name": "Pseudomonas sp. P179", "rank": "Species"}, "1422081": {"name": "Mycobacterium tuberculosis TB_RSA165", "rank": "Strain"}, "151599": {"name": "Pseudomonas phage B3", "rank": "Species"}, "657324": {"name": "Butyrivibrio fibrisolvens 16/4", "rank": "Strain"}, "42443": {"name": "Roseobacter litoralis", "rank": "Species"}, "657326": {"name": "Flavobacterium beibuense", "rank": "Species"}, "657321": {"name": "Ruminococcus bromii L2-63", "rank": "Strain"}, "760530": {"name": "Staphylococcus phage GH15", "rank": "Species"}, "657323": {"name": "Ruminococcus sp. SR1/5", "rank": "Species"}, "657322": {"name": "Faecalibacterium prausnitzii SL3/3", "rank": "Strain"}, "386585": {"name": "Escherichia coli O157:H7 str. Sakai", "rank": "Strain"}, "522260": {"name": "Brucella abortus bv. 3", "rank": "Strain"}, "439334": {"name": "Mycobacterium avium subsp. hominissuis", "rank": "Subspecies"}, "380749": {"name": "Hydrogenobaculum sp. Y04AAS1", "rank": "Species"}, "339351": {"name": "Unclassified Hantavirus", "rank": "No rank"}, "1346793": {"name": "Acinetobacter baumannii AB-HKU3-10", "rank": "Strain"}, "596317": {"name": "Staphylococcus epidermidis SK135", "rank": "Strain"}, "1346791": {"name": "Sphingobium ummariense RL-3", "rank": "Strain"}, "596315": {"name": "Peptostreptococcus stomatis DSM 17678", "rank": "Strain"}, "596312": {"name": "Micrococcus luteus SK58", "rank": "Strain"}, "1128119": {"name": "Clitoria yellow mottle virus", "rank": "Species"}, "1128118": {"name": "Parrot hepatitis B virus", "rank": "Species"}, "1128117": {"name": "Unclassified Avihepadnavirus", "rank": "No rank"}, "1128111": {"name": "Veillonella atypica KON", "rank": "Strain"}, "596319": {"name": "Staphylococcus warneri L37603", "rank": "Strain"}, "1272959": {"name": "Xiburema virus", "rank": "Species"}, "1272954": {"name": "Streptococcus pneumoniae DAR3264", "rank": "Strain"}, "1272951": {"name": "Streptococcus pneumoniae DAR831", "rank": "Strain"}, "468059": {"name": "Pedobacter oryzae DSM 19973", "rank": "Strain"}, "11598": {"name": "Hantavirus", "rank": "Genus"}, "1590026": {"name": "Bacillus sp. REN51N", "rank": "Species"}, "1590027": {"name": "Bacillus sp. A053", "rank": "Species"}, "411153": {"name": "Gramella forsetii", "rank": "Species"}, "10552": {"name": "Aviadenovirus", "rank": "Genus"}, "411154": {"name": "Gramella forsetii KT0803", "rank": "Strain"}, "373984": {"name": "Rivularia", "rank": "Genus"}, "689832": {"name": "Sedoreovirinae", "rank": "Subfamily"}, "1413535": {"name": "Staphylococcus aureus GD2010-159", "rank": "Strain"}, "1271752": {"name": "Riemerella anatipestifer RA-CH-2", "rank": "Strain"}, "1413536": {"name": "Staphylococcus aureus GD2010-169", "rank": "Strain"}, "150240": {"name": "Gemella cuniculi", "rank": "Species"}, "134362": {"name": "Capnodiales", "rank": "Order"}, "1413537": {"name": "Staphylococcus aureus GD2010-168", "rank": "Strain"}, "264731": {"name": "Prevotella ruminicola 23", "rank": "Strain"}, "412764": {"name": "Spathaspora", "rank": "Genus"}, "281090": {"name": "Leifsonia xyli subsp. xyli str. CTCB07", "rank": "Strain"}, "281091": {"name": "Azorhizobium doebereinerae", "rank": "Species"}, "1438810": {"name": "Klebsiella pneumoniae UCI 67", "rank": "Strain"}, "1438811": {"name": "Klebsiella pneumoniae UCI 68", "rank": "Strain"}, "946077": {"name": "Imtechella halotolerans K1", "rank": "Strain"}, "869": {"name": "Dichelobacter", "rank": "Genus"}, "868": {"name": "Cardiobacteriaceae", "rank": "Family"}, "866": {"name": "Ruminobacter", "rank": "Genus"}, "1413533": {"name": "Staphylococcus aureus GD2010-155", "rank": "Strain"}, "863": {"name": "Syntrophomonas wolfei", "rank": "Species"}, "862": {"name": "Syntrophomonas", "rank": "Genus"}, "861": {"name": "Fusobacterium ulcerans", "rank": "Species"}, "860": {"name": "Fusobacterium periodonticum", "rank": "Species"}, "887898": {"name": "Lautropia mirabilis ATCC 51599", "rank": "Strain"}, "6033": {"name": "Encephalitozoon", "rank": "Genus"}, "6032": {"name": "Apansporoblastina", "rank": "Suborder"}, "6036": {"name": "Pansporoblastina", "rank": "Suborder"}, "6035": {"name": "Encephalitozoon cuniculi", "rank": "Species"}, "178876": {"name": "Cryptococcus neoformans var. grubii", "rank": "Varietas"}, "1048334": {"name": "Escherichia coli O104:H4 str. 11-3677", "rank": "Strain"}, "280050": {"name": "Unclassified Aviadenovirus", "rank": "No rank"}, "1210443": {"name": "Pseudomonas stutzeri T13", "rank": "Strain"}, "866499": {"name": "Cloacibacillus evryensis DSM 19522", "rank": "Strain"}, "1210447": {"name": "Brucella melitensis bv. 1 str. BCB028", "rank": "Strain"}, "1210446": {"name": "Brucella abortus bv. 1 str. BCB027", "rank": "Strain"}, "1210445": {"name": "Brucella canis BCB018", "rank": "Strain"}, "1210444": {"name": "Brucella suis bv. 1 str. BCB025", "rank": "Strain"}, "1210449": {"name": "Brucella melitensis bv. 1 str. BCB033", "rank": "Strain"}, "1210448": {"name": "Brucella suis bv. 2 str. BCB032", "rank": "Strain"}, "161494": {"name": "Antheraea pernyi nucleopolyhedrovirus", "rank": "Species"}, "161493": {"name": "Anaeromyxobacter dehalogenans", "rank": "Species"}, "161492": {"name": "Anaeromyxobacter", "rank": "Genus"}, "11604": {"name": "Puumala virus", "rank": "Species"}, "1381464": {"name": "Blackberry vein banding associated virus", "rank": "Species"}, "11608": {"name": "Seoul virus", "rank": "Species"}, "31969": {"name": "Mollicutes", "rank": "Class"}, "31962": {"name": "Actinomadura rifamycini", "rank": "Species"}, "31963": {"name": "Clavibacter michiganensis subsp. nebraskensis", "rank": "Subspecies"}, "31964": {"name": "Clavibacter michiganensis subsp. sepedonicus", "rank": "Subspecies"}, "31966": {"name": "Leifsonia xyli subsp. cynodontis", "rank": "Subspecies"}, "658187": {"name": "Legionella drancourtii LLAP12", "rank": "Strain"}, "1394710": {"name": "Candidate division WWE3 bacterium RAAC2_WWE3_1", "rank": "Species"}, "1394711": {"name": "Candidatus Saccharibacteria bacterium RAAC3_TM7_1", "rank": "Species"}, "1394712": {"name": "Parcubacteria bacterium RAAC4_OD1_1", "rank": "Species"}, "1409531": {"name": "Staphylococcus aureus UCIM6042", "rank": "Strain"}, "149015": {"name": "Streptococcus hyovaginalis", "rank": "Species"}, "149016": {"name": "Streptococcus urinalis", "rank": "Species"}, "11571": {"name": "Bunyaviridae", "rank": "Family"}, "64292": {"name": "Ntaya virus", "rank": "Species"}, "763919": {"name": "Salmonella enterica subsp. enterica serovar Montevideo str. 19N", "rank": "Strain"}, "64294": {"name": "Yokose virus", "rank": "Species"}, "869692": {"name": "Escherichia coli 3003", "rank": "Strain"}, "869693": {"name": "Escherichia coli TW07793", "rank": "Strain"}, "2321": {"name": "Methanohalobium", "rank": "Genus"}, "2320": {"name": "Methanopyrus kandleri", "rank": "Species"}, "2325": {"name": "Thermoanaerobacter kivui", "rank": "Species"}, "869695": {"name": "Escherichia coli 900105 (10e)", "rank": "Strain"}, "167542": {"name": "Prochlorococcus marinus str. MIT 9515", "rank": "Strain"}, "167547": {"name": "Prochlorococcus marinus str. MIT 9311", "rank": "Strain"}, "167546": {"name": "Prochlorococcus marinus str. MIT 9301", "rank": "Strain"}, "167545": {"name": "Prochlorococcus marinus str. MIT 9123", "rank": "Strain"}, "167544": {"name": "Prochlorococcus marinus str. MIT 9116", "rank": "Strain"}, "167549": {"name": "Prochlorococcus marinus str. MIT 9321", "rank": "Strain"}, "167548": {"name": "Prochlorococcus marinus str. MIT 9314", "rank": "Strain"}, "196114": {"name": "Taiwanofungus camphoratus", "rank": "Species"}, "363870": {"name": "Bacillus ginsengihumi", "rank": "Species"}, "363872": {"name": "Bacillus panaciterrae", "rank": "Species"}, "1409537": {"name": "Staphylococcus aureus LPIH6011", "rank": "Strain"}, "196118": {"name": "Methanocaldococcus", "rank": "Genus"}, "196119": {"name": "Methanotorris", "rank": "Genus"}, "5324": {"name": "Trametes", "rank": "Genus"}, "993516": {"name": "Rhodopirellula baltica SWK14", "rank": "Strain"}, "556499": {"name": "Propionibacterium acidifaciens", "rank": "Species"}, "1410930": {"name": "Salmonella enterica subsp. enterica serovar Cerro str. CFSAN001692", "rank": "Strain"}, "1221437": {"name": "Grapevine virus F", "rank": "Species"}, "1492281": {"name": "Alpha proteobacterium Q-1", "rank": "Species"}, "207697": {"name": "Croton yellow vein mosaic virus", "rank": "Species"}, "356662": {"name": "Leeia oryzae", "rank": "Species"}, "667093": {"name": "Broome virus", "rank": "Species"}, "83494": {"name": "Unclassified Comamonadaceae", "rank": "No rank"}, "256729": {"name": "Lymphocystis disease virus - isolate China", "rank": "Species"}, "86049": {"name": "Cladophialophora carrionii", "rank": "Species"}, "1137255": {"name": "Salinispora arenicola CNT005", "rank": "Strain"}, "68892": {"name": "Streptococcus infantis", "rank": "Species"}, "68891": {"name": "Streptococcus peroris", "rank": "Species"}, "68895": {"name": "Cupriavidus basilensis", "rank": "Species"}, "947039": {"name": "Saccharomyces cerevisiae PW5", "rank": "Strain"}, "1027231": {"name": "Tospovirus reassortants", "rank": "No rank"}, "1027232": {"name": "Groundnut ringspot and Tomato chlorotic spot virus reassortant", "rank": "Species"}, "1460071": {"name": "Antheraea pernyi iflavirus", "rank": "Species"}, "1460070": {"name": "Ralstonia phage 1 NP-2014", "rank": "Species"}, "1439026": {"name": "Streptococcus pyogenes ABC020016937", "rank": "Strain"}, "1439027": {"name": "Streptococcus pyogenes ABC020017280", "rank": "Strain"}, "582515": {"name": "Rubidibacter lacunae KORDI 51-2", "rank": "Strain"}, "1434011": {"name": "Komagataeibacter", "rank": "Genus"}, "71237": {"name": "Staphylococcus vitulinus", "rank": "Species"}, "85007": {"name": "Corynebacterineae", "rank": "Suborder"}, "1167628": {"name": "Actinomyces massiliensis 4401292", "rank": "Strain"}, "1167629": {"name": "Bifidobacterium animalis subsp. lactis ATCC 27673", "rank": "Strain"}, "797299": {"name": "Halostagnicola larsenii XH-48", "rank": "Strain"}, "357244": {"name": "Orientia tsutsugamushi str. Boryong", "rank": "Strain"}, "478070": {"name": "Labrenzia", "rank": "Genus"}, "915425": {"name": "Human papillomavirus type 101", "rank": "Strain"}, "1170318": {"name": "Propionibacterium avidum 44067", "rank": "Strain"}, "915427": {"name": "Human papillomavirus type 112", "rank": "Strain"}, "915426": {"name": "Human papillomavirus type 109", "rank": "Strain"}, "147710": {"name": "Rhizobium sp. OR191", "rank": "Species"}, "147711": {"name": "Rhinovirus A", "rank": "Species"}, "147712": {"name": "Rhinovirus B", "rank": "Species"}, "85001": {"name": "Sphaerobacterales", "rank": "Order"}, "1422662": {"name": "Staphylococcus aureus VET0440R", "rank": "Strain"}, "1226748": {"name": "Propionibacterium acnes HL042PA3", "rank": "Strain"}, "83769": {"name": "Succinimonas amylolytica", "rank": "Species"}, "83768": {"name": "Succinimonas", "rank": "Genus"}, "1034377": {"name": "Soybean cyst nematode virus", "rank": "Species"}, "1385935": {"name": "Leptolyngbya sp. Heron Island J", "rank": "Species"}, "83763": {"name": "Succinivibrionaceae", "rank": "Family"}, "46771": {"name": "Simian virus 12", "rank": "Species"}, "46770": {"name": "Cenarchaeum symbiosum", "rank": "Species"}, "1305774": {"name": "Kingella kingae KK75", "rank": "Strain"}, "1348585": {"name": "Cellulophaga baltica NN016038", "rank": "Strain"}, "76761": {"name": "Pseudomonas veronii", "rank": "Species"}, "76760": {"name": "Pseudomonas rhodesiae", "rank": "Species"}, "345922": {"name": "Bacillus phage Fah", "rank": "Species"}, "1423429": {"name": "Mycobacterium tuberculosis BTB07-168", "rank": "Strain"}, "1392851": {"name": "Escherichia coli M5", "rank": "Strain"}, "1392850": {"name": "Escherichia coli M4", "rank": "Strain"}, "1392853": {"name": "Escherichia coli M7", "rank": "Strain"}, "1392852": {"name": "Escherichia coli M6", "rank": "Strain"}, "1305772": {"name": "Kingella kingae KK242", "rank": "Strain"}, "1392857": {"name": "Escherichia coli M11", "rank": "Strain"}, "47951": {"name": "Vibrio cyclitrophicus", "rank": "Species"}, "1049911": {"name": "Leptospira interrogans serovar Lai str. Lai", "rank": "Strain"}, "1049913": {"name": "Leptospira interrogans serovar Lai str. Langkawi", "rank": "Strain"}, "1049912": {"name": "Leptospira interrogans serovar Lai str. Lai LPS mutant", "rank": "Strain"}, "78331": {"name": "Mycobacterium canettii", "rank": "Species"}, "325348": {"name": "Unclassified Badnavirus", "rank": "No rank"}, "84379": {"name": "Brachyspira alvinipulli", "rank": "Species"}, "84378": {"name": "Brachyspira murdochii", "rank": "Species"}, "1197906": {"name": "Afipia birgiae 34632", "rank": "Strain"}, "394935": {"name": "Chromobacterium haemolyticum", "rank": "Species"}, "395568": {"name": "Glaciecola agarilytica", "rank": "Species"}, "1268061": {"name": "Streptococcus thermophilus DGCC7710", "rank": "Strain"}, "1394581": {"name": "Vibrio parahaemolyticus S034", "rank": "Strain"}, "1268068": {"name": "Pseudomonas sp. G5(2012)", "rank": "Species"}, "1394580": {"name": "Vibrio parahaemolyticus S033", "rank": "Strain"}, "637389": {"name": "Acidithiobacillus caldus ATCC 51756", "rank": "Strain"}, "204516": {"name": "Bacteroides massiliensis", "rank": "Species"}, "169688": {"name": "Zinnia leaf curl disease associated sequence", "rank": "Species"}, "1394583": {"name": "Vibrio parahaemolyticus S036", "rank": "Strain"}, "908276": {"name": "Okra enation leaf curl betasatellite", "rank": "Species"}, "908277": {"name": "Okra enation leaf curl betasatellite India:Sonipat:EL10:2006", "rank": "Strain"}, "1401651": {"name": "Candidatus Riesia pediculischaeffi PTSU", "rank": "Strain"}, "637385": {"name": "Yersinia pestis D182038", "rank": "Strain"}, "169687": {"name": "Ageratum yellow leaf curl betasatellite", "rank": "Species"}, "637387": {"name": "Mycoplasma fermentans JER", "rank": "Strain"}, "637386": {"name": "Yersinia pestis Z176003", "rank": "Strain"}, "1027947": {"name": "Macrobrachium rosenbergii Taihu virus", "rank": "Species"}, "28067": {"name": "Rubrivivax", "rank": "Genus"}, "1150157": {"name": "Bacillus sp. FJAT-13831", "rank": "Species"}, "28065": {"name": "Rhodoferax", "rank": "Genus"}, "187493": {"name": "Thalassolituus oleivorans", "rank": "Species"}, "187492": {"name": "Thalassolituus", "rank": "Genus"}, "311244": {"name": "Paenibacillus assamensis", "rank": "Species"}, "84377": {"name": "Brachyspira intermedia", "rank": "Species"}, "984186": {"name": "Cronobacter phage ENT47670", "rank": "Species"}, "1232442": {"name": "Clostridiales bacterium VE202-06", "rank": "Species"}, "1311088": {"name": "Acinetobacter baumannii 45075_1", "rank": "Strain"}, "1232441": {"name": "Clostridium scindens VE202-05", "rank": "Strain"}, "1232440": {"name": "Clostridium hathewayi VE202-04", "rank": "Strain"}, "684738": {"name": "Lactococcus lactis subsp. lactis KF147", "rank": "Strain"}, "1046965": {"name": "Cloacimonetes bacterium SCGC AAA252-N14", "rank": "Species"}, "1046964": {"name": "Cloacimonetes bacterium SCGC AAA252-N05", "rank": "Species"}, "1046967": {"name": "Cloacimonetes bacterium SCGC AAA252-O02", "rank": "Species"}, "1046966": {"name": "Cloacimonetes bacterium SCGC AAA252-N17", "rank": "Species"}, "1046961": {"name": "Cloacimonetes bacterium SCGC AAA252-L05", "rank": "Species"}, "1046960": {"name": "Cloacimonetes bacterium SCGC AAA252-K16", "rank": "Species"}, "68793": {"name": "Botryobasidium", "rank": "Genus"}, "68792": {"name": "Botryobasidiaceae", "rank": "Family"}, "1188263": {"name": "Bradyrhizobium sp. WSM2254", "rank": "Species"}, "1448140": {"name": "Pseudomonas aeruginosa YL84", "rank": "Strain"}, "1188261": {"name": "Bacillus marmarensis DSM 21297", "rank": "Strain"}, "419435": {"name": "Glypta fumiferanae ichnovirus", "rank": "Species"}, "519": {"name": "Bordetella parapertussis", "rank": "Species"}, "1158056": {"name": "Streptomyces sp. PRh5", "rank": "Species"}, "59302": {"name": "Ndumu virus", "rank": "Species"}, "59300": {"name": "Getah virus", "rank": "Species"}, "59301": {"name": "Mayaro virus", "rank": "Species"}, "1232429": {"name": "Nesterenkonia sp. NP1", "rank": "Species"}, "59305": {"name": "Bebaru virus", "rank": "Species"}, "365349": {"name": "Pelosinus fermentans", "rank": "Species"}, "942016": {"name": "Enterobacter phage EcP1", "rank": "Species"}, "1327938": {"name": "Mycobacterium phage ArcherS7", "rank": "Species"}, "1327939": {"name": "Mycobacterium phage Murphy", "rank": "Species"}, "455358": {"name": "Balneola", "rank": "Genus"}, "1327936": {"name": "Mycobacterium phage Gizmo", "rank": "Species"}, "1327937": {"name": "Mycobacterium phage Phaux", "rank": "Species"}, "1327934": {"name": "Cronobacter phage CR8", "rank": "Species"}, "1235808": {"name": "Microcystis aeruginosa DIANCHI905", "rank": "Strain"}, "1235809": {"name": "Bacteroides pyogenes JCM 6292", "rank": "Strain"}, "1235802": {"name": "Eubacterium plexicaudatum ASF492", "rank": "Strain"}, "1235803": {"name": "Parabacteroides sp. ASF519", "rank": "Species"}, "1235800": {"name": "Lachnospiraceae bacterium 10-1", "rank": "Species"}, "1235801": {"name": "Lactobacillus murinus ASF361", "rank": "Strain"}, "1235804": {"name": "Helicobacter bilis WiWa", "rank": "Strain"}, "1235805": {"name": "Escherichia coli SWW33", "rank": "Strain"}, "1304889": {"name": "Lactobacillus plantarum CMPG5300", "rank": "Strain"}, "1304888": {"name": "Geovibrio sp. L21-Ace-BES", "rank": "Species"}, "1696": {"name": "Brevibacterium", "rank": "Genus"}, "1697": {"name": "Corynebacterium ammoniagenes", "rank": "Species"}, "1694": {"name": "Bifidobacterium pseudolongum", "rank": "Species"}, "1695": {"name": "Bifidobacterium longum subsp. suis", "rank": "Subspecies"}, "1692": {"name": "Bifidobacterium magnum", "rank": "Species"}, "1693": {"name": "Bifidobacterium minimum", "rank": "Species"}, "1690": {"name": "Bifidobacterium pseudolongum subsp. globosum", "rank": "Subspecies"}, "1691": {"name": "Bifidobacterium indicum", "rank": "Species"}, "105425": {"name": "Streptacidiphilus albus", "rank": "Species"}, "105420": {"name": "Streptacidiphilus neutrinimicus", "rank": "Species"}, "105422": {"name": "Streptacidiphilus carbonis", "rank": "Species"}, "88129": {"name": "Ophiovirus", "rank": "Genus"}, "60888": {"name": "Neosartorya fischeri group", "rank": "No rank"}, "1115696": {"name": "Thermococcus prieurii virus 1", "rank": "Species"}, "1157443": {"name": "Enterococcus faecium EnGen0148", "rank": "Strain"}, "1157442": {"name": "Enterococcus faecium EnGen0147", "rank": "Strain"}, "1157441": {"name": "Enterococcus faecium EnGen0146", "rank": "Strain"}, "1220591": {"name": "Bacillus sonorensis NBRC 101234 = KCTC 13918", "rank": "Strain"}, "1157447": {"name": "Enterococcus faecium EnGen0152", "rank": "Strain"}, "1157446": {"name": "Enterococcus faecium EnGen0151", "rank": "Strain"}, "1220594": {"name": "Geobacillus caldoxylosilyticus NBRC 107762", "rank": "Strain"}, "1220595": {"name": "Geobacillus kaustophilus NBRC 102445", "rank": "Strain"}, "1157448": {"name": "Enterococcus faecium EnGen0153", "rank": "Strain"}, "585423": {"name": "Synechococcus sp. KORDI-49", "rank": "Species"}, "1262469": {"name": "Azospirillum brasilense FP2", "rank": "Strain"}, "1616789": {"name": "Salinispira", "rank": "Genus"}, "1219896": {"name": "Raccoon polyomavirus", "rank": "Species"}, "198346": {"name": "Candidatus Baumannia", "rank": "No rank"}, "910348": {"name": "Escherichia coli P12b", "rank": "Strain"}, "1324230": {"name": "Mycobacterium tuberculosis TKK-01-0014", "rank": "Strain"}, "1324231": {"name": "Mycobacterium tuberculosis TKK-01-0015", "rank": "Strain"}, "1324232": {"name": "Mycobacterium tuberculosis TKK-01-0016", "rank": "Strain"}, "1324233": {"name": "Mycobacterium tuberculosis TKK-01-0018", "rank": "Strain"}, "1324234": {"name": "Mycobacterium tuberculosis TKK-01-0019", "rank": "Strain"}, "1324235": {"name": "Mycobacterium tuberculosis TKK-01-0022", "rank": "Strain"}, "1324236": {"name": "Mycobacterium tuberculosis TKK-01-0024", "rank": "Strain"}, "1324237": {"name": "Mycobacterium tuberculosis TKK-01-0025", "rank": "Strain"}, "1324238": {"name": "Mycobacterium tuberculosis TKK-01-0027", "rank": "Strain"}, "1324239": {"name": "Mycobacterium tuberculosis TKK-01-0028", "rank": "Strain"}, "1221311": {"name": "Acinetobacter schindleri TG19614", "rank": "Strain"}, "1221310": {"name": "Acinetobacter radioresistens TG02010", "rank": "Strain"}, "217429": {"name": "Unclassified Closteroviridae", "rank": "No rank"}, "1134826": {"name": "Enterococcus faecium ERV69", "rank": "Strain"}, "1134827": {"name": "Enterococcus faecium ERV99", "rank": "Strain"}, "1134824": {"name": "Enterococcus faecium ERV26", "rank": "Strain"}, "1134825": {"name": "Enterococcus faecium ERV38", "rank": "Strain"}, "1134822": {"name": "Enterococcus faecium ERV165", "rank": "Strain"}, "1134823": {"name": "Enterococcus faecium ERV168", "rank": "Strain"}, "1134820": {"name": "Enterococcus faecium ERV102", "rank": "Strain"}, "1134821": {"name": "Enterococcus faecium ERV161", "rank": "Strain"}, "1295791": {"name": "Mycobacterium tuberculosis TKK_02_0075", "rank": "Strain"}, "1134828": {"name": "Enterococcus faecium P1123", "rank": "Strain"}, "1134829": {"name": "Enterococcus faecium P1137", "rank": "Strain"}, "1927": {"name": "Streptomyces rimosus", "rank": "Species"}, "1112349": {"name": "Staphylococcus aureus subsp. aureus NN50", "rank": "Strain"}, "712118": {"name": "Actinomyces sp. oral taxon 172", "rank": "Species"}, "71518": {"name": "Methanocorpusculum bavaricum", "rank": "Species"}, "64642": {"name": "Tetragenococcus muriaticus", "rank": "Species"}, "1245478": {"name": "Enterococcus faecium LCT-EF258", "rank": "Strain"}, "1245474": {"name": "Escherichia coli ER2796", "rank": "Strain"}, "1245475": {"name": "Nocardiopsis prasina DSM 43845", "rank": "Strain"}, "1245476": {"name": "Nocardiopsis synnemataformans DSM 44143", "rank": "Strain"}, "1245477": {"name": "Enterococcus faecium LCT-EF20", "rank": "Strain"}, "1245471": {"name": "Pseudomonas resinovorans NBRC 106553", "rank": "Strain"}, "1245472": {"name": "Nocardiopsis halophila DSM 44494", "rank": "Strain"}, "1245473": {"name": "Nocardiopsis alba DSM 43377", "rank": "Strain"}, "78587": {"name": "Asticcacaulis excentricus", "rank": "Species"}, "434922": {"name": "Coxiella burnetii Dugway 5J108-111", "rank": "Strain"}, "78580": {"name": "Mycoplasma alvi", "rank": "Species"}, "344736": {"name": "Pelagibaca bermudensis", "rank": "Species"}, "81426": {"name": "Unclassified Bradyrhizobiaceae", "rank": "No rank"}, "81424": {"name": "Clostridium methoxybenzovorans", "rank": "Species"}, "81425": {"name": "Desulfovibrio aminophilus", "rank": "Species"}, "540067": {"name": "Mycobacterium phage Lockley", "rank": "Species"}, "540066": {"name": "Mycobacterium phage KBG", "rank": "Species"}, "540065": {"name": "Mycobacterium phage Jasper", "rank": "Species"}, "540064": {"name": "Mycobacterium phage DD5", "rank": "Species"}, "1216008": {"name": "Amphibacillus jilinensis", "rank": "Species"}, "1216007": {"name": "Pseudoalteromonas ruthenica CP76", "rank": "Strain"}, "540068": {"name": "Mycobacterium phage Pukovnik", "rank": "Species"}, "1050221": {"name": "Chlamydia psittaci NJ1", "rank": "Strain"}, "194702": {"name": "Cardiobacterium valvarum", "rank": "Species"}, "194701": {"name": "Salmonella phage Fels-2", "rank": "Species"}, "1005442": {"name": "Escherichia coli 0.1288", "rank": "Strain"}, "1276258": {"name": "Spiroplasma apis B31", "rank": "Strain"}, "476523": {"name": "Pseudomonas phage PT5", "rank": "Species"}, "580596": {"name": "Butyricicoccus", "rank": "Genus"}, "1365665": {"name": "Pseudomonas syringae pv. syringae str. B301D-R", "rank": "Strain"}, "294631": {"name": "Flavobacterium phage 11b", "rank": "Species"}, "442563": {"name": "Bifidobacterium animalis subsp. lactis AD011", "rank": "Strain"}, "442562": {"name": "Rubellimicrobium mesophilum DSM 19309", "rank": "Strain"}, "1295796": {"name": "Mycobacterium tuberculosis TKK_02_0080", "rank": "Strain"}, "48292": {"name": "Hyphomicrobium zavarzinii", "rank": "Species"}, "1078016": {"name": "Rhodococcus erythropolis XP", "rank": "Strain"}, "209882": {"name": "Fusobacterium nucleatum subsp. vincentii ATCC 49256", "rank": "Strain"}, "1078018": {"name": "Lactobacillus rhamnosus CASL", "rank": "Strain"}, "48296": {"name": "Acinetobacter pittii", "rank": "Species"}, "160490": {"name": "Streptococcus pyogenes M1 GAS", "rank": "Strain"}, "160491": {"name": "Streptococcus pyogenes str. Manfredo", "rank": "Strain"}, "160492": {"name": "Xylella fastidiosa 9a5c", "rank": "Strain"}, "46618": {"name": "Rhizoctonia solani virus 717", "rank": "Species"}, "46619": {"name": "Sweet potato virus G", "rank": "Species"}, "1268323": {"name": "Chitinophagaceae bacterium JGI 0001013-J17", "rank": "Species"}, "46613": {"name": "Anaerobaculum", "rank": "Genus"}, "1408839": {"name": "Borrelia garinii IPT105", "rank": "Strain"}, "1408838": {"name": "Borrelia garinii IPT104", "rank": "Strain"}, "702458": {"name": "Listeria monocytogenes FSL F2-208", "rank": "Strain"}, "702459": {"name": "Bifidobacterium bifidum PRL2010", "rank": "Strain"}, "702452": {"name": "Listeria seeligeri FSL S4-171", "rank": "Strain"}, "1408830": {"name": "Borrelia garinii IPT90", "rank": "Strain"}, "1408833": {"name": "Borrelia garinii IPT95", "rank": "Strain"}, "1408832": {"name": "Borrelia garinii IPT94", "rank": "Strain"}, "702456": {"name": "Listeria innocua FSL S4-378", "rank": "Strain"}, "1408834": {"name": "Borrelia garinii IPT96", "rank": "Strain"}, "702454": {"name": "Listeria ivanovii FSL F6-596", "rank": "Strain"}, "1408836": {"name": "Borrelia garinii IPT99", "rank": "Strain"}, "316612": {"name": "Methylibium", "rank": "Genus"}, "1115997": {"name": "Escherichia coli Envira 8/11", "rank": "Strain"}, "1293915": {"name": "Brucella ovis IntaBari-2010-47-871", "rank": "Strain"}, "92860": {"name": "Pleosporales", "rank": "Order"}, "1293917": {"name": "Brucella ovis IntaBari-2001-319-5096", "rank": "Strain"}, "1293912": {"name": "Brucella ovis IntaBari-2009-88-3", "rank": "Strain"}, "1293913": {"name": "Brucella ovis IntaBari-2009-88-4", "rank": "Strain"}, "1111479": {"name": "Alicyclobacillus pomorum DSM 14955", "rank": "Strain"}, "1293918": {"name": "Brucella ovis IntaBari-2001-319-4082", "rank": "Strain"}, "1293919": {"name": "Brucella ovis IntaBari-2008-114-542", "rank": "Strain"}, "1115999": {"name": "Escherichia coli Jurua 18/11", "rank": "Strain"}, "1115998": {"name": "Escherichia coli Envira 10/1", "rank": "Strain"}, "352882": {"name": "Angelonia flower break virus", "rank": "Species"}, "69541": {"name": "Desulfuromonadales", "rank": "Order"}, "352888": {"name": "Unclassified T5likevirus", "rank": "No rank"}, "77008": {"name": "Pseudorhodobacter ferrugineus", "rank": "Species"}, "84564": {"name": "Ant endosymbionts", "rank": "No rank"}, "84565": {"name": "Sodalis", "rank": "Genus"}, "84566": {"name": "Sphingobacteriaceae", "rank": "Family"}, "84567": {"name": "Pedobacter", "rank": "Genus"}, "405416": {"name": "Acinetobacter baumannii ACICU", "rank": "Strain"}, "944479": {"name": "Hippea jasoniae", "rank": "Species"}, "84563": {"name": "Ant, tsetse, mealybug, aphid, etc. endosymbionts", "rank": "No rank"}, "1237500": {"name": "Nocardiopsis ganjiahuensis DSM 45031", "rank": "Strain"}, "84568": {"name": "Unclassified Sphingobacteriaceae", "rank": "No rank"}, "478441": {"name": "Halorubrum kocurii", "rank": "Species"}, "141679": {"name": "Photorhabdus luminescens subsp. laumondii", "rank": "Subspecies"}, "239984": {"name": "Nocardiopsis ganjiahuensis", "rank": "Species"}, "580047": {"name": "Chlamydia trachomatis A2497", "rank": "Strain"}, "40117": {"name": "Nitrospirae", "rank": "Phylum"}, "1357400": {"name": "Helicobacter macacae MIT 99-5501", "rank": "Strain"}, "40119": {"name": "Parvovirinae", "rank": "Subfamily"}, "40118": {"name": "Candidatus Magnetobacterium", "rank": "Genus"}, "580049": {"name": "Chlamydia trachomatis B/Jali20/OT", "rank": "Strain"}, "444922": {"name": "Psychromonas ossibalaenae", "rank": "Species"}, "1184606": {"name": "Austwickia", "rank": "Genus"}, "665102": {"name": "Abutilon Brazil virus", "rank": "Species"}, "1193007": {"name": "Leptospira borgpetersenii str. 200701203", "rank": "Strain"}, "1193009": {"name": "Leptospira borgpetersenii str. 200801926", "rank": "Strain"}, "315393": {"name": "Mimivirus", "rank": "Genus"}, "315392": {"name": "Tomato leaf curl virus-Pune-associated DNA beta", "rank": "Species"}, "1150476": {"name": "Bacillus amyloliquefaciens subsp. plantarum UCMB5113", "rank": "Strain"}, "34068": {"name": "Cycloclasticus pugetii", "rank": "Species"}, "59749": {"name": "Maize rayado fino virus", "rank": "Species"}, "1179780": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. 2010-1237", "rank": "Strain"}, "574961": {"name": "Saccharomyces cerevisiae JAY291", "rank": "Strain"}, "574962": {"name": "Pseudomonas taeanensis", "rank": "Species"}, "574965": {"name": "Streptococcus pneumoniae CCRI 1974M2", "rank": "Strain"}, "574966": {"name": "Halomonas zhanjiangensis DSM 21076", "rank": "Strain"}, "1154943": {"name": "Streptococcus agalactiae GB00900", "rank": "Strain"}, "1150475": {"name": "Bacillus amyloliquefaciens subsp. plantarum UCMB5036", "rank": "Strain"}, "634464": {"name": "Chlamydia trachomatis Sweden2", "rank": "Strain"}, "351052": {"name": "Alkalilimnicola ehrlichii", "rank": "Species"}, "176299": {"name": "Agrobacterium fabrum str. C58", "rank": "Strain"}, "914145": {"name": "Streptococcus pneumoniae 2080913", "rank": "Strain"}, "107804": {"name": "Sorghum chlorotic spot virus", "rank": "Species"}, "107806": {"name": "Buchnera aphidicola str. APS (Acyrthosiphon pisum)", "rank": "Strain"}, "935699": {"name": "Cellulophaga geojensis", "rank": "Species"}, "1154942": {"name": "Streptococcus agalactiae GB00899", "rank": "Strain"}, "935697": {"name": "Corynebacterium pseudotuberculosis CIP 52.97", "rank": "Strain"}, "1150474": {"name": "Mesoaciditoga lauensis cd-1655R = DSM 25116", "rank": "Strain"}, "59203": {"name": "Salmonella enterica subsp. arizonae", "rank": "Subspecies"}, "59202": {"name": "Salmonella enterica subsp. salamae", "rank": "Subspecies"}, "59201": {"name": "Salmonella enterica subsp. enterica", "rank": "Subspecies"}, "92793": {"name": "Aquabacterium", "rank": "Genus"}, "59207": {"name": "Salmonella enterica subsp. indica", "rank": "Subspecies"}, "59205": {"name": "Salmonella enterica subsp. houtenae", "rank": "Subspecies"}, "59204": {"name": "Salmonella enterica subsp. diarizonae", "rank": "Subspecies"}, "1310651": {"name": "Acinetobacter baumannii 230853", "rank": "Strain"}, "1435989": {"name": "Burkholderia pseudomallei MSHR983", "rank": "Strain"}, "1310653": {"name": "Acinetobacter baumannii 951631", "rank": "Strain"}, "1244103": {"name": "Streptococcus agalactiae SGBS026", "rank": "Strain"}, "1310655": {"name": "Acinetobacter baumannii 1277411", "rank": "Strain"}, "1310654": {"name": "Acinetobacter baumannii 1291820", "rank": "Strain"}, "1169268": {"name": "Staphylococcus aureus M1223", "rank": "Strain"}, "1169269": {"name": "Staphylococcus aureus M1224", "rank": "Strain"}, "1169266": {"name": "Staphylococcus aureus M1126", "rank": "Strain"}, "479713": {"name": "Primula malacoides virus China/Mar2007", "rank": "Strain"}, "1169264": {"name": "Staphylococcus aureus M1083", "rank": "Strain"}, "1169265": {"name": "Staphylococcus aureus M1109", "rank": "Strain"}, "1169262": {"name": "Staphylococcus aureus M1062", "rank": "Strain"}, "1169263": {"name": "Staphylococcus aureus M1068", "rank": "Strain"}, "1169260": {"name": "Staphylococcus aureus M1044", "rank": "Strain"}, "1169261": {"name": "Staphylococcus aureus M1061", "rank": "Strain"}, "261317": {"name": "Buchnera aphidicola (Cinara tujafilina)", "rank": "Strain"}, "1123508": {"name": "Zavarzinella formosa DSM 19928", "rank": "Strain"}, "261318": {"name": "Buchnera aphidicola (Cinara cedri)", "rank": "Strain"}, "400776": {"name": "Cohnella panacarvi", "rank": "Species"}, "939696": {"name": "Gamma proteobacterium SCGC AAA300-D14", "rank": "Species"}, "208294": {"name": "Seadornavirus", "rank": "Genus"}, "143901": {"name": "Benyvirus", "rank": "Genus"}, "263818": {"name": "Marinomonas ushuaiensis", "rank": "Species"}, "712414": {"name": "Oribacterium sp. oral taxon 108", "rank": "Species"}, "330699": {"name": "Leptospira interrogans serovar Bulgarica", "rank": "Strain"}, "263815": {"name": "Pneumocystis murina", "rank": "Species"}, "939346": {"name": "Alpha proteobacterium SCGC AAA288-N07", "rank": "Species"}, "1435985": {"name": "Burkholderia pseudomallei MSHR435", "rank": "Strain"}, "1448574": {"name": "Mycobacterium tuberculosis TKK_04_0109", "rank": "Strain"}, "1448575": {"name": "Mycobacterium tuberculosis TKK_04_0112", "rank": "Strain"}, "1448576": {"name": "Mycobacterium tuberculosis TKK_04_0113", "rank": "Strain"}, "1448577": {"name": "Mycobacterium tuberculosis TKK_04_0114", "rank": "Strain"}, "1448570": {"name": "Mycobacterium tuberculosis TKK_04_0105", "rank": "Strain"}, "1448571": {"name": "Mycobacterium tuberculosis TKK_04_0106", "rank": "Strain"}, "1448572": {"name": "Mycobacterium tuberculosis TKK_04_0107", "rank": "Strain"}, "1448573": {"name": "Mycobacterium tuberculosis TKK_04_0108", "rank": "Strain"}, "574697": {"name": "Butyricimonas", "rank": "Genus"}, "1448579": {"name": "Mycobacterium tuberculosis TKK_04_0117", "rank": "Strain"}, "98794": {"name": "Buchnera aphidicola (Schizaphis graminum)", "rank": "Strain"}, "98795": {"name": "Buchnera aphidicola (Myzus persicae)", "rank": "Strain"}, "28369": {"name": "Mycobacterium phage D29", "rank": "Species"}, "1162296": {"name": "Klebsiella pneumoniae subsp. pneumoniae DSM 30104", "rank": "Strain"}, "1162297": {"name": "Klebsiella pneumoniae subsp. pneumoniae LCT-KP214", "rank": "Strain"}, "1162294": {"name": "Serratia marcescens LCT-SM213", "rank": "Strain"}, "1162295": {"name": "Cronobacter phage CR3", "rank": "Species"}, "1162290": {"name": "Cronobacter phage CR9", "rank": "Species"}, "1154944": {"name": "Streptococcus agalactiae GB00901", "rank": "Strain"}, "903899": {"name": "Acinetobacter baumannii IS-123", "rank": "Strain"}, "903898": {"name": "Acinetobacter baumannii Naval-81", "rank": "Strain"}, "936581": {"name": "Streptococcus sp. CM7", "rank": "Species"}, "936580": {"name": "Streptococcus sp. CM6", "rank": "Species"}, "903893": {"name": "Acinetobacter baumannii OIFC143", "rank": "Strain"}, "903892": {"name": "Acinetobacter baumannii OIFC109", "rank": "Strain"}, "903890": {"name": "Acinetobacter baumannii OIFC032", "rank": "Strain"}, "936589": {"name": "Veillonella sp. AS16", "rank": "Species"}, "903896": {"name": "Acinetobacter baumannii Naval-17", "rank": "Strain"}, "903895": {"name": "Acinetobacter baumannii Canada BC-5", "rank": "Strain"}, "903894": {"name": "Acinetobacter baumannii OIFC189", "rank": "Strain"}, "1576605": {"name": "Streptomyces sp. 150FB", "rank": "Species"}, "11161": {"name": "Mumps virus", "rank": "Species"}, "1225644": {"name": "Bhendi yellow vein mosaic virus-associated alphasatellite", "rank": "Species"}, "1169358": {"name": "Escherichia coli KTE41", "rank": "Strain"}, "1225643": {"name": "Mesta yellow vein mosaic virus-associated alphasatellite", "rank": "Species"}, "1310729": {"name": "Acinetobacter baumannii 23671", "rank": "Strain"}, "1169357": {"name": "Escherichia coli KTE40", "rank": "Strain"}, "41980": {"name": "Metallosphaera", "rank": "Genus"}, "1402716": {"name": "Staphylococcus aureus M1213", "rank": "Strain"}, "1402717": {"name": "Staphylococcus aureus M1214", "rank": "Strain"}, "1402714": {"name": "Staphylococcus aureus M1209", "rank": "Strain"}, "1402715": {"name": "Staphylococcus aureus M1212", "rank": "Strain"}, "1402712": {"name": "Staphylococcus aureus M1207", "rank": "Strain"}, "1402713": {"name": "Staphylococcus aureus M1208", "rank": "Strain"}, "1402710": {"name": "Staphylococcus aureus M1205", "rank": "Strain"}, "1402711": {"name": "Staphylococcus aureus M1206", "rank": "Strain"}, "1402718": {"name": "Staphylococcus aureus M1217", "rank": "Strain"}, "1402719": {"name": "Staphylococcus aureus M1218", "rank": "Strain"}, "41295": {"name": "Rhodospirillaceae", "rank": "Family"}, "42182": {"name": "Hepatitis C virus genotype 6", "rank": "Strain"}, "41294": {"name": "Bradyrhizobiaceae", "rank": "Family"}, "155515": {"name": "Gallibacterium genomosp. 1", "rank": "Species"}, "155517": {"name": "Gallibacterium genomosp. 2", "rank": "Species"}, "41297": {"name": "Sphingomonadaceae", "rank": "Family"}, "746830": {"name": "Human polyomavirus 6", "rank": "Species"}, "746831": {"name": "Human polyomavirus 7", "rank": "Species"}, "746832": {"name": "Human papillomavirus type 127", "rank": "Strain"}, "133746": {"name": "Punctularia", "rank": "Genus"}, "1422198": {"name": "Staphylococcus aureus DAR3919", "rank": "Strain"}, "1339316": {"name": "Bacteroides fragilis str. 3998T(B)3", "rank": "Strain"}, "41293": {"name": "Unclassified Acetobacteraceae", "rank": "No rank"}, "1422192": {"name": "Staphylococcus aureus DAR3901", "rank": "Strain"}, "1422193": {"name": "Staphylococcus aureus DAR3902", "rank": "Strain"}, "1422190": {"name": "Staphylococcus aureus DAR3894", "rank": "Strain"}, "1500866": {"name": "Drosophila immigrans Nora virus", "rank": "Species"}, "1422196": {"name": "Staphylococcus aureus DAR3913", "rank": "Strain"}, "1173062": {"name": "Acinetobacter sp. HA", "rank": "Species"}, "1422194": {"name": "Staphylococcus aureus DAR3907", "rank": "Strain"}, "752140": {"name": "Pedobacter arcticus", "rank": "Species"}, "29909": {"name": "Tolypocladium", "rank": "Genus"}, "29908": {"name": "Sporothrix schenckii", "rank": "Species"}, "29907": {"name": "Sporothrix", "rank": "Genus"}, "12431": {"name": "Garlic virus C", "rank": "Species"}, "12430": {"name": "Garlic virus D", "rank": "Species"}, "12433": {"name": "Garlic virus A", "rank": "Species"}, "12435": {"name": "Sugarcane bacilliform virus", "rank": "Species"}, "928328": {"name": "Lactobacillus iners UPII 60-B", "rank": "Strain"}, "12436": {"name": "Cucumber mosaic virus satellite RNA", "rank": "Species"}, "928327": {"name": "Lactobacillus iners UPII 143-D", "rank": "Strain"}, "312169": {"name": "Leptospira kirschneri serovar Bulgarica", "rank": "Strain"}, "888745": {"name": "Streptococcus agalactiae ATCC 13813", "rank": "Strain"}, "888744": {"name": "Aspergillus fumigatus AF210", "rank": "Strain"}, "1339319": {"name": "Bacteroides fragilis str. S6L8", "rank": "Strain"}, "1408904": {"name": "Mycobacterium tuberculosis UT0001", "rank": "Strain"}, "888746": {"name": "Streptococcus peroris ATCC 700780", "rank": "Strain"}, "888741": {"name": "Kingella denitrificans ATCC 33394", "rank": "Strain"}, "888743": {"name": "Prevotella multiformis DSM 16608", "rank": "Strain"}, "888742": {"name": "Neisseria bacilliformis ATCC BAA-1200", "rank": "Strain"}, "187218": {"name": "T5likevirus", "rank": "Genus"}, "187213": {"name": "Rudivirus", "rank": "Genus"}, "187212": {"name": "Tungrovirus", "rank": "Genus"}, "187214": {"name": "Soymovirus", "rank": "Genus"}, "187217": {"name": "Tunalikevirus", "rank": "Genus"}, "1422736": {"name": "Staphylococcus aureus VET1897R", "rank": "Strain"}, "1422737": {"name": "Staphylococcus aureus VET1898R", "rank": "Strain"}, "1422734": {"name": "Staphylococcus aureus VET1895R", "rank": "Strain"}, "1422735": {"name": "Staphylococcus aureus VET1896R", "rank": "Strain"}, "1422732": {"name": "Staphylococcus aureus VET1892R", "rank": "Strain"}, "1422733": {"name": "Staphylococcus aureus VET1893R", "rank": "Strain"}, "1422730": {"name": "Staphylococcus aureus VET1886R", "rank": "Strain"}, "1422731": {"name": "Staphylococcus aureus VET1890R", "rank": "Strain"}, "1422738": {"name": "Staphylococcus aureus VET1899R", "rank": "Strain"}, "1200557": {"name": "Anaerovibrio sp. RM50", "rank": "Species"}, "760869": {"name": "Streptococcus pneumoniae 7286-06", "rank": "Strain"}, "760868": {"name": "Streptococcus pneumoniae 5185-06", "rank": "Strain"}, "227388": {"name": "Thermodesulfobium", "rank": "Genus"}, "760863": {"name": "Streptococcus pneumoniae 6901-05", "rank": "Strain"}, "760862": {"name": "Streptococcus pneumoniae 6735-05", "rank": "Strain"}, "490711": {"name": "Orgyia leucostigma NPV", "rank": "Species"}, "760860": {"name": "Streptococcus pneumoniae GA47439", "rank": "Strain"}, "760867": {"name": "Streptococcus pneumoniae 8190-05", "rank": "Strain"}, "760866": {"name": "Streptococcus pneumoniae 5787-06", "rank": "Strain"}, "760865": {"name": "Streptococcus pneumoniae 6963-05", "rank": "Strain"}, "760864": {"name": "Streptococcus pneumoniae 4027-06", "rank": "Strain"}, "88431": {"name": "Dorea longicatena", "rank": "Species"}, "245101": {"name": "Cryphonectria hypovirus 4", "rank": "Species"}, "435908": {"name": "Idiomarina salinarum", "rank": "Species"}, "1443905": {"name": "Rhodococcus fascians LMG 3625", "rank": "Strain"}, "1443900": {"name": "Rhodococcus fascians GIC36", "rank": "Strain"}, "1443901": {"name": "Rhodococcus fascians LMG 3602", "rank": "Strain"}, "1443902": {"name": "Rhodococcus fascians LMG 3605", "rank": "Strain"}, "1443903": {"name": "Rhodococcus fascians LMG 3616", "rank": "Strain"}, "1249997": {"name": "Maribacter sp. Hel_I_7", "rank": "Species"}, "768670": {"name": "Calditerrivibrio nitroreducens DSM 19672", "rank": "Strain"}, "768671": {"name": "Thiocapsa marina 5811", "rank": "Strain"}, "509190": {"name": "Caulobacter segnis ATCC 21756", "rank": "Strain"}, "509191": {"name": "Acetivibrio cellulolyticus CD2", "rank": "Strain"}, "509192": {"name": "Thermoanaerobacter ethanolicus JW 200", "rank": "Strain"}, "768679": {"name": "Thermoproteus tenax Kra 1", "rank": "Strain"}, "1331221": {"name": "Bordetella bronchiseptica MBORD624", "rank": "Strain"}, "244364": {"name": "Methylohalobius", "rank": "Genus"}, "1331223": {"name": "Bordetella bronchiseptica MBORD635", "rank": "Strain"}, "1331222": {"name": "Bordetella bronchiseptica MBORD632", "rank": "Strain"}, "1331225": {"name": "Bordetella bronchiseptica MBORD668", "rank": "Strain"}, "1409579": {"name": "Staphylococcus aureus SMMC6076", "rank": "Strain"}, "1266909": {"name": "Thioalkalivibrio sp. ALE19", "rank": "Species"}, "1266908": {"name": "Thioalkalivibrio sp. ALE6", "rank": "Species"}, "1331229": {"name": "Bordetella bronchiseptica MBORD681", "rank": "Strain"}, "1331228": {"name": "Bordetella bronchiseptica MBORD678", "rank": "Strain"}, "1409578": {"name": "Staphylococcus aureus MISS6119", "rank": "Strain"}, "1266902": {"name": "Chlamydia trachomatis E/CS88(i)", "rank": "Strain"}, "1409576": {"name": "Staphylococcus aureus SJUD6101", "rank": "Strain"}, "49928": {"name": "Unclassified Bacteria (miscellaneous)", "rank": "No rank"}, "1543207": {"name": "Rose leaf rosette-associated virus", "rank": "Species"}, "553580": {"name": "Staphylococcus aureus A8819", "rank": "Strain"}, "553581": {"name": "Staphylococcus aureus A9299", "rank": "Strain"}, "553583": {"name": "Staphylococcus aureus A9635", "rank": "Strain"}, "992061": {"name": "Helicobacter pylori Hp H-6", "rank": "Strain"}, "553588": {"name": "Staphylococcus aureus A9719", "rank": "Strain"}, "1409418": {"name": "Staphylococcus aureus CHOC6056", "rank": "Strain"}, "44249": {"name": "Paenibacillus", "rank": "Genus"}, "1279082": {"name": "Pseudomonas phage PPpW-3", "rank": "Species"}, "178606": {"name": "Leptospirillum ferriphilum", "rank": "Species"}, "1277672": {"name": "Staphylococcus phage StauST398-2", "rank": "Species"}, "868158": {"name": "Escherichia coli DEC5D", "rank": "Strain"}, "868159": {"name": "Escherichia coli DEC5E", "rank": "Strain"}, "868156": {"name": "Escherichia coli DEC5B", "rank": "Strain"}, "868157": {"name": "Escherichia coli DEC5C", "rank": "Strain"}, "868154": {"name": "Escherichia coli DEC4F", "rank": "Strain"}, "868155": {"name": "Escherichia coli DEC5A", "rank": "Strain"}, "868152": {"name": "Escherichia coli DEC4D", "rank": "Strain"}, "868153": {"name": "Escherichia coli DEC4E", "rank": "Strain"}, "868150": {"name": "Escherichia coli DEC4B", "rank": "Strain"}, "868151": {"name": "Escherichia coli DEC4C", "rank": "Strain"}, "220608": {"name": "Tomato leaf curl Bangalore virus", "rank": "Species"}, "1422689": {"name": "Staphylococcus aureus VET0488R", "rank": "Strain"}, "235909": {"name": "Geobacillus kaustophilus HTA426", "rank": "Strain"}, "641107": {"name": "Clostridium sp. DL-VIII", "rank": "Species"}, "1413439": {"name": "Staphylococcus aureus FP_N239", "rank": "Strain"}, "1413438": {"name": "Staphylococcus aureus 22P79", "rank": "Strain"}, "1224929": {"name": "Staphylococcus aureus M0404", "rank": "Strain"}, "1224928": {"name": "Staphylococcus aureus M0312", "rank": "Strain"}, "1224927": {"name": "Staphylococcus aureus M0288", "rank": "Strain"}, "1413434": {"name": "Staphylococcus aureus 1111200013", "rank": "Strain"}, "525381": {"name": "Streptococcus pneumoniae TCH8431/19A", "rank": "Strain"}, "1413436": {"name": "Staphylococcus aureus 1111205429", "rank": "Strain"}, "1224923": {"name": "Staphylococcus aureus M0240", "rank": "Strain"}, "1413430": {"name": "Staphylococcus aureus 1111001578", "rank": "Strain"}, "1224921": {"name": "Staphylococcus aureus M0210", "rank": "Strain"}, "1413432": {"name": "Staphylococcus aureus 1111101949", "rank": "Strain"}, "1409449": {"name": "Staphylococcus aureus FVRH6001", "rank": "Strain"}, "1409448": {"name": "Staphylococcus aureus UCIM6055", "rank": "Strain"}, "1281228": {"name": "Escherichia coli UMEA 3244-1", "rank": "Strain"}, "1409443": {"name": "Staphylococcus aureus AMMC6075", "rank": "Strain"}, "1409442": {"name": "Staphylococcus aureus AMMC6074", "rank": "Strain"}, "1409441": {"name": "Staphylococcus aureus AMMC6073", "rank": "Strain"}, "1281226": {"name": "Escherichia coli UMEA 3233-1", "rank": "Strain"}, "1409447": {"name": "Staphylococcus aureus UCIM6053", "rank": "Strain"}, "1409446": {"name": "Staphylococcus aureus LAMC0050", "rank": "Strain"}, "1281223": {"name": "Escherichia coli UMEA 3221-1", "rank": "Strain"}, "1409444": {"name": "Staphylococcus aureus MISS6110", "rank": "Strain"}, "1175452": {"name": "Peptoniphilus rhinitidis", "rank": "Species"}, "129789": {"name": "Natrialba aegyptia", "rank": "Species"}, "1173882": {"name": "Salmonella enterica subsp. enterica serovar Muenchen str. RKS4129", "rank": "Strain"}, "588857": {"name": "Thermoanaerobacter sp. X561", "rank": "Species"}, "1185414": {"name": "Mycobacterium abscessus M156", "rank": "Strain"}, "1224258": {"name": "Ophiostoma novo-ulmi subsp. novo-ulmi H327", "rank": "Strain"}, "1341101": {"name": "Vibrio phage VPUSM 8", "rank": "Species"}, "588858": {"name": "Salmonella enterica subsp. enterica serovar Typhimurium str. 14028S", "rank": "Strain"}, "1185418": {"name": "Klebsiella pneumoniae subsp. pneumoniae ST512-K30BO", "rank": "Strain"}, "566679": {"name": "Bradyrhizobium sp. ORS 375", "rank": "Species"}, "1333313": {"name": "Malvastrum leaf curl Philippines virus", "rank": "Species"}, "47903": {"name": "Strawberry vein banding virus", "rank": "Species"}, "1449068": {"name": "Rhodococcus sp. UNC23MFCrub1.1", "rank": "Species"}, "1417208": {"name": "Staphylococcus aureus T39093", "rank": "Strain"}, "1417209": {"name": "Staphylococcus aureus W12538", "rank": "Strain"}, "1417206": {"name": "Staphylococcus aureus T36127", "rank": "Strain"}, "1417207": {"name": "Staphylococcus aureus T39082", "rank": "Strain"}, "1417204": {"name": "Staphylococcus aureus T35615", "rank": "Strain"}, "1417205": {"name": "Staphylococcus aureus T36111", "rank": "Strain"}, "1417202": {"name": "Staphylococcus aureus T35596", "rank": "Strain"}, "1417203": {"name": "Staphylococcus aureus T35604", "rank": "Strain"}, "1417200": {"name": "Staphylococcus aureus T32070", "rank": "Strain"}, "1417201": {"name": "Staphylococcus aureus T35594", "rank": "Strain"}, "1380768": {"name": "Campylobacter jejuni subsp. jejuni 00-2538", "rank": "Strain"}, "925984": {"name": "Erwinia phage phiEt88", "rank": "Species"}, "1380763": {"name": "Paenibacillus darwinianus", "rank": "Species"}, "925983": {"name": "Erwinia phage phiEa100", "rank": "Species"}, "1380767": {"name": "Campylobacter jejuni subsp. jejuni 00-2426", "rank": "Strain"}, "996859": {"name": "Leptospira interrogans serovar Copenhageni str. Fiocruz LV3879", "rank": "Strain"}, "996858": {"name": "Leptospira interrogans serovar Copenhageni str. Fiocruz LV3834", "rank": "Strain"}, "996854": {"name": "Leptospira interrogans serovar Copenhageni str. Fiocruz LV3373", "rank": "Strain"}, "996857": {"name": "Leptospira interrogans serovar Copenhageni str. Fiocruz LV3738", "rank": "Strain"}, "996856": {"name": "Leptospira interrogans serovar Copenhageni str. Fiocruz LV3737", "rank": "Strain"}, "996851": {"name": "Leptospira interrogans serovar Copenhageni str. Fiocruz LV3096", "rank": "Strain"}, "996850": {"name": "Leptospira interrogans serovar Copenhageni str. Fiocruz LV3094", "rank": "Strain"}, "996853": {"name": "Leptospira interrogans serovar Copenhageni str. Fiocruz LV3323", "rank": "Strain"}, "613198": {"name": "Prochlorococcus sp. W7", "rank": "Species"}, "613199": {"name": "Prochlorococcus sp. W8", "rank": "Species"}, "152177": {"name": "Orchid fleck virus", "rank": "Species"}, "1278307": {"name": "Psychromonas ossibalaenae ATCC BAA-1528", "rank": "Strain"}, "1046938": {"name": "Aenigmarchaeota archaeon SCGC AAA011-F07", "rank": "Species"}, "1421959": {"name": "Mycobacterium tuberculosis TB_RSA43", "rank": "Strain"}, "1421958": {"name": "Mycobacterium tuberculosis TB_RSA42", "rank": "Strain"}, "57975": {"name": "Burkholderia thailandensis", "rank": "Species"}, "1421953": {"name": "Mycobacterium tuberculosis TB_RSA37", "rank": "Strain"}, "1421952": {"name": "Mycobacterium tuberculosis TB_RSA36", "rank": "Strain"}, "1421951": {"name": "Mycobacterium tuberculosis TB_RSA35", "rank": "Strain"}, "1421950": {"name": "Mycobacterium tuberculosis TB_RSA34", "rank": "Strain"}, "1397940": {"name": "Mycobacterium tuberculosis TKK_04_0031", "rank": "Strain"}, "1397941": {"name": "Mycobacterium tuberculosis TKK_04_0033", "rank": "Strain"}, "1421955": {"name": "Mycobacterium tuberculosis TB_RSA39", "rank": "Strain"}, "1421954": {"name": "Mycobacterium tuberculosis TB_RSA38", "rank": "Strain"}, "718219": {"name": "Chlamydia trachomatis G/9301", "rank": "Strain"}, "199596": {"name": "Methylocella silvestris", "rank": "Species"}, "375061": {"name": "Arenimonas donghaensis", "rank": "Species"}, "375063": {"name": "Haemophilus influenzae 22.4-21", "rank": "Strain"}, "199592": {"name": "Microbacterium paraoxydans", "rank": "Species"}, "860228": {"name": "Capnocytophaga canimorsus Cc5", "rank": "Strain"}, "464322": {"name": "Veillonella magna", "rank": "Species"}, "1354105": {"name": "Mycobacterium tuberculosis MAL020194", "rank": "Strain"}, "1354104": {"name": "Mycobacterium africanum MAL020193", "rank": "Strain"}, "1354107": {"name": "Mycobacterium tuberculosis MAL020196", "rank": "Strain"}, "1354106": {"name": "Mycobacterium tuberculosis MAL020195", "rank": "Strain"}, "1354101": {"name": "Mycobacterium tuberculosis MAL020186", "rank": "Strain"}, "1354103": {"name": "Mycobacterium tuberculosis MAL020192", "rank": "Strain"}, "1354102": {"name": "Mycobacterium tuberculosis MAL020187", "rank": "Strain"}, "699037": {"name": "Peptoclostridium difficile M68", "rank": "Strain"}, "1221537": {"name": "Lactobacillus florum 2F", "rank": "Strain"}, "699035": {"name": "Peptoclostridium difficile M120", "rank": "Strain"}, "699034": {"name": "Peptoclostridium difficile BI1", "rank": "Strain"}, "699033": {"name": "Peptoclostridium difficile 2007855", "rank": "Strain"}, "1354108": {"name": "Mycobacterium tuberculosis MAL020197", "rank": "Strain"}, "672161": {"name": "Chlamydia trachomatis B/TZ1A828/OT", "rank": "Strain"}, "1125630": {"name": "Klebsiella pneumoniae subsp. pneumoniae HS11286", "rank": "Strain"}, "1125635": {"name": "Escherichia coli 2733950", "rank": "Strain"}, "1125634": {"name": "Escherichia coli 174750", "rank": "Strain"}, "1125637": {"name": "Escherichia coli BCE006_MS-23", "rank": "Strain"}, "1125636": {"name": "Escherichia coli 2854350", "rank": "Strain"}, "1125639": {"name": "Escherichia coli P0298942.3", "rank": "Strain"}, "1125638": {"name": "Escherichia coli MP020980.1", "rank": "Strain"}, "1278302": {"name": "Psychromonas hadalis ATCC BAA-638", "rank": "Strain"}, "271479": {"name": "Papaya leaf curl Guandong virus", "rank": "Species"}, "1380348": {"name": "Acidobacteriaceae bacterium URHE0068", "rank": "Species"}, "1221538": {"name": "Lactobacillus florum 8D", "rank": "Strain"}, "191393": {"name": "Deferribacterales", "rank": "Order"}, "496866": {"name": "Thermoanaerobacter pseudethanolicus", "rank": "Species"}, "358823": {"name": "Streptomyces olindensis", "rank": "Species"}, "1427476": {"name": "Cimodo virus", "rank": "Species"}, "1418337": {"name": "Staphylococcus aureus T13128", "rank": "Strain"}, "1418336": {"name": "Staphylococcus aureus T13096", "rank": "Strain"}, "31988": {"name": "Aminobacter", "rank": "Genus"}, "1418334": {"name": "Staphylococcus aureus M90383", "rank": "Strain"}, "1418333": {"name": "Staphylococcus aureus M83332", "rank": "Strain"}, "1418332": {"name": "Staphylococcus aureus M79673", "rank": "Strain"}, "1418331": {"name": "Staphylococcus aureus M79667", "rank": "Strain"}, "1264579": {"name": "Halococcus sediminicola", "rank": "Species"}, "31983": {"name": "Helcococcus", "rank": "Genus"}, "31984": {"name": "Heliobacteriaceae", "rank": "Family"}, "1418338": {"name": "Staphylococcus aureus T42547", "rank": "Strain"}, "293890": {"name": "Agromyces subbeticus", "rank": "Species"}, "1410713": {"name": "Staphylococcus aureus W38597", "rank": "Strain"}, "312179": {"name": "Leptospira interrogans serovar Zanoni", "rank": "Strain"}, "411248": {"name": "Croton yellow vein mosaic betasatellite", "rank": "Species"}, "1410712": {"name": "Staphylococcus aureus T56203", "rank": "Strain"}, "1293288": {"name": "Listeria monocytogenes serotype 1/2a str. NCCP No. 15743", "rank": "Strain"}, "1293289": {"name": "Campylobacter jejuni str. NCCP No. 15742", "rank": "Strain"}, "1410715": {"name": "Staphylococcus aureus M13384", "rank": "Strain"}, "1454056": {"name": "Citrobacter freundii RLS1", "rank": "Strain"}, "326442": {"name": "Pseudoalteromonas haloplanktis TAC125", "rank": "Strain"}, "68253": {"name": "Streptomyces peruviensis", "rank": "Species"}, "1159055": {"name": "Helicobacter pylori GAM83Bi", "rank": "Strain"}, "1410716": {"name": "Staphylococcus aureus M13403", "rank": "Strain"}, "312177": {"name": "Leptospira interrogans serovar Szwajizak", "rank": "Strain"}, "334413": {"name": "Finegoldia magna ATCC 29328", "rank": "Strain"}, "181675": {"name": "Lactobacillus coleohominis", "rank": "Species"}, "1006155": {"name": "Listeria weihenstephanensis", "rank": "Species"}, "1268635": {"name": "Legionella oakridgensis ATCC 33761 = DSM 21215", "rank": "Strain"}, "444876": {"name": "Cyanophage P-SSP2", "rank": "Species"}, "1085379": {"name": "Bacillus cereus VDM006", "rank": "Strain"}, "210827": {"name": "Coniothyrium minitans RNA virus", "rank": "Species"}, "1265820": {"name": "Listeria cornellensis FSL F6-969", "rank": "Strain"}, "1265822": {"name": "Listeria fleischmannii FSL S10-1203", "rank": "Strain"}, "1265827": {"name": "Listeria grayi FSL F6-1183", "rank": "Strain"}, "1053189": {"name": "Bacillus cereus BAG5X1-1", "rank": "Strain"}, "686565": {"name": "Gokushovirinae", "rank": "Subfamily"}, "365032": {"name": "Aureispira", "rank": "Genus"}, "1053188": {"name": "Bacillus cereus BAG5O-1", "rank": "Strain"}, "1316444": {"name": "Blattabacterium sp. (Nauphoeta cinerea)", "rank": "Species"}, "456442": {"name": "Methanoregula boonei 6A8", "rank": "Strain"}, "1448778": {"name": "Mycobacterium tuberculosis M2343", "rank": "Strain"}, "1448779": {"name": "Mycobacterium tuberculosis M2342", "rank": "Strain"}, "1448772": {"name": "Mycobacterium tuberculosis M2198", "rank": "Strain"}, "1448773": {"name": "Mycobacterium tuberculosis M2193", "rank": "Strain"}, "1448770": {"name": "Mycobacterium tuberculosis M2203", "rank": "Strain"}, "1448771": {"name": "Mycobacterium tuberculosis M2199", "rank": "Strain"}, "1448776": {"name": "Mycobacterium tuberculosis M2141", "rank": "Strain"}, "1448777": {"name": "Mycobacterium tuberculosis M2352", "rank": "Strain"}, "1142511": {"name": "Wigglesworthia glossinidia endosymbiont of Glossina morsitans morsitans (Yale colony)", "rank": "Strain"}, "1448775": {"name": "Mycobacterium tuberculosis M2191", "rank": "Strain"}, "947981": {"name": "Lactobacillus phage Sha1", "rank": "Species"}, "947980": {"name": "Lactobacillus phage LF1", "rank": "Species"}, "1053239": {"name": "Bacillus cereus VD156", "rank": "Strain"}, "1053238": {"name": "Bacillus cereus VD154", "rank": "Strain"}, "1053237": {"name": "Bacillus cereus VD148", "rank": "Strain"}, "1053236": {"name": "Bacillus cereus VD146", "rank": "Strain"}, "1053235": {"name": "Bacillus cereus VD140", "rank": "Strain"}, "1053234": {"name": "Bacillus cereus VD136", "rank": "Strain"}, "1053233": {"name": "Bacillus cereus VD133", "rank": "Strain"}, "1053232": {"name": "Bacillus cereus VD131", "rank": "Strain"}, "1053231": {"name": "Bacillus cereus VD118", "rank": "Strain"}, "1053230": {"name": "Bacillus cereus VD115", "rank": "Strain"}, "742818": {"name": "Slackia piriformis YIT 12062", "rank": "Strain"}, "1427266": {"name": "Mycobacterium tuberculosis XTB13-188", "rank": "Strain"}, "1427265": {"name": "Mycobacterium tuberculosis XTB13-187", "rank": "Strain"}, "1427264": {"name": "Mycobacterium tuberculosis XTB13-186", "rank": "Strain"}, "1427262": {"name": "Mycobacterium tuberculosis XTB13-184", "rank": "Strain"}, "1427261": {"name": "Mycobacterium tuberculosis XTB13-183", "rank": "Strain"}, "1427260": {"name": "Mycobacterium tuberculosis XTB13-182", "rank": "Strain"}, "1427269": {"name": "Mycobacterium tuberculosis XTB13-191", "rank": "Strain"}, "1427268": {"name": "Mycobacterium tuberculosis XTB13-190", "rank": "Strain"}, "990314": {"name": "Vibrio anguillarum 96F", "rank": "Strain"}, "990315": {"name": "Xanthomonas campestris pv. raphani 756C", "rank": "Strain"}, "990316": {"name": "Methanosaeta concilii GP6", "rank": "Strain"}, "990317": {"name": "Streptococcus gallolyticus subsp. gallolyticus ATCC BAA-2069", "rank": "Strain"}, "651142": {"name": "Unclassified Thaumarchaeota", "rank": "No rank"}, "254786": {"name": "Streptococcus castoreus", "rank": "Species"}, "254787": {"name": "Arthrobacter gangotriensis", "rank": "Species"}, "1304924": {"name": "Klebsiella pneumoniae 646_1568", "rank": "Strain"}, "324925": {"name": "Pelodictyon phaeoclathratiforme BU-1", "rank": "Strain"}, "1304922": {"name": "Klebsiella pneumoniae 500_1420", "rank": "Strain"}, "1304923": {"name": "Klebsiella pneumoniae 540_1460", "rank": "Strain"}, "1304920": {"name": "Klebsiella pneumoniae 361_1301", "rank": "Strain"}, "1304921": {"name": "Klebsiella pneumoniae 440_1540", "rank": "Strain"}, "1108045": {"name": "Gordonia rhizosphera NBRC 16068", "rank": "Strain"}, "1401297": {"name": "Burkholderia phage JG068", "rank": "Species"}, "1232754": {"name": "Tepovirus", "rank": "Genus"}, "1307802": {"name": "Unclassified Pegivirus", "rank": "No rank"}, "1144929": {"name": "Salinispora arenicola CNQ748", "rank": "Strain"}, "1307803": {"name": "Equine pegivirus 1", "rank": "Species"}, "219704": {"name": "Avian adeno-associated virus ATCC VR-865", "rank": "Species"}, "1223": {"name": "Prochlorothrix hollandica", "rank": "Species"}, "1222": {"name": "Prochlorothrix", "rank": "Genus"}, "1221": {"name": "Prochlorotrichaceae", "rank": "Family"}, "1227": {"name": "Nitrosococcus", "rank": "Genus"}, "1224": {"name": "Proteobacteria", "rank": "Phylum"}, "1165943": {"name": "Escherichia coli O111:H8 str. CVM9574", "rank": "Strain"}, "1229": {"name": "Nitrosococcus oceani", "rank": "Species"}, "1384632": {"name": "Tomato leaf curl Gandhinagar betasatellite", "rank": "Species"}, "1384631": {"name": "Tomato leaf curl Gandhinagar virus", "rank": "Species"}, "158045": {"name": "Phaeomoniella", "rank": "Genus"}, "158046": {"name": "Phaeomoniella chlamydospora", "rank": "Species"}, "1457996": {"name": "Equus asinus papillomavirus AA-2014", "rank": "Species"}, "278993": {"name": "Thermincola", "rank": "Genus"}, "347328": {"name": "Pseudomonas phage M6", "rank": "Species"}, "637987": {"name": "Streptococcus pneumoniae str. Canada MDR_19A", "rank": "Strain"}, "1281075": {"name": "Escherichia coli HVH 142 (4-5627451)", "rank": "Strain"}, "637988": {"name": "Streptococcus pneumoniae str. Canada MDR_19F", "rank": "Strain"}, "347327": {"name": "Pseudomonas phage PA11", "rank": "Species"}, "347326": {"name": "Pseudomonas phage 119X", "rank": "Species"}, "347325": {"name": "Pseudomonas phage 73", "rank": "Species"}, "347324": {"name": "Pseudomonas phage F10", "rank": "Species"}, "470213": {"name": "Unclassified Deltapapillomavirus", "rank": "No rank"}, "470214": {"name": "Capreolus capreolus papillomavirus 1", "rank": "Strain"}, "399548": {"name": "Desulfocurvus vexinensis", "rank": "Species"}, "399549": {"name": "Metallosphaera sedula DSM 5348", "rank": "Strain"}, "36845": {"name": "Clostridium intestinale", "rank": "Species"}, "36343": {"name": "Lactococcus phage bIL67", "rank": "Species"}, "1397531": {"name": "Labrenzia sp. C1B70", "rank": "Species"}, "1397530": {"name": "Labrenzia sp. C1B10", "rank": "Species"}, "1397533": {"name": "Marinobacter sp. EN3", "rank": "Species"}, "1397532": {"name": "Marinobacter sp. EVN1", "rank": "Species"}, "1563222": {"name": "Citrobacter sp. CIP 55.13", "rank": "Species"}, "1419814": {"name": "Streptococcus sp. VT 162", "rank": "Species"}, "1439330": {"name": "Enterobacter cloacae MGH 54", "rank": "Strain"}, "1439331": {"name": "Lelliottia amnigena CHS 78", "rank": "Strain"}, "1281077": {"name": "Escherichia coli HVH 144 (4-4451937)", "rank": "Strain"}, "319475": {"name": "Clostridium lundense", "rank": "Species"}, "1162287": {"name": "Mycobacterium abscessus M115", "rank": "Strain"}, "441772": {"name": "Clostridium botulinum F str. Langeland", "rank": "Strain"}, "1392476": {"name": "Staphylococcus aureus subsp. aureus 6850", "rank": "Strain"}, "1207470": {"name": "Streptococcus pyogenes M1 476", "rank": "Strain"}, "1438738": {"name": "Klebsiella pneumoniae CHS 32", "rank": "Strain"}, "1027292": {"name": "Sporosarcina newyorkensis 2681", "rank": "Strain"}, "936596": {"name": "Lachnoanaerobaculum sp. MSX33", "rank": "Species"}, "936594": {"name": "Lachnoanaerobaculum sp. ICM7", "rank": "Species"}, "759851": {"name": "Sporosarcina newyorkensis", "rank": "Species"}, "83129": {"name": "Lactococcus phage P008", "rank": "Strain"}, "186538": {"name": "Zaire ebolavirus", "rank": "Species"}, "1315160": {"name": "Acinetobacter baumannii TG22190", "rank": "Strain"}, "1315161": {"name": "Acinetobacter baumannii TG22192", "rank": "Strain"}, "1315162": {"name": "Acinetobacter baumannii TG22194", "rank": "Strain"}, "1315163": {"name": "Acinetobacter baumannii TG22196", "rank": "Strain"}, "1315164": {"name": "Acinetobacter baumannii TG22198", "rank": "Strain"}, "1315165": {"name": "Acinetobacter baumannii TG22202", "rank": "Strain"}, "1315166": {"name": "Acinetobacter baumannii TG22204", "rank": "Strain"}, "1315167": {"name": "Acinetobacter baumannii TG22212", "rank": "Strain"}, "1315168": {"name": "Acinetobacter baumannii TG22214", "rank": "Strain"}, "1315169": {"name": "Acinetobacter baumannii TG22332", "rank": "Strain"}, "85008": {"name": "Micromonosporineae", "rank": "Suborder"}, "85009": {"name": "Propionibacterineae", "rank": "Suborder"}, "147802": {"name": "Lactobacillus iners", "rank": "Species"}, "716928": {"name": "Ensifer sojae CCBAU 05684", "rank": "Strain"}, "1041153": {"name": "Sinorhizobium meliloti GVPV12", "rank": "Strain"}, "1329835": {"name": "Enterobacter sp. BWH 27", "rank": "Species"}, "1329834": {"name": "Enterobacter sp. MGH 38", "rank": "Species"}, "1329837": {"name": "Enterobacter sp. BWH 39", "rank": "Species"}, "1329836": {"name": "Enterobacter sp. BWH 37", "rank": "Species"}, "1329831": {"name": "Enterobacter sp. MGH 33", "rank": "Species"}, "1329830": {"name": "Enterobacter sp. MGH 26", "rank": "Species"}, "1329833": {"name": "Enterobacter sp. MGH 37", "rank": "Species"}, "1329832": {"name": "Enterobacter sp. MGH 34", "rank": "Species"}, "76258": {"name": "Vibrio rumoiensis", "rank": "Species"}, "1329839": {"name": "Enterobacter sp. BIDMC 27", "rank": "Species"}, "1329838": {"name": "Enterobacter sp. BIDMC 26", "rank": "Species"}, "404235": {"name": "Maritimibacter", "rank": "Genus"}, "454154": {"name": "Paraprevotella clara", "rank": "Species"}, "1288493": {"name": "Staphylococcus aureus subsp. aureus S1800", "rank": "Strain"}, "404236": {"name": "Maritimibacter alkaliphilus", "rank": "Species"}, "1288494": {"name": "Nitrosospira sp. APG3", "rank": "Species"}, "73010": {"name": "Aeromonas encheleia", "rank": "Species"}, "454159": {"name": "Kiloniella", "rank": "Genus"}, "1191283": {"name": "Helicobacter pylori FD577", "rank": "Strain"}, "1191282": {"name": "Helicobacter pylori FD568", "rank": "Strain"}, "1191281": {"name": "Helicobacter pylori FD506", "rank": "Strain"}, "1191280": {"name": "Helicobacter pylori FD430", "rank": "Strain"}, "1191287": {"name": "Helicobacter pylori GC26", "rank": "Strain"}, "1191286": {"name": "Helicobacter pylori FD719", "rank": "Strain"}, "1191285": {"name": "Helicobacter pylori FD703", "rank": "Strain"}, "1191284": {"name": "Helicobacter pylori FD662", "rank": "Strain"}, "619300": {"name": "Spathaspora passalidarum NRRL Y-27907", "rank": "Strain"}, "741093": {"name": "Escherichia coli Xuzhou21", "rank": "Strain"}, "741091": {"name": "Rahnella sp. Y9602", "rank": "Species"}, "327160": {"name": "Candidatus Accumulibacter phosphatis", "rank": "Species"}, "396005": {"name": "Gilvimarinus chinensis", "rank": "Species"}, "383381": {"name": "Erythrobacter sp. JL475", "rank": "Species"}, "502346": {"name": "Escherichia coli O157:H7 str. TW14588", "rank": "Strain"}, "502347": {"name": "Escherichia albertii TW07627", "rank": "Strain"}, "752790": {"name": "Escherichia coli CUMT8", "rank": "Strain"}, "1254425": {"name": "Porcine astrovirus 3", "rank": "Species"}, "1007122": {"name": "Marinimicrobia bacterium SCGC AAA160-C11", "rank": "Species"}, "1160769": {"name": "Salmonella enterica subsp. enterica serovar Worthington", "rank": "Strain"}, "1505946": {"name": "Mesorhizobium sp. SOD10", "rank": "Species"}, "62059": {"name": "Shallot yellow stripe virus", "rank": "Species"}, "93217": {"name": "Pandoraea", "rank": "Genus"}, "1293895": {"name": "Tropheryma whipplei str. Art1", "rank": "Strain"}, "1293897": {"name": "Tropheryma whipplei str. Endo32", "rank": "Strain"}, "1293896": {"name": "Tropheryma whipplei str. Dig15", "rank": "Strain"}, "213465": {"name": "Syntrophobacteraceae", "rank": "Family"}, "352927": {"name": "Unclassified Crinivirus", "rank": "No rank"}, "352926": {"name": "Unclassified Astroviridae", "rank": "No rank"}, "213468": {"name": "Syntrophaceae", "rank": "Family"}, "405440": {"name": "Xylella fastidiosa M12", "rank": "Strain"}, "78395": {"name": "Sugarcane streak Reunion virus", "rank": "Species"}, "388741": {"name": "Bacillus selenatarsenatis", "rank": "Species"}, "78398": {"name": "Pectobacterium carotovorum subsp. odoriferum", "rank": "Subspecies"}, "487904": {"name": "Xanthomonas hortorum pv. carotae", "rank": "Strain"}, "1238424": {"name": "Haloquadratum walsbyi J07HQW1", "rank": "Strain"}, "1246650": {"name": "Blechum interveinal chlorosis virus", "rank": "Species"}, "388747": {"name": "Unclassified Verrucomicrobiales (miscellaneous)", "rank": "No rank"}, "337479": {"name": "Rickettsia endosymbiont of Bemisia tabaci", "rank": "Species"}, "1448431": {"name": "Mycobacterium tuberculosis TKK_03_0096", "rank": "Strain"}, "1448430": {"name": "Mycobacterium tuberculosis TKK_03_0094", "rank": "Strain"}, "1448433": {"name": "Mycobacterium tuberculosis TKK_03_0099", "rank": "Strain"}, "1448432": {"name": "Mycobacterium tuberculosis TKK_03_0098", "rank": "Strain"}, "1448435": {"name": "Mycobacterium tuberculosis TKK_03_0101", "rank": "Strain"}, "1448434": {"name": "Mycobacterium tuberculosis TKK_03_0100", "rank": "Strain"}, "1448437": {"name": "Mycobacterium tuberculosis TKK_03_0103", "rank": "Strain"}, "1448436": {"name": "Mycobacterium tuberculosis TKK_03_0102", "rank": "Strain"}, "1448439": {"name": "Mycobacterium tuberculosis TKK_03_0105", "rank": "Strain"}, "565995": {"name": "Bundibugyo virus", "rank": "Species"}, "1238423": {"name": "Salinibacter sp. J07SB67", "rank": "Species"}, "998520": {"name": "Pseudoalteromonas sp. NW 4327", "rank": "Species"}, "508460": {"name": "Cloacibacillus evryensis", "rank": "Species"}, "1121129": {"name": "Butyricimonas synergistica DSM 23225", "rank": "Strain"}, "266749": {"name": "Chryseobacterium jeonii", "rank": "Species"}, "266748": {"name": "Chryseobacterium antarcticum", "rank": "Species"}, "1249676": {"name": "Grapevine endophyte endornavirus", "rank": "Species"}, "1238422": {"name": "Streptococcus pneumoniae 357", "rank": "Strain"}, "596495": {"name": "Sciscionella", "rank": "Genus"}, "909613": {"name": "Actinokineospora sp. EG49", "rank": "Species"}, "406340": {"name": "Ralstonia phage RSA1", "rank": "Species"}, "11320": {"name": "Influenza A virus", "rank": "Species"}, "1151339": {"name": "Peptoclostridium difficile DA00191", "rank": "Strain"}, "1151338": {"name": "Peptoclostridium difficile DA00189", "rank": "Strain"}, "687351": {"name": "Torque teno virus 12", "rank": "Species"}, "1151332": {"name": "Peptoclostridium difficile DA00154", "rank": "Strain"}, "1151331": {"name": "Peptoclostridium difficile DA00149", "rank": "Strain"}, "1151330": {"name": "Peptoclostridium difficile DA00145", "rank": "Strain"}, "1151337": {"name": "Peptoclostridium difficile DA00183", "rank": "Strain"}, "687354": {"name": "Torque teno virus 15", "rank": "Species"}, "1151335": {"name": "Peptoclostridium difficile DA00167", "rank": "Strain"}, "1151334": {"name": "Peptoclostridium difficile DA00165", "rank": "Strain"}, "935557": {"name": "Sinorhizobium arboris LMG 14919", "rank": "Strain"}, "935554": {"name": "Rhizobium leguminosarum bv. viciae WSM1481", "rank": "Strain"}, "935553": {"name": "Rhizobium leguminosarum bv. viciae TOM", "rank": "Strain"}, "935550": {"name": "Rhizobium leguminosarum bv. trifolii SRDI943", "rank": "Strain"}, "1446558": {"name": "Escherichia coli O121:H19 str. 2009EL1302", "rank": "Strain"}, "1154970": {"name": "Streptococcus agalactiae GB01003", "rank": "Strain"}, "1446559": {"name": "Escherichia coli O121:H19 str. 2009EL1412", "rank": "Strain"}, "75922": {"name": "Mycobacterium tusciae", "rank": "Species"}, "1284808": {"name": "Klebsiella pneumoniae UHKPC06", "rank": "Strain"}, "1284809": {"name": "Klebsiella pneumoniae UHKPC02", "rank": "Strain"}, "1284806": {"name": "Klebsiella pneumoniae UHKPC18", "rank": "Strain"}, "1284807": {"name": "Klebsiella pneumoniae UHKPC31", "rank": "Strain"}, "1284804": {"name": "Klebsiella pneumoniae UHKPC07", "rank": "Strain"}, "1284805": {"name": "Klebsiella pneumoniae UHKPC17", "rank": "Strain"}, "1284802": {"name": "Klebsiella pneumoniae UHKPC33", "rank": "Strain"}, "1284803": {"name": "Klebsiella pneumoniae UHKPC59", "rank": "Strain"}, "1284800": {"name": "Klebsiella pneumoniae UHKPC61", "rank": "Strain"}, "1336252": {"name": "Staphylococcus aureus SA16", "rank": "Strain"}, "1345598": {"name": "Helicobacter pylori SA216C", "rank": "Strain"}, "1345599": {"name": "Helicobacter pylori SA220A", "rank": "Strain"}, "1345594": {"name": "Helicobacter pylori SA214A", "rank": "Strain"}, "1345595": {"name": "Helicobacter pylori SA214C", "rank": "Strain"}, "1345596": {"name": "Helicobacter pylori SA215C", "rank": "Strain"}, "1345590": {"name": "Helicobacter pylori SA210A", "rank": "Strain"}, "1345591": {"name": "Helicobacter pylori SA210C", "rank": "Strain"}, "1345592": {"name": "Helicobacter pylori SA213A", "rank": "Strain"}, "1345593": {"name": "Helicobacter pylori SA213C", "rank": "Strain"}, "79917": {"name": "Japanese yam mosaic virus", "rank": "Species"}, "183192": {"name": "Escherichia coli O157:H-", "rank": "Strain"}, "1169228": {"name": "Brucella melitensis UK3/06", "rank": "Strain"}, "1497681": {"name": "Listeriaceae bacterium FSL M6-0635", "rank": "Species"}, "129141": {"name": "Citrus leaf blotch virus", "rank": "Species"}, "79918": {"name": "Broad bean necrosis virus", "rank": "Species"}, "129143": {"name": "Cherry necrotic rusty mottle virus", "rank": "Species"}, "907348": {"name": "Treponema saccharophilum DSM 2985", "rank": "Strain"}, "401618": {"name": "Candidatus Riesia", "rank": "Genus"}, "401619": {"name": "Candidatus Riesia pediculicola", "rank": "Species"}, "1121468": {"name": "Desulfovirgula thermocuniculi DSM 16036", "rank": "Strain"}, "1215915": {"name": "Lactococcus raffinolactis 4877", "rank": "Strain"}, "1521389": {"name": "McMurdo Ice Shelf pond-associated circular DNA virus-5", "rank": "Species"}, "1121467": {"name": "Desulfovibrio zosterae DSM 11974", "rank": "Strain"}, "401614": {"name": "Francisella tularensis subsp. novicida U112", "rank": "Strain"}, "1121462": {"name": "Desulfovibrio putealis DSM 16056", "rank": "Strain"}, "889306": {"name": "Jeotgalibacillus soli Cunha et al. 2012", "rank": "Species"}, "319": {"name": "Pseudomonas syringae pv. phaseolicola", "rank": "Strain"}, "318": {"name": "Pseudomonas syringae pv. glycinea", "rank": "Strain"}, "317": {"name": "Pseudomonas syringae", "rank": "Species"}, "316": {"name": "Pseudomonas stutzeri", "rank": "Species"}, "709991": {"name": "Odoribacter splanchnicus DSM 20712", "rank": "Strain"}, "885383": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. CDC_2010K_1729", "rank": "Strain"}, "1534549": {"name": "Unclassified Gallivirus", "rank": "No rank"}, "120961": {"name": "Roseiflexus", "rank": "Genus"}, "120962": {"name": "Roseiflexus castenholzii", "rank": "Species"}, "635076": {"name": "Ageratum leaf curl Cameroon betasatellite", "rank": "Species"}, "306254": {"name": "Campylobacter coli RM2228", "rank": "Strain"}, "885380": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. CDC_2010K_1558", "rank": "Strain"}, "184751": {"name": "Vitivirus", "rank": "Genus"}, "1229172": {"name": "Leptolyngbya sp. KIOST-1", "rank": "Species"}, "184754": {"name": "Simian picornavirus strain N203", "rank": "Species"}, "903916": {"name": "Acinetobacter sp. WC-136", "rank": "Species"}, "903917": {"name": "Acinetobacter sp. WC-487", "rank": "Species"}, "903914": {"name": "Acinetobacter baumannii IS-58", "rank": "Strain"}, "903915": {"name": "Acinetobacter sp. WC-141", "rank": "Species"}, "903912": {"name": "Acinetobacter baumannii IS-116", "rank": "Strain"}, "414778": {"name": "Planococcus donghaensis", "rank": "Species"}, "903910": {"name": "Acinetobacter baumannii OIFC110", "rank": "Strain"}, "1048830": {"name": "Mycoplasma iowae 695", "rank": "Strain"}, "903918": {"name": "Acinetobacter sp. WC-323", "rank": "Species"}, "903919": {"name": "Acinetobacter baumannii WC-348", "rank": "Strain"}, "155322": {"name": "Bacillus toyonensis", "rank": "Species"}, "449972": {"name": "Chelativorans", "rank": "Genus"}, "866345": {"name": "Helicobacter pylori F30", "rank": "Strain"}, "412967": {"name": "Vibrio cholerae MAK 757", "rank": "Strain"}, "1352943": {"name": "Vibrio harveyi E385", "rank": "Strain"}, "11242": {"name": "Rinderpest virus (strain Kabete O)", "rank": "Strain"}, "11241": {"name": "Rinderpest virus", "rank": "Species"}, "95341": {"name": "Sapovirus", "rank": "Genus"}, "11246": {"name": "Bovine respiratory syncytial virus", "rank": "Species"}, "11245": {"name": "Pneumovirus", "rank": "Genus"}, "11244": {"name": "Pneumovirinae", "rank": "Subfamily"}, "885386": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. CDC_2010K_1457", "rank": "Strain"}, "1205910": {"name": "Nocardiopsis alba ATCC BAA-2165", "rank": "Strain"}, "55802": {"name": "Thermococcus barophilus", "rank": "Species"}, "58839": {"name": "Encephalitozoon intestinalis", "rank": "Species"}, "482058": {"name": "Ralstonia phage RSL1", "rank": "Species"}, "1182177": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN000752", "rank": "Strain"}, "885387": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. CDC_2010K_1747", "rank": "Strain"}, "1160221": {"name": "Brucella melitensis UK22/06", "rank": "Strain"}, "1160220": {"name": "Brucella melitensis 64/150", "rank": "Strain"}, "1328359": {"name": "Brucella abortus B10-0091", "rank": "Strain"}, "1328358": {"name": "Brucella abortus B10-0018", "rank": "Strain"}, "1160225": {"name": "Brucella melitensis F8/01-155", "rank": "Strain"}, "1160224": {"name": "Brucella melitensis 66/59", "rank": "Strain"}, "1160227": {"name": "Brucella suis 63/198", "rank": "Strain"}, "1160226": {"name": "Brucella melitensis F2/06-6", "rank": "Strain"}, "1160229": {"name": "Brucella suis F12/02", "rank": "Strain"}, "1328352": {"name": "Brucella abortus 90-0737", "rank": "Strain"}, "1328351": {"name": "Brucella abortus 90-0775", "rank": "Strain"}, "1328350": {"name": "Brucella abortus 90-0742", "rank": "Strain"}, "1328357": {"name": "Brucella abortus 01-0065", "rank": "Strain"}, "1328356": {"name": "Brucella abortus 01-0585", "rank": "Strain"}, "484022": {"name": "Francisella philomiragia subsp. philomiragia ATCC 25017", "rank": "Strain"}, "1328354": {"name": "Brucella abortus 94-1313", "rank": "Strain"}, "12260": {"name": "Bean pod mottle virus", "rank": "Species"}, "12261": {"name": "Cowpea severe mosaic virus", "rank": "Species"}, "12262": {"name": "Red clover mottle virus", "rank": "Species"}, "12263": {"name": "Squash mosaic virus", "rank": "Species"}, "12264": {"name": "Cowpea mosaic virus", "rank": "Species"}, "12266": {"name": "Dianthovirus", "rank": "Genus"}, "12267": {"name": "Red clover necrotic mosaic virus", "rank": "Species"}, "12268": {"name": "Carnation ringspot virus", "rank": "Species"}, "12269": {"name": "Fabavirus", "rank": "Genus"}, "547163": {"name": "Mycobacterium vulneris", "rank": "Species"}, "5579": {"name": "Aureobasidium", "rank": "Genus"}, "1422017": {"name": "Mycobacterium tuberculosis TB_RSA101", "rank": "Strain"}, "1422016": {"name": "Mycobacterium tuberculosis TB_RSA100", "rank": "Strain"}, "1422015": {"name": "Mycobacterium tuberculosis TB_RSA99", "rank": "Strain"}, "1422014": {"name": "Mycobacterium tuberculosis TB_RSA98", "rank": "Strain"}, "936048": {"name": "Propionibacterium sp. 434-HC2", "rank": "Species"}, "1422012": {"name": "Mycobacterium tuberculosis TB_RSA96", "rank": "Strain"}, "1422011": {"name": "Mycobacterium tuberculosis TB_RSA95", "rank": "Strain"}, "655863": {"name": "Grosmannia clavigera kw1407", "rank": "Strain"}, "936046": {"name": "Agaricus bisporus var. bisporus H97", "rank": "Strain"}, "936047": {"name": "Propionibacterium sp. 409-HC1", "rank": "Species"}, "1422019": {"name": "Mycobacterium tuberculosis TB_RSA103", "rank": "Strain"}, "1422018": {"name": "Mycobacterium tuberculosis TB_RSA102", "rank": "Strain"}, "54032": {"name": "Mitosporic Orbiliaceae", "rank": "No rank"}, "1355528": {"name": "Helicobacter pylori UM065", "rank": "Strain"}, "1355529": {"name": "Helicobacter pylori UM067", "rank": "Strain"}, "928289": {"name": "Pigeon picornavirus B", "rank": "Species"}, "1100069": {"name": "Bacteroidetes Order II. Incertae sedis", "rank": "Order"}, "1471529": {"name": "Prochlorococcus sp. scB245a_521N3", "rank": "Species"}, "1471528": {"name": "Prochlorococcus sp. scB245a_521M10", "rank": "Species"}, "1471523": {"name": "Prochlorococcus sp. scB245a_520M11", "rank": "Species"}, "1471522": {"name": "Prochlorococcus sp. scB245a_520K10", "rank": "Species"}, "1471521": {"name": "Prochlorococcus sp. scB245a_520F22", "rank": "Species"}, "1471520": {"name": "Prochlorococcus sp. scB245a_520E22", "rank": "Species"}, "1471527": {"name": "Prochlorococcus sp. scB245a_521K15", "rank": "Species"}, "1471526": {"name": "Prochlorococcus sp. scB245a_521C8", "rank": "Species"}, "1471525": {"name": "Prochlorococcus sp. scB245a_521B10", "rank": "Species"}, "1471524": {"name": "Prochlorococcus sp. scB245a_521A19", "rank": "Species"}, "348823": {"name": "Maize Iranian mosaic virus", "rank": "Species"}, "1444149": {"name": "Escherichia coli 2-052-05_S3_C2", "rank": "Strain"}, "1444148": {"name": "Escherichia coli 2-011-08_S3_C2", "rank": "Strain"}, "1444145": {"name": "Escherichia coli 6-319-05_S3_C1", "rank": "Strain"}, "1444144": {"name": "Escherichia coli 6-175-07_S3_C1", "rank": "Strain"}, "1444147": {"name": "Escherichia coli 2-005-03_S3_C2", "rank": "Strain"}, "1444146": {"name": "Escherichia coli 6-537-08_S3_C1", "rank": "Strain"}, "1444141": {"name": "Escherichia coli 3-373-03_S3_C1", "rank": "Strain"}, "1444140": {"name": "Escherichia coli 3-267-03_S3_C1", "rank": "Strain"}, "1444143": {"name": "Escherichia coli 4-203-08_S3_C1", "rank": "Strain"}, "1444142": {"name": "Escherichia coli 3-475-03_S3_C1", "rank": "Strain"}, "326202": {"name": "Vanilla distortion mosaic virus", "rank": "Species"}, "11795": {"name": "Friend murine leukemia virus", "rank": "Strain"}, "94700": {"name": "Dicliptera yellow mottle virus", "rank": "Species"}, "1335230": {"name": "Pseudomonas phage PaBG", "rank": "Species"}, "1281165": {"name": "Escherichia coli KOEGE 62 (175a)", "rank": "Strain"}, "2099": {"name": "Mycoplasma hyopneumoniae", "rank": "Species"}, "2098": {"name": "Mycoplasma hominis", "rank": "Species"}, "1408129": {"name": "Mesocricetus auratus papillomavirus 1", "rank": "Species"}, "2093": {"name": "Mycoplasma", "rank": "Genus"}, "2092": {"name": "Mycoplasmataceae", "rank": "Family"}, "2095": {"name": "Mycoplasma capricolum", "rank": "Species"}, "2094": {"name": "Mycoplasma arginini", "rank": "Species"}, "2097": {"name": "Mycoplasma genitalium", "rank": "Species"}, "2096": {"name": "Mycoplasma gallisepticum", "rank": "Species"}, "1203631": {"name": "Propionibacterium sp. KPL2003", "rank": "Species"}, "1203632": {"name": "Corynebacterium sp. KPL2004", "rank": "Species"}, "1203633": {"name": "Propionibacterium sp. KPL2005", "rank": "Species"}, "1203634": {"name": "Propionibacterium sp. KPL2008", "rank": "Species"}, "1203635": {"name": "Propionibacterium sp. KPL2009", "rank": "Species"}, "64300": {"name": "Modoc virus", "rank": "Species"}, "422282": {"name": "Candidate division WWE3", "rank": "No rank"}, "1081103": {"name": "Metarhizium album ARSEF 1941", "rank": "Strain"}, "336809": {"name": "Candidatus Sulcia", "rank": "Genus"}, "1136428": {"name": "Salinispora arenicola CNT850", "rank": "Strain"}, "1136429": {"name": "Salinispora arenicola CNR921", "rank": "Strain"}, "1136424": {"name": "Salinispora pacifica CNT603", "rank": "Strain"}, "1136425": {"name": "Salinispora arenicola CNB458", "rank": "Strain"}, "1136426": {"name": "Salinispora arenicola CNX482", "rank": "Strain"}, "1136427": {"name": "Salinispora arenicola CNH646", "rank": "Strain"}, "927576": {"name": "Pan troglodytes verus polyomavirus 1b", "rank": "Strain"}, "1136421": {"name": "Salinispora pacifica CNT138", "rank": "Strain"}, "1136422": {"name": "Salinispora pacifica CNT148", "rank": "Strain"}, "1136423": {"name": "Salinispora pacifica CNT150", "rank": "Strain"}, "649639": {"name": "Bacillus cellulosilyticus DSM 2522", "rank": "Strain"}, "290028": {"name": "Human coronavirus HKU1", "rank": "Species"}, "330922": {"name": "Psychrobacter cryohalolentis", "rank": "Species"}, "507475": {"name": "Tomato leaf curl Cotabato virus", "rank": "Species"}, "507474": {"name": "Tomato leaf curl Cebu virus", "rank": "Species"}, "507476": {"name": "Tomato leaf curl Mindanao virus", "rank": "Species"}, "652706": {"name": "Oribacterium sp. oral taxon 078", "rank": "Species"}, "1132855": {"name": "Methylotenera mobilis 13", "rank": "Strain"}, "877468": {"name": "Salmonella enterica subsp. enterica serovar Newport str. USMARC-S3124.1", "rank": "Strain"}, "652708": {"name": "Bacteroidetes oral taxon 274", "rank": "Species"}, "1463831": {"name": "Streptomyces sp. NRRL B-2375", "rank": "Species"}, "1513235": {"name": "Cafeteria roenbergensis virus", "rank": "Species"}, "1513236": {"name": "Cuevavirus", "rank": "Genus"}, "1513237": {"name": "Lloviu cuevavirus", "rank": "Species"}, "1513233": {"name": "Benyviridae", "rank": "Family"}, "37482": {"name": "Laceyella sacchari", "rank": "Species"}, "1513239": {"name": "Dyolambdapapillomavirus", "rank": "Genus"}, "37487": {"name": "Marichromatium purpuratum", "rank": "Species"}, "994837": {"name": "Candidatus Parvarchaeum acidiphilum ARMAN-4_'5-way FS'", "rank": "Strain"}, "31507": {"name": "Anticarsia gemmatalis nucleopolyhedrovirus", "rank": "Species"}, "1460691": {"name": "Pseudomonas sp. P482", "rank": "Species"}, "31503": {"name": "Maize white line mosaic satellite virus", "rank": "Species"}, "167019": {"name": "Pelargonium line pattern virus", "rank": "Species"}, "669008": {"name": "Enterobacteria phage 285P", "rank": "Species"}, "209252": {"name": "Nocardia asiatica", "rank": "Species"}, "1157486": {"name": "Enterococcus faecium EnGen0191", "rank": "Strain"}, "1077859": {"name": "Tomato chlorotic leaf distortion virus", "rank": "Species"}, "1355531": {"name": "Helicobacter pylori UM114", "rank": "Strain"}, "1157485": {"name": "Enterococcus faecium EnGen0190", "rank": "Strain"}, "1157484": {"name": "Enterococcus faecium EnGen0189", "rank": "Strain"}, "937835": {"name": "Pseudomonas phage PA1/KOR/2010", "rank": "Species"}, "206349": {"name": "Hydrogenophilaceae", "rank": "Family"}, "1173929": {"name": "Salmonella enterica subsp. enterica serovar Typhimurium var. Copenhagen str. 0084", "rank": "Strain"}, "212045": {"name": "Bacillus anthracis str. Western North America USA6153", "rank": "Strain"}, "212042": {"name": "Anaplasma phagocytophilum str. HZ", "rank": "Strain"}, "510516": {"name": "Aspergillus oryzae RIB40", "rank": "Strain"}, "1134459": {"name": "Pseudomonas aeruginosa PADK2_CF510", "rank": "Strain"}, "290399": {"name": "Arthrobacter sp. FB24", "rank": "Species"}, "290398": {"name": "Chromohalobacter salexigens DSM 3043", "rank": "Strain"}, "1134453": {"name": "Escherichia coli OK1114", "rank": "Strain"}, "290397": {"name": "Anaeromyxobacter dehalogenans 2CP-C", "rank": "Strain"}, "1134457": {"name": "Microcystis aeruginosa TAIHU98", "rank": "Strain"}, "1134456": {"name": "Vibrio cholerae IEC224", "rank": "Strain"}, "1134455": {"name": "Klebsiella oxytoca 11492-1", "rank": "Strain"}, "1134454": {"name": "Propionibacterium acnes HL096PA1", "rank": "Strain"}, "399781": {"name": "Paramecium bursaria Chlorella virus FR483", "rank": "Strain"}, "61645": {"name": "Enterobacter asburiae", "rank": "Species"}, "204270": {"name": "Pseudomonas phage phiKMV", "rank": "Species"}, "1306990": {"name": "Streptomyces sp. R1-NS-10", "rank": "Species"}, "857293": {"name": "Caloramator australicus RC3", "rank": "Strain"}, "857292": {"name": "Streptococcus intermedius F0395", "rank": "Strain"}, "857291": {"name": "Prevotella histicola F0411", "rank": "Strain"}, "857290": {"name": "Scardovia wiggsiae F0424", "rank": "Strain"}, "1123501": {"name": "Wenxinia marina DSM 24838", "rank": "Strain"}, "1123500": {"name": "Weissella halotolerans DSM 20190", "rank": "Strain"}, "1123503": {"name": "Woodsholea maritima DSM 17123", "rank": "Strain"}, "1123502": {"name": "Wohlfahrtiimonas chitiniclastica DSM 18708", "rank": "Strain"}, "1123504": {"name": "Xenophilus azovorans DSM 13620", "rank": "Strain"}, "1123507": {"name": "Yaniella halotolerans DSM 15476", "rank": "Strain"}, "1435463": {"name": "Bifidobacterium thermacidophilum subsp. porcinum DSM 17755", "rank": "Strain"}, "1123509": {"name": "Zooshikella ganghwensis DSM 15267", "rank": "Strain"}, "1055803": {"name": "Pseudoalteromonas sp. TB51", "rank": "Species"}, "1055806": {"name": "Psychrobacter sp. AC24", "rank": "Species"}, "157268": {"name": "Helicobacter winghamensis", "rank": "Species"}, "33060": {"name": "Yersinia mollaretii", "rank": "Species"}, "1354314": {"name": "Cardinium endosymbiont cBtQ1 of Bemisia tabaci", "rank": "Strain"}, "363716": {"name": "Nora virus", "rank": "Species"}, "721927": {"name": "Jaapiales", "rank": "Order"}, "760760": {"name": "Streptococcus pneumoniae GA11184", "rank": "Strain"}, "909954": {"name": "Lactobacillus johnsonii DPC 6026", "rank": "Strain"}, "760763": {"name": "Streptococcus pneumoniae GA11304", "rank": "Strain"}, "992099": {"name": "Helicobacter pylori Hp P-2b", "rank": "Strain"}, "760765": {"name": "Streptococcus pneumoniae GA11663", "rank": "Strain"}, "760766": {"name": "Streptococcus pneumoniae GA11856", "rank": "Strain"}, "760767": {"name": "Streptococcus pneumoniae GA13224", "rank": "Strain"}, "992095": {"name": "Helicobacter pylori Hp H-24c", "rank": "Strain"}, "992094": {"name": "Helicobacter pylori Hp H-24b", "rank": "Strain"}, "992091": {"name": "Helicobacter pylori Hp P-74", "rank": "Strain"}, "992092": {"name": "Helicobacter pylori Hp H-5b", "rank": "Strain"}, "1455601": {"name": "Escherichia coli G3/10", "rank": "Strain"}, "1455602": {"name": "Klebsiella pneumoniae 4006", "rank": "Strain"}, "1455603": {"name": "Klebsiella pneumoniae 4541-2", "rank": "Strain"}, "1455604": {"name": "Klebsiella pneumoniae 11227-1", "rank": "Strain"}, "1455605": {"name": "Klebsiella pneumoniae 7699", "rank": "Strain"}, "1129035": {"name": "Macroptilium yellow vein virus", "rank": "Species"}, "1455607": {"name": "Kosakonia radicincitans UMEnt01/12", "rank": "Strain"}, "1455608": {"name": "Haladaptatus cibarius D43", "rank": "Strain"}, "1455609": {"name": "Haloterrigena jeotgali A29", "rank": "Strain"}, "1159028": {"name": "Helicobacter pylori GAM119Bi", "rank": "Strain"}, "120793": {"name": "Mycobacterium avium complex (MAC)", "rank": "Species group"}, "1295009": {"name": "Candidatus Methanomassiliicoccus intestinalis Issoire-Mx1", "rank": "Strain"}, "983548": {"name": "Dokdonia sp. 4H-3-7-5", "rank": "Species"}, "1159026": {"name": "Helicobacter pylori GAM117Ai", "rank": "Strain"}, "983545": {"name": "Glaciecola sp. 4H-3-7+YE-5", "rank": "Species"}, "983544": {"name": "Lacinutrix sp. 5H-3-7-4", "rank": "Species"}, "1159025": {"name": "Helicobacter pylori GAM115Ai", "rank": "Strain"}, "384359": {"name": "Ralstonia phage RSM1", "rank": "Species"}, "110618": {"name": "Nectriaceae", "rank": "Family"}, "1312904": {"name": "Legionella pneumophila subsp. pneumophila LPE509", "rank": "Strain"}, "1471448": {"name": "Prochlorococcus sp. scB241_527L15", "rank": "Species"}, "1471449": {"name": "Prochlorococcus sp. scB241_527L16", "rank": "Species"}, "1224919": {"name": "Staphylococcus aureus M0104", "rank": "Strain"}, "1159021": {"name": "Helicobacter pylori GAM103Bi", "rank": "Strain"}, "151276": {"name": "Bacteroides coprosuis", "rank": "Species"}, "1288121": {"name": "Alistipes senegalensis", "rank": "Species"}, "1288120": {"name": "Anaerococcus senegalensis", "rank": "Species"}, "1288122": {"name": "Edwardsiella piscicida C07-087", "rank": "Strain"}, "1341711": {"name": "Mycobacterium tuberculosis PanR0202", "rank": "Strain"}, "181486": {"name": "Pyrobaculum calidifontis", "rank": "Species"}, "519851": {"name": "Ureaplasma parvum serovar 6 str. ATCC 27818", "rank": "Strain"}, "1388058": {"name": "Staphylococcus aureus M0099", "rank": "Strain"}, "1388059": {"name": "Staphylococcus aureus M0100", "rank": "Strain"}, "1388056": {"name": "Staphylococcus aureus M0097", "rank": "Strain"}, "1388057": {"name": "Staphylococcus aureus M0098", "rank": "Strain"}, "1388054": {"name": "Staphylococcus aureus M0095", "rank": "Strain"}, "1388055": {"name": "Staphylococcus aureus M0096", "rank": "Strain"}, "1388052": {"name": "Staphylococcus aureus M0093", "rank": "Strain"}, "1388053": {"name": "Staphylococcus aureus M0094", "rank": "Strain"}, "1388050": {"name": "Staphylococcus aureus M0089", "rank": "Strain"}, "1413445": {"name": "Staphylococcus aureus M520-1", "rank": "Strain"}, "190905": {"name": "Lactobacillus kefiranofaciens subsp. kefiranofaciens", "rank": "Subspecies"}, "1079469": {"name": "Salmonella enterica subsp. enterica serovar Saintpaul str. JO2008", "rank": "Strain"}, "1079466": {"name": "Bradyrhizobium elkanii USDA 3259", "rank": "Strain"}, "1079467": {"name": "Bradyrhizobium japonicum USDA 38", "rank": "Strain"}, "1079460": {"name": "Rhizobium mongolense USDA 1844", "rank": "Strain"}, "1410661": {"name": "Lachnospira multipara LB2003", "rank": "Strain"}, "1410660": {"name": "Lachnobacterium bovis C6A12", "rank": "Strain"}, "1410663": {"name": "Megasphaera elsdenii T81", "rank": "Strain"}, "1410662": {"name": "Lachnospira multipara MC2003", "rank": "Strain"}, "1410665": {"name": "Mitsuokella jalaludinii DSM 13811", "rank": "Strain"}, "1410664": {"name": "Methanobrevibacter wolinii SH", "rank": "Strain"}, "1410667": {"name": "Prevotella ruminicola Ga6B6", "rank": "Strain"}, "1410666": {"name": "Prevotella brevis P6B11", "rank": "Strain"}, "1410669": {"name": "Pseudomonas putida OUS82", "rank": "Strain"}, "1410668": {"name": "Proteiniclasticum ruminis DSM 24773", "rank": "Strain"}, "1306421": {"name": "Burkholderia pseudomallei MSHR5855", "rank": "Strain"}, "1306420": {"name": "Burkholderia pseudomallei MSHR5848", "rank": "Strain"}, "481743": {"name": "Paenibacillus sp. Y412MC10", "rank": "Species"}, "148447": {"name": "Burkholderia phymatum", "rank": "Species"}, "1265678": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 05.O.06", "rank": "Strain"}, "1265679": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 10.A.05", "rank": "Strain"}, "1265670": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 43.E.09", "rank": "Strain"}, "1265671": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 65.H.72", "rank": "Strain"}, "1265672": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 70.E.05", "rank": "Strain"}, "1265673": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 01.O.05", "rank": "Strain"}, "1265674": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 72.A.52", "rank": "Strain"}, "1265675": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 48.E.08", "rank": "Strain"}, "1265676": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 53.F.08", "rank": "Strain"}, "1265677": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 58.E.08", "rank": "Strain"}, "714995": {"name": "Komagataeibacter hansenii ATCC 23769", "rank": "Strain"}, "1173798": {"name": "Salmonella enterica subsp. enterica serovar Albany str. ATCC 51960", "rank": "Strain"}, "1281254": {"name": "Escherichia coli UMEA 3609-1", "rank": "Strain"}, "1281255": {"name": "Escherichia coli UMEA 3617-1", "rank": "Strain"}, "1354302": {"name": "Aeromonas hydrophila 4AK4", "rank": "Strain"}, "1465809": {"name": "Clostridium senegalense", "rank": "Species"}, "1281256": {"name": "Escherichia coli UMEA 3632-1", "rank": "Strain"}, "555791": {"name": "Staphylococcus massiliensis", "rank": "Species"}, "538979": {"name": "Xanthomonas phage phiL7", "rank": "Species"}, "503361": {"name": "Flavobacterium sasangense", "rank": "Species"}, "985054": {"name": "Ruegeria halocynthiae", "rank": "Species"}, "985053": {"name": "Vulcanisaeta moutnovskia 768-28", "rank": "Strain"}, "1189": {"name": "Stigonematales", "rank": "Order"}, "1186": {"name": "Calothrix", "rank": "Genus"}, "1184": {"name": "Leptolyngbya boryana", "rank": "Species"}, "1185": {"name": "Rivulariaceae", "rank": "Family"}, "1182": {"name": "Scytonemataceae", "rank": "Family"}, "1043004": {"name": "Aureobasidium namibiae CBS 147.97", "rank": "Strain"}, "659495": {"name": "Catenovulum agarivorans YM01", "rank": "Strain"}, "1214205": {"name": "Streptococcus suis YS49", "rank": "Strain"}, "1214204": {"name": "Streptococcus suis YS46", "rank": "Strain"}, "1214207": {"name": "Streptococcus suis YS53", "rank": "Strain"}, "1214206": {"name": "Streptococcus suis YS50", "rank": "Strain"}, "1214201": {"name": "Streptococcus suis YS4", "rank": "Strain"}, "1214200": {"name": "Streptococcus suis YS39", "rank": "Strain"}, "1214203": {"name": "Streptococcus suis YS44", "rank": "Strain"}, "1214202": {"name": "Streptococcus suis YS43", "rank": "Strain"}, "118117": {"name": "Buchnera aphidicola (Uroleucon ambrosiae)", "rank": "Strain"}, "1214209": {"name": "Streptococcus suis YS56", "rank": "Strain"}, "1214208": {"name": "Streptococcus suis YS54", "rank": "Strain"}, "1388580": {"name": "Staphylococcus aureus M0789", "rank": "Strain"}, "1388581": {"name": "Staphylococcus aureus M0790", "rank": "Strain"}, "1388582": {"name": "Staphylococcus aureus M0791", "rank": "Strain"}, "1388583": {"name": "Staphylococcus aureus M0793", "rank": "Strain"}, "1388584": {"name": "Staphylococcus aureus M0794", "rank": "Strain"}, "1388585": {"name": "Staphylococcus aureus M0796", "rank": "Strain"}, "1317678": {"name": "Wolbachia pipientis wMelPop", "rank": "Strain"}, "1385755": {"name": "Synthetic Escherichia coli C321.deltaA", "rank": "Strain"}, "1388588": {"name": "Staphylococcus aureus M0801", "rank": "Strain"}, "1395587": {"name": "Paenibacillus sp. MAEPY2", "rank": "Species"}, "1395580": {"name": "Enterobacter sp. DC4", "rank": "Species"}, "715480": {"name": "Sunflower mild mosaic virus", "rank": "Species"}, "1298899": {"name": "Euryarchaeota archaeon SCGC AAA287-I03", "rank": "Species"}, "388408": {"name": "Labrenzia alexandrii", "rank": "Species"}, "1409761": {"name": "Staphylococcus aureus DAR5883", "rank": "Strain"}, "1394180": {"name": "Ralstonia solanacearum Rs-09-161", "rank": "Strain"}, "797515": {"name": "Lactobacillus parafarraginis F0439", "rank": "Strain"}, "797516": {"name": "Lactobacillus kisonensis F0435", "rank": "Strain"}, "193": {"name": "Azospirillum lipoferum", "rank": "Species"}, "192": {"name": "Azospirillum brasilense", "rank": "Species"}, "191": {"name": "Azospirillum", "rank": "Genus"}, "190": {"name": "Aquaspirillum serpens", "rank": "Species"}, "197": {"name": "Campylobacter jejuni", "rank": "Species"}, "196": {"name": "Campylobacter fetus", "rank": "Species"}, "195": {"name": "Campylobacter coli", "rank": "Species"}, "194": {"name": "Campylobacter", "rank": "Genus"}, "199": {"name": "Campylobacter concisus", "rank": "Species"}, "198": {"name": "Campylobacter hyointestinalis", "rank": "Species"}, "1407649": {"name": "Pseudomonas aeruginosa RB", "rank": "Strain"}, "712288": {"name": "Fusobacterium sp. oral taxon 370", "rank": "Species"}, "670888": {"name": "Escherichia coli 1827-70", "rank": "Strain"}, "1298894": {"name": "Euryarchaeota archaeon SCGC AAA287-N16", "rank": "Species"}, "1358413": {"name": "Lactobacillus plantarum AY01", "rank": "Strain"}, "1358412": {"name": "Acinetobacter baumannii EGD-HP18", "rank": "Strain"}, "40373": {"name": "Acinetobacter sp. CIP-A165", "rank": "Species"}, "1358410": {"name": "Campylobacter coli 15-537360", "rank": "Strain"}, "883168": {"name": "Streptococcus urinalis FB127-CNA-2", "rank": "Strain"}, "883169": {"name": "Turicella otitidis ATCC 51513", "rank": "Strain"}, "883164": {"name": "Staphylococcus lugdunensis ACS-027-V-Sch2", "rank": "Strain"}, "883165": {"name": "Campylobacter ureolyticus ACS-301-V-Sch3b", "rank": "Strain"}, "883166": {"name": "Staphylococcus simulans ACS-120-V-Sch1", "rank": "Strain"}, "883167": {"name": "Streptococcus intermedius F0413", "rank": "Strain"}, "883161": {"name": "Propionimicrobium lymphophilum ACS-093-V-SCH5", "rank": "Strain"}, "883162": {"name": "Enterococcus faecium FB129-CNAB4", "rank": "Strain"}, "883163": {"name": "Sphingobium yanoikuyae ATCC 51230", "rank": "Strain"}, "1454": {"name": "Bacillus azotoformans", "rank": "Species"}, "1455": {"name": "Bacillus badius", "rank": "Species"}, "1056830": {"name": "Mycobacterium phage Charlie", "rank": "Species"}, "1056831": {"name": "Mycobacterium phage Larva", "rank": "Species"}, "1450": {"name": "Alicyclobacillus acidoterrestris", "rank": "Species"}, "1452": {"name": "Bacillus atrophaeus", "rank": "Species"}, "1310992": {"name": "Acinetobacter baumannii 44327_8", "rank": "Strain"}, "1310990": {"name": "Acinetobacter baumannii 44327_6", "rank": "Strain"}, "1310991": {"name": "Acinetobacter baumannii 44327_7", "rank": "Strain"}, "1474807": {"name": "Mojiang virus", "rank": "Species"}, "223997": {"name": "Murine norovirus 1", "rank": "Strain"}, "931890": {"name": "Eremothecium cymbalariae DBVPG#7215", "rank": "Strain"}, "298975": {"name": "Turnip crinkle virus virulent satellite RNA C", "rank": "Strain"}, "298974": {"name": "Tobacco bushy top virus satellite-like RNA", "rank": "Species"}, "114727": {"name": "H1N1 subtype", "rank": "Strain"}, "114729": {"name": "H2N2 subtype", "rank": "Strain"}, "498055": {"name": "Arenimonas oryziterrae", "rank": "Species"}, "1157685": {"name": "Rhizobium sp. JGI 0001005-H05", "rank": "Species"}, "1157686": {"name": "Rhizobium sp. JGI 0001005-K05", "rank": "Species"}, "1157681": {"name": "Caulobacter sp. JGI 0001013-O16", "rank": "Species"}, "1157680": {"name": "Caulobacter sp. JGI 0001013-D04", "rank": "Species"}, "1157683": {"name": "Staphylococcus sp. JGI 0001002-I23", "rank": "Species"}, "539329": {"name": "Francisella philomiragia subsp. philomiragia ATCC 25015", "rank": "Strain"}, "1157689": {"name": "Caulobacter sp. JGI 0001010-J14", "rank": "Species"}, "685445": {"name": "Enterobacter aerogenes FGI35", "rank": "Strain"}, "185954": {"name": "Mal de Rio Cuarto virus", "rank": "Species"}, "700598": {"name": "Niastella koreensis GR20-10", "rank": "Strain"}, "1116482": {"name": "Pectobacterium phage phiTE", "rank": "Species"}, "700595": {"name": "Desulfocurvus", "rank": "Genus"}, "267410": {"name": "Listeria monocytogenes serotype 4b str. H7858", "rank": "Strain"}, "786": {"name": "Rickettsia akari", "rank": "Species"}, "915059": {"name": "Flammeovirga pacifica", "rank": "Species"}, "1352823": {"name": "Saccharomyces cerevisiae NAM34-4C", "rank": "Strain"}, "1352824": {"name": "Saccharomyces cerevisiae IR-2", "rank": "Strain"}, "47678": {"name": "Bacteroides caccae", "rank": "Species"}, "39729": {"name": "Potyviridae", "rank": "Family"}, "47671": {"name": "Lautropia mirabilis", "rank": "Species"}, "47670": {"name": "Lautropia", "rank": "Genus"}, "39720": {"name": "Walleye dermal sarcoma virus", "rank": "Species"}, "39724": {"name": "Circoviridae", "rank": "Family"}, "39725": {"name": "Circovirus", "rank": "Genus"}, "222645": {"name": "Halovirus HF1", "rank": "Species"}, "1157021": {"name": "Staphylococcus aureus M0328", "rank": "Strain"}, "1157020": {"name": "Staphylococcus aureus M0326", "rank": "Strain"}, "1157023": {"name": "Staphylococcus aureus M0330", "rank": "Strain"}, "1157022": {"name": "Staphylococcus aureus M0329", "rank": "Strain"}, "1157025": {"name": "Staphylococcus aureus M0347", "rank": "Strain"}, "1157024": {"name": "Staphylococcus aureus M0340", "rank": "Strain"}, "1116158": {"name": "Escherichia coli P0302308.10", "rank": "Strain"}, "1116159": {"name": "Escherichia coli P0302308.11", "rank": "Strain"}, "1116156": {"name": "Escherichia coli P0302308.4", "rank": "Strain"}, "1157028": {"name": "Staphylococcus aureus M0408", "rank": "Strain"}, "1116154": {"name": "Escherichia coli P0302308.2", "rank": "Strain"}, "1116155": {"name": "Escherichia coli P0302308.3", "rank": "Strain"}, "1116152": {"name": "Escherichia coli P0299438.2", "rank": "Strain"}, "1116153": {"name": "Escherichia coli P0302308.1", "rank": "Strain"}, "1116150": {"name": "Escherichia coli P0298942.14", "rank": "Strain"}, "1116151": {"name": "Escherichia coli P0298942.15", "rank": "Strain"}, "66872": {"name": "Streptomyces baarnensis", "rank": "Species"}, "1480065": {"name": "Pygoscelis adeliae papillomavirus", "rank": "Species"}, "1960": {"name": "Streptomyces vinaceus", "rank": "Species"}, "353769": {"name": "Unclassified Gammaretrovirus", "rank": "No rank"}, "1409638": {"name": "Staphylococcus aureus AMMC6119", "rank": "Strain"}, "1409639": {"name": "Staphylococcus aureus MISS6176", "rank": "Strain"}, "1961": {"name": "Streptomyces virginiae", "rank": "Species"}, "1444224": {"name": "Escherichia coli 3-373-03_S4_C1", "rank": "Strain"}, "1444225": {"name": "Escherichia coli 3-475-03_S4_C1", "rank": "Strain"}, "1444226": {"name": "Escherichia coli 6-175-07_S4_C1", "rank": "Strain"}, "1444227": {"name": "Escherichia coli 6-537-08_S4_C1", "rank": "Strain"}, "1444220": {"name": "Escherichia coli 3-020-07_S4_C1", "rank": "Strain"}, "1444221": {"name": "Escherichia coli 3-073-06_S4_C1", "rank": "Strain"}, "1444222": {"name": "Escherichia coli 3-105-05_S4_C1", "rank": "Strain"}, "1444223": {"name": "Escherichia coli 3-267-03_S4_C1", "rank": "Strain"}, "220341": {"name": "Salmonella enterica subsp. enterica serovar Typhi str. CT18", "rank": "Strain"}, "220340": {"name": "Bean golden yellow mosaic virus", "rank": "Species"}, "220343": {"name": "Gemmobacter nectariphilus", "rank": "Species"}, "1280944": {"name": "Hyphomonas sp. CY54-11-8", "rank": "Species"}, "442493": {"name": "Enterococcus phage phiEF24C", "rank": "Species"}, "66874": {"name": "Streptomyces bicolor", "rank": "Species"}, "1422569": {"name": "Staphylococcus aureus VET0302R", "rank": "Strain"}, "1422568": {"name": "Staphylococcus aureus VET0301R", "rank": "Strain"}, "1422567": {"name": "Staphylococcus aureus VET0300R", "rank": "Strain"}, "1422566": {"name": "Staphylococcus aureus VET0299R", "rank": "Strain"}, "1422565": {"name": "Staphylococcus aureus VET0298R", "rank": "Strain"}, "1422564": {"name": "Staphylococcus aureus VET0297R", "rank": "Strain"}, "1422563": {"name": "Staphylococcus aureus VET0296R", "rank": "Strain"}, "1422562": {"name": "Staphylococcus aureus VET0295R", "rank": "Strain"}, "1422561": {"name": "Staphylococcus aureus VET0294R", "rank": "Strain"}, "1422560": {"name": "Staphylococcus aureus VET0293R", "rank": "Strain"}, "1417211": {"name": "Staphylococcus aureus W73601", "rank": "Strain"}, "1417210": {"name": "Staphylococcus aureus W15951", "rank": "Strain"}, "186846": {"name": "Phi29likevirus", "rank": "Genus"}, "186845": {"name": "Petuvirus", "rank": "Genus"}, "186844": {"name": "Panicovirus", "rank": "Genus"}, "1287289": {"name": "Mesorhizobium sp. LSHC416B00", "rank": "Species"}, "1417212": {"name": "Staphylococcus aureus W73649", "rank": "Strain"}, "12064": {"name": "Enterovirus E", "rank": "Species"}, "656443": {"name": "Escherichia coli TA271", "rank": "Strain"}, "1428": {"name": "Bacillus thuringiensis", "rank": "Species"}, "1158338": {"name": "Persephonella sp. IF05-L8", "rank": "Species"}, "232244": {"name": "Belliella", "rank": "Genus"}, "1095730": {"name": "Streptococcus constellatus subsp. constellatus SK53", "rank": "Strain"}, "1095731": {"name": "Streptococcus intermedius SK54", "rank": "Strain"}, "1095733": {"name": "Streptococcus parasanguinis F0449", "rank": "Strain"}, "1095734": {"name": "Streptococcus pseudopneumoniae SK674", "rank": "Strain"}, "1095735": {"name": "Streptococcus mitis SK616", "rank": "Strain"}, "1095736": {"name": "Streptococcus mitis SK575", "rank": "Strain"}, "1095737": {"name": "Streptococcus mitis SK579", "rank": "Strain"}, "1095738": {"name": "Streptococcus oralis SK1074", "rank": "Strain"}, "1095739": {"name": "Streptococcus oralis SK10", "rank": "Strain"}, "904768": {"name": "Staphylococcus aureus subsp. aureus 21334", "rank": "Strain"}, "508750": {"name": "Kenaf leaf curl virus-India:Bahraich:2007", "rank": "Strain"}, "45634": {"name": "Streptococcus cristatus", "rank": "Species"}, "1370121": {"name": "Mycobacterium sp. UM_WWY", "rank": "Species"}, "1370120": {"name": "Mycobacterium sp. UM_WGJ", "rank": "Species"}, "1370123": {"name": "Mycobacterium tuberculosis OSDD105", "rank": "Strain"}, "1370122": {"name": "Rhizobium undicola ORS 992 = ATCC 700741", "rank": "Strain"}, "1370125": {"name": "Mycobacterium iranicum UM_TJL", "rank": "Strain"}, "1370124": {"name": "Mycobacterium tuberculosis str. OSDD515", "rank": "Strain"}, "1370126": {"name": "Acinetobacter baumannii DU202", "rank": "Strain"}, "202947": {"name": "Actinobacillus equuli subsp. equuli", "rank": "Subspecies"}, "1233873": {"name": "Geobacillus sp. GHH01", "rank": "Species"}, "1224925": {"name": "Staphylococcus aureus M0273", "rank": "Strain"}, "980427": {"name": "Deinococcus wulumuqiensis", "rank": "Species"}, "1331059": {"name": "Pseudomonas aeruginosa MSH-10", "rank": "Strain"}, "1331051": {"name": "Candidatus Saccharimonas", "rank": "Genus"}, "913": {"name": "Nitrobacter winogradskyi", "rank": "Species"}, "912": {"name": "Nitrobacter hamburgensis", "rank": "Species"}, "911": {"name": "Nitrobacter", "rank": "Genus"}, "916": {"name": "Nitrosomonas eutropha", "rank": "Species"}, "915": {"name": "Nitrosomonas europaea", "rank": "Species"}, "914": {"name": "Nitrosomonas", "rank": "Genus"}, "919": {"name": "Thiobacillus", "rank": "Genus"}, "980422": {"name": "Strawberry lethal yellows phytoplasma (CPA) str. NZSb11", "rank": "Strain"}, "1007869": {"name": "Rhodococcus phage E3", "rank": "Species"}, "257363": {"name": "Rickettsia typhi str. Wilmington", "rank": "Strain"}, "1412478": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. SA20084824", "rank": "Strain"}, "56946": {"name": "Afipia broomeae", "rank": "Species"}, "1076630": {"name": "Mycobacterium phage AnnaL29", "rank": "Species"}, "233191": {"name": "Caldilinea", "rank": "Genus"}, "660514": {"name": "Novispirillum", "rank": "Genus"}, "1091052": {"name": "Dickeya phage Limestone", "rank": "Species"}, "1408321": {"name": "Lachnospiraceae bacterium AC2028", "rank": "Species"}, "1408320": {"name": "Lachnospiraceae bacterium AC2014", "rank": "Species"}, "1408323": {"name": "Lachnospiraceae bacterium MA2020", "rank": "Species"}, "1408322": {"name": "Lachnospiraceae bacterium AC3007", "rank": "Species"}, "1408324": {"name": "Lachnospiraceae bacterium MC2017", "rank": "Species"}, "1201010": {"name": "Staphylococcus aureus subsp. aureus SA957", "rank": "Strain"}, "199310": {"name": "Escherichia coli CFT073", "rank": "Strain"}, "473531": {"name": "Nitrosococcus watsonii", "rank": "Species"}, "887070": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. 607307-2", "rank": "Strain"}, "42764": {"name": "Oliveros virus", "rank": "Species"}, "440085": {"name": "Methylobacterium extorquens CM4", "rank": "Strain"}, "1121912": {"name": "Gelidibacter mesophilus DSM 14095", "rank": "Strain"}, "117942": {"name": "Desulfurellaceae", "rank": "Family"}, "261965": {"name": "Kangiella aquimarina", "rank": "Species"}, "743299": {"name": "Acidithiobacillus ferrivorans SS3", "rank": "Strain"}, "1169158": {"name": "Streptomyces sp. CNS615", "rank": "Species"}, "1169159": {"name": "Streptomyces sp. CNY228", "rank": "Species"}, "1169151": {"name": "Micromonospora sp. CNB394", "rank": "Species"}, "1169152": {"name": "Nocardia sp. CNY236", "rank": "Species"}, "1169153": {"name": "Nocardiopsis sp. CNS639", "rank": "Species"}, "1169154": {"name": "Streptomyces sp. CNT372", "rank": "Species"}, "1169155": {"name": "Streptomyces sp. CNT302", "rank": "Species"}, "1169156": {"name": "Streptomyces sp. CNB091", "rank": "Species"}, "502790": {"name": "Aeromonas diversa", "rank": "Species"}, "907486": {"name": "Aggregatibacter actinomycetemcomitans serotype a str. H5P1", "rank": "Strain"}, "907487": {"name": "Aggregatibacter actinomycetemcomitans serotype d str. I63B", "rank": "Strain"}, "1235459": {"name": "Salmonella enterica subsp. enterica serovar Mbandaka str. 2009K-0807", "rank": "Strain"}, "1235458": {"name": "Stenotrophomonas maltophilia AU12-09", "rank": "Strain"}, "1235454": {"name": "Vibrio cholerae CP1113", "rank": "Strain"}, "1235457": {"name": "Ralstonia sp. AU12-08", "rank": "Species"}, "1235456": {"name": "Vibrio cholerae CP1114", "rank": "Strain"}, "907488": {"name": "Aggregatibacter actinomycetemcomitans serotype e str. SC1083", "rank": "Strain"}, "907489": {"name": "Aggregatibacter actinomycetemcomitans serotype e str. SCC393", "rank": "Strain"}, "1412475": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. SA20093266", "rank": "Strain"}, "28875": {"name": "Rotavirus A", "rank": "Species"}, "28876": {"name": "Rotavirus B", "rank": "Species"}, "28871": {"name": "Taterapox virus", "rank": "Species"}, "28873": {"name": "Camelpox virus", "rank": "Species"}, "92712": {"name": "Simkaniaceae", "rank": "Family"}, "1118153": {"name": "Halomonas sp. GFAJ-1", "rank": "Species"}, "92714": {"name": "Waddliaceae", "rank": "Family"}, "1435996": {"name": "Burkholderia pseudomallei MSHR2990", "rank": "Strain"}, "1156986": {"name": "Diplorickettsia massiliensis 20B", "rank": "Strain"}, "309886": {"name": "Deinococcus apachensis", "rank": "Species"}, "1279036": {"name": "Variovorax sp. JGI 0001013-M04", "rank": "Species"}, "1279035": {"name": "Variovorax sp. JGI 0001013-L10", "rank": "Species"}, "1279034": {"name": "Burkholderia sp. JGI 0001009-G23", "rank": "Species"}, "1206545": {"name": "Klebsiella phage 0507-KN2-1", "rank": "Species"}, "1279031": {"name": "Agrobacterium sp. 33MFTa1.1", "rank": "Species"}, "927193": {"name": "Acinetobacter baumannii A118", "rank": "Strain"}, "1279039": {"name": "Mycobacterium tuberculosis 1034", "rank": "Strain"}, "1279038": {"name": "Novispirillum itersonii subsp. itersonii ATCC 12639", "rank": "Strain"}, "1447517": {"name": "Mycobacterium tuberculosis MD14709", "rank": "Strain"}, "1447516": {"name": "Mycobacterium tuberculosis MD14435", "rank": "Strain"}, "1447515": {"name": "Mycobacterium tuberculosis MD14002", "rank": "Strain"}, "1447514": {"name": "Mycobacterium tuberculosis MD13878", "rank": "Strain"}, "1447513": {"name": "Mycobacterium tuberculosis MD15973", "rank": "Strain"}, "1447512": {"name": "Mycobacterium tuberculosis MD14832", "rank": "Strain"}, "1447511": {"name": "Mycobacterium tuberculosis MD14621", "rank": "Strain"}, "1447510": {"name": "Mycobacterium tuberculosis MD13874", "rank": "Strain"}, "1120988": {"name": "Anaerobiospirillum succiniciproducens DSM 6400", "rank": "Strain"}, "1094970": {"name": "Alpha proteobacterium JGI 0001002-I18", "rank": "Species"}, "1447519": {"name": "Mycobacterium tuberculosis MD15597", "rank": "Strain"}, "1447518": {"name": "Mycobacterium tuberculosis MD14825", "rank": "Strain"}, "10257": {"name": "Parapoxvirus", "rank": "Genus"}, "1047004": {"name": "Microgenomates bacterium SCGC AAA011-J08", "rank": "Species"}, "10255": {"name": "Variola virus", "rank": "Species"}, "1047006": {"name": "Omnitrophica bacterium SCGC AAA252-B19", "rank": "Species"}, "1586081": {"name": "Pseudomonas sp. C5pp", "rank": "Species"}, "1047003": {"name": "Candidatus Microgenomatus auricola SCGC AAA011-E14", "rank": "Strain"}, "1047002": {"name": "Microgenomates bacterium SCGC AAA255-J07", "rank": "Species"}, "203193": {"name": "Halobiforma", "rank": "Genus"}, "203192": {"name": "Pseudomonas chloritidismutans", "rank": "Species"}, "1047009": {"name": "Marinimicrobia bacterium SCGC AAA011-A05", "rank": "Species"}, "10258": {"name": "Orf virus", "rank": "Species"}, "1176736": {"name": "Pitaya virus X", "rank": "Species"}, "931460": {"name": "Staphylococcus aureus subsp. aureus CIGC93", "rank": "Strain"}, "1224510": {"name": "Nepavirus", "rank": "Species"}, "1167724": {"name": "Oxalobacteraceae bacterium JGI 001010-B17", "rank": "Species"}, "263892": {"name": "Bougainvillea chlorotic vein banding virus", "rank": "Species"}, "469008": {"name": "Escherichia coli BL21(DE3)", "rank": "Strain"}, "1167727": {"name": "Rhizobiales bacterium JGI 001012-O08", "rank": "Species"}, "1231180": {"name": "Nitratireductor pacificus", "rank": "Species"}, "1501268": {"name": "Prochlorococcus sp. MIT 0604", "rank": "Species"}, "1501269": {"name": "Prochlorococcus sp. MIT 0801", "rank": "Species"}, "1313421": {"name": "Aureispira sp. CCB-QB1", "rank": "Species"}, "980584": {"name": "Flavobacteriaceae bacterium HQM9", "rank": "Species"}, "535722": {"name": "Microsporum gypseum CBS 118893", "rank": "Strain"}, "189723": {"name": "Prevotella micans", "rank": "Species"}, "189722": {"name": "Prevotella marshii", "rank": "Species"}, "1134055": {"name": "Verrucomicrobium sp. 3C", "rank": "Species"}, "196588": {"name": "Porphyrobacter cryptus", "rank": "Species"}, "416419": {"name": "Archaeal BJ1 virus", "rank": "Species"}, "1193048": {"name": "Leptospira kirschneri str. 200803703", "rank": "Strain"}, "1159195": {"name": "Southern elephant seal virus", "rank": "Species"}, "1159199": {"name": "Mycoplasma gallisepticum NC96_1596-4-2P", "rank": "Strain"}, "1159198": {"name": "Mycoplasma gallisepticum NC95_13295-2-2P", "rank": "Strain"}, "1234878": {"name": "Dragonfly cyclicusvirus", "rank": "Species"}, "1208667": {"name": "Lactobacillus phage f-AQ113", "rank": "Species"}, "10871": {"name": "Pseudomonas phage Pf1", "rank": "Species"}, "10870": {"name": "Enterobacteria phage M13", "rank": "Species"}, "1208662": {"name": "Cronobacter malonaticus 507", "rank": "Strain"}, "10876": {"name": "Acholeplasma phage MV-L1", "rank": "Species"}, "1444770": {"name": "Xylella fastidiosa PLS229", "rank": "Strain"}, "1208661": {"name": "Cronobacter dublinensis 582", "rank": "Strain"}, "1234871": {"name": "Lactococcus lactis subsp. cremoris TIFN1", "rank": "Strain"}, "1234872": {"name": "Dragonfly circularisvirus", "rank": "Species"}, "903818": {"name": "Holophaga foetida DSM 6591", "rank": "Strain"}, "1234874": {"name": "Dragonfly orbiculatusvirus", "rank": "Species"}, "1234877": {"name": "Lactococcus lactis subsp. cremoris TIFN7", "rank": "Strain"}, "307623": {"name": "Tubulinosematidae", "rank": "Family"}, "1505233": {"name": "Chitinivibrionales", "rank": "Order"}, "1505232": {"name": "Chitinivibrio alkaliphilus", "rank": "Species"}, "1505231": {"name": "Chitinivibrio", "rank": "Genus"}, "1505234": {"name": "Chitinivibrionaceae", "rank": "Family"}, "1125862": {"name": "Deferrisoma", "rank": "Genus"}, "1125863": {"name": "Deferrisoma camini S3R1", "rank": "Strain"}, "313612": {"name": "Lyngbya sp. PCC 8106", "rank": "Species"}, "882084": {"name": "Saccharomonospora paurometabolica YIM 90007", "rank": "Strain"}, "882085": {"name": "Saccharomonospora saliphila YIM 90502", "rank": "Strain"}, "882086": {"name": "Saccharomonospora xinjiangensis XJ-54", "rank": "Strain"}, "649761": {"name": "Prevotella veroralis F0319", "rank": "Strain"}, "882080": {"name": "Actinopolyspora iraqiensis IQ-H1", "rank": "Strain"}, "882081": {"name": "Saccharomonospora azurea NA-128", "rank": "Strain"}, "882082": {"name": "Saccharomonospora cyanea NA-134", "rank": "Strain"}, "882083": {"name": "Saccharomonospora marina XMU15", "rank": "Strain"}, "390235": {"name": "Pseudomonas putida W619", "rank": "Strain"}, "97139": {"name": "Clostridium sp. ASF502", "rank": "Species"}, "390236": {"name": "Borrelia afzelii PKo", "rank": "Strain"}, "97138": {"name": "Clostridium sp. ASF356", "rank": "Species"}, "325675": {"name": "Unclassified Arterivirus", "rank": "No rank"}, "325676": {"name": "Nam Dinh virus", "rank": "Strain"}, "1094988": {"name": "Candida albicans GC75", "rank": "Strain"}, "95337": {"name": "Vesivirus", "rank": "Genus"}, "1203069": {"name": "Lactobacillus gigeriorum", "rank": "Species"}, "1441612": {"name": "Vibrio parahaemolyticus TUMSAT_H10_S6", "rank": "Strain"}, "95339": {"name": "Lagovirus", "rank": "Genus"}, "1446641": {"name": "Escherichia coli O157:H7 str. 2011EL-2111", "rank": "Strain"}, "1441610": {"name": "Vibrio parahaemolyticus TUMSAT_H01_S4", "rank": "Strain"}, "12348": {"name": "Lactobacillus phage LL-H", "rank": "Species"}, "1184252": {"name": "Streptococcus suis S735", "rank": "Strain"}, "1184253": {"name": "Anaplasma phagocytophilum str. HZ2", "rank": "Strain"}, "12345": {"name": "Bacillus phage GA-1", "rank": "Species"}, "1184251": {"name": "Thermogladius cellulolyticus 1633", "rank": "Strain"}, "1184254": {"name": "Anaplasma phagocytophilum str. Dog2", "rank": "Strain"}, "1422112": {"name": "Mycobacterium tuberculosis TB_RSA199", "rank": "Strain"}, "1422113": {"name": "Mycobacterium tuberculosis TB_RSA200", "rank": "Strain"}, "1422110": {"name": "Mycobacterium tuberculosis TB_RSA196", "rank": "Strain"}, "1422111": {"name": "Mycobacterium tuberculosis TB_RSA197", "rank": "Strain"}, "1422116": {"name": "Staphylococcus aureus DAR3507", "rank": "Strain"}, "1422117": {"name": "Staphylococcus aureus DAR3508", "rank": "Strain"}, "1422114": {"name": "Staphylococcus aureus DAR3504", "rank": "Strain"}, "1422115": {"name": "Staphylococcus aureus DAR3505", "rank": "Strain"}, "1462938": {"name": "Rickettsia sp. ISO7", "rank": "Species"}, "97137": {"name": "Lactobacillus sp. ASF360", "rank": "Species"}, "1422118": {"name": "Staphylococcus aureus DAR3512", "rank": "Strain"}, "1422119": {"name": "Staphylococcus aureus DAR3515", "rank": "Strain"}, "44276": {"name": "Leptospira interrogans serovar Pomona", "rank": "Strain"}, "282685": {"name": "Nocardia jiangxiensis", "rank": "Species"}, "645110": {"name": "Cecembia lonarensis", "rank": "Species"}, "1412682": {"name": "Staphylococcus aureus M77202", "rank": "Strain"}, "1385427": {"name": "Betacoronavirus Erinaceus/VMC/DEU/2012", "rank": "Species"}, "1385420": {"name": "Francisella sp. W12-1067", "rank": "Species"}, "523794": {"name": "Leptotrichia buccalis C-1013-b", "rank": "Strain"}, "1232430": {"name": "Nosocomiicoccus sp. NP2", "rank": "Species"}, "1232436": {"name": "Coriobacteriaceae bacterium GD5", "rank": "Species"}, "925131": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. CVM_81-2490", "rank": "Strain"}, "925132": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. SL909", "rank": "Strain"}, "925133": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. SL913", "rank": "Strain"}, "1232438": {"name": "Clostridiales bacterium VE202-01", "rank": "Species"}, "241407": {"name": "Saccharomycetales incertae sedis", "rank": "No rank"}, "868163": {"name": "Escherichia coli DEC6D", "rank": "Strain"}, "28050": {"name": "Lachnospira", "rank": "Genus"}, "28051": {"name": "Lachnospira multipara", "rank": "Species"}, "28056": {"name": "Micromonosporaceae", "rank": "Family"}, "1219031": {"name": "Comamonas aquatica NBRC 14918", "rank": "Strain"}, "1277649": {"name": "STL polyomavirus", "rank": "Species"}, "1478160": {"name": "Human papillomavirus type 178", "rank": "Species"}, "1219037": {"name": "Sphingobium xenophagum NBRC 107872", "rank": "Strain"}, "1123321": {"name": "Streptomyces sulphureus DSM 40104", "rank": "Strain"}, "248744": {"name": "Marvinbryantia", "rank": "Genus"}, "423211": {"name": "Streptococcus suis GZ1", "rank": "Strain"}, "423212": {"name": "Legionella pneumophila 2300/99 Alcoy", "rank": "Strain"}, "868166": {"name": "Escherichia coli DEC7B", "rank": "Strain"}, "326320": {"name": "Dokdonia donghaensis", "rank": "Species"}, "592678": {"name": "Amycolatopsis halophila YIM 93223", "rank": "Strain"}, "765910": {"name": "Marichromatium purpuratum 984", "rank": "Strain"}, "765911": {"name": "Thiocystis violascens DSM 198", "rank": "Strain"}, "765912": {"name": "Thioflavicoccus mobilis 8321", "rank": "Strain"}, "1123322": {"name": "Streptomyces vitaminophilus DSM 41686", "rank": "Strain"}, "765914": {"name": "Thiorhodospira sibirica ATCC 700588", "rank": "Strain"}, "1458717": {"name": "Mycobacterium phage 40AC", "rank": "Species"}, "1043205": {"name": "Serinicoccus profundi MCCC 1A05965", "rank": "Strain"}, "1128912": {"name": "Glaciecola mesophila KMM 241", "rank": "Strain"}, "1413506": {"name": "Staphylococcus aureus R0615", "rank": "Strain"}, "29282": {"name": "Haloarcula japonica", "rank": "Species"}, "1413501": {"name": "Staphylococcus aureus R0353", "rank": "Strain"}, "1231627": {"name": "Lysinibacillus fusiformis ZB2", "rank": "Strain"}, "36814": {"name": "Mycobacterium rhodesiae", "rank": "Species"}, "36812": {"name": "Mycobacterium genavense", "rank": "Species"}, "929102": {"name": "Lactococcus lactis subsp. lactis CV56", "rank": "Strain"}, "36819": {"name": "Amycolatopsis azurea", "rank": "Species"}, "1033994": {"name": "Pseudomonas sp. MOIL14HWK12:I2", "rank": "Species"}, "762051": {"name": "Leuconostoc kimchii IMSNU 11154", "rank": "Strain"}, "1454010": {"name": "Cellulomonas sp. HZM", "rank": "Species"}, "1147158": {"name": "Enterobacterial phage mEp390", "rank": "Species"}, "1147159": {"name": "Ornithinibacillus scapharcae", "rank": "Species"}, "1147154": {"name": "Enterobacteria phage mEpX2", "rank": "Species"}, "1147155": {"name": "Enterobacteria phage vB_EcoS_Rogue1", "rank": "Species"}, "1147156": {"name": "Enterobacterial phage mEp213", "rank": "Species"}, "1147157": {"name": "Enterobacterial phage mEp234", "rank": "Species"}, "1147150": {"name": "Enterobacteria phage mEp235", "rank": "Species"}, "1147151": {"name": "Enterobacteria phage mEp237", "rank": "Species"}, "1147152": {"name": "Enterobacteria phage mEp460", "rank": "Species"}, "1147153": {"name": "Enterobacteria phage mEpX1", "rank": "Species"}, "198589": {"name": "Beet western yellows ST9 associated virus", "rank": "Species"}, "245188": {"name": "Loktanella vestfoldensis", "rank": "Species"}, "617134": {"name": "Vibrio ordalii FS-144", "rank": "Strain"}, "245186": {"name": "Loktanella", "rank": "Genus"}, "178354": {"name": "Taro bacilliform virus", "rank": "Species"}, "67281": {"name": "Streptomyces californicus", "rank": "Species"}, "67287": {"name": "Streptomyces cinnabarinus", "rank": "Species"}, "1352932": {"name": "Klebsiella pneumoniae LCT-KP182", "rank": "Strain"}, "1352933": {"name": "Klebsiella pneumoniae LCT-KP289", "rank": "Strain"}, "1352936": {"name": "Streptomyces roseochromogenus subsp. oscitans DS 12.976", "rank": "Strain"}, "83406": {"name": "Gamma proteobacterium HdN1", "rank": "Species"}, "1133022": {"name": "Burkholderia phage AH2", "rank": "Species"}, "1030145": {"name": "Pseudomonas tolaasii PMS117", "rank": "Strain"}, "39637": {"name": "Equid herpesvirus 8", "rank": "Species"}, "493915": {"name": "Pseudoalteromonas sp. NJ631", "rank": "Species"}, "67754": {"name": "Tomato chlorosis virus", "rank": "Species"}, "1112631": {"name": "Bat Paramyxovirus Eid_hel/GH-M74a/GHA/2009", "rank": "Species"}, "67753": {"name": "Crinivirus", "rank": "Genus"}, "211787": {"name": "Human papillomavirus type 92", "rank": "Strain"}, "525306": {"name": "Lactobacillus acidophilus ATCC 4796", "rank": "Strain"}, "327984": {"name": "Unclassified Iridovirus", "rank": "No rank"}, "525309": {"name": "Lactobacillus antri DSM 16041", "rank": "Strain"}, "1296096": {"name": "Cryptococcus pinus CBS 10737", "rank": "Strain"}, "1141660": {"name": "Providencia sneebia DSM 19967", "rank": "Strain"}, "1141661": {"name": "Providencia alcalifaciens Dmel2", "rank": "Strain"}, "1141662": {"name": "Providencia burhodogranariea DSM 19968", "rank": "Strain"}, "1141663": {"name": "Providencia rettgeri Dmel1", "rank": "Strain"}, "322855": {"name": "Xanthomonas phage Xp15", "rank": "Species"}, "944018": {"name": "Nematocida sp. 1 ERTm2", "rank": "Strain"}, "875093": {"name": "Streptococcus pseudoporcinus LQ 940-04", "rank": "Strain"}, "591962": {"name": "Aeromonas fluvialis", "rank": "Species"}, "797209": {"name": "Haladaptatus paucihalophilus DX253", "rank": "Strain"}, "191460": {"name": "Sida mottle virus", "rank": "Species"}, "191463": {"name": "Sida yellow mosaic virus", "rank": "Species"}, "591968": {"name": "Clostridium botulinum B1", "rank": "Strain"}, "1074125": {"name": "Streptococcus mutans TCI-148", "rank": "Strain"}, "66883": {"name": "Streptomyces cyaneofuscatus", "rank": "Species"}, "1027468": {"name": "Farmington virus", "rank": "Species"}, "875329": {"name": "Pseudomonas syringae pv. glycinea str. B076", "rank": "Strain"}, "875328": {"name": "Mycobacterium sp. JDM601", "rank": "Species"}, "875323": {"name": "Rose leaf curl virus", "rank": "Species"}, "387090": {"name": "Bacteroides coprophilus", "rank": "Species"}, "387093": {"name": "Sulfurovum sp. NBC37-1", "rank": "Species"}, "387092": {"name": "Nitratiruptor sp. SB155-2", "rank": "Species"}, "387095": {"name": "Maribius", "rank": "Genus"}, "875325": {"name": "Rose leaf curl betasatellite", "rank": "Species"}, "875324": {"name": "Eclipta yellow vein virus", "rank": "Species"}, "1074076": {"name": "Streptococcus sobrinus TCI-355", "rank": "Strain"}, "1074077": {"name": "Streptococcus sobrinus TCI-357", "rank": "Strain"}, "1074074": {"name": "Streptococcus sobrinus TCI-352", "rank": "Strain"}, "1074072": {"name": "Streptococcus sobrinus TCI-348", "rank": "Strain"}, "1074071": {"name": "Streptococcus sobrinus TCI-345", "rank": "Strain"}, "1378069": {"name": "Lactobacillus casei 5b", "rank": "Strain"}, "1074078": {"name": "Streptococcus sobrinus TCI-363", "rank": "Strain"}, "1074079": {"name": "Streptococcus sobrinus TCI-366", "rank": "Strain"}, "667585": {"name": "Burkholderia sp. JPY251", "rank": "Species"}, "1145163": {"name": "Neisseria meningitidis NM3147", "rank": "Strain"}, "1145162": {"name": "Neisseria meningitidis M13265", "rank": "Strain"}, "1145161": {"name": "Neisseria meningitidis NM477", "rank": "Strain"}, "1130304": {"name": "Crenarchaeote SCGC AAA261-N13", "rank": "Species"}, "1130303": {"name": "Crenarchaeote SCGC AAA261-L22", "rank": "Species"}, "1145166": {"name": "Neisseria meningitidis 2000081", "rank": "Strain"}, "1145165": {"name": "Neisseria meningitidis 2001073", "rank": "Strain"}, "1130300": {"name": "Crenarchaeote SCGC AAA261-F05", "rank": "Species"}, "398000": {"name": "Campylobacter jejuni subsp. jejuni CG8486", "rank": "Strain"}, "1145168": {"name": "Neisseria meningitidis 2004032", "rank": "Strain"}, "398007": {"name": "Dolichospermum circinale AWQC131C", "rank": "Strain"}, "119858": {"name": "Bacillus sonorensis", "rank": "Species"}, "119859": {"name": "Microchaetaceae", "rank": "Family"}, "1452514": {"name": "Sosuga virus", "rank": "Species"}, "1452516": {"name": "Caprine kobuvirus", "rank": "Species"}, "119856": {"name": "Francisella tularensis subsp. tularensis", "rank": "Subspecies"}, "119857": {"name": "Francisella tularensis subsp. holarctica", "rank": "Subspecies"}, "467705": {"name": "Streptococcus gordonii str. Challis substr. CH1", "rank": "Strain"}, "180541": {"name": "Salinisphaera", "rank": "Genus"}, "180542": {"name": "Salinisphaera shabanensis", "rank": "Species"}, "1035120": {"name": "Deferrisoma camini", "rank": "Species"}, "945360": {"name": "Shigella flexneri CDC 796-83", "rank": "Strain"}, "1354189": {"name": "Mycobacterium africanum MAL020185", "rank": "Strain"}, "1354188": {"name": "Mycobacterium africanum MAL020176", "rank": "Strain"}, "1354187": {"name": "Mycobacterium africanum MAL020135", "rank": "Strain"}, "1354186": {"name": "Mycobacterium africanum MAL020107", "rank": "Strain"}, "1354181": {"name": "Mycobacterium africanum MAL010131", "rank": "Strain"}, "360145": {"name": "Grosmannia", "rank": "Genus"}, "1354183": {"name": "Mycobacterium africanum MAL010137", "rank": "Strain"}, "1354182": {"name": "Mycobacterium tuberculosis MAL010136", "rank": "Strain"}, "667632": {"name": "Burkholderia sp. JPY347", "rank": "Species"}, "117681": {"name": "Pseudomonas gingeri", "rank": "Species"}, "1348776": {"name": "Mycobacterium tuberculosis 43-16836", "rank": "Strain"}, "1388319": {"name": "Staphylococcus aureus M0481", "rank": "Strain"}, "1511840": {"name": "Primula malacoides virus 1", "rank": "Species"}, "111780": {"name": "Stanieria cyanosphaera PCC 7437", "rank": "Strain"}, "502558": {"name": "Eggerthella sp. YY7918", "rank": "Species"}, "1511847": {"name": "Fusarium solani virus 1", "rank": "Species"}, "1388311": {"name": "Staphylococcus aureus M0465", "rank": "Strain"}, "1388310": {"name": "Staphylococcus aureus M0464", "rank": "Strain"}, "1388313": {"name": "Staphylococcus aureus M0469", "rank": "Strain"}, "1388312": {"name": "Staphylococcus aureus M0466", "rank": "Strain"}, "1388315": {"name": "Staphylococcus aureus M0472", "rank": "Strain"}, "1388314": {"name": "Staphylococcus aureus M0471", "rank": "Strain"}, "1388317": {"name": "Staphylococcus aureus M0476", "rank": "Strain"}, "1388316": {"name": "Staphylococcus aureus M0475", "rank": "Strain"}, "397353": {"name": "Pseudomonas phage MP22", "rank": "Species"}, "1125975": {"name": "Thermoanaerobacter indiensis BSB-33", "rank": "Strain"}, "365617": {"name": "Paenibacillus sabinae", "rank": "Species"}, "1398492": {"name": "Vibrio cholerae E306", "rank": "Strain"}, "1398491": {"name": "Borrelia valaisiana Tom4006", "rank": "Strain"}, "1398490": {"name": "Borrelia afzelii Tom3107", "rank": "Strain"}, "378211": {"name": "Methyloversatilis universalis", "rank": "Species"}, "378210": {"name": "Methyloversatilis", "rank": "Genus"}, "1198672": {"name": "Corynebacterium glutamicum Z188", "rank": "Strain"}, "999552": {"name": "Leisingera methylohalidivorans DSM 14336", "rank": "Strain"}, "1393719": {"name": "Staphylococcus aureus M0753", "rank": "Strain"}, "1393718": {"name": "Staphylococcus aureus M0749", "rank": "Strain"}, "1393715": {"name": "Staphylococcus aureus M1579", "rank": "Strain"}, "1393714": {"name": "Staphylococcus aureus M1577", "rank": "Strain"}, "1393717": {"name": "Staphylococcus aureus M0747", "rank": "Strain"}, "1393716": {"name": "Staphylococcus aureus M1580", "rank": "Strain"}, "1393711": {"name": "Staphylococcus aureus M1574", "rank": "Strain"}, "1393710": {"name": "Staphylococcus aureus M1573", "rank": "Strain"}, "1393713": {"name": "Staphylococcus aureus M1576", "rank": "Strain"}, "1393712": {"name": "Staphylococcus aureus M1575", "rank": "Strain"}, "84096": {"name": "Gordonia alkanivorans", "rank": "Species"}, "665568": {"name": "Paraoerskovia", "rank": "Genus"}, "1303518": {"name": "Chthonomonas calidirosea T49", "rank": "Strain"}, "475777": {"name": "Phlox Virus B", "rank": "Species"}, "1561172": {"name": "Ustilaginoidea virens RNA virus M", "rank": "Species"}, "1214121": {"name": "Xylella fastidiosa 32", "rank": "Strain"}, "1561171": {"name": "Ustilaginoidea virens RNA virus L", "rank": "Species"}, "878220": {"name": "Chryseobacterium sp. StRB126", "rank": "Species"}, "1317131": {"name": "Escherichia coli O157 str. NCCP15738", "rank": "Strain"}, "1317130": {"name": "Escherichia coli O157 str. NCCP15739", "rank": "Strain"}, "647171": {"name": "Methanotorris formicicus Mc-S-70", "rank": "Strain"}, "310103": {"name": "Senecio yellow mosaic virus", "rank": "Species"}, "1112250": {"name": "Chlamydia psittaci C19/98", "rank": "Strain"}, "216816": {"name": "Bifidobacterium longum", "rank": "Species"}, "359359": {"name": "Smaragdicoccus niigatensis", "rank": "Species"}, "359350": {"name": "Unclassified L5likevirus", "rank": "No rank"}, "1194669": {"name": "Pseudomonas aeruginosa N002", "rank": "Strain"}, "515622": {"name": "Butyrivibrio proteoclasticus B316", "rank": "Strain"}, "714309": {"name": "Merremia mosaic Puerto Rico virus", "rank": "Species"}, "714308": {"name": "Rhynchosia mild mosaic virus", "rank": "Species"}, "57482": {"name": "European bat lyssavirus 1", "rank": "Species"}, "323733": {"name": "Rhizobium etli bv. mimosae", "rank": "Strain"}, "1553": {"name": "Clostridium tetanomorphum", "rank": "Species"}, "1557": {"name": "Clostridium litorale", "rank": "Species"}, "1556": {"name": "Gottschalkia acidurici", "rank": "Species"}, "981431": {"name": "Pseudomonas phage PAK_P3", "rank": "Species"}, "326457": {"name": "Unclassified Verrucomicrobia", "rank": "No rank"}, "1206782": {"name": "Bartonella bacilliformis INS", "rank": "Strain"}, "1206781": {"name": "Paenibacillus alvei DSM 29", "rank": "Strain"}, "1206780": {"name": "Mycobacterium bovis BCG str. Korea 1168P", "rank": "Strain"}, "195950": {"name": "Tannerella", "rank": "Genus"}, "675844": {"name": "Brambyvirus", "rank": "Genus"}, "675845": {"name": "Emaravirus", "rank": "Genus"}, "55744": {"name": "Equid herpesvirus 9", "rank": "Species"}, "1402693": {"name": "Staphylococcus aureus M1184", "rank": "Strain"}, "58117": {"name": "Microbispora rosea", "rank": "Species"}, "564886": {"name": "Enterobacteria phage YYZ-2008", "rank": "Species"}, "1218490": {"name": "Torque teno zalophus virus 1", "rank": "Species"}, "1290": {"name": "Staphylococcus hominis", "rank": "Species"}, "1124939": {"name": "Salmonella enterica subsp. enterica serovar Heidelberg str. N26457", "rank": "Strain"}, "1124938": {"name": "Salmonella enterica subsp. enterica serovar Heidelberg str. N19871", "rank": "Strain"}, "1417087": {"name": "Staphylococcus aureus T83705", "rank": "Strain"}, "568704": {"name": "Lactobacillus rhamnosus Lc 705", "rank": "Strain"}, "1124933": {"name": "Salmonella enterica subsp. enterica serovar Hadar str. ATCC 51956", "rank": "Strain"}, "1124935": {"name": "Salmonella enterica subsp. enterica serovar Heidelberg str. 24390", "rank": "Strain"}, "1124934": {"name": "Salmonella enterica subsp. enterica serovar Heidelberg str. 82-2052", "rank": "Strain"}, "1124937": {"name": "Salmonella enterica subsp. enterica serovar Heidelberg str. 41579", "rank": "Strain"}, "1124936": {"name": "Salmonella enterica subsp. enterica serovar Heidelberg str. 41578", "rank": "Strain"}, "1392389": {"name": "Intestinimonas", "rank": "Genus"}, "1392388": {"name": "Sweet potato leaf curl Shanghai virus", "rank": "Species"}, "1417082": {"name": "Staphylococcus aureus F73229", "rank": "Strain"}, "568707": {"name": "Bordetella bronchiseptica 253", "rank": "Strain"}, "1392387": {"name": "Sweet potato leaf curl Japan virus", "rank": "Species"}, "564644": {"name": "Endornaviridae", "rank": "Family"}, "1402499": {"name": "Pseudomonas aeruginosa S35004", "rank": "Strain"}, "1402498": {"name": "Pseudomonas aeruginosa 6077", "rank": "Strain"}, "1379740": {"name": "Clostridium botulinum A2B3 87", "rank": "Strain"}, "1402495": {"name": "Pseudomonas aeruginosa JJ692", "rank": "Strain"}, "1402494": {"name": "Pseudomonas aeruginosa S54485", "rank": "Strain"}, "1402497": {"name": "Pseudomonas aeruginosa 19660", "rank": "Strain"}, "1402496": {"name": "Pseudomonas aeruginosa U2504", "rank": "Strain"}, "1402491": {"name": "Pseudomonas aeruginosa CF5", "rank": "Strain"}, "1402490": {"name": "Pseudomonas aeruginosa CF27", "rank": "Strain"}, "1402493": {"name": "Pseudomonas aeruginosa UDL", "rank": "Strain"}, "1402492": {"name": "Pseudomonas aeruginosa X24509", "rank": "Strain"}, "47735": {"name": "Bibersteinia trehalosi", "rank": "Species"}, "47736": {"name": "Carrot mottle mimic virus", "rank": "Species"}, "1402698": {"name": "Staphylococcus aureus M1190", "rank": "Strain"}, "483537": {"name": "Alternaria alternata virus 1", "rank": "Species"}, "1267021": {"name": "Frischella perrara", "rank": "Species"}, "1218727": {"name": "French bean severe leaf curl virus", "rank": "Species"}, "1245608": {"name": "Marinimicrobia bacterium JGI 0000113-D11", "rank": "Species"}, "184250": {"name": "Streptococcus constellatus subsp. pharyngis", "rank": "Subspecies"}, "1245607": {"name": "Proteobacteria bacterium JGI 0000113-L05", "rank": "Species"}, "1116219": {"name": "Staphylococcus aureus subsp. aureus VRS6", "rank": "Strain"}, "1116218": {"name": "Staphylococcus aureus subsp. aureus VRS5", "rank": "Strain"}, "1437612": {"name": "Bifidobacterium stercoris JCM 15918", "rank": "Strain"}, "1437611": {"name": "Bifidobacterium saeculare DSM 6531 = LMG 14934", "rank": "Strain"}, "1437610": {"name": "Bifidobacterium reuteri DSM 23975", "rank": "Strain"}, "1116211": {"name": "Mycoplasma hyopneumoniae 168-L", "rank": "Strain"}, "1029718": {"name": "Candidatus Arthromitus sp. SFB-mouse-Japan", "rank": "Strain"}, "1116213": {"name": "Candidatus Mycoplasma haemominutum 'Birmingham 1'", "rank": "Strain"}, "1116215": {"name": "Staphylococcus aureus subsp. aureus VRS2", "rank": "Strain"}, "1116214": {"name": "Staphylococcus aureus subsp. aureus VRS1", "rank": "Strain"}, "1116217": {"name": "Staphylococcus aureus subsp. aureus VRS4", "rank": "Strain"}, "1116216": {"name": "Staphylococcus aureus subsp. aureus VRS3a", "rank": "Strain"}, "858455": {"name": "Rhodomicrobium udaipurense JA643", "rank": "Strain"}, "180957": {"name": "Pectobacterium carotovorum subsp. brasiliense", "rank": "Subspecies"}, "1005494": {"name": "Escherichia coli PA10", "rank": "Strain"}, "991972": {"name": "Vibrio cholerae HC-55C2", "rank": "Strain"}, "263511": {"name": "Crocosphaera watsonii", "rank": "Species"}, "263510": {"name": "Crocosphaera", "rank": "Genus"}, "1204543": {"name": "Staphylococcus phage SA11", "rank": "Species"}, "91347": {"name": "Enterobacteriales", "rank": "Order"}, "1204540": {"name": "Enterococcus phage EfaCPT1", "rank": "Species"}, "746543": {"name": "Shimoni bat virus", "rank": "Species"}, "333919": {"name": "Zetapapillomavirus 1", "rank": "Species"}, "333918": {"name": "Zetapapillomavirus", "rank": "Genus"}, "1409577": {"name": "Staphylococcus aureus SJUD6109", "rank": "Strain"}, "991977": {"name": "Vibrio cholerae HC-59A1", "rank": "Strain"}, "1409575": {"name": "Staphylococcus aureus SJUD6098", "rank": "Strain"}, "1409574": {"name": "Staphylococcus aureus SJOS6126", "rank": "Strain"}, "1409573": {"name": "Staphylococcus aureus SJUD6110", "rank": "Strain"}, "1409572": {"name": "Staphylococcus aureus SJUD6111", "rank": "Strain"}, "1409571": {"name": "Staphylococcus aureus SJUD6107", "rank": "Strain"}, "991976": {"name": "Vibrio cholerae HC-57A2", "rank": "Strain"}, "1422688": {"name": "Staphylococcus aureus VET0486R", "rank": "Strain"}, "287752": {"name": "Aurantimonas manganoxydans SI85-9A1", "rank": "Strain"}, "991975": {"name": "Vibrio cholerae HC-57A1", "rank": "Strain"}, "1422682": {"name": "Staphylococcus aureus VET0471R", "rank": "Strain"}, "1422683": {"name": "Staphylococcus aureus VET0472R", "rank": "Strain"}, "1422680": {"name": "Staphylococcus aureus VET0469R", "rank": "Strain"}, "1422681": {"name": "Staphylococcus aureus VET0470R", "rank": "Strain"}, "1422686": {"name": "Staphylococcus aureus VET0481R", "rank": "Strain"}, "1422687": {"name": "Staphylococcus aureus VET0485R", "rank": "Strain"}, "1422684": {"name": "Staphylococcus aureus VET0473R", "rank": "Strain"}, "1422685": {"name": "Staphylococcus aureus VET0478R", "rank": "Strain"}, "63723": {"name": "South African cassava mosaic virus", "rank": "Species"}, "12103": {"name": "Cardiovirus", "rank": "Genus"}, "907191": {"name": "Raspberry latent virus", "rank": "Species"}, "12104": {"name": "Encephalomyocarditis virus", "rank": "Species"}, "1120705": {"name": "Sphingopyxis sp. LC363", "rank": "Species"}, "12109": {"name": "Aphthovirus", "rank": "Genus"}, "1448534": {"name": "Mycobacterium tuberculosis TKK_05SA_0020", "rank": "Strain"}, "1005499": {"name": "Escherichia coli PA24", "rank": "Strain"}, "1422350": {"name": "Staphylococcus aureus DAR5824", "rank": "Strain"}, "1422351": {"name": "Staphylococcus aureus DAR5823", "rank": "Strain"}, "1422352": {"name": "Staphylococcus aureus DAR5822", "rank": "Strain"}, "1422353": {"name": "Staphylococcus aureus DAR5821", "rank": "Strain"}, "1422354": {"name": "Staphylococcus aureus DAR5820", "rank": "Strain"}, "1422355": {"name": "Staphylococcus aureus DAR5819", "rank": "Strain"}, "1422357": {"name": "Staphylococcus aureus DAR5817", "rank": "Strain"}, "1422358": {"name": "Staphylococcus aureus DAR5816", "rank": "Strain"}, "1422359": {"name": "Staphylococcus aureus DAR5815", "rank": "Strain"}, "1446729": {"name": "Escherichia coli O26:H11 str. 2011C-3274", "rank": "Strain"}, "881945": {"name": "Canary polyomavirus", "rank": "Species"}, "1412810": {"name": "Staphylococcus aureus W50092", "rank": "Strain"}, "1412811": {"name": "Staphylococcus aureus W50101", "rank": "Strain"}, "1412812": {"name": "Staphylococcus aureus W50110", "rank": "Strain"}, "1412815": {"name": "Escherichia coli 148", "rank": "Strain"}, "1412816": {"name": "Escherichia coli 320", "rank": "Strain"}, "1412817": {"name": "Escherichia coli 681", "rank": "Strain"}, "1412818": {"name": "Escherichia coli 38.27", "rank": "Strain"}, "13366": {"name": "Brettanomyces", "rank": "Genus"}, "449400": {"name": "Kenaf leaf curl virus", "rank": "Species"}, "1081702": {"name": "Tamus red mosaic virus", "rank": "Species"}, "1410855": {"name": "Staphylococcus aureus W73060", "rank": "Strain"}, "1477404": {"name": "Dinoroseobacter phage DFL12phi1", "rank": "Species"}, "748667": {"name": "Grapevine Bulgarian latent virus", "rank": "Species"}, "1328870": {"name": "Enterococcus faecium UC7251", "rank": "Strain"}, "553470": {"name": "Dolichospermum circinale AWQC310F", "rank": "Strain"}, "1519438": {"name": "Eubacterium sp. ER2", "rank": "Species"}, "1519439": {"name": "Oscillibacter sp. ER4", "rank": "Species"}, "862261": {"name": "Caldanaerobius", "rank": "Genus"}, "316330": {"name": "Microbispora sp. ATCC PTA-5024", "rank": "Species"}, "484020": {"name": "Bifidobacterium bifidum BGN4", "rank": "Strain"}, "1134794": {"name": "Enterococcus faecalis ERV65", "rank": "Strain"}, "1134795": {"name": "Enterococcus faecalis ERV68", "rank": "Strain"}, "1134796": {"name": "Enterococcus faecalis ERV72", "rank": "Strain"}, "1134797": {"name": "Enterococcus faecalis ERV73", "rank": "Strain"}, "1134790": {"name": "Enterococcus faecalis ERV37", "rank": "Strain"}, "1134791": {"name": "Enterococcus faecalis ERV41", "rank": "Strain"}, "1134792": {"name": "Enterococcus faecalis ERV62", "rank": "Strain"}, "1134793": {"name": "Enterococcus faecalis ERV63", "rank": "Strain"}, "1134798": {"name": "Enterococcus faecalis ERV81", "rank": "Strain"}, "1134799": {"name": "Enterococcus faecalis ERV85", "rank": "Strain"}, "1347912": {"name": "Stenotrophomonas maltophilia stmalt0377", "rank": "Strain"}, "1347913": {"name": "Stenotrophomonas maltophilia stmalt0435", "rank": "Strain"}, "300879": {"name": "Cassia yellow blotch virus", "rank": "Species"}, "610245": {"name": "Asaia prunellae", "rank": "Species"}, "610244": {"name": "Asaia astilbis", "rank": "Species"}, "610243": {"name": "Asaia platycodi", "rank": "Species"}, "1122154": {"name": "Lactococcus chungangensis CAU 28 = DSM 22330", "rank": "Strain"}, "1122157": {"name": "Laribacter hongkongensis DSM 14985", "rank": "Strain"}, "1122151": {"name": "Lactobacillus paralimentarius DSM 13238 = JCM 10415", "rank": "Strain"}, "1122153": {"name": "Lactobacillus saerimneri DSM 16049", "rank": "Strain"}, "1122152": {"name": "Lactobacillus psittaci DSM 15354", "rank": "Strain"}, "1122158": {"name": "Leeia oryzae DSM 17879", "rank": "Strain"}, "1427228": {"name": "Mycobacterium tuberculosis XTB13-138", "rank": "Strain"}, "1244528": {"name": "Campylobacter fetus subsp. testudinum 03-427", "rank": "Strain"}, "289366": {"name": "Small anellovirus 1", "rank": "Strain"}, "289367": {"name": "Small anellovirus 2", "rank": "Strain"}, "289365": {"name": "Human parvovirus 4", "rank": "Strain"}, "10442": {"name": "Baculoviridae", "rank": "Family"}, "999378": {"name": "Lactobacillus casei LC2W", "rank": "Strain"}, "4827": {"name": "Mucorales", "rank": "Order"}, "443342": {"name": "Candidate division TM7 genomosp. GTL1", "rank": "Species"}, "10449": {"name": "Lymantria dispar multiple nucleopolyhedrovirus", "rank": "Species"}, "1413390": {"name": "Staphylococcus aureus 87807-11", "rank": "Strain"}, "1413391": {"name": "Staphylococcus aureus 87807-9", "rank": "Strain"}, "1413392": {"name": "Staphylococcus aureus 87807-12", "rank": "Strain"}, "1413393": {"name": "Staphylococcus aureus 87807-16", "rank": "Strain"}, "1413394": {"name": "Staphylococcus aureus 1484-9", "rank": "Strain"}, "1413395": {"name": "Staphylococcus aureus 75495-3", "rank": "Strain"}, "1413396": {"name": "Staphylococcus aureus 76669-6", "rank": "Strain"}, "1413397": {"name": "Staphylococcus aureus 84069-2", "rank": "Strain"}, "1413398": {"name": "Staphylococcus aureus 86770-7", "rank": "Strain"}, "1413399": {"name": "Staphylococcus aureus 88088-1", "rank": "Strain"}, "768491": {"name": "Serratia sp. S4", "rank": "Species"}, "1298898": {"name": "Euryarchaeota archaeon SCGC AAA286-E23", "rank": "Species"}, "57666": {"name": "Sulfurospirillum arcachonense", "rank": "Species"}, "57665": {"name": "Sulfurospirillum", "rank": "Genus"}, "1416026": {"name": "Yellow tailflower mild mottle virus", "rank": "Species"}, "295419": {"name": "Rubellimicrobium thermophilum", "rank": "Species"}, "295418": {"name": "Rubellimicrobium", "rank": "Genus"}, "1121398": {"name": "Desulfobacter vibrioformis DSM 8776", "rank": "Strain"}, "1121399": {"name": "Desulfatiglans anilini DSM 4660", "rank": "Strain"}, "1121396": {"name": "Desulfobacter curvatus DSM 3379", "rank": "Strain"}, "1121394": {"name": "Desulfatirhabdium butyrativorans DSM 18734", "rank": "Strain"}, "1046625": {"name": "Acinetobacter lwoffii WJ10621", "rank": "Strain"}, "1121392": {"name": "Desulfatibacillum aliphaticivorans DSM 15576", "rank": "Strain"}, "1298895": {"name": "Euryarchaeota archaeon SCGC AAA287-E17", "rank": "Species"}, "696870": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. SE8a", "rank": "Strain"}, "379329": {"name": "Stx2-converting phage 86", "rank": "Species"}, "1345514": {"name": "Helicobacter pylori SA34A", "rank": "Strain"}, "1345515": {"name": "Helicobacter pylori SA34C", "rank": "Strain"}, "1345516": {"name": "Helicobacter pylori SA35A", "rank": "Strain"}, "1345517": {"name": "Helicobacter pylori SA35C", "rank": "Strain"}, "1345510": {"name": "Helicobacter pylori SA222A", "rank": "Strain"}, "1345511": {"name": "Helicobacter pylori SA222C", "rank": "Strain"}, "1345512": {"name": "Helicobacter pylori SA224A", "rank": "Strain"}, "1345513": {"name": "Helicobacter pylori SA31C", "rank": "Strain"}, "1345518": {"name": "Helicobacter pylori SA224C", "rank": "Strain"}, "1345519": {"name": "Helicobacter pylori SA226A", "rank": "Strain"}, "1340745": {"name": "Vibrio phage VFJ", "rank": "Species"}, "490910": {"name": "Arthrobacter sp. W1", "rank": "Species"}, "490913": {"name": "Sulfitobacter phage EE36phi1", "rank": "Species"}, "490912": {"name": "Silicibacter phage DSS3phi2", "rank": "Species"}, "904760": {"name": "Staphylococcus aureus subsp. aureus 21310", "rank": "Strain"}, "904761": {"name": "Staphylococcus aureus subsp. aureus 21311", "rank": "Strain"}, "904762": {"name": "Staphylococcus aureus subsp. aureus 21314", "rank": "Strain"}, "904763": {"name": "Staphylococcus aureus subsp. aureus 21318", "rank": "Strain"}, "904764": {"name": "Staphylococcus aureus subsp. aureus 21320", "rank": "Strain"}, "904765": {"name": "Staphylococcus aureus subsp. aureus 21321", "rank": "Strain"}, "904766": {"name": "Staphylococcus aureus subsp. aureus 21331", "rank": "Strain"}, "904767": {"name": "Staphylococcus aureus subsp. aureus 21333", "rank": "Strain"}, "1287281": {"name": "Mesorhizobium sp. LNJC405B00", "rank": "Species"}, "1287280": {"name": "Mesorhizobium sp. LNJC403B00", "rank": "Species"}, "1287285": {"name": "Mesorhizobium sp. LSHC412B00", "rank": "Species"}, "1287287": {"name": "Mesorhizobium sp. LSHC414A00", "rank": "Species"}, "76634": {"name": "Mycetocola", "rank": "Genus"}, "1151265": {"name": "Peptoclostridium difficile CD42", "rank": "Strain"}, "394": {"name": "Sinorhizobium fredii NGR234", "rank": "Strain"}, "396": {"name": "Rhizobium phaseoli", "rank": "Species"}, "1280668": {"name": "Butyrivibrio sp. XPD2006", "rank": "Species"}, "76636": {"name": "Mycetocola saprophilus", "rank": "Species"}, "399": {"name": "Neorhizobium galegae", "rank": "Species"}, "398": {"name": "Rhizobium tropici", "rank": "Species"}, "550984": {"name": "Halomonas sp. HAL1", "rank": "Species"}, "29530": {"name": "Cytophaga aurantiaca", "rank": "Species"}, "29536": {"name": "Flavobacterium succinicans", "rank": "Species"}, "27288": {"name": "Naumovozyma castellii", "rank": "Species"}, "27289": {"name": "Naumovozyma dairenensis", "rank": "Species"}, "1458922": {"name": "Acinetobacter baumannii LY5", "rank": "Strain"}, "1458920": {"name": "Acinetobacter baumannii LY3", "rank": "Strain"}, "1458921": {"name": "Acinetobacter baumannii LY4", "rank": "Strain"}, "1458926": {"name": "Acinetobacter baumannii LY9", "rank": "Strain"}, "1053202": {"name": "Bacillus cereus HuA2-3", "rank": "Strain"}, "1071764": {"name": "Chlamydia trachomatis F/SotonF3", "rank": "Strain"}, "1427221": {"name": "Mycobacterium tuberculosis XTB13-131", "rank": "Strain"}, "1226723": {"name": "Canis familiaris papillomavirus 13", "rank": "Strain"}, "614212": {"name": "Burkholderia oxyphila", "rank": "Species"}, "29287": {"name": "Natronococcus", "rank": "Genus"}, "614215": {"name": "Nocardiopsis sp. TP-A0876", "rank": "Species"}, "1128911": {"name": "Glaciecola arctica", "rank": "Species"}, "29283": {"name": "Halorubrum distributum", "rank": "Species"}, "1033991": {"name": "Rhizobium leguminosarum bv. trifolii CB782", "rank": "Strain"}, "1033992": {"name": "Pseudomonas oleovorans MOIL14HWK12", "rank": "Strain"}, "1033993": {"name": "Pseudomonas sp. MOIL14HWK12:I1", "rank": "Species"}, "29288": {"name": "Natronococcus occultus", "rank": "Species"}, "1033996": {"name": "Nitrososphaerales", "rank": "Order"}, "1033997": {"name": "Nitrososphaeraceae", "rank": "Family"}, "1499967": {"name": "Bacterium UASB270", "rank": "Species"}, "44060": {"name": "Streptomyces megasporus", "rank": "Species"}, "1006061": {"name": "Duck hepatitis A virus 1", "rank": "Strain"}, "1415773": {"name": "Mycoplasma ovis str. Michigan", "rank": "Strain"}, "1415774": {"name": "Clostridium botulinum 202F", "rank": "Strain"}, "1415775": {"name": "Clostridium baratii str. Sullivan", "rank": "Strain"}, "1415776": {"name": "Streptococcus thermophilus TH1435", "rank": "Strain"}, "1415777": {"name": "Bartonella grahamii ATCC 700132", "rank": "Strain"}, "1415778": {"name": "Porticoccus hydrocarbonoclasticus MCTG13d", "rank": "Strain"}, "1415779": {"name": "Polycyclovorans algicola TG408", "rank": "Strain"}, "1240758": {"name": "Escherichia coli O104:H4 str. Ec11-9450", "rank": "Strain"}, "142102": {"name": "Taura syndrome virus", "rank": "Species"}, "1232203": {"name": "Bacillus thuringiensis serovar aizawai str. Leapi01", "rank": "Strain"}, "1502852": {"name": "Massilia sp. LC238", "rank": "Species"}, "1502850": {"name": "Sphingopyxis sp. LC81", "rank": "Species"}, "1502851": {"name": "Bosea sp. LC85", "rank": "Species"}, "1049565": {"name": "Klebsiella pneumoniae KCTC 2242", "rank": "Strain"}, "1299319": {"name": "Pseudomonas putida LF54", "rank": "Strain"}, "1299310": {"name": "Macanavirus", "rank": "Genus"}, "1299311": {"name": "Betanecrovirus", "rank": "Genus"}, "1299312": {"name": "Gallantivirus", "rank": "Genus"}, "1299313": {"name": "Zeavirus", "rank": "Genus"}, "326176": {"name": "Unclassified Tospovirus", "rank": "No rank"}, "161675": {"name": "Tamana bat virus", "rank": "Species"}, "1051503": {"name": "Bacillus subtilis subsp. spizizenii DV1-B-1", "rank": "Strain"}, "913239": {"name": "Riemerella anatipestifer RA-YM", "rank": "Strain"}, "1463164": {"name": "Klebsiella sp. 07A044", "rank": "Species"}, "1463165": {"name": "Klebsiella sp. 18A069", "rank": "Species"}, "1428443": {"name": "Oenococcus oeni S23", "rank": "Strain"}, "1428440": {"name": "Oenococcus oeni S161", "rank": "Strain"}, "1003890": {"name": "Unclassified Betaflexiviridae", "rank": "No rank"}, "1003891": {"name": "Hardenbergia virus A", "rank": "Species"}, "991022": {"name": "Seal anellovirus TFFN/USA/2006", "rank": "Species"}, "245685": {"name": "Enterobacteria phage TLS", "rank": "Species"}, "1463836": {"name": "Streptomyces sp. NRRL B-3229", "rank": "Species"}, "1463837": {"name": "Streptomyces sp. NRRL B-3253", "rank": "Species"}, "1463834": {"name": "Streptomyces sp. NRRL B-24501", "rank": "Species"}, "1463835": {"name": "Streptomyces sp. NRRL B-2790", "rank": "Species"}, "1463832": {"name": "Streptomyces sp. NRRL B-24051", "rank": "Species"}, "1463833": {"name": "Streptomyces sp. NRRL B-24484", "rank": "Species"}, "1463830": {"name": "Streptomyces sp. NRRL B-2030", "rank": "Species"}, "991974": {"name": "Vibrio cholerae HC-56A2", "rank": "Strain"}, "61273": {"name": "Ophiostoma piceae", "rank": "Species"}, "991978": {"name": "Vibrio cholerae HC-59B1", "rank": "Strain"}, "68985": {"name": "Methanopyrales", "rank": "Order"}, "1463838": {"name": "Streptomyces sp. NRRL B-5680", "rank": "Species"}, "1463839": {"name": "Streptomyces sp. NRRL F-2202", "rank": "Species"}, "582402": {"name": "Hirschia baltica ATCC 49814", "rank": "Strain"}, "1227924": {"name": "Pseudomonas putida TRO1", "rank": "Strain"}, "96": {"name": "Gallionella", "rank": "Genus"}, "99": {"name": "Ancylobacter", "rank": "Genus"}, "53954": {"name": "Sugarcane streak mosaic virus", "rank": "Species"}, "1221298": {"name": "Acinetobacter haemolyticus TG19602", "rank": "Strain"}, "53953": {"name": "Pyrococcus horikoshii", "rank": "Species"}, "1292023": {"name": "Leucobacter sp. UCD-THU", "rank": "Species"}, "1292022": {"name": "Curtobacterium flaccumfaciens UCD-AKU", "rank": "Strain"}, "1292020": {"name": "Dietzia sp. UCD-THP", "rank": "Species"}, "1292027": {"name": "Pseudomonas azotifigens DSM 17556", "rank": "Strain"}, "1292026": {"name": "Desulfobulbus sp. Dsb1", "rank": "Species"}, "1292025": {"name": "Desulfobulbus sp. Dsb5", "rank": "Species"}, "1292024": {"name": "Desulfovibrio sp. Dsv1", "rank": "Species"}, "1292029": {"name": "Pseudomonas parafulva DSM 17004", "rank": "Strain"}, "1292028": {"name": "Pseudomonas cremoricolorata DSM 17059", "rank": "Strain"}, "2013": {"name": "Nocardiopsis", "rank": "Genus"}, "2012": {"name": "Thermomonosporaceae", "rank": "Family"}, "2015": {"name": "Nocardiopsis prasina", "rank": "Species"}, "2014": {"name": "Nocardiopsis dassonvillei", "rank": "Species"}, "2019": {"name": "Thermomonospora", "rank": "Genus"}, "1221293": {"name": "Acinetobacter calcoaceticus TG19585", "rank": "Strain"}, "370833": {"name": "Tomato torrado virus", "rank": "Species"}, "1121092": {"name": "Bacillus kribbensis DSM 17871", "rank": "Strain"}, "167634": {"name": "Grapevine rootstock stem lesion associated virus", "rank": "Species"}, "167639": {"name": "Ilyobacter", "rank": "Genus"}, "1531960": {"name": "Pseudomonas sp. BIC-A1/1_c5+c0+c2", "rank": "Species"}, "592205": {"name": "Helicobacter pylori B38", "rank": "Strain"}, "592206": {"name": "Helleborus net necrosis virus", "rank": "Species"}, "1221299": {"name": "Acinetobacter haemolyticus TG21157", "rank": "Strain"}, "1221296": {"name": "Acinetobacter nosocomialis TG19596", "rank": "Strain"}, "1221297": {"name": "Acinetobacter haemolyticus TG19599", "rank": "Strain"}, "1221294": {"name": "Acinetobacter calcoaceticus TG19588", "rank": "Strain"}, "1221295": {"name": "Acinetobacter calcoaceticus TG19593", "rank": "Strain"}, "1221292": {"name": "Acinetobacter baumannii TG19582", "rank": "Strain"}, "1418300": {"name": "Staphylococcus aureus H19392", "rank": "Strain"}, "1221290": {"name": "Acinetobacter baumannii AB_TG5064", "rank": "Strain"}, "1221291": {"name": "Acinetobacter baylyi TG19579", "rank": "Strain"}, "1531963": {"name": "Comamonadaceae bacterium BICA1-1", "rank": "Species"}, "1353255": {"name": "Gyalolechia flavorubescens KoLRI002931", "rank": "Strain"}, "1418306": {"name": "Staphylococcus aureus H43687", "rank": "Strain"}, "2209": {"name": "Methanosarcina mazei", "rank": "Species"}, "428031": {"name": "Moritella dasanensis", "rank": "Species"}, "321661": {"name": "Pseudomonas vranovensis", "rank": "Species"}, "1418304": {"name": "Staphylococcus aureus H22632", "rank": "Strain"}, "583356": {"name": "Ignisphaera aggregans DSM 17230", "rank": "Strain"}, "583357": {"name": "Thermoanaerobacter mathranii", "rank": "Species"}, "583358": {"name": "Thermoanaerobacter mathranii subsp. mathranii str. A3", "rank": "Strain"}, "649890": {"name": "Broad bean true mosaic virus", "rank": "Species"}, "140110": {"name": "Nectria haematococca", "rank": "Species"}, "2204": {"name": "Methanomicrobium", "rank": "Genus"}, "292800": {"name": "Flavonifractor plautii", "rank": "Species"}, "292806": {"name": "Lysinibacillus massiliensis", "rank": "Species"}, "292805": {"name": "Wolbachia endosymbiont strain TRS of Brugia malayi", "rank": "Strain"}, "888809": {"name": "Streptococcus sanguinis SK72", "rank": "Strain"}, "888807": {"name": "Streptococcus sanguinis SK1", "rank": "Strain"}, "2206": {"name": "Methanosarcinaceae", "rank": "Family"}, "888801": {"name": "Lactobacillus iners ATCC 55195", "rank": "Strain"}, "321662": {"name": "Pseudomonas moraviensis", "rank": "Species"}, "2207": {"name": "Methanosarcina", "rank": "Genus"}, "1168865": {"name": "Corynebacterium pseudotuberculosis 258", "rank": "Strain"}, "2201": {"name": "Methanofollis liminatans", "rank": "Species"}, "1439288": {"name": "Streptococcus pyogenes ABC020058759", "rank": "Strain"}, "1439289": {"name": "Streptococcus pyogenes ABC020059502", "rank": "Strain"}, "2202": {"name": "Methanospirillum", "rank": "Genus"}, "1439283": {"name": "Streptococcus pyogenes ABC020057168", "rank": "Strain"}, "2203": {"name": "Methanospirillum hungatei", "rank": "Species"}, "1439286": {"name": "Streptococcus pyogenes ABC020057442", "rank": "Strain"}, "1439287": {"name": "Streptococcus pyogenes ABC020057449", "rank": "Strain"}, "1439284": {"name": "Streptococcus pyogenes ABC020057192", "rank": "Strain"}, "583355": {"name": "Coraliomargarita akajimensis DSM 45221", "rank": "Strain"}, "1409663": {"name": "Staphylococcus aureus UCIM6105", "rank": "Strain"}, "1409662": {"name": "Staphylococcus aureus AGEN6042", "rank": "Strain"}, "1281007": {"name": "Escherichia coli HVH 63 (4-2542528)", "rank": "Strain"}, "269213": {"name": "Humulus japonicus latent virus", "rank": "Species"}, "1713": {"name": "Oerskovia turbata", "rank": "Species"}, "115979": {"name": "Bacillus nealsonii", "rank": "Species"}, "1711": {"name": "Cellulomonas flavigena", "rank": "Species"}, "1710": {"name": "Cellulosimicrobium cellulans", "rank": "Species"}, "1717": {"name": "Corynebacterium diphtheriae", "rank": "Species"}, "1716": {"name": "Corynebacterium", "rank": "Genus"}, "490567": {"name": "Arenimonas", "rank": "Genus"}, "1444277": {"name": "Escherichia coli 3-073-06_S4_C3", "rank": "Strain"}, "1719": {"name": "Corynebacterium pseudotuberculosis", "rank": "Species"}, "1718": {"name": "Corynebacterium glutamicum", "rank": "Species"}, "152500": {"name": "Burkholderia dolosa", "rank": "Species"}, "1409665": {"name": "Staphylococcus aureus UCIM6106", "rank": "Strain"}, "1500296": {"name": "Chryseobacterium sp. YR480", "rank": "Species"}, "1409664": {"name": "Staphylococcus aureus MISS6092", "rank": "Strain"}, "710111": {"name": "Frankia sp. QA3", "rank": "Species"}, "710112": {"name": "Haloarcula hispanica pleomorphic virus 1", "rank": "Species"}, "1409669": {"name": "Staphylococcus aureus FVRH6079", "rank": "Strain"}, "1291303": {"name": "Leptospira santarosai serovar Szwajizak", "rank": "Strain"}, "1444278": {"name": "Escherichia coli 3-105-05_S4_C3", "rank": "Strain"}, "1291307": {"name": "Leptospira interrogans serovar Canicola str. P2655", "rank": "Strain"}, "1291304": {"name": "Leptospira santarosai serovar Szwajizak str. Oregon", "rank": "Strain"}, "1436290": {"name": "Candidatus Symbiobacter mobilis", "rank": "Species"}, "1291309": {"name": "Leptospira interrogans serovar Jalna str. 2008720117", "rank": "Strain"}, "1291308": {"name": "Leptospira interrogans serovar Jalna str. 2008720116", "rank": "Strain"}, "1072571": {"name": "Salmonella enterica subsp. enterica serovar Paratyphi A str. YN09620", "rank": "Strain"}, "1072570": {"name": "Salmonella enterica subsp. enterica serovar Paratyphi A str. JX05-19", "rank": "Strain"}, "1104668": {"name": "Unclassified candidate division TM6", "rank": "No rank"}, "1151231": {"name": "Escherichia coli B93", "rank": "Strain"}, "888808": {"name": "Streptococcus sanguinis SK49", "rank": "Strain"}, "872326": {"name": "Lactobacillus equicursoris 66c", "rank": "Strain"}, "872327": {"name": "Lactobacillus pasteurii", "rank": "Species"}, "290315": {"name": "Chlorobium limicola DSM 245", "rank": "Strain"}, "290314": {"name": "Sapovirus C12", "rank": "Strain"}, "290317": {"name": "Chlorobium phaeobacteroides DSM 266", "rank": "Strain"}, "290318": {"name": "Chlorobium phaeovibrioides DSM 265", "rank": "Strain"}, "1500295": {"name": "Chryseobacterium sp. YR477", "rank": "Species"}, "627439": {"name": "Human enteric coronavirus strain 4408", "rank": "Species"}, "435998": {"name": "Serratia marcescens WW4", "rank": "Strain"}, "1434925": {"name": "Burkholderia pseudomallei MSHR5569", "rank": "Strain"}, "1434926": {"name": "Burkholderia pseudomallei MSHR5596", "rank": "Strain"}, "1434927": {"name": "Burkholderia pseudomallei MSHR3964", "rank": "Subspecies"}, "1434928": {"name": "Burkholderia pseudomallei ABCPW 107", "rank": "Subspecies"}, "1434929": {"name": "Burkholderia pseudomallei ABCPW 111", "rank": "Subspecies"}, "119644": {"name": "Hymenobacter aerophilus", "rank": "Species"}, "1115818": {"name": "Streptococcus pyogenes GA19700", "rank": "Strain"}, "1115819": {"name": "Streptococcus pyogenes GA41039", "rank": "Strain"}, "1115812": {"name": "Streptococcus pyogenes GA41046", "rank": "Strain"}, "1115813": {"name": "Streptococcus pyogenes GA41345", "rank": "Strain"}, "1115810": {"name": "Streptococcus pyogenes UTSW-2", "rank": "Strain"}, "1115811": {"name": "Streptococcus pyogenes UTMEM-1", "rank": "Strain"}, "1115816": {"name": "Streptococcus pyogenes GA06023", "rank": "Strain"}, "1115817": {"name": "Streptococcus pyogenes GA40468", "rank": "Strain"}, "1115814": {"name": "Streptococcus pyogenes GA40634", "rank": "Strain"}, "1115815": {"name": "Streptococcus pyogenes GA19681", "rank": "Strain"}, "992015": {"name": "Helicobacter pylori CPY1662", "rank": "Strain"}, "992014": {"name": "Helicobacter pylori CPY1313", "rank": "Strain"}, "992017": {"name": "Helicobacter pylori CPY3281", "rank": "Strain"}, "992016": {"name": "Helicobacter pylori CPY1962", "rank": "Strain"}, "992010": {"name": "Vibrio sp. HENC-01", "rank": "Species"}, "992013": {"name": "Helicobacter pylori CPY1124", "rank": "Strain"}, "992012": {"name": "Vibrio sp. HENC-03", "rank": "Species"}, "992019": {"name": "Helicobacter pylori CPY6261", "rank": "Strain"}, "992018": {"name": "Helicobacter pylori CPY6081", "rank": "Strain"}, "1268240": {"name": "Bacteroides cellulosilyticus WH2", "rank": "Strain"}, "1422518": {"name": "Staphylococcus aureus VET0224R", "rank": "Strain"}, "316401": {"name": "Escherichia coli ETEC H10407", "rank": "Strain"}, "1422519": {"name": "Staphylococcus aureus VET0227R", "rank": "Strain"}, "316407": {"name": "Escherichia coli str. K-12 substr. W3110", "rank": "Strain"}, "267212": {"name": "Neisseria bacilliformis", "rank": "Species"}, "999438": {"name": "Treponema denticola SP37", "rank": "Strain"}, "999439": {"name": "Treponema denticola SP44", "rank": "Strain"}, "216595": {"name": "Pseudomonas fluorescens SBW25", "rank": "Strain"}, "216594": {"name": "Mycobacterium marinum M", "rank": "Strain"}, "216597": {"name": "Salmonella enterica subsp. enterica serovar Typhimurium str. SL1344", "rank": "Strain"}, "216596": {"name": "Rhizobium leguminosarum bv. viciae 3841", "rank": "Strain"}, "999432": {"name": "Treponema denticola H-22", "rank": "Strain"}, "999433": {"name": "Treponema denticola MYR-T", "rank": "Strain"}, "999430": {"name": "Treponema denticola ATCC 35404", "rank": "Strain"}, "999431": {"name": "Treponema denticola H1-T", "rank": "Strain"}, "999436": {"name": "Treponema denticola SP32", "rank": "Strain"}, "999437": {"name": "Treponema denticola SP33", "rank": "Strain"}, "999434": {"name": "Treponema denticola OTK", "rank": "Strain"}, "999435": {"name": "Treponema denticola SP23", "rank": "Strain"}, "291048": {"name": "Caminibacter mediatlanticus", "rank": "Species"}, "1221304": {"name": "Acinetobacter sp. TG2027", "rank": "Species"}, "436717": {"name": "Acinetobacter oleivorans DR1", "rank": "Strain"}, "51589": {"name": "Haloarcula hispanica", "rank": "Species"}, "117563": {"name": "Granulicatella", "rank": "Genus"}, "1429767": {"name": "Erwinia phage Ea9-2", "rank": "Species"}, "1313298": {"name": "Teredinibacter turnerae 1133Y.S.0a.04", "rank": "Strain"}, "1454227": {"name": "Ageratum yellow vein China alphasatellite", "rank": "Species"}, "1313294": {"name": "Borrelia parkeri SLO", "rank": "Strain"}, "1313295": {"name": "Borrelia hermsii YBT", "rank": "Strain"}, "197183": {"name": "Alkanindiges illinoisensis", "rank": "Species"}, "1313290": {"name": "Erysipelothrix rhusiopathiae SY1027", "rank": "Strain"}, "1313291": {"name": "Borrelia hermsii MTW", "rank": "Strain"}, "1313292": {"name": "Borrelia coriaceae Co53", "rank": "Strain"}, "1313293": {"name": "Borrelia anserina BA2", "rank": "Strain"}, "34011": {"name": "Niveispirillum irakense", "rank": "Species"}, "1394677": {"name": "Vibrio parahaemolyticus S143", "rank": "Strain"}, "714640": {"name": "Papaya leaf curl betasatellite", "rank": "Species"}, "1053648": {"name": "Candidatus Tremblaya princeps PCVAL", "rank": "Strain"}, "1309583": {"name": "Bacillus phage MG-B1", "rank": "Species"}, "1394672": {"name": "Vibrio parahaemolyticus S138", "rank": "Strain"}, "1394670": {"name": "Vibrio parahaemolyticus S136", "rank": "Strain"}, "1439285": {"name": "Streptococcus pyogenes ABC020057288", "rank": "Strain"}, "1562565": {"name": "Pyrinomonas", "rank": "Genus"}, "1394679": {"name": "Vibrio parahaemolyticus S145", "rank": "Strain"}, "1394678": {"name": "Vibrio parahaemolyticus S144", "rank": "Strain"}, "34019": {"name": "Candidatus Liberibacter", "rank": "Genus"}, "1310754": {"name": "Acinetobacter baumannii 2887", "rank": "Strain"}, "1310755": {"name": "Acinetobacter baumannii 628418", "rank": "Strain"}, "1310756": {"name": "Acinetobacter baumannii 1294243", "rank": "Strain"}, "1310757": {"name": "Acinetobacter baumannii 755829", "rank": "Strain"}, "1310750": {"name": "Acinetobacter baumannii 1064293_45", "rank": "Strain"}, "1310751": {"name": "Acinetobacter baumannii 1022959", "rank": "Strain"}, "1310752": {"name": "Acinetobacter baumannii 1293320", "rank": "Strain"}, "1310753": {"name": "Acinetobacter baumannii 1296252", "rank": "Strain"}, "142843": {"name": "Hop mosaic virus", "rank": "Species"}, "1182711": {"name": "Escherichia coli KTE121", "rank": "Strain"}, "1310758": {"name": "Acinetobacter baumannii 1266220", "rank": "Strain"}, "1310759": {"name": "Acinetobacter baumannii 573719", "rank": "Strain"}, "1422364": {"name": "Staphylococcus aureus DAR5809", "rank": "Strain"}, "55987": {"name": "Infectious salmon anemia virus", "rank": "Species"}, "1408974": {"name": "Mycobacterium tuberculosis UT0124", "rank": "Strain"}, "1408975": {"name": "Mycobacterium tuberculosis UT0017", "rank": "Strain"}, "1408970": {"name": "Mycobacterium tuberculosis UT0115", "rank": "Strain"}, "1408971": {"name": "Mycobacterium tuberculosis UT0116", "rank": "Strain"}, "1408972": {"name": "Mycobacterium tuberculosis UT0118", "rank": "Strain"}, "1408973": {"name": "Mycobacterium tuberculosis UT0123", "rank": "Strain"}, "1164882": {"name": "Lachnoanaerobaculum", "rank": "Genus"}, "400634": {"name": "Lysinibacillus", "rank": "Genus"}, "543302": {"name": "Alicyclobacillus acidocaldarius LAA1", "rank": "Strain"}, "1446675": {"name": "Escherichia coli O157:H7 str. K2581", "rank": "Strain"}, "1446674": {"name": "Escherichia coli O157:H7 str. K2324", "rank": "Strain"}, "1446677": {"name": "Escherichia coli O157:H7 str. K2845", "rank": "Strain"}, "1446676": {"name": "Escherichia coli O157:H7 str. K2622", "rank": "Strain"}, "1446671": {"name": "Escherichia coli O157:H7 str. K2188", "rank": "Strain"}, "1446670": {"name": "Escherichia coli O157:H7 str. K1927", "rank": "Strain"}, "1446673": {"name": "Escherichia coli O157:H7 str. K2192", "rank": "Strain"}, "1446672": {"name": "Escherichia coli O157:H7 str. K2191", "rank": "Strain"}, "1446679": {"name": "Escherichia coli O157:H7 str. K4396", "rank": "Strain"}, "1446678": {"name": "Escherichia coli O157:H7 str. K2854", "rank": "Strain"}, "1261061": {"name": "Gardnerella vaginalis JCP7719", "rank": "Strain"}, "1261060": {"name": "Gardnerella vaginalis JCP7672", "rank": "Strain"}, "1261063": {"name": "Gardnerella vaginalis JCP8017B", "rank": "Strain"}, "1261062": {"name": "Gardnerella vaginalis JCP8017A", "rank": "Strain"}, "1261065": {"name": "Gardnerella vaginalis JCP8070", "rank": "Strain"}, "1261064": {"name": "Gardnerella vaginalis JCP8066", "rank": "Strain"}, "1261067": {"name": "Gardnerella vaginalis JCP8151A", "rank": "Strain"}, "1261066": {"name": "Gardnerella vaginalis JCP8108", "rank": "Strain"}, "1261069": {"name": "Gardnerella vaginalis JCP8481A", "rank": "Strain"}, "1261068": {"name": "Gardnerella vaginalis JCP8151B", "rank": "Strain"}, "1397876": {"name": "Mycobacterium tuberculosis TKK_02_0045", "rank": "Strain"}, "1421860": {"name": "Staphylococcus aureus H72131", "rank": "Strain"}, "1266054": {"name": "Algiphilaceae", "rank": "Family"}, "1421866": {"name": "Staphylococcus aureus H84959", "rank": "Strain"}, "1388508": {"name": "Staphylococcus aureus M0702", "rank": "Strain"}, "568987": {"name": "Candidatus Hamiltonella", "rank": "Genus"}, "1421865": {"name": "Staphylococcus aureus H84958", "rank": "Strain"}, "1388500": {"name": "Staphylococcus aureus M0741", "rank": "Strain"}, "1388501": {"name": "Staphylococcus aureus M0742", "rank": "Strain"}, "1388502": {"name": "Staphylococcus aureus M0625", "rank": "Strain"}, "1388503": {"name": "Staphylococcus aureus M0635", "rank": "Strain"}, "1388504": {"name": "Staphylococcus aureus M0650", "rank": "Strain"}, "314230": {"name": "Blastopirellula marina DSM 3645", "rank": "Strain"}, "1388506": {"name": "Staphylococcus aureus M0675", "rank": "Strain"}, "1388507": {"name": "Staphylococcus aureus M0688", "rank": "Strain"}, "75309": {"name": "Rhodanobacter", "rank": "Genus"}, "237684": {"name": "Salinibacillus aidingensis", "rank": "Species"}, "1236": {"name": "Gammaproteobacteria", "rank": "Class"}, "1168478": {"name": "Persicivirga phage P12024S", "rank": "Species"}, "1168479": {"name": "Persicivirga phage P12024L", "rank": "Species"}, "1079752": {"name": "Neisseria meningitidis Nm3127", "rank": "Strain"}, "1079753": {"name": "Neisseria meningitidis Nm2732", "rank": "Strain"}, "1079754": {"name": "Neisseria meningitidis Nm6938", "rank": "Strain"}, "1079755": {"name": "Neisseria meningitidis Nm6756", "rank": "Strain"}, "1079756": {"name": "Neisseria meningitidis Nm8663", "rank": "Strain"}, "1079757": {"name": "Neisseria meningitidis Nm1140", "rank": "Strain"}, "248452": {"name": "Psychrobacter aquaticus", "rank": "Species"}, "1190451": {"name": "Campylobacter phage CP21", "rank": "Species"}, "475254": {"name": "Pedobacter borealis", "rank": "Species"}, "1198627": {"name": "Mycobacterium abscessus subsp. bolletii str. GO 06", "rank": "Strain"}, "1125980": {"name": "Vibrio harveyi CAIM 1792", "rank": "Strain"}, "1198629": {"name": "Pseudomonas aeruginosa MRW44.1", "rank": "Strain"}, "1434177": {"name": "Shigella flexneri Shi06HN347", "rank": "Strain"}, "1434176": {"name": "Shigella flexneri Shi06HN344", "rank": "Strain"}, "1434175": {"name": "Shigella flexneri Shi06HN159", "rank": "Strain"}, "1434174": {"name": "Shigella flexneri Shi06GS02", "rank": "Strain"}, "1434173": {"name": "Shigella flexneri 2005GS061", "rank": "Strain"}, "1434172": {"name": "Shigella flexneri 2005184", "rank": "Strain"}, "1434171": {"name": "Shigella flexneri 2005051", "rank": "Strain"}, "1434170": {"name": "Shigella flexneri 2005025", "rank": "Strain"}, "1434179": {"name": "Shigella flexneri Shi06AH091", "rank": "Strain"}, "1434178": {"name": "Shigella flexneri Shi06HN091", "rank": "Strain"}, "367488": {"name": "Blattabacterium sp. (Periplaneta americana)", "rank": "Species"}, "10600": {"name": "Human papillomavirus type 6b", "rank": "Strain"}, "42838": {"name": "Ammonifex degensii", "rank": "Species"}, "314496": {"name": "Tomato mild yellow leaf curl Aragua virus - Venezuela:10:2003", "rank": "Strain"}, "366686": {"name": "TYLCCNV-Y322 satellite DNA beta", "rank": "Species"}, "230158": {"name": "Haemophilus phage Aaphi23", "rank": "Species"}, "1071757": {"name": "Chlamydia trachomatis D/SotonD5", "rank": "Strain"}, "223919": {"name": "Clostridium diolis", "rank": "Species"}, "39945": {"name": "Unclassified Mollicutes", "rank": "No rank"}, "938772": {"name": "Beta proteobacterium SCGC AAA027-C02", "rank": "Species"}, "483219": {"name": "Myxococcus fulvus HW-1", "rank": "Strain"}, "483216": {"name": "Bacteroides eggerthii DSM 20697", "rank": "Strain"}, "483217": {"name": "Bacteroides dorei DSM 17855", "rank": "Strain"}, "483214": {"name": "Methanobrevibacter smithii DSM 2375", "rank": "Strain"}, "483215": {"name": "Bacteroides finegoldii DSM 17565", "rank": "Strain"}, "39948": {"name": "Dialister", "rank": "Genus"}, "39949": {"name": "Zymophilus", "rank": "Genus"}, "889813": {"name": "Colobus guereza papillomavirus type 2", "rank": "Strain"}, "701175": {"name": "Vibrio caribbeanicus", "rank": "Species"}, "701176": {"name": "Vibrio sp. N418", "rank": "Species"}, "701177": {"name": "Escherichia coli O55:H7 str. CB9615", "rank": "Strain"}, "280236": {"name": "Nocardiopsis gilva", "rank": "Species"}, "927668": {"name": "Pseudanabaena biceps PCC 7429", "rank": "Strain"}, "927669": {"name": "Pseudanabaena biceps", "rank": "Species"}, "927666": {"name": "Streptococcus oralis Uo5", "rank": "Strain"}, "1218513": {"name": "Serratia marcescens W2.3", "rank": "Strain"}, "927661": {"name": "Cryptosporangium arvum DSM 44712", "rank": "Strain"}, "1577051": {"name": "Thermus sp. 2.9", "rank": "Species"}, "232799": {"name": "Iflavirus", "rank": "Genus"}, "232795": {"name": "Dicistroviridae", "rank": "Family"}, "5482": {"name": "Candida tropicalis", "rank": "Species"}, "5480": {"name": "Candida parapsilosis", "rank": "Species"}, "1505663": {"name": "Erysipelatoclostridium", "rank": "Genus"}, "1505664": {"name": "Gottschalkia", "rank": "Genus"}, "11553": {"name": "Influenza C virus (C/Ann Arbor/1/50)", "rank": "Strain"}, "11552": {"name": "Influenza C virus", "rank": "Species"}, "202611": {"name": "Lysinibacillus odysseyi", "rank": "Species"}, "1118059": {"name": "Kallipyga massiliensis ph2", "rank": "Strain"}, "231683": {"name": "Saccharospirillum", "rank": "Genus"}, "1118055": {"name": "Anaerococcus sp. PH9", "rank": "Species"}, "1118054": {"name": "Brevibacillus massiliensis", "rank": "Species"}, "1118057": {"name": "Peptoniphilus grossensis ph5", "rank": "Strain"}, "1118056": {"name": "Anaerococcus obesiensis ph10", "rank": "Strain"}, "604354": {"name": "Thermococcus sibiricus MM 739", "rank": "Strain"}, "362246": {"name": "Unclassified Ampelovirus", "rank": "No rank"}, "570417": {"name": "Wolbachia endosymbiont of Culex quinquefasciatus Pel", "rank": "Strain"}, "570416": {"name": "Bacillus thuringiensis serovar kurstaki str. YBT-1520", "rank": "Strain"}, "482564": {"name": "Oscillatoria nigro-viridis", "rank": "Species"}, "2252": {"name": "Haloferax mediterranei", "rank": "Species"}, "2251": {"name": "Haloferax", "rank": "Genus"}, "2250": {"name": "Halococcus morrhuae", "rank": "Species"}, "2257": {"name": "Natronomonas pharaonis", "rank": "Species"}, "2256": {"name": "Natronobacterium", "rank": "Genus"}, "2254": {"name": "Haloferax lucentense", "rank": "Species"}, "2259": {"name": "Thermococcaceae", "rank": "Family"}, "2258": {"name": "Thermococcales", "rank": "Order"}, "10832": {"name": "Tomato yellow leaf curl virus", "rank": "Species"}, "1458279": {"name": "Staphylococcus aureus USA300-ISMMS1", "rank": "Strain"}, "1458276": {"name": "Aeromonas jandaei Riv2", "rank": "Strain"}, "1458277": {"name": "Bordetella pertussis B200", "rank": "Strain"}, "1458274": {"name": "Vibrio cholerae O1 biovar El Tor str. L-3226", "rank": "Strain"}, "1458275": {"name": "Hylemonella gracilis str. Niagara R", "rank": "Strain"}, "1541818": {"name": "Sedimentitalea", "rank": "Genus"}, "5269": {"name": "Ustilago", "rank": "Genus"}, "5268": {"name": "Ustilaginaceae", "rank": "Family"}, "1208590": {"name": "Cronobacter turicensis 564", "rank": "Strain"}, "1208591": {"name": "Cronobacter malonaticus 681", "rank": "Strain"}, "1208592": {"name": "Cronobacter sakazakii 680", "rank": "Strain"}, "1281059": {"name": "Escherichia coli HVH 122 (4-6851606)", "rank": "Strain"}, "1281056": {"name": "Escherichia coli HVH 119 (4-6879578)", "rank": "Strain"}, "5262": {"name": "Pucciniaceae", "rank": "Family"}, "1281054": {"name": "Escherichia coli HVH 117 (4-6857191)", "rank": "Strain"}, "1281055": {"name": "Escherichia coli HVH 118 (4-7345399)", "rank": "Strain"}, "5267": {"name": "Ustilaginales", "rank": "Order"}, "1208599": {"name": "Bacillus sp. FJAT-14515", "rank": "Species"}, "1281050": {"name": "Escherichia coli HVH 114 (4-7037740)", "rank": "Strain"}, "1281051": {"name": "Escherichia coli HVH 115 (4-4465997)", "rank": "Strain"}, "1240385": {"name": "Escherichia coli O157:H7 str. H093800014", "rank": "Strain"}, "1429759": {"name": "Mycobacterium phage EagleEye", "rank": "Species"}, "1429758": {"name": "Pseudomonas phage phiIBB-PAA2", "rank": "Species"}, "262543": {"name": "Exiguobacterium sibiricum 255-15", "rank": "Strain"}, "40754": {"name": "Thioploca ingrica", "rank": "Species"}, "173443": {"name": "Salmonella phage ST64T", "rank": "Species"}, "40751": {"name": "Thioploca", "rank": "Genus"}, "1170230": {"name": "Penicillium digitatum Pd1", "rank": "Strain"}, "246861": {"name": "Grimontia", "rank": "Genus"}, "1476577": {"name": "Candidatus Saccharibacteria oral taxon TM7x", "rank": "Species"}, "1048983": {"name": "Anditalea andensis", "rank": "Species"}, "1155739": {"name": "Moorea producens", "rank": "Species"}, "1155738": {"name": "Moorea", "rank": "Genus"}, "696472": {"name": "Ostreococcus tauri virus 2", "rank": "Species"}, "1178541": {"name": "Bacillus safensis FO-36b", "rank": "Strain"}, "1178540": {"name": "Bacillus sp. DW5-4", "rank": "Species"}, "1178544": {"name": "Bacillus altitudinis 41KF2b", "rank": "Strain"}, "512088": {"name": "Pineapple bacilliform comosus virus", "rank": "Species"}, "679901": {"name": "Methanosalsum zhilinae DSM 4017", "rank": "Strain"}, "158787": {"name": "Bifidobacterium scardovii", "rank": "Species"}, "80679": {"name": "Thioflavicoccus mobilis", "rank": "Species"}, "1247649": {"name": "Bordetella holmesii ATCC 51541", "rank": "Strain"}, "1247648": {"name": "Bordetella holmesii 1058", "rank": "Strain"}, "552398": {"name": "Ruminococcaceae bacterium D16", "rank": "Species"}, "1247645": {"name": "Bordetella holmesii 35009", "rank": "Strain"}, "552397": {"name": "Unclassified Ruminococcaceae", "rank": "No rank"}, "1247647": {"name": "Bordetella holmesii 70147", "rank": "Strain"}, "1247646": {"name": "Bordetella holmesii 41130", "rank": "Strain"}, "1543419": {"name": "Torque teno Tadarida brasiliensis virus", "rank": "Species"}, "766728": {"name": "Meyerozyma", "rank": "Genus"}, "766729": {"name": "Vibrio vulnificus JY1305", "rank": "Strain"}, "382262": {"name": "Prochlorococcus phage P-GSP1", "rank": "Species"}, "644295": {"name": "Methanohalobium evestigatum Z-7303", "rank": "Strain"}, "172391": {"name": "Tomato chlorotic mottle virus", "rank": "Species"}, "1448768": {"name": "Mycobacterium tuberculosis M2206", "rank": "Strain"}, "452563": {"name": "Cladosporiaceae", "rank": "Family"}, "1055539": {"name": "Escherichia coli O91", "rank": "Strain"}, "208050": {"name": "Unclassified Peptococcaceae", "rank": "No rank"}, "1055532": {"name": "Helicobacter pylori Aklavik86", "rank": "Strain"}, "1055530": {"name": "Helicobacter pylori SNT49", "rank": "Strain"}, "1055531": {"name": "Helicobacter pylori Aklavik117", "rank": "Strain"}, "930774": {"name": "Salmonella enterica subsp. enterica serovar Paratyphi B str. ATCC 10719", "rank": "Strain"}, "930775": {"name": "Salmonella enterica subsp. enterica serovar Paratyphi B str. ATCC 19940", "rank": "Strain"}, "1519406": {"name": "Sewage-associated gemycircularvirus-11", "rank": "Species"}, "1213732": {"name": "Staphylococcus aureus M0892", "rank": "Strain"}, "1386970": {"name": "Clostridium perfringens JJC", "rank": "Strain"}, "5258": {"name": "Pucciniales", "rank": "Order"}, "1513525": {"name": "Sida golden mosaic Buckup virus", "rank": "Species"}, "1513527": {"name": "Sweet potato leaf curl Uganda virus", "rank": "Species"}, "1430440": {"name": "Magnetospirillum gryphiswaldense MSR-1 v2", "rank": "Strain"}, "1430444": {"name": "Escherichia phage vB_EcoM_JS09", "rank": "Species"}, "1125725": {"name": "Treponema socranskii subsp. socranskii VPI DR56BR1116 = ATCC 35536", "rank": "Strain"}, "523909": {"name": "Musca domestica salivary gland hypertrophy virus", "rank": "Strain"}, "271155": {"name": "Flavobacterium antarcticum", "rank": "Species"}, "264634": {"name": "Acholeplasma equifetale", "rank": "Species"}, "192584": {"name": "Phthorimaea operculella granulovirus", "rank": "Species"}, "1412627": {"name": "Staphylococcus aureus F23336", "rank": "Strain"}, "1412626": {"name": "Staphylococcus aureus F20115", "rank": "Strain"}, "1412625": {"name": "Staphylococcus aureus F20105", "rank": "Strain"}, "1412624": {"name": "Staphylococcus aureus F16470", "rank": "Strain"}, "1412623": {"name": "Staphylococcus aureus F16432", "rank": "Strain"}, "1412622": {"name": "Staphylococcus aureus F13027", "rank": "Strain"}, "1412621": {"name": "Staphylococcus aureus F13022", "rank": "Strain"}, "1412629": {"name": "Staphylococcus aureus F23353", "rank": "Strain"}, "1412628": {"name": "Staphylococcus aureus F23347", "rank": "Strain"}, "1086749": {"name": "Mycobacterium phage Dreamboat", "rank": "Species"}, "653045": {"name": "Streptomyces violaceusniger Tu 4113", "rank": "Strain"}, "425010": {"name": "Botryotinia fuckeliana partitivirus 1", "rank": "Species"}, "425011": {"name": "Aspergillus niger CBS 513.88", "rank": "Strain"}, "1417019": {"name": "Mycobacterium tuberculosis KT-0037", "rank": "Strain"}, "1417018": {"name": "Mycobacterium tuberculosis KT-0034", "rank": "Strain"}, "1417017": {"name": "Mycobacterium tuberculosis KT-0033", "rank": "Strain"}, "1417016": {"name": "Mycobacterium tuberculosis KT-0032", "rank": "Strain"}, "1417015": {"name": "Mycobacterium tuberculosis KT-0031", "rank": "Strain"}, "1417014": {"name": "Mycobacterium tuberculosis KT-0029", "rank": "Strain"}, "1417013": {"name": "Mycobacterium tuberculosis KT-0025", "rank": "Strain"}, "1417012": {"name": "Mycobacterium tuberculosis KT-0020", "rank": "Strain"}, "1417011": {"name": "Mycobacterium tuberculosis KT-0018", "rank": "Strain"}, "1417010": {"name": "Mycobacterium tuberculosis KT-0012", "rank": "Strain"}, "10366": {"name": "Murid herpesvirus 1", "rank": "Species"}, "10365": {"name": "Muromegalovirus", "rank": "Genus"}, "1382304": {"name": "Alicyclobacillus macrosporangiidus CPP55", "rank": "Strain"}, "1382305": {"name": "Sporosarcina sp. D27", "rank": "Species"}, "591023": {"name": "Actinobacillus minor 202", "rank": "Strain"}, "1382301": {"name": "Lactobacillus plantarum EGD-AQ4", "rank": "Strain"}, "1382302": {"name": "Brevibacillus thermoruber PM1", "rank": "Strain"}, "1382303": {"name": "Caulobacteraceae bacterium PMMR1", "rank": "Species"}, "1173456": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN000228", "rank": "Strain"}, "1173457": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN000191", "rank": "Strain"}, "1173454": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN000192", "rank": "Strain"}, "1173455": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN000218", "rank": "Strain"}, "1173452": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN000198", "rank": "Strain"}, "1173453": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN000203", "rank": "Strain"}, "1173450": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN000221", "rank": "Strain"}, "1173451": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN000208", "rank": "Strain"}, "590998": {"name": "Cellulomonas fimi ATCC 484", "rank": "Strain"}, "1173458": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN000206", "rank": "Strain"}, "1173459": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN000211", "rank": "Strain"}, "90370": {"name": "Salmonella enterica subsp. enterica serovar Typhi", "rank": "Strain"}, "350688": {"name": "Alkaliphilus oremlandii OhILAs", "rank": "Strain"}, "88404": {"name": "Methanocorpusculaceae", "rank": "Family"}, "1413215": {"name": "Geobacillus thermodenitrificans subsp. thermodenitrificans DSM 465", "rank": "Strain"}, "1413214": {"name": "Paenibacillus polymyxa SQR-21", "rank": "Strain"}, "165301": {"name": "Lentzea", "rank": "Genus"}, "1413216": {"name": "Acinetobacter baumannii PKAB07", "rank": "Strain"}, "1125779": {"name": "Corynebacterium pyruviciproducens ATCC BAA-1742", "rank": "Strain"}, "1413213": {"name": "Bacillus licheniformis G-1", "rank": "Strain"}, "134599": {"name": "Tomato rugose mosaic virus", "rank": "Species"}, "242750": {"name": "Prevotella bergensis", "rank": "Species"}, "749219": {"name": "Moraxella catarrhalis RH4", "rank": "Strain"}, "1444310": {"name": "Bacillus flexus T6186-2", "rank": "Strain"}, "1444311": {"name": "Ochrobactrum intermedium 2745-2", "rank": "Strain"}, "1287326": {"name": "Mesorhizobium sp. LSJC269B00", "rank": "Species"}, "1128071": {"name": "Clostridium phage phi24R", "rank": "Species"}, "1287325": {"name": "Mesorhizobium sp. LSJC268A00", "rank": "Species"}, "1287322": {"name": "Mesorhizobium sp. LSJC265A00", "rank": "Species"}, "561231": {"name": "Pectobacterium wasabiae WPP163", "rank": "Strain"}, "1287321": {"name": "Mesorhizobium sp. LSJC264A00", "rank": "Species"}, "1444314": {"name": "Paenibacillus ehimensis A2", "rank": "Strain"}, "1444315": {"name": "Lysobacter capsici AZ78", "rank": "Strain"}, "333774": {"name": "Unclassified Papillomaviridae", "rank": "No rank"}, "5351": {"name": "Tricholomataceae", "rank": "Family"}, "1304883": {"name": "Dechloromonas agitata is5", "rank": "Strain"}, "1074488": {"name": "Brachybacterium squillarum M-6-3", "rank": "Strain"}, "1409529": {"name": "Staphylococcus aureus MISS6033", "rank": "Strain"}, "1074482": {"name": "Bifidobacterium breve DPC 6330", "rank": "Strain"}, "1074486": {"name": "Klebsiella pneumoniae 1191100241", "rank": "Strain"}, "1074485": {"name": "Corynebacterium pseudotuberculosis 316", "rank": "Strain"}, "463": {"name": "Fluoribacter dumoffii", "rank": "Species"}, "157782": {"name": "Pseudomonas parafulva", "rank": "Species"}, "461": {"name": "Fluoribacter", "rank": "Genus"}, "469": {"name": "Acinetobacter", "rank": "Genus"}, "468": {"name": "Moraxellaceae", "rank": "Family"}, "1418104": {"name": "Clostridium argentinense CDC 2741", "rank": "Strain"}, "1418105": {"name": "Rhizobium gallicum bv. gallicum R602", "rank": "Strain"}, "1418107": {"name": "Aeromonas hydrophila pc104A", "rank": "Strain"}, "558884": {"name": "Aeromonas sp. AE122", "rank": "Species"}, "375451": {"name": "Roseobacter denitrificans OCh 114", "rank": "Strain"}, "1410755": {"name": "Staphylococcus aureus M64191", "rank": "Strain"}, "1410754": {"name": "Staphylococcus aureus H75198", "rank": "Strain"}, "1410757": {"name": "Staphylococcus aureus T34696", "rank": "Strain"}, "1410756": {"name": "Staphylococcus aureus M70590", "rank": "Strain"}, "1410751": {"name": "Staphylococcus aureus M64164", "rank": "Strain"}, "1410750": {"name": "Staphylococcus aureus H69239", "rank": "Strain"}, "1410753": {"name": "Staphylococcus aureus W18443", "rank": "Strain"}, "1410752": {"name": "Staphylococcus aureus M67290", "rank": "Strain"}, "377628": {"name": "Yersinia pestis Nepal516", "rank": "Strain"}, "1410759": {"name": "Staphylococcus aureus W21472", "rank": "Strain"}, "1410758": {"name": "Staphylococcus aureus T34703", "rank": "Strain"}, "198833": {"name": "Vesicular stomatitis Alagoas virus", "rank": "Species"}, "34038": {"name": "Rahnella aquatilis", "rank": "Species"}, "1304884": {"name": "Desulfitibacter alkalitolerans DSM 16504", "rank": "Strain"}, "334207": {"name": "Betapapillomavirus 3", "rank": "Species"}, "334204": {"name": "Mupapillomavirus 2", "rank": "Species"}, "334205": {"name": "Nupapillomavirus 1", "rank": "Species"}, "334202": {"name": "Mupapillomavirus", "rank": "Genus"}, "334203": {"name": "Mupapillomavirus 1", "rank": "Species"}, "338781": {"name": "Micromonas pusilla reovirus", "rank": "Species"}, "334208": {"name": "Betapapillomavirus 4", "rank": "Species"}, "334209": {"name": "Betapapillomavirus 5", "rank": "Species"}, "1304887": {"name": "Geobacter bremensis R1", "rank": "Strain"}, "1527523": {"name": "Macrophomina phaseolina tobamo-like virus", "rank": "Species"}, "561230": {"name": "Pectobacterium carotovorum subsp. carotovorum PC1", "rank": "Strain"}, "1388748": {"name": "Cronobacter zurichensis LMG 23730", "rank": "Strain"}, "1388749": {"name": "Campylobacter lari NCTC 11845", "rank": "Strain"}, "1388747": {"name": "Cronobacter pulveris LMG 24059", "rank": "Strain"}, "1388744": {"name": "Brucella suis 06-791-1309", "rank": "Strain"}, "1388745": {"name": "Brucella melitensis 02-7258", "rank": "Strain"}, "1388742": {"name": "Brucella suis 06-997-1672", "rank": "Strain"}, "620894": {"name": "Cotton leaf curl Burewala virus", "rank": "Species"}, "1388740": {"name": "Brucella melitensis 11-1823-3434", "rank": "Strain"}, "1388741": {"name": "Brucella suis 97-9757", "rank": "Strain"}, "1522072": {"name": "Sphingobium sp. ba1", "rank": "Species"}, "1384461": {"name": "Bat coronavirus CDPHE15/USA/2006", "rank": "Species"}, "557393": {"name": "Erwinia phage phiEa21-4", "rank": "Species"}, "232802": {"name": "Mulard duck circovirus", "rank": "Strain"}, "1094979": {"name": "Marinobacter manganoxydans MnI7-9", "rank": "Strain"}, "1156719": {"name": "Halorubrum pleomorphic virus 2", "rank": "Species"}, "1131483": {"name": "Eidolon helvum (bat) parvovirus", "rank": "Strain"}, "197345": {"name": "Psychroflexus tropicus", "rank": "Species"}, "1131485": {"name": "Artibeus jamaicensis parvovirus 1", "rank": "Species"}, "554283": {"name": "Flavobacterium chungangense", "rank": "Species"}, "1077282": {"name": "Neisseria meningitidis Nm8187", "rank": "Strain"}, "588672": {"name": "Patulibacter americanus", "rank": "Species"}, "1077285": {"name": "Bacteroides faecis MAJ27", "rank": "Strain"}, "1077286": {"name": "Ganoderma lucidum G.260125-1", "rank": "Strain"}, "1499392": {"name": "Chromobacteriaceae", "rank": "Family"}, "427081": {"name": "Xanthomonas fuscans subsp. aurantifolii str. ICPB 11122", "rank": "Strain"}, "427082": {"name": "Xanthomonas fuscans subsp. aurantifolii str. ICPB 10535", "rank": "Strain"}, "670955": {"name": "Candidatus Uzinura", "rank": "No rank"}, "670956": {"name": "Candidatus Uzinura diaspidicola", "rank": "Species"}, "1439013": {"name": "Streptococcus pyogenes ABC020014925", "rank": "Strain"}, "1439012": {"name": "Streptococcus pyogenes ABC020014897", "rank": "Strain"}, "1439011": {"name": "Streptococcus pyogenes ABC020014764", "rank": "Strain"}, "1439010": {"name": "Streptococcus pyogenes ABC020014690", "rank": "Strain"}, "1439017": {"name": "Streptococcus pyogenes ABC020015294", "rank": "Strain"}, "1439016": {"name": "Streptococcus pyogenes ABC020015292", "rank": "Strain"}, "1439015": {"name": "Streptococcus pyogenes ABC020015285", "rank": "Strain"}, "1439014": {"name": "Streptococcus pyogenes ABC020015277", "rank": "Strain"}, "543736": {"name": "Rhodococcus opacus PD630", "rank": "Strain"}, "152794": {"name": "Corynebacterium efficiens", "rank": "Species"}, "38142": {"name": "Hirame rhabdovirus", "rank": "Species"}, "38144": {"name": "Unclassified Flaviviridae", "rank": "No rank"}, "543737": {"name": "Francisella tularensis subsp. tularensis MA00-2987", "rank": "Strain"}, "663237": {"name": "Bacillus phage Wip1", "rank": "Species"}, "869689": {"name": "Escherichia coli 3.3884", "rank": "Strain"}, "1401244": {"name": "Methanobrevibacter arboriphilus ANOR1", "rank": "Strain"}, "2358": {"name": "Desulfomonile tiedjei", "rank": "Species"}, "869681": {"name": "Escherichia coli 4.0522", "rank": "Strain"}, "2357": {"name": "Desulfomonile", "rank": "Genus"}, "869683": {"name": "Escherichia coli 96.154", "rank": "Strain"}, "869682": {"name": "Escherichia coli JB1-95", "rank": "Strain"}, "2352": {"name": "Flexistipes sinusarabici", "rank": "Species"}, "869684": {"name": "Escherichia coli 5.0959", "rank": "Strain"}, "2350": {"name": "Haliscomenobacter hydrossis", "rank": "Species"}, "2351": {"name": "Flexistipes", "rank": "Genus"}, "563772": {"name": "Vibrio parahaemolyticus AQ4037", "rank": "Strain"}, "1430435": {"name": "Salmonella enterica subsp. enterica serovar Bovismorbificans str. Sal609", "rank": "Strain"}, "426118": {"name": "Sulfolobus islandicus M.16.4", "rank": "Strain"}, "426114": {"name": "Thiomonas arsenitoxydans", "rank": "Species"}, "426117": {"name": "Methylobacterium sp. 4-46", "rank": "Species"}, "83770": {"name": "Succinivibrio", "rank": "Genus"}, "83771": {"name": "Succinivibrio dextrinosolvens", "rank": "Species"}, "83778": {"name": "Kineosporiaceae", "rank": "Family"}, "92244": {"name": "Thioalkalimicrobium", "rank": "Genus"}, "279540": {"name": "Gremmeniella abietina RNA virus MS2", "rank": "Species"}, "1292373": {"name": "Propionibacterium granulosum TM11", "rank": "Strain"}, "1292372": {"name": "Propionibacterium avidum TM16", "rank": "Strain"}, "46769": {"name": "Cenarchaeum", "rank": "Genus"}, "1296990": {"name": "Komagataeibacter xylinus E25", "rank": "Strain"}, "1258582": {"name": "Enterococcus faecalis 20.SD.W.06", "rank": "Strain"}, "1258583": {"name": "Corynebacterium ulcerans NCTC 12077", "rank": "Strain"}, "1258580": {"name": "Escherichia coli LCT-EC59", "rank": "Strain"}, "1094971": {"name": "Alpha proteobacterium JGI 0001002-C12", "rank": "Species"}, "65699": {"name": "Neisseria meningitidis serogroup A", "rank": "Strain"}, "76777": {"name": "Malassezia sympodialis", "rank": "Species"}, "1492296": {"name": "Sugarcane white streak virus", "rank": "Species"}, "1387989": {"name": "Staphylococcus aureus M0008", "rank": "Strain"}, "1387988": {"name": "Staphylococcus aureus M0007", "rank": "Strain"}, "1387987": {"name": "Staphylococcus aureus M0005", "rank": "Strain"}, "1094973": {"name": "Beta proteobacterium JGI 0001002-P8", "rank": "Species"}, "216592": {"name": "Escherichia coli 042", "rank": "Strain"}, "135616": {"name": "Piscirickettsiaceae", "rank": "Family"}, "859198": {"name": "Salmonella enterica subsp. enterica serovar Montevideo str. 609460", "rank": "Strain"}, "859199": {"name": "Salmonella enterica subsp. enterica serovar Montevideo str. 507440-20", "rank": "Strain"}, "859196": {"name": "Salmonella enterica subsp. enterica serovar Newport str. CVM 19536", "rank": "Strain"}, "859197": {"name": "Salmonella enterica subsp. enterica serovar Newport str. CVM 4176", "rank": "Strain"}, "859194": {"name": "Mycoplasma haemofelis Ohio2", "rank": "Strain"}, "859192": {"name": "Candidatus Nitrosoarchaeum limnia BG20", "rank": "Strain"}, "515319": {"name": "Unclassified Caulimovirus", "rank": "No rank"}, "216599": {"name": "Shigella sonnei 53G", "rank": "Strain"}, "1177187": {"name": "Saccharomyces cerevisiae P283", "rank": "Strain"}, "1177180": {"name": "Kosakonia radicincitans DSM 16656", "rank": "Strain"}, "717048": {"name": "Unclassified archaeal dsDNA viruses", "rank": "No rank"}, "1177181": {"name": "Alcanivorax jadensis T9", "rank": "Strain"}, "1314848": {"name": "Escherichia coli STEC O174:H46 str. I-151", "rank": "Strain"}, "169691": {"name": "Tobacco leaf curl disease associated sequence", "rank": "Species"}, "1314845": {"name": "Escherichia coli STEC O174:H2 str. 02-04446", "rank": "Strain"}, "169693": {"name": "Okra yellow vein disease associated sequence", "rank": "Species"}, "1314847": {"name": "Escherichia coli STEC O174:H8 str. 02-07607", "rank": "Strain"}, "1314840": {"name": "Escherichia coli O174:H2", "rank": "Strain"}, "1314841": {"name": "Escherichia coli O174:H8", "rank": "Strain"}, "1314842": {"name": "Escherichia coli O174:H46", "rank": "Strain"}, "169696": {"name": "Hollyhock leaf crumple virus satellite DNA", "rank": "Species"}, "45237": {"name": "Helminthosporium victoriae virus 190S", "rank": "Species"}, "45234": {"name": "Cordyceps", "rank": "Genus"}, "398626": {"name": "Helicobacter macacae", "rank": "Species"}, "1413504": {"name": "Staphylococcus aureus R0545", "rank": "Strain"}, "132919": {"name": "Rhodococcus jostii", "rank": "Species"}, "1410760": {"name": "Staphylococcus aureus W21479", "rank": "Strain"}, "1104591": {"name": "Aminicenantes bacterium JGI 0000014-B08", "rank": "Species"}, "1410761": {"name": "Staphylococcus aureus M73849", "rank": "Strain"}, "1555202": {"name": "Escherichia phage 121Q", "rank": "Species"}, "1555208": {"name": "Ruegeria phage DSS3-P1", "rank": "Species"}, "147709": {"name": "Carnobacterium inhibens", "rank": "Species"}, "147700": {"name": "Rhizobium etli bv. phaseoli", "rank": "Strain"}, "935586": {"name": "Neisseria meningitidis ES14902", "rank": "Strain"}, "935587": {"name": "Neisseria meningitidis M6190", "rank": "Strain"}, "1281045": {"name": "Escherichia coli HVH 109 (4-6977162)", "rank": "Strain"}, "935588": {"name": "Neisseria meningitidis M01-240355", "rank": "Strain"}, "935589": {"name": "Neisseria meningitidis NZ-05/33", "rank": "Strain"}, "257310": {"name": "Bordetella bronchiseptica RB50", "rank": "Strain"}, "257311": {"name": "Bordetella parapertussis 12822", "rank": "Strain"}, "59374": {"name": "Fibrobacter succinogenes subsp. succinogenes S85", "rank": "Strain"}, "257314": {"name": "Lactobacillus johnsonii NCC 533", "rank": "Strain"}, "1333568": {"name": "Streptococcus agalactiae MC623", "rank": "Strain"}, "1219072": {"name": "Vibrio halioticoli NBRC 102217", "rank": "Strain"}, "1333569": {"name": "Streptococcus agalactiae MC624", "rank": "Strain"}, "796620": {"name": "Vibrio caribbeanicus ATCC BAA-2122", "rank": "Strain"}, "1235835": {"name": "Anaerotruncus sp. G3(2012)", "rank": "Species"}, "1235834": {"name": "Kosakonia sacchari SP1", "rank": "Strain"}, "1235833": {"name": "Acinetobacter calcoaceticus subsp. anitratus XM1570", "rank": "Strain"}, "572239": {"name": "Wheat yellow dwarf virus-GPV", "rank": "Species"}, "91061": {"name": "Bacilli", "rank": "Class"}, "71995": {"name": "Paenibacillus vortex", "rank": "Species"}, "1421886": {"name": "Staphylococcus aureus T24515", "rank": "Strain"}, "685892": {"name": "Pseudomonas phage PaP1", "rank": "Species"}, "71999": {"name": "Kocuria palustris", "rank": "Species"}, "685899": {"name": "Papaya lethal yellowing virus", "rank": "Species"}, "1392849": {"name": "Escherichia coli M3", "rank": "Strain"}, "1049908": {"name": "Leptospira interrogans serovar Icterohaemorrhagiae str. P2547", "rank": "Strain"}, "1049909": {"name": "Leptospira interrogans serovar Icterohaemorrhagiae str. P2554", "rank": "Strain"}, "1049902": {"name": "Leptospira interrogans serovar Grippotyphosa str. UI 08368", "rank": "Strain"}, "1049903": {"name": "Leptospira interrogans serovar Grippotyphosa str. UI 08434", "rank": "Strain"}, "1049906": {"name": "Leptospira interrogans serovar Hebdomadis str. R499", "rank": "Strain"}, "1049907": {"name": "Leptospira interrogans serovar Icterohaemorrhagiae str. P2422", "rank": "Strain"}, "1049904": {"name": "Leptospira interrogans serovar Grippotyphosa str. UI 12764", "rank": "Strain"}, "1049905": {"name": "Leptospira interrogans serovar Grippotyphosa str. UI 12769", "rank": "Strain"}, "78346": {"name": "Bifidobacterium ruminantium", "rank": "Species"}, "78345": {"name": "Bifidobacterium merycicum", "rank": "Species"}, "78344": {"name": "Bifidobacterium gallinarum", "rank": "Species"}, "78343": {"name": "Bifidobacterium boum", "rank": "Species"}, "78342": {"name": "Bifidobacterium gallicum", "rank": "Species"}, "56486": {"name": "Elm mottle virus", "rank": "Species"}, "92003": {"name": "Azoarcus toluclasticus", "rank": "Species"}, "1421889": {"name": "Staphylococcus aureus T35622", "rank": "Strain"}, "1388391": {"name": "Staphylococcus aureus M0591", "rank": "Strain"}, "1388390": {"name": "Staphylococcus aureus M0590", "rank": "Strain"}, "1457165": {"name": "Wallerfield virus", "rank": "Species"}, "1388392": {"name": "Staphylococcus aureus M0592", "rank": "Strain"}, "1388395": {"name": "Staphylococcus aureus M0598", "rank": "Strain"}, "1388394": {"name": "Staphylococcus aureus M0595", "rank": "Strain"}, "1388396": {"name": "Staphylococcus aureus M0599", "rank": "Strain"}, "1010834": {"name": "Mycobacterium tuberculosis HKBS1", "rank": "Strain"}, "1010835": {"name": "Mycobacterium tuberculosis BT2", "rank": "Strain"}, "1010836": {"name": "Mycobacterium tuberculosis BT1", "rank": "Strain"}, "1448480": {"name": "Mycobacterium tuberculosis TKK_04_0080", "rank": "Strain"}, "1448481": {"name": "Mycobacterium tuberculosis TKK_04_0081", "rank": "Strain"}, "1448482": {"name": "Mycobacterium tuberculosis TKK_04_0082", "rank": "Strain"}, "1448483": {"name": "Mycobacterium tuberculosis TKK_04_0083", "rank": "Strain"}, "1448484": {"name": "Mycobacterium tuberculosis TKK_04_0084", "rank": "Strain"}, "1448485": {"name": "Mycobacterium tuberculosis TKK_04_0086", "rank": "Strain"}, "1448486": {"name": "Mycobacterium tuberculosis TKK_05MA_0001", "rank": "Strain"}, "1448488": {"name": "Mycobacterium tuberculosis TKK_05MA_0004", "rank": "Strain"}, "4958": {"name": "Debaryomyces", "rank": "Genus"}, "1325634": {"name": "Candida albicans Ca529L", "rank": "Strain"}, "177874": {"name": "WEEV complex", "rank": "No rank"}, "1104599": {"name": "Atribacteria bacterium SCGC AB-164-G04", "rank": "Species"}, "177875": {"name": "SFV complex", "rank": "No rank"}, "528346": {"name": "Neisseria gonorrhoeae 35/02", "rank": "Strain"}, "984195": {"name": "Pseudomonas sp. SHC52", "rank": "Species"}, "665079": {"name": "Sclerotinia sclerotiorum 1980 UF-70", "rank": "Strain"}, "1104598": {"name": "Atribacteria bacterium SCGC AB-164-D21", "rank": "Species"}, "392500": {"name": "Shewanella woodyi ATCC 51908", "rank": "Strain"}, "912320": {"name": "Piscine myocarditis virus AL V-708", "rank": "Species"}, "1046978": {"name": "Cloacimonetes bacterium SCGC AAA255-L20", "rank": "Species"}, "687386": {"name": "Torque teno sus virus 1a", "rank": "Species"}, "1046973": {"name": "Cloacimonetes bacterium SCGC AAA252-P14", "rank": "Species"}, "687384": {"name": "Torque teno felis virus", "rank": "Species"}, "687385": {"name": "Torque teno canis virus", "rank": "Species"}, "687382": {"name": "Torque teno tamarin virus", "rank": "Species"}, "687383": {"name": "Torque teno douroucouli virus", "rank": "Species"}, "687380": {"name": "Torque teno midi virus 2", "rank": "Species"}, "1046975": {"name": "Cloacimonetes bacterium SCGC AAA255-C20", "rank": "Species"}, "278081": {"name": "Lentisphaerales", "rank": "Order"}, "1402662": {"name": "Staphylococcus aureus M1150", "rank": "Strain"}, "1402663": {"name": "Staphylococcus aureus M1151", "rank": "Strain"}, "1402660": {"name": "Staphylococcus aureus M1148", "rank": "Strain"}, "186497": {"name": "Pyrococcus furiosus DSM 3638", "rank": "Strain"}, "1402666": {"name": "Staphylococcus aureus M1154", "rank": "Strain"}, "1402667": {"name": "Staphylococcus aureus M1155", "rank": "Strain"}, "1402664": {"name": "Staphylococcus aureus M1152", "rank": "Strain"}, "1402665": {"name": "Staphylococcus aureus M1153", "rank": "Strain"}, "1402668": {"name": "Staphylococcus aureus M1156", "rank": "Strain"}, "1402669": {"name": "Staphylococcus aureus M1157", "rank": "Strain"}, "1446730": {"name": "Escherichia coli O26:H11 str. 2011C-3282", "rank": "Strain"}, "1446731": {"name": "Escherichia coli O26:H11 str. 2011C-3387", "rank": "Strain"}, "1446732": {"name": "Escherichia coli O26:H11 str. 2011C-3506", "rank": "Strain"}, "1446733": {"name": "Escherichia coli O26:H11 str. 2011C-3655", "rank": "Strain"}, "1446734": {"name": "Escherichia coli O26:NM str. 2010C-4347", "rank": "Strain"}, "1446735": {"name": "Escherichia coli O26:NM str. 2010C-4788", "rank": "Strain"}, "1446736": {"name": "Escherichia coli O28ac:NM", "rank": "Strain"}, "1446737": {"name": "Escherichia coli O28ac:NM str. 02-3404", "rank": "Strain"}, "1446738": {"name": "Escherichia coli O39:NM", "rank": "Strain"}, "1446739": {"name": "Escherichia coli O39:NM str. F8704-2", "rank": "Strain"}, "1449755": {"name": "Acinetobacter baumannii Pulsotype 27", "rank": "Strain"}, "1449752": {"name": "Staphylococcus epidermidis PM221", "rank": "Strain"}, "869729": {"name": "Escherichia coli UM146", "rank": "Strain"}, "118099": {"name": "Buchnera aphidicola (Acyrthosiphon pisum)", "rank": "Strain"}, "691961": {"name": "Raptor siadenovirus A", "rank": "Species"}, "691963": {"name": "Rhodococcus phage ReqiPine5", "rank": "Species"}, "691965": {"name": "Rhodococcus phage ReqiPepy6", "rank": "Species"}, "691964": {"name": "Rhodococcus phage ReqiPoco6", "rank": "Species"}, "691966": {"name": "Rhodococcus phage ReqiDocB7", "rank": "Species"}, "888055": {"name": "Leptotrichia wadei F0279", "rank": "Strain"}, "1388429": {"name": "Staphylococcus aureus M0645", "rank": "Strain"}, "1388428": {"name": "Staphylococcus aureus M0644", "rank": "Strain"}, "216895": {"name": "Vibrio vulnificus CMCP6", "rank": "Strain"}, "1388423": {"name": "Staphylococcus aureus M0637", "rank": "Strain"}, "1388422": {"name": "Staphylococcus aureus M0636", "rank": "Strain"}, "1388421": {"name": "Staphylococcus aureus M0634", "rank": "Strain"}, "1388420": {"name": "Staphylococcus aureus M0632", "rank": "Strain"}, "1388427": {"name": "Staphylococcus aureus M0643", "rank": "Strain"}, "1388426": {"name": "Staphylococcus aureus M0642", "rank": "Strain"}, "1388425": {"name": "Staphylococcus aureus M0640", "rank": "Strain"}, "1388424": {"name": "Staphylococcus aureus M0638", "rank": "Strain"}, "115117": {"name": "Desulfovibrio desulfuricans subsp. desulfuricans", "rank": "Subspecies"}, "545935": {"name": "Unassigned Picovirinae", "rank": "No rank"}, "545932": {"name": "Luz24likevirus", "rank": "Genus"}, "490759": {"name": "Marinobacter sp. BSs20148", "rank": "Species"}, "760827": {"name": "Streptococcus pneumoniae GA44511", "rank": "Strain"}, "1417985": {"name": "Bacillus thuringiensis LM1212", "rank": "Strain"}, "185782": {"name": "Aquareovirus C", "rank": "Species"}, "1198700": {"name": "Brucella abortus RB51-AHVLA", "rank": "Strain"}, "187327": {"name": "Acidaminococcus intestini", "rank": "Species"}, "187326": {"name": "Megasphaera micronuciformis", "rank": "Species"}, "187328": {"name": "Veillonella montpellierensis", "rank": "Species"}, "671074": {"name": "Vibrio mimicus VM603", "rank": "Strain"}, "671076": {"name": "Vibrio mimicus VM573", "rank": "Strain"}, "10761": {"name": "Shigella phage Sf6", "rank": "Species"}, "10760": {"name": "Enterobacteria phage T7", "rank": "Species"}, "203683": {"name": "Planctomycetia", "rank": "Class"}, "203682": {"name": "Planctomycetes", "rank": "Phylum"}, "604162": {"name": "Neisseria meningitidis 8013", "rank": "Strain"}, "1417988": {"name": "Enterococcus sp. TR", "rank": "Species"}, "75888": {"name": "Baboon orthoreovirus", "rank": "Species"}, "1043628": {"name": "Drechslerella stenobrocha 248", "rank": "Strain"}, "938631": {"name": "Alpha proteobacterium SCGC AAA027-J10", "rank": "Species"}, "938633": {"name": "Alpha proteobacterium SCGC AAA027-L15", "rank": "Species"}, "935200": {"name": "Sulfuricella", "rank": "Genus"}, "1195085": {"name": "Cronobacter phage CR5", "rank": "Species"}, "1195084": {"name": "Enterobacteria phage Chi", "rank": "Species"}, "1195087": {"name": "Sunshine virus", "rank": "Species"}, "1195086": {"name": "Staphylococcus phage SA13", "rank": "Species"}, "1245027": {"name": "Proteus mirabilis C05028", "rank": "Strain"}, "1162671": {"name": "Saccharomyces cerevisiae M3836", "rank": "Strain"}, "1162672": {"name": "Saccharomyces cerevisiae M3837", "rank": "Strain"}, "1162673": {"name": "Saccharomyces cerevisiae M3838", "rank": "Strain"}, "1162674": {"name": "Saccharomyces cerevisiae M3839", "rank": "Strain"}, "1562566": {"name": "Acidobacteria subdivision 4", "rank": "No rank"}, "1438762": {"name": "Klebsiella pneumoniae CHS 56", "rank": "Strain"}, "1120967": {"name": "Algoriphagus terrigena DSM 22685", "rank": "Strain"}, "1245029": {"name": "Bacillus anthracis str. Carbosap", "rank": "Strain"}, "1245028": {"name": "Neisseria meningitidis Nm11003", "rank": "Strain"}, "40566": {"name": "Actinosynnema", "rank": "Genus"}, "40567": {"name": "Actinosynnema mirum", "rank": "Species"}, "1127439": {"name": "Xanthomonas axonopodis pv. malvacearum str. GSPB2388", "rank": "Strain"}, "40562": {"name": "Strophariaceae", "rank": "Family"}, "260827": {"name": "Vibrio phage VP5", "rank": "Species"}, "11988": {"name": "Turnip crinkle virus", "rank": "Species"}, "11985": {"name": "Carmovirus", "rank": "Genus"}, "11986": {"name": "Carnation mottle virus", "rank": "Species"}, "11987": {"name": "Melon necrotic spot virus", "rank": "Species"}, "11983": {"name": "Norwalk virus", "rank": "Species"}, "50960": {"name": "Helicobacter trogontum", "rank": "Species"}, "147266": {"name": "Agrobacterium albertimagni", "rank": "Species"}, "147268": {"name": "Thioalkalimicrobium cyclicum", "rank": "Species"}, "1121879": {"name": "Ferrimonas kyonanensis DSM 18153", "rank": "Strain"}, "1121878": {"name": "Ferrimonas futtsuensis DSM 18154", "rank": "Strain"}, "1121871": {"name": "Eremococcus coleocola DSM 15696", "rank": "Strain"}, "1445512": {"name": "Gilliamella apicola SCGC AB-598-P17", "rank": "Strain"}, "1445515": {"name": "Snodgrassella alvi SCGC AB-598-O11", "rank": "Strain"}, "1445514": {"name": "Gilliamella apicola SCGC AB-598-I20", "rank": "Strain"}, "1121875": {"name": "Eudoraea adriatica DSM 19308", "rank": "Strain"}, "1121874": {"name": "Erysipelothrix tonsillarum DSM 14972", "rank": "Strain"}, "1296416": {"name": "Aquimarina megaterium XH134", "rank": "Strain"}, "46242": {"name": "Spodoptera litura nucleopolyhedrovirus", "rank": "Species"}, "1296415": {"name": "Aquimarina sp. SW150", "rank": "Species"}, "349521": {"name": "Hahella chejuensis KCTC 2396", "rank": "Strain"}, "349520": {"name": "Paenibacillus polymyxa E681", "rank": "Strain"}, "373045": {"name": "Escherichia coli O111:NM", "rank": "Strain"}, "122586": {"name": "Neisseria meningitidis MC58", "rank": "Strain"}, "122587": {"name": "Neisseria meningitidis Z2491", "rank": "Strain"}, "1249468": {"name": "Burkholderia pseudomallei NCTC 13178", "rank": "Strain"}, "186371": {"name": "Bhendi yellow vein betasatellite", "rank": "Species"}, "333990": {"name": "Carnobacterium sp. AT7", "rank": "Species"}, "1340853": {"name": "Chlamydia trachomatis F/11-96", "rank": "Strain"}, "5302": {"name": "Agaricomycotina", "rank": "No rank"}, "5303": {"name": "Polyporales", "rank": "Order"}, "1249467": {"name": "Okra enation leaf curl alphasatellite", "rank": "Species"}, "1340854": {"name": "Enterobacter cloacae str. Hanford", "rank": "Strain"}, "1422602": {"name": "Staphylococcus aureus VET0343R", "rank": "Strain"}, "167375": {"name": "Cyanobium", "rank": "Genus"}, "1422600": {"name": "Staphylococcus aureus VET0341R", "rank": "Strain"}, "1422601": {"name": "Staphylococcus aureus VET0342R", "rank": "Strain"}, "461876": {"name": "Alkaliphilus oremlandii", "rank": "Species"}, "1422607": {"name": "Staphylococcus aureus VET0358R", "rank": "Strain"}, "1422604": {"name": "Staphylococcus aureus VET0353R", "rank": "Strain"}, "1422605": {"name": "Staphylococcus aureus VET0354R", "rank": "Strain"}, "1422608": {"name": "Staphylococcus aureus VET0359R", "rank": "Strain"}, "1422609": {"name": "Staphylococcus aureus VET0360R", "rank": "Strain"}, "889510": {"name": "Digitaria didactyla striate mosaic virus", "rank": "Species"}, "561522": {"name": "Streptococcus pyogenes MGAS2111", "rank": "Strain"}, "186928": {"name": "Unclassified Lachnospiraceae", "rank": "No rank"}, "12188": {"name": "White clover mosaic virus", "rank": "Species"}, "764595": {"name": "Bacillus phage W.Ph.", "rank": "Species"}, "1246301": {"name": "Variovorax paradoxus B4", "rank": "Strain"}, "12181": {"name": "Papaya mosaic virus", "rank": "Species"}, "12180": {"name": "Narcissus mosaic virus", "rank": "Species"}, "12183": {"name": "Potato virus X", "rank": "Species"}, "12182": {"name": "Potato aucuba mosaic virus", "rank": "Species"}, "12187": {"name": "Strawberry mild yellow edge virus", "rank": "Species"}, "579": {"name": "Kluyvera", "rank": "Genus"}, "571": {"name": "Klebsiella oxytoca", "rank": "Species"}, "570": {"name": "Klebsiella", "rank": "Genus"}, "573": {"name": "Klebsiella pneumoniae", "rank": "Species"}, "1348635": {"name": "Vibrio diazotrophicus NBRC 103148", "rank": "Strain"}, "575": {"name": "Raoultella planticola", "rank": "Species"}, "574": {"name": "Klebsiella pneumoniae subsp. ozaenae", "rank": "Subspecies"}, "576": {"name": "Klebsiella sp.", "rank": "Species"}, "286156": {"name": "Photorhabdus asymbiotica subsp. australis", "rank": "Subspecies"}, "86029": {"name": "Bacillus subtilis subsp. natto", "rank": "Subspecies"}, "1412898": {"name": "Bacillus amyloliquefaciens CC178", "rank": "Strain"}, "1352588": {"name": "Mycobacterium tuberculosis PanR0803", "rank": "Strain"}, "1412896": {"name": "Campylobacter coli K3", "rank": "Strain"}, "1412897": {"name": "Campylobacter coli K7", "rank": "Strain"}, "1423551": {"name": "Mycobacterium tuberculosis BTB11-371", "rank": "Strain"}, "1423550": {"name": "Mycobacterium tuberculosis BTB11-343", "rank": "Strain"}, "1423553": {"name": "Mycobacterium tuberculosis BTB12-002", "rank": "Strain"}, "1423552": {"name": "Mycobacterium tuberculosis BTB12-001", "rank": "Strain"}, "1423555": {"name": "Mycobacterium tuberculosis BTB12-054", "rank": "Strain"}, "1423554": {"name": "Mycobacterium tuberculosis BTB12-046", "rank": "Strain"}, "1423557": {"name": "Mycobacterium tuberculosis BTB12-162", "rank": "Strain"}, "1423556": {"name": "Mycobacterium tuberculosis BTB12-094", "rank": "Strain"}, "1423559": {"name": "Mycobacterium tuberculosis BTB12-211", "rank": "Strain"}, "1423558": {"name": "Mycobacterium tuberculosis BTB12-206", "rank": "Strain"}, "200644": {"name": "Flavobacteriales", "rank": "Order"}, "200643": {"name": "Bacteroidia", "rank": "Class"}, "1136172": {"name": "Vibrio cyclitrophicus ZF205", "rank": "Strain"}, "172296": {"name": "Bovine parvovirus - 2", "rank": "Strain"}, "1420600": {"name": "Anguilla anguilla circovirus", "rank": "Species"}, "749498": {"name": "Enterococcus faecalis TX0027", "rank": "Strain"}, "891424": {"name": "Salmonella enterica subsp. enterica serovar Typhimurium str. CDC_2009K1153", "rank": "Strain"}, "891422": {"name": "Salmonella enterica subsp. enterica serovar Typhimurium str. CDC_2009K1283", "rank": "Strain"}, "200415": {"name": "Caldisphaera lagunensis", "rank": "Species"}, "891420": {"name": "Salmonella enterica subsp. enterica serovar Javiana str. ATCC BAA-1593", "rank": "Strain"}, "891421": {"name": "Salmonella enterica subsp. enterica serovar Typhimurium str. CDC_2009K1158", "rank": "Strain"}, "1463662": {"name": "Pseudomonas sp. CHM02", "rank": "Species"}, "749497": {"name": "Enterococcus faecalis TX0017", "rank": "Strain"}, "1413534": {"name": "Staphylococcus aureus GD2010-158", "rank": "Strain"}, "1136170": {"name": "Vibrio cyclitrophicus ZF99", "rank": "Strain"}, "1379259": {"name": "Serratia fonticola UTAD54", "rank": "Strain"}, "1112264": {"name": "Chlamydia psittaci 03DC35", "rank": "Strain"}, "110578": {"name": "Bartonella vinsonii subsp. arupensis", "rank": "Subspecies"}, "1112265": {"name": "Chlamydia psittaci 04DC42", "rank": "Strain"}, "516466": {"name": "Burkholderia sp. H160", "rank": "Species"}, "416916": {"name": "Aggregatibacter", "rank": "Genus"}, "43130": {"name": "Onion yellow dwarf virus", "rank": "Species"}, "1005559": {"name": "Escherichia coli CB7326", "rank": "Strain"}, "1005558": {"name": "Escherichia coli 5905", "rank": "Strain"}, "1005555": {"name": "Escherichia coli TT12B", "rank": "Strain"}, "1005554": {"name": "Escherichia coli EC1870", "rank": "Strain"}, "1005557": {"name": "Escherichia coli MA6", "rank": "Strain"}, "135720": {"name": "Neisseria meningitidis serogroup C", "rank": "Strain"}, "1005553": {"name": "Escherichia coli EC1869", "rank": "Strain"}, "1005552": {"name": "Escherichia coli EC1868", "rank": "Strain"}, "1412542": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20120970", "rank": "Strain"}, "1279999": {"name": "Vibrio campbellii 200612B", "rank": "Strain"}, "1412540": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20121751", "rank": "Strain"}, "1412541": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20121750", "rank": "Strain"}, "1412546": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20120240", "rank": "Strain"}, "1412547": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20120229", "rank": "Strain"}, "1412544": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20120505", "rank": "Strain"}, "1412545": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20120498", "rank": "Strain"}, "1582223": {"name": "Sporosarcina sp. ZBG7A", "rank": "Species"}, "1412549": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20111510", "rank": "Strain"}, "1286151": {"name": "Pseudomonas aeruginosa 18A", "rank": "Strain"}, "10386": {"name": "Gallid herpesvirus 1", "rank": "Species"}, "43685": {"name": "Lactococcus phage r1t", "rank": "Species"}, "1417118": {"name": "Staphylococcus aureus H47224", "rank": "Strain"}, "1417119": {"name": "Staphylococcus aureus F82600", "rank": "Strain"}, "43680": {"name": "Ascovirus", "rank": "Genus"}, "35838": {"name": "Holophaga", "rank": "Genus"}, "35839": {"name": "Holophaga foetida", "rank": "Species"}, "1417112": {"name": "Staphylococcus aureus W70659", "rank": "Strain"}, "1417113": {"name": "Staphylococcus aureus H47183", "rank": "Strain"}, "1417110": {"name": "Staphylococcus aureus W70568", "rank": "Strain"}, "1417111": {"name": "Staphylococcus aureus M42514", "rank": "Strain"}, "35832": {"name": "Bilophila", "rank": "Genus"}, "1417117": {"name": "Staphylococcus aureus H47169", "rank": "Strain"}, "35830": {"name": "Acetivibrio cellulolyticus", "rank": "Species"}, "1417115": {"name": "Staphylococcus aureus F82568", "rank": "Strain"}, "1348244": {"name": "Kingella kingae KK245", "rank": "Strain"}, "1348243": {"name": "Kingella kingae KK98", "rank": "Strain"}, "1348242": {"name": "Kingella kingae KK260", "rank": "Strain"}, "1348241": {"name": "Kingella kingae KK158", "rank": "Strain"}, "1348240": {"name": "Kingella kingae KK189", "rank": "Strain"}, "84162": {"name": "Cryptobacterium", "rank": "Genus"}, "84163": {"name": "Cryptobacterium curtum", "rank": "Species"}, "1348249": {"name": "Methanobrevibacter boviskoreani", "rank": "Species"}, "35340": {"name": "Mouse parvovirus 1", "rank": "Strain"}, "35341": {"name": "Watermelon chlorotic stunt virus", "rank": "Species"}, "35342": {"name": "Unclassified ssDNA viruses", "rank": "No rank"}, "35343": {"name": "Pseudomonas phage phiCTX", "rank": "Species"}, "35345": {"name": "Lactococcus phage TP901-1", "rank": "Species"}, "1182539": {"name": "Candida albicans A84", "rank": "Strain"}, "1182538": {"name": "Candida albicans A155", "rank": "Strain"}, "1074148": {"name": "Streptococcus mutans TCI-187", "rank": "Strain"}, "1074149": {"name": "Streptococcus mutans TCI-191", "rank": "Strain"}, "1182531": {"name": "Candida albicans 3153A", "rank": "Strain"}, "1074143": {"name": "Streptococcus mutans TCI-176", "rank": "Strain"}, "1074140": {"name": "Streptococcus mutans TCI-173", "rank": "Strain"}, "1182532": {"name": "Candida albicans CHN1", "rank": "Strain"}, "1074146": {"name": "Streptococcus mutans TCI-179", "rank": "Strain"}, "1182534": {"name": "Candida albicans A48", "rank": "Strain"}, "1074144": {"name": "Streptococcus mutans TCI-177", "rank": "Strain"}, "1182536": {"name": "Candida albicans A92", "rank": "Strain"}, "64897": {"name": "Borrelia bissettii", "rank": "Species"}, "1121315": {"name": "Terrisporobacter glycolicus ATCC 14880 = DSM 1288", "rank": "Strain"}, "155493": {"name": "Gallibacterium", "rank": "Genus"}, "64898": {"name": "Aquificaceae", "rank": "Family"}, "1121319": {"name": "Clostridium hydrogeniformans DSM 21757", "rank": "Strain"}, "112228": {"name": "Hydrangea ringspot virus", "rank": "Species"}, "112229": {"name": "Pepino mosaic virus", "rank": "Species"}, "112227": {"name": "Cactus virus X", "rank": "Species"}, "749550": {"name": "Escherichia coli MS 200-1", "rank": "Strain"}, "749551": {"name": "Selenomonas artemidis F0399", "rank": "Strain"}, "1339246": {"name": "Leuconostoc pseudomesenteroides 1159", "rank": "Strain"}, "871271": {"name": "Candidatus Zinderia insecticola CARI", "rank": "Strain"}, "1315173": {"name": "Acinetobacter baumannii TG27307", "rank": "Strain"}, "285514": {"name": "Streptomyces xylophagus", "rank": "Species"}, "1357278": {"name": "Pseudomonas syringae CC1544", "rank": "Strain"}, "1315172": {"name": "Acinetobacter baumannii TG27299", "rank": "Strain"}, "1357276": {"name": "Pseudomonas syringae CC1524", "rank": "Strain"}, "1357277": {"name": "Pseudomonas syringae CC1543", "rank": "Strain"}, "1357274": {"name": "Pseudomonas syringae CC1466", "rank": "Strain"}, "1357275": {"name": "Pseudomonas syringae CC1513", "rank": "Strain"}, "1357272": {"name": "Pseudomonas syringae CC1417", "rank": "Strain"}, "1315171": {"name": "Acinetobacter baumannii TG27295", "rank": "Strain"}, "1357270": {"name": "Pseudomonas syringae UB246", "rank": "Strain"}, "1357271": {"name": "Pseudomonas syringae CC1416", "rank": "Strain"}, "1128333": {"name": "Sinorhizobium fredii CCBAU 83643", "rank": "Strain"}, "1128332": {"name": "Sinorhizobium fredii CCBAU 83622", "rank": "Strain"}, "1128331": {"name": "Sinorhizobium fredii CCBAU 45436", "rank": "Strain"}, "1128330": {"name": "Sinorhizobium fredii CCBAU 25509", "rank": "Strain"}, "1087332": {"name": "Actibacterium mucosum", "rank": "Species"}, "1128335": {"name": "Sinorhizobium fredii CCBAU 83753", "rank": "Strain"}, "668547": {"name": "Teratosphaeriaceae", "rank": "Family"}, "1315177": {"name": "Acinetobacter baumannii TG27371", "rank": "Strain"}, "1315176": {"name": "Acinetobacter baumannii TG27319", "rank": "Strain"}, "85015": {"name": "Nocardioidaceae", "rank": "Family"}, "67819": {"name": "Armatimonadetes", "rank": "Phylum"}, "67818": {"name": "Atribacteria", "rank": "Phylum"}, "1194972": {"name": "Mycobacterium vaccae ATCC 25954", "rank": "Strain"}, "1194970": {"name": "Yersinia pestis 2501", "rank": "Strain"}, "1315174": {"name": "Acinetobacter baumannii TG27311", "rank": "Strain"}, "166501": {"name": "Thermobaculum terrenum", "rank": "Species"}, "67810": {"name": "Acetothermia", "rank": "Phylum"}, "411489": {"name": "Clostridium sp. L2-50", "rank": "Species"}, "411481": {"name": "Bifidobacterium adolescentis L2-32", "rank": "Strain"}, "411483": {"name": "Faecalibacterium prausnitzii A2-165", "rank": "Strain"}, "411484": {"name": "Clostridium sp. SS2/1", "rank": "Species"}, "411485": {"name": "Faecalibacterium prausnitzii M21/2", "rank": "Strain"}, "411486": {"name": "Clostridium sp. M62/1", "rank": "Species"}, "614": {"name": "Serratia liquefaciens", "rank": "Species"}, "32612": {"name": "Lettuce necrotic yellows virus", "rank": "Species"}, "1315178": {"name": "Acinetobacter baumannii TG27379", "rank": "Strain"}, "611": {"name": "Salmonella enterica subsp. enterica serovar Heidelberg", "rank": "Strain"}, "613": {"name": "Serratia", "rank": "Genus"}, "661979": {"name": "Brachybacterium squillarum", "rank": "Species"}, "1140002": {"name": "Enterococcus avium ATCC 14025", "rank": "Strain"}, "32619": {"name": "Sorghum mosaic virus", "rank": "Species"}, "618": {"name": "Serratia odorifera", "rank": "Species"}, "1241371": {"name": "Abalone herpesvirus Victoria/AUS/2009", "rank": "Species"}, "1381751": {"name": "Brevibacterium sp. VCM10", "rank": "Species"}, "1002273": {"name": "Avian gyrovirus 2", "rank": "Species"}, "1410929": {"name": "Salmonella enterica subsp. enterica serovar Cerro str. CFSAN001691", "rank": "Strain"}, "1182683": {"name": "Escherichia coli KTE76", "rank": "Strain"}, "1182682": {"name": "Escherichia coli KTE75", "rank": "Strain"}, "1182681": {"name": "Escherichia coli KTE74", "rank": "Strain"}, "1182680": {"name": "Escherichia coli KTE73", "rank": "Strain"}, "1182687": {"name": "Escherichia coli KTE80", "rank": "Strain"}, "1182686": {"name": "Escherichia coli KTE79", "rank": "Strain"}, "1182685": {"name": "Escherichia coli KTE78", "rank": "Strain"}, "1182684": {"name": "Escherichia coli KTE77", "rank": "Strain"}, "1182689": {"name": "Escherichia coli KTE83", "rank": "Strain"}, "1182688": {"name": "Escherichia coli KTE81", "rank": "Strain"}, "1271533": {"name": "Propionibacterium acnes HL202PA1", "rank": "Strain"}, "364763": {"name": "Ferrimonas kyonanensis", "rank": "Species"}, "364764": {"name": "Ferrimonas futtsuensis", "rank": "Species"}, "712898": {"name": "Pantoea vagans C9-1", "rank": "Strain"}, "1183241": {"name": "Persimmon cryptic virus", "rank": "Species"}, "1388629": {"name": "Staphylococcus aureus M0858", "rank": "Strain"}, "142187": {"name": "Hydrogenedentes", "rank": "Phylum"}, "142182": {"name": "Gemmatimonadetes", "rank": "Phylum"}, "1388621": {"name": "Staphylococcus aureus M0848", "rank": "Strain"}, "1388620": {"name": "Staphylococcus aureus M0846", "rank": "Strain"}, "1388623": {"name": "Staphylococcus aureus M0851", "rank": "Strain"}, "1388622": {"name": "Staphylococcus aureus M0850", "rank": "Strain"}, "1388625": {"name": "Staphylococcus aureus M0853", "rank": "Strain"}, "1388624": {"name": "Staphylococcus aureus M0852", "rank": "Strain"}, "1388627": {"name": "Staphylococcus aureus M0855", "rank": "Strain"}, "1388626": {"name": "Staphylococcus aureus M0854", "rank": "Strain"}, "1260983": {"name": "Leptospirillum sp. Group IV 'UBA BS'", "rank": "Strain"}, "1260982": {"name": "Leptospirillum sp. Group IV", "rank": "Species"}, "235279": {"name": "Helicobacter hepaticus ATCC 51449", "rank": "Strain"}, "210007": {"name": "Streptococcus mutans UA159", "rank": "Strain"}, "261934": {"name": "Pleomorphomonas oryzae", "rank": "Species"}, "1438987": {"name": "Streptococcus pyogenes ABC020004984", "rank": "Strain"}, "1438988": {"name": "Streptococcus pyogenes ABC020005405", "rank": "Strain"}, "1438989": {"name": "Streptococcus pyogenes ABC020005716", "rank": "Strain"}, "154322": {"name": "Oleavirus", "rank": "Genus"}, "1239787": {"name": "Streptococcus pneumoniae 3051", "rank": "Strain"}, "1388509": {"name": "Staphylococcus aureus M0714", "rank": "Strain"}, "211977": {"name": "Aravan virus", "rank": "Species"}, "1220162": {"name": "Trichosporon asahii var. asahii CBS 8904", "rank": "Strain"}, "37733": {"name": "Prunus necrotic ringspot virus", "rank": "Species"}, "268748": {"name": "Prochlorococcus phage P-SSP7", "rank": "Species"}, "68903": {"name": "Terracoccus", "rank": "Genus"}, "37734": {"name": "Enterococcus casseliflavus", "rank": "Species"}, "68909": {"name": "Deinococcus geothermalis", "rank": "Species"}, "1790": {"name": "Mycobacterium asiaticum", "rank": "Species"}, "1797": {"name": "Mycobacterium thermoresistibile", "rank": "Species"}, "1795": {"name": "Mycobacterium neoaurum", "rank": "Species"}, "268746": {"name": "Prochlorococcus phage P-SSM2", "rank": "Species"}, "314231": {"name": "Fulvimarina pelagi HTCC2506", "rank": "Strain"}, "1027364": {"name": "Edwardsiella tarda DT", "rank": "Strain"}, "702444": {"name": "Bacteroides xylanisolvens SD CC 2a", "rank": "Strain"}, "1388505": {"name": "Staphylococcus aureus M0662", "rank": "Strain"}, "568988": {"name": "Candidatus Regiella", "rank": "Genus"}, "314232": {"name": "Loktanella vestfoldensis SKA53", "rank": "Strain"}, "222545": {"name": "Xylariomycetidae", "rank": "Subclass"}, "222544": {"name": "Sordariomycetidae", "rank": "Subclass"}, "1321606": {"name": "Bacillus selenatarsenatis SF-1", "rank": "Strain"}, "743836": {"name": "Methylocystis sp. SB2", "rank": "Species"}, "743835": {"name": "Bacillus anthracis str. A16", "rank": "Strain"}, "1197706": {"name": "Arthrobacter sp. M2012083", "rank": "Species"}, "1325731": {"name": "Flavobacterium phage 6H", "rank": "Species"}, "1485544": {"name": "Ferriphaselus sp. R-1", "rank": "Species"}, "1485545": {"name": "Zetaproteobacteria bacterium TAG-1", "rank": "Species"}, "1485543": {"name": "Selenomonas sp. AE3005", "rank": "Species"}, "870478": {"name": "Burkholderia sp. MR1", "rank": "Species"}, "297254": {"name": "Lactobacillus phage LL-Ku", "rank": "Species"}, "392499": {"name": "Sphingomonas wittichii RW1", "rank": "Strain"}, "687349": {"name": "Torque teno virus 10", "rank": "Species"}, "29404": {"name": "Microlunatus", "rank": "Genus"}, "77813": {"name": "Merremia mosaic virus", "rank": "Species"}, "910310": {"name": "Turicibacter sp. HGF1", "rank": "Species"}, "910311": {"name": "Eggerthella sp. HGA1", "rank": "Species"}, "910312": {"name": "Porphyromonas asaccharolytica PR426713P-I", "rank": "Strain"}, "910313": {"name": "Streptococcus pseudoporcinus SPIN 20026", "rank": "Strain"}, "910314": {"name": "Dialister microaerophilus UPII 345-E", "rank": "Strain"}, "1550073": {"name": "Sphingomonas sp. 37zxx", "rank": "Species"}, "1281265": {"name": "Escherichia coli UMEA 3702-1", "rank": "Strain"}, "1151309": {"name": "Peptoclostridium difficile 824", "rank": "Strain"}, "103810": {"name": "Riemerella columbina", "rank": "Species"}, "103816": {"name": "Rhodococcus pyridinivorans", "rank": "Species"}, "59919": {"name": "Prochlorococcus marinus subsp. pastoris str. CCMP1986", "rank": "Strain"}, "656088": {"name": "Mycoplasma mycoides group", "rank": "Species group"}, "1281269": {"name": "Escherichia coli UMEA 3718-1", "rank": "Strain"}, "265477": {"name": "Desulfotomaculum alcoholivorax", "rank": "Species"}, "265470": {"name": "Desulfurispora thermophila", "rank": "Species"}, "1320553": {"name": "Afipia sp. NBIMC_P1-C2", "rank": "Species"}, "1320552": {"name": "Afipia sp. NBIMC_P1-C1", "rank": "Species"}, "1320555": {"name": "Mesorhizobium sp. NBIMC_P2-C1", "rank": "Species"}, "1320554": {"name": "Afipia sp. NBIMC_P1-C3", "rank": "Species"}, "1320557": {"name": "Mesorhizobium sp. NBIMC_P2-C2", "rank": "Species"}, "1320556": {"name": "Mesorhizobium sp. NBIMC_P2-C3", "rank": "Species"}, "1439207": {"name": "Streptococcus pyogenes ABC020052211", "rank": "Strain"}, "1439204": {"name": "Streptococcus pyogenes ABC020052023", "rank": "Strain"}, "1439205": {"name": "Streptococcus pyogenes ABC020052203", "rank": "Strain"}, "143361": {"name": "Filifactor alocis", "rank": "Species"}, "47681": {"name": "Enterovirus sp.", "rank": "Species"}, "1439208": {"name": "Streptococcus pyogenes ABC020052216", "rank": "Strain"}, "1439209": {"name": "Streptococcus pyogenes ABC020052218", "rank": "Strain"}, "434131": {"name": "Neorickettsia risticii str. Illinois", "rank": "Strain"}, "47687": {"name": "Mycoplasma alligatoris", "rank": "Species"}, "1259823": {"name": "Enterobacter hormaechei YT2", "rank": "Strain"}, "1259824": {"name": "Enterococcus faecium 13.SD.W.09", "rank": "Strain"}, "1259825": {"name": "Enterococcus casseliflavus 14-MB-W-14", "rank": "Strain"}, "293136": {"name": "Desulfitibacter", "rank": "Genus"}, "45067": {"name": "Legionella lansingensis", "rank": "Species"}, "487838": {"name": "Xanthomonas axonopodis pv. punicae", "rank": "Strain"}, "45065": {"name": "Legionella geestiana", "rank": "Species"}, "741705": {"name": "Coniophora puteana RWD-64-598 SS2", "rank": "Strain"}, "944289": {"name": "Gymnopus luxurians FD-317 M1", "rank": "Strain"}, "944288": {"name": "Plicaturopsis crispa FD-325 SS-3", "rank": "Strain"}, "1311106": {"name": "Acinetobacter baumannii 16553_9", "rank": "Strain"}, "1311107": {"name": "Acinetobacter baumannii 16553_10", "rank": "Strain"}, "1311105": {"name": "Acinetobacter baumannii 16553_8", "rank": "Strain"}, "1235276": {"name": "Staphylococcus aureus PPUKM-332-2009", "rank": "Strain"}, "1311103": {"name": "Acinetobacter baumannii 16553_6", "rank": "Strain"}, "1311100": {"name": "Acinetobacter baumannii 16553_3", "rank": "Strain"}, "1311101": {"name": "Acinetobacter baumannii 16553_4", "rank": "Strain"}, "1311108": {"name": "Acinetobacter baumannii 25569_1", "rank": "Strain"}, "1311109": {"name": "Acinetobacter baumannii 25569_2", "rank": "Strain"}, "1280002": {"name": "Vibrio jasicida 090810c", "rank": "Strain"}, "1280000": {"name": "Vibrio owensii ATCC 25919", "rank": "Strain"}, "1280001": {"name": "Vibrio jasicida MWB 21", "rank": "Strain"}, "1280004": {"name": "Vibrio owensii LMG 25430", "rank": "Strain"}, "627344": {"name": "Zymomonas mobilis subsp. mobilis ATCC 29191", "rank": "Strain"}, "627343": {"name": "Zymomonas mobilis subsp. mobilis str. CP4 = NRRL B-14023", "rank": "Strain"}, "1400879": {"name": "Mycobacterium tuberculosis KT-0014", "rank": "Strain"}, "1400875": {"name": "Mycobacterium tuberculosis KT-0008", "rank": "Strain"}, "1400874": {"name": "Mycobacterium tuberculosis KT-0007", "rank": "Strain"}, "1400877": {"name": "Mycobacterium tuberculosis KT-0011", "rank": "Strain"}, "1400871": {"name": "Mycobacterium tuberculosis KT-0002", "rank": "Strain"}, "1400870": {"name": "Mycobacterium tuberculosis KT-0001", "rank": "Strain"}, "1400873": {"name": "Mycobacterium tuberculosis KT-0006", "rank": "Strain"}, "1400872": {"name": "Mycobacterium tuberculosis KT-0003", "rank": "Strain"}, "41764": {"name": "Hordeum mosaic virus", "rank": "Species"}, "41763": {"name": "Agropyron mosaic virus", "rank": "Species"}, "1151026": {"name": "Cladosporium sphaerospermum UM 843", "rank": "Strain"}, "349054": {"name": "Unclassified Fusellovirus", "rank": "No rank"}, "435910": {"name": "Cronobacter pulveris", "rank": "Species"}, "1398067": {"name": "Staphylococcus aureus M1457", "rank": "Strain"}, "1398064": {"name": "Staphylococcus aureus M1454", "rank": "Strain"}, "1398065": {"name": "Staphylococcus aureus M1455", "rank": "Strain"}, "1398062": {"name": "Staphylococcus aureus M1452", "rank": "Strain"}, "1398063": {"name": "Staphylococcus aureus M1453", "rank": "Strain"}, "1398060": {"name": "Staphylococcus aureus M1448", "rank": "Strain"}, "1398061": {"name": "Staphylococcus aureus M1449", "rank": "Strain"}, "258224": {"name": "Corynebacterium resistens", "rank": "Species"}, "1398068": {"name": "Staphylococcus aureus M1458", "rank": "Strain"}, "1398069": {"name": "Staphylococcus aureus M1459", "rank": "Strain"}, "546267": {"name": "Neisseria polysaccharea ATCC 43768", "rank": "Strain"}, "546266": {"name": "Neisseria mucosa ATCC 25996", "rank": "Strain"}, "546265": {"name": "Neisseria lactamica ATCC 23970", "rank": "Strain"}, "546264": {"name": "Neisseria flavescens NRL30031/H210", "rank": "Strain"}, "546263": {"name": "Neisseria elongata subsp. glycolytica ATCC 29315", "rank": "Strain"}, "546262": {"name": "Neisseria cinerea ATCC 14685", "rank": "Strain"}, "1111735": {"name": "Sedimenticola selenatireducens DSM 17993", "rank": "Strain"}, "1111734": {"name": "Propionibacterium acidipropionici DSM 4900", "rank": "Strain"}, "1111738": {"name": "Thermocrispum agreste DSM 44070", "rank": "Strain"}, "546269": {"name": "Filifactor alocis ATCC 35896", "rank": "Strain"}, "546268": {"name": "Neisseria subflava NJ9703", "rank": "Strain"}, "1117942": {"name": "Corynebacterium pseudotuberculosis P54B96", "rank": "Strain"}, "1117943": {"name": "Sinorhizobium fredii HH103", "rank": "Strain"}, "1117941": {"name": "Lactococcus lactis subsp. lactis NCDO 2118", "rank": "Strain"}, "436243": {"name": "Tomato leaf curl Joydebpur betasatellite", "rank": "Species"}, "436242": {"name": "Pepper leaf curl virus satellite DNA beta", "rank": "Species"}, "1399915": {"name": "Pectobacterium phage PM1", "rank": "Species"}, "1399914": {"name": "African elephant polyomavirus 1", "rank": "Species"}, "58290": {"name": "Archaeoglobus veneficus", "rank": "Species"}, "1537166": {"name": "Porcine stool-associated circular virus 7", "rank": "Species"}, "1537167": {"name": "Porcine stool-associated circular virus 8", "rank": "Species"}, "1537164": {"name": "Porcine stool-associated circular virus 1", "rank": "Species"}, "1537165": {"name": "Porcine stool-associated circular virus 6", "rank": "Species"}, "1537168": {"name": "Porcine stool-associated circular virus 9", "rank": "Species"}, "262668": {"name": "Acinetobacter beijerinckii", "rank": "Species"}, "580165": {"name": "Bacillus cytotoxicus", "rank": "Species"}, "1236399": {"name": "Pan troglodytes schweinfurthii polyomavirus 2", "rank": "Species"}, "1236398": {"name": "Macaca fascicularis polyomavirus 1", "rank": "Species"}, "1447464": {"name": "Mycobacterium tuberculosis MD18116", "rank": "Strain"}, "1236392": {"name": "Cebus albifrons polyomavirus 1", "rank": "Species"}, "1236391": {"name": "Ateles paniscus polyomavirus 1", "rank": "Species"}, "742823": {"name": "Sutterella wadsworthensis 2_1_59BFAA", "rank": "Strain"}, "1053175": {"name": "Bacillus cereus BAG1X2-3", "rank": "Strain"}, "1053176": {"name": "Bacillus cereus BAG2O-1", "rank": "Strain"}, "742820": {"name": "Streptococcus anginosus 1_2_62CV", "rank": "Strain"}, "1053170": {"name": "Bacillus cereus BAG1X1-1", "rank": "Strain"}, "1053171": {"name": "Bacillus cereus BAG1X1-2", "rank": "Strain"}, "1053172": {"name": "Bacillus cereus BAG1X1-3", "rank": "Strain"}, "1053173": {"name": "Bacillus cereus BAG1X2-1", "rank": "Strain"}, "68244": {"name": "Streptomyces novaecaesareae", "rank": "Species"}, "1053178": {"name": "Bacillus cereus BAG2O-3", "rank": "Strain"}, "68242": {"name": "Streptomyces natalensis", "rank": "Species"}, "889232": {"name": "Campylobacter jejuni subsp. jejuni 1798", "rank": "Strain"}, "889233": {"name": "Campylobacter jejuni subsp. jejuni 1854", "rank": "Strain"}, "889230": {"name": "Campylobacter jejuni subsp. jejuni 1213", "rank": "Strain"}, "889231": {"name": "Campylobacter jejuni subsp. jejuni 1577", "rank": "Strain"}, "889236": {"name": "Campylobacter jejuni subsp. jejuni LMG 9872", "rank": "Strain"}, "889237": {"name": "Campylobacter jejuni subsp. jejuni LMG 23210", "rank": "Strain"}, "889234": {"name": "Campylobacter jejuni subsp. jejuni 1893", "rank": "Strain"}, "889235": {"name": "Campylobacter jejuni subsp. jejuni 1928", "rank": "Strain"}, "485243": {"name": "Non-mammal papillomaviruses", "rank": "No rank"}, "485241": {"name": "Caretta caretta papillomavirus 1", "rank": "Strain"}, "889239": {"name": "Campylobacter jejuni subsp. jejuni LMG 23216", "rank": "Strain"}, "96468": {"name": "Nocardia vinacea", "rank": "Species"}, "441768": {"name": "Acholeplasma laidlawii PG-8A", "rank": "Strain"}, "441769": {"name": "Bacillus coahuilensis m4-4", "rank": "Strain"}, "634502": {"name": "Arthrospira platensis str. Paraca", "rank": "Strain"}, "634503": {"name": "Edwardsiella ictaluri 93-146", "rank": "Strain"}, "634500": {"name": "Erwinia billingiae Eb661", "rank": "Strain"}, "1174526": {"name": "Wheat dwarf India virus", "rank": "Species"}, "634504": {"name": "Bartonella grahamii as4aup", "rank": "Strain"}, "1174529": {"name": "Candidatus Liberibacter asiaticus str. gxpsy", "rank": "Strain"}, "1174528": {"name": "Fischerella sp. PCC 9339", "rank": "Species"}, "679429": {"name": "Fusarium tricinctum species complex", "rank": "No rank"}, "190192": {"name": "Methanopyrus kandleri AV19", "rank": "Strain"}, "108098": {"name": "Human mastadenovirus B", "rank": "Species"}, "1236573": {"name": "Bacillus phage BMBtp2", "rank": "Species"}, "1169349": {"name": "Escherichia sp. KTE31", "rank": "Species"}, "1169348": {"name": "Escherichia coli KTE29", "rank": "Strain"}, "1004049": {"name": "Spissistilus festinus reovirus", "rank": "Species"}, "1169341": {"name": "Escherichia coli KTE22", "rank": "Strain"}, "1169340": {"name": "Escherichia coli KTE21", "rank": "Strain"}, "1169343": {"name": "Escherichia coli KTE24", "rank": "Strain"}, "1169342": {"name": "Escherichia coli KTE23", "rank": "Strain"}, "1169345": {"name": "Escherichia coli KTE26", "rank": "Strain"}, "1169344": {"name": "Escherichia coli KTE25", "rank": "Strain"}, "1169347": {"name": "Escherichia coli KTE28", "rank": "Strain"}, "1169346": {"name": "Escherichia coli KTE27", "rank": "Strain"}, "509532": {"name": "Gossypium punctatum mild leaf curl virus", "rank": "Species"}, "509531": {"name": "Gossypium darwinii symptomless virus", "rank": "Strain"}, "1447498": {"name": "Mycobacterium tuberculosis MD15770", "rank": "Strain"}, "1447499": {"name": "Mycobacterium tuberculosis MD15751", "rank": "Strain"}, "1321366": {"name": "Salmonella enterica subsp. enterica serovar Saintpaul str. S-70", "rank": "Strain"}, "1447492": {"name": "Mycobacterium tuberculosis MD16571", "rank": "Strain"}, "1447493": {"name": "Mycobacterium tuberculosis MD17006", "rank": "Strain"}, "1447490": {"name": "Mycobacterium tuberculosis MD15226", "rank": "Strain"}, "1447491": {"name": "Mycobacterium tuberculosis MD16568", "rank": "Strain"}, "1447496": {"name": "Mycobacterium tuberculosis MD15956", "rank": "Strain"}, "1447497": {"name": "Mycobacterium tuberculosis MD15977", "rank": "Strain"}, "1447494": {"name": "Mycobacterium tuberculosis MD15430", "rank": "Strain"}, "1447495": {"name": "Mycobacterium tuberculosis MD17232", "rank": "Strain"}, "1158658": {"name": "Enterococcus faecalis EnGen0298", "rank": "Strain"}, "1116053": {"name": "Escherichia coli P0299917.7", "rank": "Strain"}, "93368": {"name": "Pseudaminobacter", "rank": "Genus"}, "93369": {"name": "Pseudaminobacter salicylatoxidans", "rank": "Species"}, "1158653": {"name": "Enterococcus faecalis EnGen0310", "rank": "Strain"}, "1158652": {"name": "Enterococcus faecium EnGen0312", "rank": "Strain"}, "1158651": {"name": "Enterococcus faecium EnGen0323", "rank": "Strain"}, "1158650": {"name": "Enterococcus faecium EnGen0321", "rank": "Strain"}, "1158657": {"name": "Enterococcus faecalis EnGen0303", "rank": "Strain"}, "1158656": {"name": "Enterococcus faecalis EnGen0280", "rank": "Strain"}, "1158655": {"name": "Enterococcus faecalis EnGen0307", "rank": "Strain"}, "1158654": {"name": "Enterococcus faecalis EnGen0294", "rank": "Strain"}, "174145": {"name": "Endosymbiont of Bathymodiolus sp.", "rank": "Species"}, "745411": {"name": "Gallaecimonas xiamenensis 3-C-1", "rank": "Strain"}, "1168169": {"name": "Methylomonas sp. 11b", "rank": "Species"}, "536019": {"name": "Mesorhizobium opportunistum WSM2075", "rank": "Strain"}, "536018": {"name": "Mesorhizobium australicum", "rank": "Species"}, "1298928": {"name": "Pasteurella multocida RIIF", "rank": "Strain"}, "1298929": {"name": "Pasteurella multocida 1500C", "rank": "Strain"}, "1298924": {"name": "Pasteurella multocida 1500E", "rank": "Strain"}, "1298925": {"name": "Pasteurella multocida 2000", "rank": "Strain"}, "1298926": {"name": "Pasteurella multocida 93002", "rank": "Strain"}, "1298927": {"name": "Pasteurella multocida P1933", "rank": "Strain"}, "1298920": {"name": "Desulfotomaculum guttoideum DSM 4024", "rank": "Strain"}, "1298921": {"name": "Bacillus coagulans CSIL1", "rank": "Strain"}, "1298922": {"name": "Bifidobacterium longum D2957", "rank": "Strain"}, "231434": {"name": "Beijerinckia mobilis", "rank": "Species"}, "79600": {"name": "Marine birnavirus", "rank": "Species"}, "392332": {"name": "Geoalkalibacter", "rank": "Genus"}, "392333": {"name": "Geoalkalibacter ferrihydriticus", "rank": "Species"}, "75387": {"name": "Apricot latent virus", "rank": "Species"}, "1281249": {"name": "Escherichia coli UMEA 3426-1", "rank": "Strain"}, "1276181": {"name": "Chaerephon polyomavirus 1", "rank": "Species"}, "1276187": {"name": "Eidolon polyomavirus 1", "rank": "Species"}, "1276184": {"name": "Otomops polyomavirus 1", "rank": "Species"}, "1276185": {"name": "Otomops polyomavirus 2", "rank": "Species"}, "1471457": {"name": "Prochlorococcus sp. scB241_528N20", "rank": "Species"}, "1471456": {"name": "Prochlorococcus sp. scB241_528N17", "rank": "Species"}, "1471455": {"name": "Prochlorococcus sp. scB241_528K19", "rank": "Species"}, "1159019": {"name": "Helicobacter pylori GAM100Ai", "rank": "Strain"}, "1471453": {"name": "Prochlorococcus sp. scB241_528J14", "rank": "Species"}, "1471452": {"name": "Prochlorococcus sp. scB241_527P5", "rank": "Species"}, "1471451": {"name": "Prochlorococcus sp. scB241_527N11", "rank": "Species"}, "1471450": {"name": "Prochlorococcus sp. scB241_527L22", "rank": "Species"}, "33903": {"name": "Streptomyces avermitilis", "rank": "Species"}, "33905": {"name": "Bifidobacterium thermophilum", "rank": "Species"}, "150060": {"name": "Halonatronum saccharophilum", "rank": "Species"}, "1471458": {"name": "Prochlorococcus sp. scB241_528N8", "rank": "Species"}, "904769": {"name": "Staphylococcus aureus subsp. aureus 21337", "rank": "Strain"}, "888054": {"name": "Bacteroidetes bacterium oral taxon 272 str. F0290", "rank": "Strain"}, "1427183": {"name": "Mycobacterium tuberculosis XTB13-089", "rank": "Strain"}, "35802": {"name": "Brucella abortus bv. 1", "rank": "Strain"}, "127886": {"name": "Bacillus hemicellulosilyticus", "rank": "Species"}, "643680": {"name": "Saccharomyces cerevisiae EC1118", "rank": "Strain"}, "11089": {"name": "Yellow fever virus", "rank": "Species"}, "334767": {"name": "Ignisphaera", "rank": "Genus"}, "11085": {"name": "Langat virus", "rank": "Species"}, "1427186": {"name": "Mycobacterium tuberculosis XTB13-092", "rank": "Strain"}, "11086": {"name": "Louping ill virus", "rank": "Species"}, "11080": {"name": "St. Louis encephalitis virus", "rank": "Species"}, "11083": {"name": "Powassan virus", "rank": "Species"}, "11082": {"name": "West Nile virus", "rank": "Species"}, "888057": {"name": "Aggregatibacter segnis ATCC 33393", "rank": "Strain"}, "671135": {"name": "Xylella fastidiosa subsp. sandyi", "rank": "Subspecies"}, "10680": {"name": "Enterobacteria phage P4", "rank": "Species"}, "10685": {"name": "Bacillus phage SPO1", "rank": "Species"}, "10689": {"name": "Vibrio phage CP-T1", "rank": "Species"}, "1035191": {"name": "Brevundimonas diminuta 470-4", "rank": "Strain"}, "888056": {"name": "Actinomyces sp. oral taxon 448 str. F0400", "rank": "Strain"}, "1242989": {"name": "Leptospira santarosai serovar Shermani str. 1342KT", "rank": "Strain"}, "483218": {"name": "Bacteroides pectinophilus ATCC 43243", "rank": "Strain"}, "35800": {"name": "Nitrospina", "rank": "Genus"}, "1446547": {"name": "Escherichia coli O118:H16 str. 07-4255", "rank": "Strain"}, "1446546": {"name": "Escherichia coli O118:H16 str. 06-3612", "rank": "Strain"}, "1446545": {"name": "Escherichia coli O118:H16 str. 06-3256", "rank": "Strain"}, "1446544": {"name": "Escherichia coli O118:H16", "rank": "Strain"}, "1446543": {"name": "Escherichia coli O113:H21 str. 07-4224", "rank": "Strain"}, "1446542": {"name": "Escherichia coli O111:NM str. K6915", "rank": "Strain"}, "1446541": {"name": "Escherichia coli O111:NM str. K6908", "rank": "Strain"}, "1446540": {"name": "Escherichia coli O111:NM str. K6904", "rank": "Strain"}, "366602": {"name": "Caulobacter sp. K31", "rank": "Species"}, "1446549": {"name": "Escherichia coli O118:H16 str. 2009C-4446", "rank": "Strain"}, "1446548": {"name": "Escherichia coli O118:H16 str. 08-3651", "rank": "Strain"}, "337049": {"name": "Alphapapillomavirus 11", "rank": "Species"}, "337048": {"name": "Alphapapillomavirus 1", "rank": "Species"}, "337041": {"name": "Alphapapillomavirus 9", "rank": "Species"}, "337043": {"name": "Alphapapillomavirus 4", "rank": "Species"}, "337042": {"name": "Alphapapillomavirus 7", "rank": "Species"}, "337044": {"name": "Alphapapillomavirus 5", "rank": "Species"}, "177437": {"name": "Desulfobacterium autotrophicum HRM2", "rank": "Strain"}, "177439": {"name": "Desulfotalea psychrophila LSv54", "rank": "Strain"}, "1218591": {"name": "Leptospira vanthielii serovar Holland str. Waz Holland = ATCC 700522", "rank": "Strain"}, "1218593": {"name": "Leptospira santarosai str. ST188", "rank": "Strain"}, "1218595": {"name": "Leptospira santarosai str. CBC613", "rank": "Strain"}, "1218594": {"name": "Leptospira santarosai str. CBC1531", "rank": "Strain"}, "1218597": {"name": "Leptospira weilii serovar Ranarum", "rank": "Strain"}, "453852": {"name": "Joostella marina", "rank": "Species"}, "1218599": {"name": "Leptospira wolbachii serovar Codice str. CDC", "rank": "Strain"}, "1218598": {"name": "Leptospira weilii serovar Ranarum str. ICFT", "rank": "Strain"}, "689697": {"name": "Salisaeta", "rank": "Genus"}, "1274363": {"name": "Polycyclovorans", "rank": "Genus"}, "886": {"name": "Thermodesulfobacterium thermophilum", "rank": "Species"}, "1177762": {"name": "Psipapillomavirus 1", "rank": "Species"}, "1177763": {"name": "Omegapapillomavirus 1", "rank": "Species"}, "1177764": {"name": "Dyodeltapapillomavirus 1", "rank": "Species"}, "1177765": {"name": "Dyoepsilonpapillomavirus 1", "rank": "Species"}, "1154798": {"name": "Streptococcus agalactiae FSL S3-102", "rank": "Strain"}, "1154799": {"name": "Streptococcus agalactiae FSL S3-442", "rank": "Strain"}, "1154796": {"name": "Streptococcus agalactiae FSL S3-090", "rank": "Strain"}, "1154797": {"name": "Streptococcus agalactiae FSL S3-014", "rank": "Strain"}, "1154794": {"name": "Streptococcus agalactiae FSL S3-023", "rank": "Strain"}, "1154795": {"name": "Streptococcus agalactiae FSL S3-337", "rank": "Strain"}, "1154792": {"name": "Streptococcus agalactiae FSL S3-170", "rank": "Strain"}, "1154793": {"name": "Streptococcus agalactiae FSL S3-568", "rank": "Strain"}, "1154791": {"name": "Streptococcus agalactiae FSL S3-128", "rank": "Strain"}, "202697": {"name": "Jaapia argillacea", "rank": "Species"}, "202696": {"name": "Jaapia", "rank": "Genus"}, "1439118": {"name": "Streptococcus pyogenes ABC020040643", "rank": "Strain"}, "451754": {"name": "Clostridium perfringens B str. ATCC 3626", "rank": "Strain"}, "451755": {"name": "Clostridium perfringens E str. JGS1987", "rank": "Strain"}, "451756": {"name": "Clostridium perfringens CPE str. F4969", "rank": "Strain"}, "451757": {"name": "Clostridium perfringens NCTC 8239", "rank": "Strain"}, "451751": {"name": "Clostridium perfringens B", "rank": "Strain"}, "451752": {"name": "Clostridium perfringens E", "rank": "Strain"}, "202698": {"name": "Punctularia strigosozonata", "rank": "Species"}, "1232666": {"name": "Staphylococcus sciuri subsp. sciuri Z8", "rank": "Strain"}, "1006554": {"name": "Acetobacter pasteurianus NBRC 101655", "rank": "Strain"}, "1006551": {"name": "Klebsiella oxytoca KCTC 1686", "rank": "Strain"}, "1282995": {"name": "Serratia phage Eta", "rank": "Species"}, "167129": {"name": "Moroccan watermelon mosaic virus", "rank": "Species"}, "1002921": {"name": "Porcine sapelovirus 1", "rank": "Strain"}, "1538639": {"name": "Smithella sp. D17", "rank": "Species"}, "55148": {"name": "Deinococcus proteolyticus", "rank": "Species"}, "1239286": {"name": "Firmicutes bacterium JGI 0000112-H15", "rank": "Species"}, "1239287": {"name": "Firmicutes bacterium JGI 0000112-P22", "rank": "Species"}, "348043": {"name": "Streptomyces davawensis", "rank": "Species"}, "96892": {"name": "Nanovirus-like particle", "rank": "Species"}, "1302286": {"name": "Lactobacillus namurensis str. Chizuka 01", "rank": "Strain"}, "929712": {"name": "Patulibacter minatonensis DSM 18081", "rank": "Strain"}, "929713": {"name": "Niabella soli DSM 19437", "rank": "Strain"}, "1335307": {"name": "Burkholderia pseudomallei MSHR305", "rank": "Strain"}, "1335304": {"name": "Escherichia coli O104:H21 str. CFSAN002237", "rank": "Strain"}, "1335302": {"name": "Escherichia coli O104:H21", "rank": "Strain"}, "1335303": {"name": "Escherichia coli O104:H21 str. CFSAN002236", "rank": "Strain"}, "1229907": {"name": "Brucella abortus bv. 1 str. 134", "rank": "Strain"}, "1094755": {"name": "Bartonella sp. DB5-6", "rank": "Species"}, "1458186": {"name": "Alphasatellites", "rank": "No rank"}, "1417097": {"name": "Staphylococcus aureus W65885", "rank": "Strain"}, "1417096": {"name": "Staphylococcus aureus F76239", "rank": "Strain"}, "1417095": {"name": "Staphylococcus aureus F76218", "rank": "Strain"}, "1417094": {"name": "Staphylococcus aureus H41109", "rank": "Strain"}, "1417093": {"name": "Staphylococcus aureus H41079", "rank": "Strain"}, "1417092": {"name": "Staphylococcus aureus H41070", "rank": "Strain"}, "1417091": {"name": "Staphylococcus aureus W65904", "rank": "Strain"}, "1417090": {"name": "Staphylococcus aureus W65865", "rank": "Strain"}, "447909": {"name": "Geobacillus virus E2", "rank": "Species"}, "1417099": {"name": "Staphylococcus aureus T86574", "rank": "Strain"}, "1417098": {"name": "Staphylococcus aureus M42507", "rank": "Strain"}, "521720": {"name": "Pseudomonas caeni", "rank": "Species"}, "1410845": {"name": "Staphylococcus aureus T84594", "rank": "Strain"}, "1410844": {"name": "Staphylococcus aureus M36089", "rank": "Strain"}, "281492": {"name": "Avian adeno-associated virus strain DA-1", "rank": "Strain"}, "1410846": {"name": "Staphylococcus aureus T84592", "rank": "Strain"}, "1410841": {"name": "Staphylococcus aureus F80381", "rank": "Strain"}, "424944": {"name": "Salmonella phage SETP3", "rank": "Species"}, "424947": {"name": "Salmonella phage SETP7", "rank": "Species"}, "1410842": {"name": "Staphylococcus aureus F80375", "rank": "Strain"}, "424949": {"name": "Salmonella phage SETP13", "rank": "Species"}, "354354": {"name": "Niastella", "rank": "Genus"}, "1410849": {"name": "Staphylococcus aureus H45765", "rank": "Strain"}, "1410848": {"name": "Staphylococcus aureus H45755", "rank": "Strain"}, "866909": {"name": "Vibrio tubiashii NCIMB 1337 = ATCC 19106", "rank": "Strain"}, "1266446": {"name": "Mycobacterium tuberculosis PanR0704", "rank": "Strain"}, "53427": {"name": "Gordonia hirsuta", "rank": "Species"}, "53423": {"name": "Thermodesulfovibrio islandicus", "rank": "Species"}, "53422": {"name": "Thermobrachium celere", "rank": "Species"}, "60217": {"name": "Shewanella violacea", "rank": "Species"}, "2701": {"name": "Gardnerella", "rank": "Genus"}, "2702": {"name": "Gardnerella vaginalis", "rank": "Species"}, "1461580": {"name": "Bacillus sp. JCE", "rank": "Species"}, "1461582": {"name": "Jeotgalicoccus sp. 13MG44_air", "rank": "Species"}, "1413578": {"name": "Staphylococcus aureus ZTA11/03130-3ST", "rank": "Strain"}, "1413570": {"name": "Staphylococcus aureus ZTA10/00045-9HST", "rank": "Strain"}, "1413572": {"name": "Staphylococcus aureus ZTA10/00058-8HST", "rank": "Strain"}, "1413574": {"name": "Staphylococcus aureus ZTA10/00047-8HST", "rank": "Strain"}, "1413575": {"name": "Staphylococcus aureus ZTA09/03576-9HST", "rank": "Strain"}, "1413576": {"name": "Staphylococcus aureus ZTA09/03576-8HST", "rank": "Strain"}, "1413577": {"name": "Staphylococcus aureus DICM09/00997-9HST2", "rank": "Strain"}, "460870": {"name": "Lactobacillus nodensis", "rank": "Species"}, "1590596": {"name": "Sphingobacterium sp. T2", "rank": "Species"}, "85151": {"name": "Aneurinibacillus group", "rank": "No rank"}, "713887": {"name": "Candidatus Atelocyanobacterium thalassa", "rank": "Species"}, "85154": {"name": "Streptococcus phage O1205", "rank": "Species"}, "291176": {"name": "Bartonella melophagi", "rank": "Species"}, "291175": {"name": "Sapovirus Hu/Dresden/pJG-Sap01/DE", "rank": "Strain"}, "409287": {"name": "Tobacco leaf curl Thailand virus", "rank": "Species"}, "718252": {"name": "Faecalibacterium prausnitzii L2-6", "rank": "Strain"}, "1341660": {"name": "Francisella tularensis subsp. tularensis str. SCHU S4 substr. FSC043", "rank": "Strain"}, "1341661": {"name": "Francisella tularensis subsp. tularensis str. SCHU S4 substr. FTS-634/635", "rank": "Strain"}, "718251": {"name": "Edwardsiella tarda FL6-60", "rank": "Strain"}, "947557": {"name": "Yersinia enterocolitica NFO", "rank": "Strain"}, "1349417": {"name": "Ruminiclostridium thermocellum BC1", "rank": "Strain"}, "1341669": {"name": "Brucella abortus 01-4165", "rank": "Strain"}, "1349410": {"name": "Pandoravirus salinus", "rank": "Species"}, "1422809": {"name": "Staphylococcus aureus VET1949S", "rank": "Strain"}, "1305730": {"name": "Methylobacterium sp. EUR3 AL-11", "rank": "Species"}, "1305732": {"name": "Microbacterium sp. KROCY2", "rank": "Species"}, "219571": {"name": "Rhodanobacter fulvus", "rank": "Species"}, "1305734": {"name": "Polaromonas sp. EUR3 1.2.1", "rank": "Species"}, "1305735": {"name": "Oceanicola sp. HL-35", "rank": "Species"}, "1305737": {"name": "Algoriphagus marincola HL-49", "rank": "Strain"}, "1305738": {"name": "Mycobacterium orygis", "rank": "Species"}, "1305739": {"name": "Mycobacterium orygis 112400015", "rank": "Strain"}, "1273539": {"name": "Streptococcus iniae IUSA1", "rank": "Strain"}, "1353941": {"name": "Acinetobacter harbinensis", "rank": "Species"}, "1422804": {"name": "Staphylococcus aureus VET1822S", "rank": "Strain"}, "341663": {"name": "Aspergillus terreus NIH2624", "rank": "Strain"}, "1414742": {"name": "Arthrobacter phage vB_ArS-ArV2", "rank": "Species"}, "1422805": {"name": "Staphylococcus aureus VET1917S", "rank": "Strain"}, "1547495": {"name": "Salivirus FHB", "rank": "Species"}, "82654": {"name": "Pseudanabaena sp. PCC 7367", "rank": "Species"}, "439484": {"name": "Unclassified Oceanospirillales (miscellaneous)", "rank": "No rank"}, "1422807": {"name": "Staphylococcus aureus VET1923S", "rank": "Strain"}, "1422800": {"name": "Staphylococcus aureus VET1738S", "rank": "Strain"}, "119069": {"name": "Hydrogenophilales", "rank": "Order"}, "1422801": {"name": "Staphylococcus aureus VET1779S", "rank": "Strain"}, "1422802": {"name": "Staphylococcus aureus VET1816S", "rank": "Strain"}, "1072588": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 246555-3", "rank": "Strain"}, "1380600": {"name": "Flaviramulus ichthyoenteri Th78", "rank": "Strain"}, "1380604": {"name": "Mesorhizobium sp. NBIMC_P2-C4", "rank": "Species"}, "515635": {"name": "Dictyoglomus turgidum DSM 6724", "rank": "Strain"}, "100901": {"name": "Wolbachia endosymbiont of Onchocerca ochengi", "rank": "Species"}, "1421856": {"name": "Staphylococcus aureus H65882", "rank": "Strain"}, "1421857": {"name": "Staphylococcus aureus H65883", "rank": "Strain"}, "1421854": {"name": "Staphylococcus aureus H65878", "rank": "Strain"}, "1421855": {"name": "Staphylococcus aureus H65881", "rank": "Strain"}, "1421852": {"name": "Staphylococcus aureus H65856", "rank": "Strain"}, "1421853": {"name": "Staphylococcus aureus H65863", "rank": "Strain"}, "1397869": {"name": "Mycobacterium tuberculosis TKK_02_0027", "rank": "Strain"}, "1421851": {"name": "Staphylococcus aureus H65853", "rank": "Strain"}, "1278306": {"name": "Fusobacterium russii ATCC 25533", "rank": "Strain"}, "1397866": {"name": "Mycobacterium tuberculosis TKK_02_0021", "rank": "Strain"}, "1397865": {"name": "Mycobacterium tuberculosis TKK_02_0020", "rank": "Strain"}, "1397864": {"name": "Mycobacterium tuberculosis TKK_02_0019", "rank": "Strain"}, "1397863": {"name": "Mycobacterium tuberculosis TKK_02_0018", "rank": "Strain"}, "1397862": {"name": "Mycobacterium tuberculosis TKK_02_0017", "rank": "Strain"}, "1278300": {"name": "Mycoplasma moatsii ATCC 27625", "rank": "Strain"}, "1421859": {"name": "Staphylococcus aureus H71778", "rank": "Strain"}, "208557": {"name": "Pasteuria nishizawae", "rank": "Species"}, "292407": {"name": "Dyadobacter crusticola", "rank": "Species"}, "710421": {"name": "Mycobacterium chubuense NBB4", "rank": "Strain"}, "1037262": {"name": "Salmonella enterica subsp. enterica serovar Typhimurium str. AZ 057", "rank": "Strain"}, "50709": {"name": "Acidocella", "rank": "Genus"}, "1412543": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20120548", "rank": "Strain"}, "363408": {"name": "Nonlabens", "rank": "Genus"}, "368454": {"name": "Halorubrum arcis", "rank": "Species"}, "1354145": {"name": "Mycobacterium tuberculosis MAL010086", "rank": "Strain"}, "205908": {"name": "Cypovirus 14", "rank": "Species"}, "1354144": {"name": "Mycobacterium tuberculosis MAL010080", "rank": "Strain"}, "199704": {"name": "Roniviridae", "rank": "Family"}, "199703": {"name": "Okavirus", "rank": "Genus"}, "1354146": {"name": "Mycobacterium tuberculosis MAL010087", "rank": "Strain"}, "1310636": {"name": "Acinetobacter baumannii 1429530", "rank": "Strain"}, "1452724": {"name": "Flavobacterium psychrophilum FPG3", "rank": "Strain"}, "1452725": {"name": "Flavobacterium psychrophilum FPG101", "rank": "Strain"}, "1452721": {"name": "Pseudoalteromonas lipolytica SCSIO 04301", "rank": "Strain"}, "1236403": {"name": "Pan troglodytes verus polyomavirus 5", "rank": "Species"}, "299768": {"name": "Streptococcus thermophilus CNRZ1066", "rank": "Strain"}, "1236402": {"name": "Pan troglodytes verus polyomavirus 4", "rank": "Species"}, "299767": {"name": "Enterobacter ludwigii", "rank": "Species"}, "1418272": {"name": "Staphylococcus aureus T16600", "rank": "Strain"}, "1418273": {"name": "Staphylococcus aureus T16615", "rank": "Strain"}, "1418270": {"name": "Staphylococcus aureus M72054", "rank": "Strain"}, "1418271": {"name": "Staphylococcus aureus M72087", "rank": "Strain"}, "1418276": {"name": "Staphylococcus aureus W75234", "rank": "Strain"}, "1418277": {"name": "Staphylococcus aureus W82215", "rank": "Strain"}, "1418274": {"name": "Staphylococcus aureus T16619", "rank": "Strain"}, "1418275": {"name": "Staphylococcus aureus W75229", "rank": "Strain"}, "585204": {"name": "Streptococcus mitis SK597", "rank": "Strain"}, "1418278": {"name": "Staphylococcus aureus W85806_020613", "rank": "Strain"}, "1418279": {"name": "Staphylococcus aureus W85837", "rank": "Strain"}, "585202": {"name": "Streptococcus mitis SK321", "rank": "Strain"}, "246618": {"name": "Bifidobacterium thermacidophilum", "rank": "Species"}, "1410062": {"name": "Pumpkin yellow mosaic virus", "rank": "Species"}, "913070": {"name": "Salmonella enterica subsp. enterica serovar Gaminara", "rank": "Strain"}, "913074": {"name": "Salmonella enterica subsp. enterica serovar Inverness", "rank": "Strain"}, "913079": {"name": "Salmonella enterica subsp. enterica serovar Mississippi", "rank": "Strain"}, "111527": {"name": "Pseudomallei group", "rank": "Species group"}, "1388128": {"name": "Staphylococcus aureus M0194", "rank": "Strain"}, "1388129": {"name": "Staphylococcus aureus M0196", "rank": "Strain"}, "1388122": {"name": "Staphylococcus aureus M0185", "rank": "Strain"}, "1388123": {"name": "Staphylococcus aureus M0186", "rank": "Strain"}, "1388120": {"name": "Staphylococcus aureus M0183", "rank": "Strain"}, "1388121": {"name": "Staphylococcus aureus M0184", "rank": "Strain"}, "1388126": {"name": "Staphylococcus aureus M0191", "rank": "Strain"}, "1388127": {"name": "Staphylococcus aureus M0193", "rank": "Strain"}, "1388124": {"name": "Staphylococcus aureus M0187", "rank": "Strain"}, "1388125": {"name": "Staphylococcus aureus M0188", "rank": "Strain"}, "1151225": {"name": "Escherichia coli B26-1", "rank": "Strain"}, "1151224": {"name": "Escherichia coli B5-2", "rank": "Strain"}, "1151227": {"name": "Escherichia coli B40-1", "rank": "Strain"}, "1072587": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 241981", "rank": "Strain"}, "1151221": {"name": "Escherichia coli B36-1", "rank": "Strain"}, "1151220": {"name": "Escherichia coli B29-2", "rank": "Strain"}, "1072583": {"name": "Halomonas boliviensis LC1", "rank": "Strain"}, "369723": {"name": "Salinispora tropica CNB-440", "rank": "Strain"}, "1072589": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 392869-1", "rank": "Strain"}, "1311024": {"name": "Acinetobacter baumannii 25493_10", "rank": "Strain"}, "1311027": {"name": "Acinetobacter baumannii 44437_3", "rank": "Strain"}, "1311020": {"name": "Acinetobacter baumannii 25493_6", "rank": "Strain"}, "1311023": {"name": "Acinetobacter baumannii 25493_9", "rank": "Strain"}, "1311022": {"name": "Acinetobacter baumannii 25493_8", "rank": "Strain"}, "1311029": {"name": "Acinetobacter baumannii 44437_5", "rank": "Strain"}, "1311028": {"name": "Acinetobacter baumannii 44437_4", "rank": "Strain"}, "1118058": {"name": "Actinomyces sp. ph3", "rank": "Species"}, "1419583": {"name": "Pseudomonas mandelii PD30", "rank": "Strain"}, "1419584": {"name": "Aeromonas hydrophila J-1", "rank": "Strain"}, "1182760": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. 08-0128", "rank": "Strain"}, "1182761": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. 08-0627", "rank": "Strain"}, "1182762": {"name": "Enterococcus sp. C1", "rank": "Species"}, "1310868": {"name": "Acinetobacter baumannii 25307_4", "rank": "Strain"}, "1310869": {"name": "Acinetobacter baumannii 25307_5", "rank": "Strain"}, "1310866": {"name": "Acinetobacter baumannii 25307_2", "rank": "Strain"}, "1310867": {"name": "Acinetobacter baumannii 25307_3", "rank": "Strain"}, "1310864": {"name": "Acinetobacter baumannii 24845_10", "rank": "Strain"}, "1310865": {"name": "Acinetobacter baumannii 25307_1", "rank": "Strain"}, "1310862": {"name": "Acinetobacter baumannii 24845_8", "rank": "Strain"}, "1310863": {"name": "Acinetobacter baumannii 24845_9", "rank": "Strain"}, "1310860": {"name": "Acinetobacter baumannii 24845_6", "rank": "Strain"}, "1310861": {"name": "Acinetobacter baumannii 24845_7", "rank": "Strain"}, "682311": {"name": "Streptomyces sp. DpondAA-B6", "rank": "Species"}, "593588": {"name": "Vibrio cholerae MJ-1236", "rank": "Strain"}, "1293501": {"name": "Coxiella burnetii Z3055", "rank": "Strain"}, "1293500": {"name": "Tropheryma whipplei str. Neuro1", "rank": "Strain"}, "2111": {"name": "Mycoplasma arthritidis", "rank": "Species"}, "1438771": {"name": "Klebsiella pneumoniae CHS 65", "rank": "Strain"}, "1438770": {"name": "Klebsiella pneumoniae CHS 64", "rank": "Strain"}, "1288826": {"name": "Marinobacter santoriniensis NKSG1", "rank": "Strain"}, "1438772": {"name": "Klebsiella pneumoniae CHS 66", "rank": "Strain"}, "1438775": {"name": "Klebsiella pneumoniae CHS 71", "rank": "Strain"}, "2112": {"name": "Mycoplasma bovigenitalium", "rank": "Species"}, "1438777": {"name": "Klebsiella pneumoniae CHS 73", "rank": "Strain"}, "291988": {"name": "Thermosediminibacter", "rank": "Genus"}, "1438779": {"name": "Klebsiella pneumoniae CHS 75", "rank": "Strain"}, "1438778": {"name": "Klebsiella pneumoniae CHS 74", "rank": "Strain"}, "291985": {"name": "Erythrobacter vulgaris", "rank": "Species"}, "1288829": {"name": "Pepper yellow leaf curl China virus", "rank": "Species"}, "1411589": {"name": "Staphylococcus aureus W21945", "rank": "Strain"}, "1411588": {"name": "Staphylococcus aureus W21940", "rank": "Strain"}, "979218": {"name": "Staphylococcus epidermidis NIHLM003", "rank": "Strain"}, "979219": {"name": "Staphylococcus epidermidis NIHLM001", "rank": "Strain"}, "593585": {"name": "Vibrio albensis VL426", "rank": "Strain"}, "1411583": {"name": "Staphylococcus aureus W12628", "rank": "Strain"}, "1073": {"name": "Rhodopseudomonas", "rank": "Genus"}, "1411581": {"name": "Staphylococcus aureus T86048", "rank": "Strain"}, "1411580": {"name": "Staphylococcus aureus T86045", "rank": "Strain"}, "1076": {"name": "Rhodopseudomonas palustris", "rank": "Species"}, "1411586": {"name": "Staphylococcus aureus W16013", "rank": "Strain"}, "1411585": {"name": "Staphylococcus aureus W16001", "rank": "Strain"}, "1411584": {"name": "Staphylococcus aureus W15997", "rank": "Strain"}, "1489678": {"name": "Deinococcus sp. RL", "rank": "Species"}, "251749": {"name": "Phaeocystis globosa virus", "rank": "Species"}, "1392077": {"name": "Staphylococcus aureus M1080", "rank": "Strain"}, "251747": {"name": "Chromobacterium subtsugae", "rank": "Species"}, "66377": {"name": "Streptomyces violens", "rank": "Species"}, "66370": {"name": "Streptomyces flaveus", "rank": "Species"}, "66373": {"name": "Streptomyces niger", "rank": "Species"}, "66378": {"name": "Streptomyces yerevanensis", "rank": "Species"}, "1388298": {"name": "Staphylococcus aureus M0447", "rank": "Strain"}, "1388299": {"name": "Staphylococcus aureus M0448", "rank": "Strain"}, "1388294": {"name": "Staphylococcus aureus M0441", "rank": "Strain"}, "1388295": {"name": "Staphylococcus aureus M0442", "rank": "Strain"}, "1388296": {"name": "Staphylococcus aureus M0444", "rank": "Strain"}, "1388297": {"name": "Staphylococcus aureus M0445", "rank": "Strain"}, "1388290": {"name": "Staphylococcus aureus M0435", "rank": "Strain"}, "1388291": {"name": "Staphylococcus aureus M0437", "rank": "Strain"}, "1388292": {"name": "Staphylococcus aureus M0439", "rank": "Strain"}, "1388293": {"name": "Staphylococcus aureus M0440", "rank": "Strain"}, "114292": {"name": "Typhus group", "rank": "Species group"}, "114295": {"name": "Unclassified Rickettsia", "rank": "No rank"}, "1116028": {"name": "Escherichia coli 2866450", "rank": "Strain"}, "1116029": {"name": "Escherichia coli 2866550", "rank": "Strain"}, "1116022": {"name": "Escherichia coli 2860650", "rank": "Strain"}, "1116023": {"name": "Escherichia coli 2861200", "rank": "Strain"}, "1116020": {"name": "Escherichia coli 2853500", "rank": "Strain"}, "1116021": {"name": "Escherichia coli 2860050", "rank": "Strain"}, "1116026": {"name": "Escherichia coli 2865200", "rank": "Strain"}, "543632": {"name": "Actinoplanes subtropicus", "rank": "Species"}, "1116024": {"name": "Escherichia coli 2862600", "rank": "Strain"}, "1116025": {"name": "Escherichia coli 2864350", "rank": "Strain"}, "888060": {"name": "Centipeda periodontii DSM 2778", "rank": "Strain"}, "216371": {"name": "Penicillium stoloniferum virus S", "rank": "Species"}, "888062": {"name": "Dialister micraerophilus DSM 19965", "rank": "Strain"}, "1151438": {"name": "Peptoclostridium difficile P74", "rank": "Strain"}, "888063": {"name": "Enterobacter hormaechei ATCC 49162", "rank": "Strain"}, "1151439": {"name": "Peptoclostridium difficile P75", "rank": "Strain"}, "888064": {"name": "Enterococcus italicus DSM 15952", "rank": "Strain"}, "1048339": {"name": "Sporichthya polymorpha DSM 43042", "rank": "Strain"}, "313602": {"name": "Unclassified Flavobacteriales", "rank": "No rank"}, "153027": {"name": "Desulforegula", "rank": "Genus"}, "153026": {"name": "Desulforegula conservatrix", "rank": "Species"}, "888066": {"name": "Enterococcus casseliflavus ATCC 12755", "rank": "Strain"}, "1406512": {"name": "Candidatus Methanomassiliicoccus intestinalis", "rank": "Species"}, "186457": {"name": "Aureusvirus", "rank": "Genus"}, "358766": {"name": "Methanoregula boonei", "rank": "Species"}, "358764": {"name": "Border disease virus", "rank": "Species"}, "1486421": {"name": "Listeria phage LMSP-25", "rank": "Species"}, "1486422": {"name": "Listeria phage List-36", "rank": "Species"}, "1486423": {"name": "Lactoccocus phage WP-2", "rank": "Species"}, "1486424": {"name": "Mycobacterium phage Bernal13", "rank": "Species"}, "1486425": {"name": "Mycobacterium phage Kampy", "rank": "Species"}, "1486426": {"name": "Mycobacterium phage Phantastic", "rank": "Species"}, "1486427": {"name": "Mycobacterium phage ZoeJ", "rank": "Species"}, "1217640": {"name": "Acinetobacter baumannii NIPH 190", "rank": "Strain"}, "1217641": {"name": "Acinetobacter baumannii NIPH 615", "rank": "Strain"}, "1217642": {"name": "Acinetobacter baumannii NIPH 1362", "rank": "Strain"}, "1217643": {"name": "Acinetobacter baumannii NIPH 1669", "rank": "Strain"}, "1217644": {"name": "Acinetobacter baumannii NIPH 1734", "rank": "Strain"}, "1217645": {"name": "Acinetobacter baumannii NIPH 2061", "rank": "Strain"}, "1217646": {"name": "Acinetobacter baumannii NIPH 24", "rank": "Strain"}, "1217647": {"name": "Acinetobacter baumannii NIPH 60", "rank": "Strain"}, "1217648": {"name": "Acinetobacter beijerinckii CIP 110307", "rank": "Strain"}, "1217649": {"name": "Acinetobacter beijerinckii ANC 3835", "rank": "Strain"}, "1108070": {"name": "Pediococcus phage clP1", "rank": "Species"}, "1435425": {"name": "Pseudomonas sp. QTF5", "rank": "Species"}, "646413": {"name": "Streptococcus phage 5093", "rank": "Species"}, "82117": {"name": "Unclassified Alphaproteobacteria", "rank": "No rank"}, "82116": {"name": "Acetobacterium dehalogenans", "rank": "Species"}, "82115": {"name": "Rhizobiaceae", "rank": "Family"}, "1310638": {"name": "Acinetobacter baumannii 1437282", "rank": "Strain"}, "1402510": {"name": "Pseudomonas aeruginosa BWHPSA010", "rank": "Strain"}, "1402511": {"name": "Pseudomonas aeruginosa BWHPSA011", "rank": "Strain"}, "1402512": {"name": "Pseudomonas aeruginosa BWHPSA012", "rank": "Strain"}, "1402513": {"name": "Pseudomonas aeruginosa BWHPSA013", "rank": "Strain"}, "1402514": {"name": "Pseudomonas aeruginosa BWHPSA014", "rank": "Strain"}, "1402515": {"name": "Pseudomonas aeruginosa BWHPSA015", "rank": "Strain"}, "1402516": {"name": "Pseudomonas aeruginosa BWHPSA016", "rank": "Strain"}, "1402517": {"name": "Pseudomonas aeruginosa BWHPSA017", "rank": "Strain"}, "1402518": {"name": "Pseudomonas aeruginosa BWHPSA018", "rank": "Strain"}, "1402519": {"name": "Pseudomonas aeruginosa BWHPSA019", "rank": "Strain"}, "1117379": {"name": "Bacillus bataviensis LMG 21833", "rank": "Strain"}, "1422206": {"name": "Staphylococcus aureus DAR5877", "rank": "Strain"}, "1095648": {"name": "Vibrio cholerae O1 str. EM-1626", "rank": "Strain"}, "1095649": {"name": "Vibrio cholerae O1 str. EM-1676A", "rank": "Strain"}, "1385511": {"name": "Pontibacillus marinus BH030004 = DSM 16465", "rank": "Strain"}, "1095644": {"name": "Vibrio cholerae O1 str. AG-8040", "rank": "Strain"}, "1095645": {"name": "Vibrio cholerae O1 str. AG-7404", "rank": "Strain"}, "236814": {"name": "Chryseobacterium formosense", "rank": "Species"}, "1095647": {"name": "Vibrio cholerae O1 str. EM-1546", "rank": "Strain"}, "1095640": {"name": "Vibrio cholerae O1 str. EDC-020", "rank": "Strain"}, "1422204": {"name": "Staphylococcus aureus DAR22", "rank": "Strain"}, "1095642": {"name": "Vibrio cholerae O1 str. Nep-21106", "rank": "Strain"}, "1095643": {"name": "Vibrio cholerae O1 str. Nep-21113", "rank": "Strain"}, "1422205": {"name": "Staphylococcus aureus DAR5878", "rank": "Strain"}, "1422202": {"name": "Staphylococcus aureus DAR3933", "rank": "Strain"}, "1385515": {"name": "Lysobacter defluvii IMMIB APB-9 = DSM 18482", "rank": "Strain"}, "194963": {"name": "Ensifer americanum", "rank": "Species"}, "194961": {"name": "Erbovirus", "rank": "Genus"}, "194960": {"name": "Kobuvirus", "rank": "Genus"}, "194966": {"name": "Enterobacteria phage SP6", "rank": "Species"}, "194965": {"name": "Aichivirus B", "rank": "Species"}, "71667": {"name": "Waddlia chondrophila", "rank": "Species"}, "71666": {"name": "Waddlia", "rank": "Genus"}, "1422201": {"name": "Staphylococcus aureus DAR3930", "rank": "Strain"}, "38525": {"name": "Avian metapneumovirus", "rank": "Species"}, "129953": {"name": "Bovine mastadenovirus A", "rank": "Species"}, "1116391": {"name": "Paenibacillus mucilaginosus 3016", "rank": "Strain"}, "85831": {"name": "Bacteroides acidifaciens", "rank": "Species"}, "1281058": {"name": "Escherichia coli HVH 121 (4-6877826)", "rank": "Strain"}, "10242": {"name": "Orthopoxvirus", "rank": "Genus"}, "1536770": {"name": "Paenibacillus sp. FSL R5-0345", "rank": "Species"}, "1536771": {"name": "Paenibacillus sp. FSL R5-0912", "rank": "Species"}, "1536772": {"name": "Paenibacillus sp. FSL R7-0273", "rank": "Species"}, "1536773": {"name": "Paenibacillus sp. FSL R7-0331", "rank": "Species"}, "1536774": {"name": "Paenibacillus sp. FSL H7-0357", "rank": "Species"}, "1536775": {"name": "Paenibacillus sp. FSL H7-0737", "rank": "Species"}, "1281057": {"name": "Escherichia coli HVH 120 (4-6978681)", "rank": "Strain"}, "318161": {"name": "Shewanella denitrificans OS217", "rank": "Strain"}, "348604": {"name": "Enterobacteria phage T4 sensu lato", "rank": "Species"}, "318167": {"name": "Shewanella frigidimarina NCIMB 400", "rank": "Strain"}, "1281052": {"name": "Escherichia coli HVH 115 (4-4465989)", "rank": "Strain"}, "1047011": {"name": "Unclassified Caldiserica", "rank": "No rank"}, "1281053": {"name": "Escherichia coli HVH 116 (4-6879942)", "rank": "Strain"}, "40199": {"name": "Fusarium avenaceum", "rank": "Species"}, "1410895": {"name": "Staphylococcus aureus M44986", "rank": "Strain"}, "765079": {"name": "Propionibacterium acnes HL110PA3", "rank": "Strain"}, "765078": {"name": "Propionibacterium acnes HL110PA2", "rank": "Strain"}, "765077": {"name": "Propionibacterium acnes HL110PA1", "rank": "Strain"}, "765076": {"name": "Propionibacterium acnes HL074PA1", "rank": "Strain"}, "765075": {"name": "Propionibacterium acnes HL072PA2", "rank": "Strain"}, "765074": {"name": "Propionibacterium acnes HL072PA1", "rank": "Strain"}, "765073": {"name": "Propionibacterium acnes HL043PA2", "rank": "Strain"}, "765072": {"name": "Propionibacterium acnes HL043PA1", "rank": "Strain"}, "765071": {"name": "Propionibacterium acnes HL078PA1", "rank": "Strain"}, "765070": {"name": "Propionibacterium acnes HL013PA2", "rank": "Strain"}, "1126915": {"name": "Escherichia coli C717_10", "rank": "Strain"}, "1126917": {"name": "Escherichia coli C732_98", "rank": "Strain"}, "1126916": {"name": "Escherichia coli C725_88", "rank": "Strain"}, "1126911": {"name": "Escherichia coli C639_08", "rank": "Strain"}, "1126912": {"name": "Escherichia coli C652_10", "rank": "Strain"}, "1050719": {"name": "Unclassified Crenarchaeota (miscellaneous)", "rank": "No rank"}, "127507": {"name": "Vibrio phage VfO3K6", "rank": "Species"}, "1126919": {"name": "Escherichia coli C751_03", "rank": "Strain"}, "1126918": {"name": "Escherichia coli C743_03", "rank": "Strain"}, "1290429": {"name": "Rickettsia prowazekii str. GvF12", "rank": "Strain"}, "1290428": {"name": "Rickettsia prowazekii str. Breinl", "rank": "Strain"}, "432026": {"name": "Mixiales", "rank": "Order"}, "1290427": {"name": "Rickettsia prowazekii str. NMRC Madrid E", "rank": "Strain"}, "264574": {"name": "Oceanimonas smirnovii", "rank": "Species"}, "137722": {"name": "Azospirillum sp. B510", "rank": "Strain"}, "1432325": {"name": "Candidatus Aminicenans sakinawicola", "rank": "Species"}, "638786": {"name": "Orangutan polyomavirus", "rank": "Species"}, "1432327": {"name": "Candidatus Microgenomatus auricola", "rank": "Species"}, "5179": {"name": "Sclerotinia", "rank": "Genus"}, "5178": {"name": "Helotiales", "rank": "Order"}, "185008": {"name": "Butyrivibrio hungatei", "rank": "Species"}, "1432328": {"name": "Candidatus Paceibacter", "rank": "Genus"}, "1432329": {"name": "Candidatus Paceibacter normanii", "rank": "Species"}, "243924": {"name": "Pseudomonas lutea", "rank": "Species"}, "1193503": {"name": "Gilliamella", "rank": "Genus"}, "1193501": {"name": "Pseudomonas aeruginosa SJTD-1", "rank": "Strain"}, "1229675": {"name": "Pseudomonas phage vB_PaeP_C1-14_Or", "rank": "Strain"}, "63118": {"name": "Lactococcus phage bIL170", "rank": "Strain"}, "420994": {"name": "Sphingobium ummariense", "rank": "Species"}, "1078090": {"name": "Coprococcus sp. HPP0074", "rank": "Species"}, "1078091": {"name": "Coprococcus sp. HPP0048", "rank": "Species"}, "396323": {"name": "Acinetobacter brisouii", "rank": "Species"}, "1008460": {"name": "Pyrococcus yayanosii", "rank": "Species"}, "69014": {"name": "Thermococcus kodakarensis KOD1", "rank": "Strain"}, "1218108": {"name": "Empedobacter brevis NBRC 14943 = ATCC 43319", "rank": "Strain"}, "1218102": {"name": "Alcaligenes faecalis subsp. faecalis NBRC 13111", "rank": "Strain"}, "1218103": {"name": "Chryseobacterium indologenes NBRC 14944", "rank": "Strain"}, "1235981": {"name": "Burkholderiales bacterium JGI 0001002-H06", "rank": "Species"}, "1218101": {"name": "Yersinia pseudotuberculosis NBRC 105692", "rank": "Strain"}, "1235986": {"name": "Acidobacteria bacterium JGI 0001001-H03", "rank": "Species"}, "1218104": {"name": "Cronobacter sakazakii NBRC 102416", "rank": "Strain"}, "1235984": {"name": "Massilia sp. JGI 0001003-B08", "rank": "Species"}, "335972": {"name": "Vibrio litoralis", "rank": "Species"}, "1127354": {"name": "Salmonella enterica subsp. enterica serovar Newport str. #11-3", "rank": "Strain"}, "1127355": {"name": "Salmonella enterica subsp. enterica serovar Newport str. #11-2", "rank": "Strain"}, "1127356": {"name": "Escherichia coli 4_1_47FAA", "rank": "Strain"}, "1127357": {"name": "Salmonella phage SPN9CC", "rank": "Species"}, "451753": {"name": "Clostridium perfringens CPE", "rank": "Strain"}, "1127353": {"name": "Salmonella enterica subsp. enterica serovar Newport str. #11-4", "rank": "Strain"}, "1170233": {"name": "Unclassified Morbillivirus", "rank": "No rank"}, "346673": {"name": "Coccolithovirus", "rank": "Genus"}, "346674": {"name": "Unclassified Chlorovirus", "rank": "No rank"}, "1234365": {"name": "Helicobacter pylori Rif1", "rank": "Strain"}, "173976": {"name": "Cycas necrotic stunt virus", "rank": "Species"}, "78058": {"name": "Paenibacillus lentimorbus", "rank": "Species"}, "236100": {"name": "Marinobacter algicola", "rank": "Species"}, "1544364": {"name": "Microviridae IME-16", "rank": "Species"}, "1110693": {"name": "Escherichia coli str. K-12 substr. MDS42", "rank": "Strain"}, "1086030": {"name": "Shigella flexneri 5a str. M90T", "rank": "Strain"}, "1110697": {"name": "Nocardia asteroides NBRC 15531", "rank": "Strain"}, "1110694": {"name": "Pantoea agglomerans IG1", "rank": "Strain"}, "702980": {"name": "Salmonella enterica subsp. enterica serovar Typhimurium str. ST4581", "rank": "Strain"}, "702982": {"name": "Salmonella enterica subsp. enterica serovar Saintpaul str. SARA26", "rank": "Strain"}, "702983": {"name": "Salmonella enterica subsp. enterica serovar Paratyphi B str. SARA56", "rank": "Strain"}, "702984": {"name": "Salmonella enterica subsp. enterica serovar Paratyphi B str. SARA61", "rank": "Strain"}, "1423767": {"name": "Lactobacillus kitasatonis DSM 16761 = JCM 1039", "rank": "Strain"}, "341225": {"name": "Clostridium saccharogumia", "rank": "Species"}, "1502101": {"name": "Sclerotinia sclerotiorum debilitation-associated RNA virus 2", "rank": "Species"}, "1003238": {"name": "Chlamydophila abortus LLG", "rank": "Strain"}, "1234362": {"name": "Vibrio sp. 624788", "rank": "Species"}, "1256230": {"name": "Lactobacillus paracasei subsp. tolerans Lpl7", "rank": "Strain"}, "1052810": {"name": "Calescamantes bacterium SCGC AAA471-M6", "rank": "Species"}, "1052811": {"name": "Fervidibacteria bacterium JGI 0000001-B9", "rank": "Species"}, "1052812": {"name": "Fervidibacteria bacterium JGI 0000001-D5", "rank": "Species"}, "1052813": {"name": "Fervidibacteria bacterium JGI 0000001-G10", "rank": "Species"}, "1052814": {"name": "Fervidibacteria bacterium JGI 0000054-H05", "rank": "Species"}, "1052815": {"name": "Aerophobetes", "rank": "Phylum"}, "1052817": {"name": "Aerophobetes bacterium SCGC AAA255-F10", "rank": "Species"}, "305900": {"name": "Endozoicomonas elysicola", "rank": "Species"}, "135248": {"name": "Francisella tularensis subsp. mediasiatica", "rank": "Subspecies"}, "1129147": {"name": "Klebsiella phage KP27", "rank": "Species"}, "1129146": {"name": "Pseudomonas phage vB_PaeS_PMG1", "rank": "Species"}, "1129145": {"name": "Pseudomonas phage phi297", "rank": "Species"}, "321": {"name": "Pseudomonas syringae pv. syringae", "rank": "Strain"}, "322": {"name": "Pseudomonas syringae pv. tabaci", "rank": "Strain"}, "323": {"name": "Pseudomonas syringae pv. tomato", "rank": "Strain"}, "42565": {"name": "Halomonas salina", "rank": "Species"}, "329": {"name": "Ralstonia pickettii", "rank": "Species"}, "1549811": {"name": "Bacillus sp. BSC154", "rank": "Species"}, "1448409": {"name": "Mycobacterium tuberculosis TKK_03_0062", "rank": "Strain"}, "172827": {"name": "Meiothermus taiwanensis", "rank": "Species"}, "1448400": {"name": "Mycobacterium tuberculosis TKK_03_0039", "rank": "Strain"}, "1448401": {"name": "Mycobacterium tuberculosis TKK_03_0040", "rank": "Strain"}, "1448402": {"name": "Mycobacterium tuberculosis TKK_03_0042", "rank": "Strain"}, "1448403": {"name": "Mycobacterium tuberculosis TKK_03_0044", "rank": "Strain"}, "1448404": {"name": "Mycobacterium tuberculosis TKK_03_0047", "rank": "Strain"}, "1448405": {"name": "Mycobacterium tuberculosis TKK_03_0050", "rank": "Strain"}, "1448406": {"name": "Mycobacterium tuberculosis TKK_03_0058", "rank": "Strain"}, "1448407": {"name": "Mycobacterium tuberculosis TKK_03_0059", "rank": "Strain"}, "1243664": {"name": "Bacillus sp. G2(2012b)", "rank": "Species"}, "1249627": {"name": "Thiorhodococcus sp. AK35", "rank": "Species"}, "880158": {"name": "Unclassified Prasinovirus", "rank": "No rank"}, "880159": {"name": "Bathycoccus sp. RCC1105 virus BpV1", "rank": "Strain"}, "187420": {"name": "Methanothermobacter thermautotrophicus str. Delta H", "rank": "Strain"}, "273677": {"name": "Microbacterium oleivorans", "rank": "Species"}, "104623": {"name": "Serratia sp. ATCC 39006", "rank": "Species"}, "123375": {"name": "Solobacterium", "rank": "Genus"}, "56094": {"name": "Aquareovirus A", "rank": "Species"}, "942731": {"name": "Unclassified Alphaflexiviridae", "rank": "No rank"}, "638315": {"name": "Legionella longbeachae D-4968", "rank": "Strain"}, "638313": {"name": "Human bocavirus 3", "rank": "Strain"}, "1471515": {"name": "Prochlorococcus sp. scB245a_519L21", "rank": "Species"}, "356828": {"name": "Metascardovia criceti", "rank": "Species"}, "356829": {"name": "Bifidobacterium tsurumiense", "rank": "Species"}, "571800": {"name": "Psychrobacter sp. G", "rank": "Species"}, "1539853": {"name": "Yamadazyma/Candida clade", "rank": "No rank"}, "356827": {"name": "Metascardovia", "rank": "Genus"}, "383631": {"name": "Methylophilales bacterium HTCC2181", "rank": "Species"}, "383630": {"name": "Unclassified Methylophilales", "rank": "No rank"}, "13690": {"name": "Sphingobium yanoikuyae", "rank": "Species"}, "1225732": {"name": "Ectropis obliqua virus", "rank": "Species"}, "697286": {"name": "Paenibacillus larvae subsp. larvae DSM 25719", "rank": "Strain"}, "1328323": {"name": "Cellulophaga geojensis KL-A", "rank": "Strain"}, "697284": {"name": "Paenibacillus larvae subsp. larvae DSM 25430", "rank": "Strain"}, "1328326": {"name": "Salmonella enterica subsp. enterica serovar Anatum str. 06-0532", "rank": "Strain"}, "1328327": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. 07-0873", "rank": "Strain"}, "1328324": {"name": "Klebsiella pneumoniae subsp. pneumoniae KPNIH27", "rank": "Strain"}, "1328325": {"name": "Klebsiella pneumoniae subsp. pneumoniae KPR0928", "rank": "Strain"}, "1328328": {"name": "Salmonella enterica subsp. enterica serovar Hadar str. 2012K-0272", "rank": "Strain"}, "1070408": {"name": "Human papillomavirus type 135", "rank": "Strain"}, "484019": {"name": "Thermosipho africanus TCF52B", "rank": "Strain"}, "484018": {"name": "Bacteroides plebeius DSM 17135", "rank": "Strain"}, "1158758": {"name": "Thioalkalivibrio sp. ALJ9", "rank": "Species"}, "1158759": {"name": "Thioalkalivibrio sp. ALJ10", "rank": "Species"}, "1160218": {"name": "Brucella melitensis R3/07-2", "rank": "Strain"}, "1160219": {"name": "Brucella melitensis F1/06 B10", "rank": "Strain"}, "1160210": {"name": "Brucella melitensis F3/02", "rank": "Strain"}, "1160211": {"name": "Brucella melitensis F10/05-2", "rank": "Strain"}, "888027": {"name": "Lactobacillus delbrueckii subsp. lactis DSM 20072", "rank": "Strain"}, "1160214": {"name": "Brucella melitensis UK22/04", "rank": "Strain"}, "1160215": {"name": "Brucella melitensis F5/07-239A", "rank": "Strain"}, "1160216": {"name": "Brucella melitensis UK37/05", "rank": "Strain"}, "1160217": {"name": "Brucella melitensis UK14/06", "rank": "Strain"}, "1151188": {"name": "Enterococcus faecalis EnGen0061", "rank": "Strain"}, "1159061": {"name": "Helicobacter pylori GAMchJs117Ai", "rank": "Strain"}, "1031542": {"name": "Campylobacter volucris", "rank": "Species"}, "699264": {"name": "Candidatus Omnitrophus fodinae SCGC AAA011-A17", "rank": "Strain"}, "93133": {"name": "Mycosphaerellaceae", "rank": "Family"}, "502801": {"name": "Yersinia pseudotuberculosis PB1/+", "rank": "Strain"}, "502800": {"name": "Yersinia pseudotuberculosis YPIII", "rank": "Strain"}, "1112912": {"name": "Brucella suis VBI22", "rank": "Strain"}, "33867": {"name": "Unclassified Euryarchaeota", "rank": "No rank"}, "33861": {"name": "Unclassified Crenarchaeota", "rank": "No rank"}, "1444174": {"name": "Escherichia coli 6-537-08_S3_C2", "rank": "Strain"}, "1444175": {"name": "Escherichia coli 2-005-03_S3_C3", "rank": "Strain"}, "1444176": {"name": "Escherichia coli 2-011-08_S3_C3", "rank": "Strain"}, "1444177": {"name": "Escherichia coli 2-052-05_S3_C3", "rank": "Strain"}, "1444170": {"name": "Escherichia coli 3-475-03_S3_C2", "rank": "Strain"}, "1444171": {"name": "Escherichia coli 4-203-08_S3_C2", "rank": "Strain"}, "1444172": {"name": "Escherichia coli 6-175-07_S3_C2", "rank": "Strain"}, "1444173": {"name": "Escherichia coli 6-319-05_S3_C2", "rank": "Strain"}, "1444178": {"name": "Escherichia coli 2-156-04_S3_C3", "rank": "Strain"}, "1444179": {"name": "Escherichia coli 2-177-06_S3_C3", "rank": "Strain"}, "1495039": {"name": "Mesoaciditoga lauensis", "rank": "Species"}, "1495038": {"name": "Mesoaciditoga", "rank": "Genus"}, "436907": {"name": "Vanderwaltozyma polyspora DSM 70294", "rank": "Strain"}, "120957": {"name": "Nocardia abscessus", "rank": "Species"}, "130369": {"name": "Porcine mastadenovirus A", "rank": "Species"}, "306263": {"name": "Campylobacter lari RM2100", "rank": "Strain"}, "306264": {"name": "Campylobacter upsaliensis RM3195", "rank": "Strain"}, "1434932": {"name": "Burkholderia pseudomallei MSHR5609", "rank": "Strain"}, "11272": {"name": "Chandipura virus", "rank": "Species"}, "29256": {"name": "Trichomonas vaginalis virus", "rank": "Species"}, "29255": {"name": "Giardia lamblia virus", "rank": "Species"}, "11271": {"name": "Vesiculovirus", "rank": "Genus"}, "11277": {"name": "Vesicular stomatitis Indiana virus", "rank": "Species"}, "29250": {"name": "Heliothis zea nudivirus", "rank": "Species"}, "1233675": {"name": "Honeysuckle yellow vein Kagoshima virus", "rank": "Species"}, "29258": {"name": "SsDNA viruses", "rank": "No rank"}, "1434931": {"name": "Burkholderia pseudomallei MSHR5608", "rank": "Strain"}, "11901": {"name": "Bovine leukemia virus", "rank": "Species"}, "304222": {"name": "Cotton leaf curl Gezira betasatellite", "rank": "Species"}, "11908": {"name": "Human T-lymphotropic virus 1", "rank": "Strain"}, "11909": {"name": "Human T-lymphotropic virus 2", "rank": "Strain"}, "1297534": {"name": "Streptococcus dentisani 7746", "rank": "Strain"}, "1094564": {"name": "Bartonella washoensis 085-0475", "rank": "Strain"}, "1094562": {"name": "Bartonella vinsonii subsp. arupensis OK-94-513", "rank": "Strain"}, "1094563": {"name": "Bartonella washoensis Sb944nv", "rank": "Strain"}, "1094560": {"name": "Bartonella taylorii 8TBB", "rank": "Strain"}, "1094561": {"name": "Bartonella vinsonii subsp. arupensis Pm136co", "rank": "Strain"}, "412883": {"name": "Vibrio cholerae MZO-3", "rank": "Strain"}, "185637": {"name": "Pseudoplusia includens densovirus", "rank": "Strain"}, "5529": {"name": "Metarhizium", "rank": "Genus"}, "137357": {"name": "Lactobacillus equi", "rank": "Species"}, "1074889": {"name": "Blattabacterium sp. (Mastotermes darwiniensis) str. MADAR", "rank": "Strain"}, "54005": {"name": "Peptoniphilus harei", "rank": "Species"}, "29875": {"name": "Trichoderma virens", "rank": "Species"}, "1431713": {"name": "Pseudomonas aeruginosa VRFPA07", "rank": "Strain"}, "426428": {"name": "Fusarium oxysporum f. sp. lycopersici 4287", "rank": "Strain"}, "575913": {"name": "Sea turtle tornovirus 1", "rank": "Species"}, "426421": {"name": "Sediminibacterium salmoneum", "rank": "Species"}, "575918": {"name": "Tomato leaf curl Patna betasatellite", "rank": "Species"}, "1305788": {"name": "Kingella kingae AA255", "rank": "Strain"}, "286730": {"name": "Alkaliflexus imshenetskii", "rank": "Species"}, "455488": {"name": "Anaeromyxobacter dehalogenans 2CP-1", "rank": "Strain"}, "1295808": {"name": "Mycobacterium tuberculosis OFXR-16", "rank": "Strain"}, "1295804": {"name": "Mycobacterium tuberculosis OFXR-12", "rank": "Strain"}, "1295805": {"name": "Mycobacterium tuberculosis OFXR-13", "rank": "Strain"}, "1295806": {"name": "Mycobacterium tuberculosis OFXR-14", "rank": "Strain"}, "1295807": {"name": "Mycobacterium tuberculosis OFXR-15", "rank": "Strain"}, "1295800": {"name": "Mycobacterium tuberculosis OFXR-5", "rank": "Strain"}, "1295801": {"name": "Mycobacterium tuberculosis OFXR-7", "rank": "Strain"}, "1295802": {"name": "Mycobacterium tuberculosis OFXR-10", "rank": "Strain"}, "374810": {"name": "Enterobacteria phage 933W sensu lato", "rank": "Species"}, "32011": {"name": "Methylophilaceae", "rank": "Family"}, "552396": {"name": "Erysipelotrichaceae bacterium 5_2_54FAA", "rank": "Species"}, "32012": {"name": "Thiomonas", "rank": "Genus"}, "1247644": {"name": "Bordetella holmesii 30539", "rank": "Strain"}, "32019": {"name": "Campylobacter fetus subsp. fetus", "rank": "Subspecies"}, "1089299": {"name": "Streptococcus pneumoniae 1974M1-LZD", "rank": "Strain"}, "1408159": {"name": "Thermotoga caldifontis AZM44c09", "rank": "Strain"}, "867845": {"name": "Chloroflexus sp. Y-396-1", "rank": "Species"}, "937593": {"name": "Geobacillus stearothermophilus ATCC 7953", "rank": "Strain"}, "1417192": {"name": "Staphylococcus aureus T18851", "rank": "Strain"}, "1417193": {"name": "Staphylococcus aureus T18865", "rank": "Strain"}, "1417191": {"name": "Staphylococcus aureus T15889", "rank": "Strain"}, "1417196": {"name": "Staphylococcus aureus T25283", "rank": "Strain"}, "1417197": {"name": "Staphylococcus aureus T28640", "rank": "Strain"}, "1417194": {"name": "Staphylococcus aureus T22051", "rank": "Strain"}, "1417195": {"name": "Staphylococcus aureus T22071_080712", "rank": "Strain"}, "1417198": {"name": "Staphylococcus aureus T28649", "rank": "Strain"}, "1417199": {"name": "Staphylococcus aureus T28653", "rank": "Strain"}, "385957": {"name": "Amycolatopsis sp. ATCC 39116", "rank": "Species"}, "1523412": {"name": "Pseudoalteromonas sp. A2", "rank": "Species"}, "37960": {"name": "Unclassified Partitiviridae", "rank": "No rank"}, "37961": {"name": "Atkinsonella hypoxylon virus", "rank": "Species"}, "66976": {"name": "Legionella pneumophila serogroup 1", "rank": "Strain"}, "33056": {"name": "Candidatus Kinetoplastibacterium crithidii", "rank": "Species"}, "33057": {"name": "Thauera", "rank": "Genus"}, "33055": {"name": "Kinetoplastibacterium", "rank": "Genus"}, "1228997": {"name": "Riemerella anatipestifer RA-CH-1", "rank": "Strain"}, "33059": {"name": "Acidithiobacillus caldus", "rank": "Species"}, "2205": {"name": "Methanomicrobium mobile", "rank": "Species"}, "1147787": {"name": "Pseudomonas aeruginosa PAO1H2O", "rank": "Strain"}, "314281": {"name": "Pseudoalteromonas tunicata", "rank": "Species"}, "1397873": {"name": "Mycobacterium tuberculosis TKK_02_0036", "rank": "Strain"}, "1147786": {"name": "Pseudomonas mandelii JR-1", "rank": "Strain"}, "1347370": {"name": "Pantoea sp. FF5", "rank": "Species"}, "158899": {"name": "Collimonas fungivorans", "rank": "Species"}, "519442": {"name": "Halorhabdus utahensis DSM 12940", "rank": "Strain"}, "1080709": {"name": "Methanomassiliicoccus", "rank": "Genus"}, "60481": {"name": "Shewanella sp. MR-7", "rank": "Species"}, "60480": {"name": "Shewanella sp. MR-4", "rank": "Species"}, "1123288": {"name": "Sporomusa ovata DSM 2662", "rank": "Strain"}, "1312978": {"name": "Arthrobacter sp. H41", "rank": "Species"}, "85618": {"name": "Ateline herpesvirus 3", "rank": "Species"}, "913865": {"name": "Desulfosporosinus sp. OT", "rank": "Species"}, "1139219": {"name": "Enterococcus dispar ATCC 51266", "rank": "Strain"}, "667126": {"name": "Methanocaldococcus villosus", "rank": "Species"}, "667127": {"name": "Klebsiella pneumoniae subsp. rhinoscleromatis ATCC 13884", "rank": "Strain"}, "667120": {"name": "Edwardsiella tarda 080813", "rank": "Strain"}, "667121": {"name": "Edwardsiella tarda ATCC 15947 = NBRC 105688", "rank": "Strain"}, "667128": {"name": "Pasteurella dagmatis ATCC 43325", "rank": "Strain"}, "667129": {"name": "Serratia odorifera DSM 4582", "rank": "Strain"}, "1185659": {"name": "Xanthomonas axonopodis pv. manihotis str. CIO1", "rank": "Strain"}, "1185658": {"name": "Xanthomonas axonopodis pv. manihotis str. Xam1134", "rank": "Strain"}, "1185655": {"name": "Xanthomonas axonopodis pv. manihotis str. Xam669", "rank": "Strain"}, "1185654": {"name": "Pyrococcus furiosus COM1", "rank": "Strain"}, "1185657": {"name": "Xanthomonas axonopodis pv. manihotis str. Xam678", "rank": "Strain"}, "1185656": {"name": "Xanthomonas axonopodis pv. manihotis str. Xam672", "rank": "Strain"}, "1185651": {"name": "Enterovibrio norvegicus FF-454", "rank": "Strain"}, "1185650": {"name": "Mycobacterium abscessus subsp. abcessus", "rank": "Subspecies"}, "1185653": {"name": "Planococcus antarcticus DSM 14505", "rank": "Strain"}, "1185652": {"name": "Sinorhizobium fredii USDA 257", "rank": "Strain"}, "1041929": {"name": "Cavally virus", "rank": "Strain"}, "1501145": {"name": "Neosynechococcus sphagnicola", "rank": "Species"}, "1501143": {"name": "Neosynechococcus", "rank": "Genus"}, "997346": {"name": "Desmospora sp. 8437", "rank": "Species"}, "997347": {"name": "Fusobacterium nucleatum subsp. animalis ATCC 51191", "rank": "Strain"}, "997344": {"name": "Salmonella enterica subsp. enterica serovar Newport str. RI_10P078", "rank": "Strain"}, "997345": {"name": "Salmonella enterica subsp. enterica serovar Newport str. RI_10P079", "rank": "Strain"}, "997342": {"name": "Salmonella enterica subsp. enterica serovar Newport str. RI_10P068", "rank": "Strain"}, "1056495": {"name": "Caldisphaera lagunensis DSM 15908", "rank": "Strain"}, "997340": {"name": "Salmonella enterica subsp. enterica serovar Newport str. WA_14885", "rank": "Strain"}, "997341": {"name": "Salmonella enterica subsp. enterica serovar Newport str. WA_14900", "rank": "Strain"}, "500153": {"name": "Streptomyces avicenniae", "rank": "Species"}, "331111": {"name": "Escherichia coli O139:H28 str. E24377A", "rank": "Strain"}, "997348": {"name": "Neisseria macacae ATCC 33926", "rank": "Strain"}, "1224141": {"name": "Acinetobacter baumannii ZWS1219", "rank": "Strain"}, "502049": {"name": "Thalassospira profundimaris", "rank": "Species"}, "1224142": {"name": "Actinobacillus pleuropneumoniae S8", "rank": "Strain"}, "1224145": {"name": "Dickeya sp. MK7", "rank": "Species"}, "1070774": {"name": "Halonotius sp. J07HN4", "rank": "Species"}, "1224147": {"name": "Dickeya zeae NCPPB 3532", "rank": "Strain"}, "1224146": {"name": "Dickeya zeae NCPPB 3531", "rank": "Strain"}, "1224149": {"name": "Dickeya dadantii NCPPB 3537", "rank": "Strain"}, "1224148": {"name": "Dickeya chrysanthemi NCPPB 3533", "rank": "Strain"}, "331112": {"name": "Escherichia coli HS", "rank": "Strain"}, "57046": {"name": "Salmonella enterica subsp. enterica serovar Paratyphi C", "rank": "Strain"}, "57045": {"name": "Salmonella enterica subsp. enterica serovar Paratyphi B", "rank": "Strain"}, "460364": {"name": "Wheat eqlid mosaic virus", "rank": "Species"}, "460363": {"name": "Unclassified Tritimovirus", "rank": "No rank"}, "1388589": {"name": "Staphylococcus aureus M0802", "rank": "Strain"}, "1388354": {"name": "Staphylococcus aureus M0537", "rank": "Strain"}, "1427229": {"name": "Mycobacterium tuberculosis XTB13-140", "rank": "Strain"}, "1001726": {"name": "Mycobacterium abscessus 4S-0726-RA", "rank": "Strain"}, "1001727": {"name": "Mycobacterium abscessus 4S-0726-RB", "rank": "Strain"}, "1073372": {"name": "Streptococcus parasanguinis CC87K", "rank": "Strain"}, "1001725": {"name": "Mycobacterium abscessus 4S-0116-R", "rank": "Strain"}, "1001722": {"name": "Mycobacterium abscessus 4S-0303", "rank": "Strain"}, "1001723": {"name": "Mycobacterium abscessus 4S-0206", "rank": "Strain"}, "1073376": {"name": "Ruminococcus lactaris CC59_002D", "rank": "Strain"}, "1001721": {"name": "Mycobacterium abscessus 3A-0119-R", "rank": "Strain"}, "548687": {"name": "Macavirus", "rank": "Genus"}, "1001728": {"name": "Mycobacterium abscessus 5S-0304", "rank": "Strain"}, "1001729": {"name": "Mycobacterium abscessus 5S-0421", "rank": "Strain"}, "155414": {"name": "Eimeria brunetti RNA virus 1", "rank": "Species"}, "548685": {"name": "Malacoherpesviridae", "rank": "Family"}, "1169234": {"name": "Brucella sp. 56/94", "rank": "Species"}, "81028": {"name": "Treponema brennaborense", "rank": "Species"}, "81029": {"name": "Hyphomonas adhaerens", "rank": "Species"}, "760758": {"name": "Streptococcus pneumoniae GA08780", "rank": "Strain"}, "292691": {"name": "Gramella", "rank": "Genus"}, "760750": {"name": "Streptococcus pneumoniae GA06083", "rank": "Strain"}, "760755": {"name": "Streptococcus pneumoniae GA07643", "rank": "Strain"}, "760754": {"name": "Streptococcus pneumoniae GA07228", "rank": "Strain"}, "195773": {"name": "Cladonia metacorallifera", "rank": "Species"}, "760756": {"name": "Streptococcus pneumoniae GA07914", "rank": "Strain"}, "1427227": {"name": "Mycobacterium tuberculosis XTB13-137", "rank": "Strain"}, "1455654": {"name": "Milk vetch dwarf C3 alphasatellite", "rank": "Species"}, "1455653": {"name": "Milk vetch dwarf C2 alphasatellite", "rank": "Species"}, "1455652": {"name": "Milk vetch dwarf C10 alphasatellite", "rank": "Species"}, "1455651": {"name": "Milk vetch dwarf C1 alphasatellite", "rank": "Species"}, "1427226": {"name": "Mycobacterium tuberculosis XTB13-136", "rank": "Strain"}, "699182": {"name": "Mimoreovirus", "rank": "Genus"}, "328613": {"name": "Unclassified Ascovirus", "rank": "No rank"}, "699187": {"name": "Treponema denticola F0402", "rank": "Strain"}, "328615": {"name": "Trichoplusia ni ascovirus 2c", "rank": "Species"}, "699185": {"name": "Enterococcus faecalis S613", "rank": "Strain"}, "699184": {"name": "Bacillus cereus SJ1", "rank": "Strain"}, "699189": {"name": "Iflaviridae", "rank": "Family"}, "237631": {"name": "Ustilago maydis 521", "rank": "Strain"}, "1402208": {"name": "Lactobacillus ruminis DPC 6832", "rank": "Strain"}, "1448648": {"name": "Mycobacterium tuberculosis M1287", "rank": "Strain"}, "1448649": {"name": "Mycobacterium tuberculosis M1288", "rank": "Strain"}, "1448646": {"name": "Mycobacterium tuberculosis M1283", "rank": "Strain"}, "1448647": {"name": "Mycobacterium tuberculosis M1272", "rank": "Strain"}, "1448644": {"name": "Mycobacterium tuberculosis M1273", "rank": "Strain"}, "1448645": {"name": "Mycobacterium tuberculosis M1274", "rank": "Strain"}, "1448642": {"name": "Mycobacterium tuberculosis M1270", "rank": "Strain"}, "1448643": {"name": "Mycobacterium tuberculosis M1271", "rank": "Strain"}, "1448640": {"name": "Mycobacterium tuberculosis M1236", "rank": "Strain"}, "1448641": {"name": "Mycobacterium tuberculosis M1253", "rank": "Strain"}, "119072": {"name": "Caldanaerobacter subterraneus subsp. tengcongensis", "rank": "Subspecies"}, "168": {"name": "Treponema pallidum subsp. pertenue", "rank": "Subspecies"}, "994476": {"name": "Yersinia enterocolitica subsp. palearctica 105.5R(r)", "rank": "Strain"}, "162": {"name": "Treponema phagedenis", "rank": "Species"}, "163": {"name": "Treponema bryantii", "rank": "Species"}, "160": {"name": "Treponema pallidum", "rank": "Species"}, "161": {"name": "Treponema pallidum subsp. pallidum", "rank": "Subspecies"}, "167": {"name": "Treponema succinifaciens", "rank": "Species"}, "990998": {"name": "Vibrio ordalii ATCC 33509", "rank": "Strain"}, "165": {"name": "Treponema saccharophilum", "rank": "Species"}, "1388005": {"name": "Staphylococcus aureus M0028", "rank": "Strain"}, "1388004": {"name": "Staphylococcus aureus M0027", "rank": "Strain"}, "1427319": {"name": "Mycobacterium tuberculosis XTB13-251", "rank": "Strain"}, "1388006": {"name": "Staphylococcus aureus M0030", "rank": "Strain"}, "1388001": {"name": "Staphylococcus aureus M0024", "rank": "Strain"}, "1388000": {"name": "Staphylococcus aureus M0022", "rank": "Strain"}, "1388003": {"name": "Staphylococcus epidermidis M0026", "rank": "Strain"}, "1388002": {"name": "Staphylococcus aureus M0025", "rank": "Strain"}, "1427313": {"name": "Mycobacterium tuberculosis XTB13-244", "rank": "Strain"}, "1427312": {"name": "Mycobacterium tuberculosis XTB13-242", "rank": "Strain"}, "1427311": {"name": "Mycobacterium tuberculosis XTB13-241", "rank": "Strain"}, "1427310": {"name": "Mycobacterium tuberculosis XTB13-240", "rank": "Strain"}, "1388009": {"name": "Staphylococcus aureus M0036", "rank": "Strain"}, "1388008": {"name": "Staphylococcus aureus M0034", "rank": "Strain"}, "1427315": {"name": "Mycobacterium tuberculosis XTB13-246", "rank": "Strain"}, "1427314": {"name": "Mycobacterium tuberculosis XTB13-245", "rank": "Strain"}, "691": {"name": "Vibrio natriegens", "rank": "Species"}, "1306414": {"name": "Mycobacterium tuberculosis EAI5", "rank": "Strain"}, "1306417": {"name": "Burkholderia pseudomallei MSHR5858", "rank": "Strain"}, "1306413": {"name": "Mycobacterium tuberculosis CAS", "rank": "Strain"}, "1306418": {"name": "Burkholderia pseudomallei HBPUB10134a", "rank": "Strain"}, "1306419": {"name": "Burkholderia pseudomallei HBPUB10303a", "rank": "Strain"}, "1410658": {"name": "Kandleria vitulina MC3001", "rank": "Strain"}, "1410659": {"name": "Kandleria vitulina WCE2011", "rank": "Strain"}, "1328311": {"name": "Borrelia burgdorferi CA382", "rank": "Strain"}, "1410650": {"name": "Butyrivibrio proteoclasticus P6B7", "rank": "Strain"}, "1410651": {"name": "Clostridium aerotolerans DSM 5434", "rank": "Strain"}, "1410652": {"name": "Clostridium beijerinckii HUN142", "rank": "Strain"}, "1410653": {"name": "Clostridium lundense DSM 17049", "rank": "Strain"}, "1410654": {"name": "Corynebacterium vitaeruminis Ga6A13", "rank": "Strain"}, "1410655": {"name": "Enterococcus faecalis PF3", "rank": "Strain"}, "1410656": {"name": "Fusobacterium necrophorum HUN048", "rank": "Strain"}, "1410657": {"name": "Kandleria vitulina DSM 20405", "rank": "Strain"}, "1265627": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 73.H.09", "rank": "Strain"}, "1265626": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 54.O.08", "rank": "Strain"}, "1265625": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 49.E.09", "rank": "Strain"}, "1265624": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 44.E.09", "rank": "Strain"}, "1265623": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 46.E.09", "rank": "Strain"}, "1265622": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 40.E.08", "rank": "Strain"}, "1265621": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 38.O.03", "rank": "Strain"}, "1265620": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 68.U.05", "rank": "Strain"}, "1265629": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 56.O.08", "rank": "Strain"}, "1265628": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 51.E.09", "rank": "Strain"}, "1310949": {"name": "Acinetobacter baumannii 24975_5", "rank": "Strain"}, "1310948": {"name": "Acinetobacter baumannii 24975_4", "rank": "Strain"}, "1310941": {"name": "Acinetobacter baumannii 25935_7", "rank": "Strain"}, "1310940": {"name": "Acinetobacter baumannii 25935_6", "rank": "Strain"}, "1310943": {"name": "Acinetobacter baumannii 25935_9", "rank": "Strain"}, "1310942": {"name": "Acinetobacter baumannii 25935_8", "rank": "Strain"}, "1310945": {"name": "Acinetobacter baumannii 24975_1", "rank": "Strain"}, "1310944": {"name": "Acinetobacter baumannii 25935_10", "rank": "Strain"}, "240016": {"name": "Verrucomicrobium spinosum DSM 4136 = JCM 18804", "rank": "Strain"}, "240015": {"name": "Acidobacterium capsulatum ATCC 51196", "rank": "Strain"}, "1406789": {"name": "Bacillus phage Pony", "rank": "Species"}, "1406788": {"name": "Bacillus phage Riggi", "rank": "Species"}, "1151305": {"name": "Peptoclostridium difficile CD212", "rank": "Strain"}, "1406785": {"name": "Bacillus phage Grass", "rank": "Species"}, "1406784": {"name": "Bacillus phage Glittering", "rank": "Species"}, "1406786": {"name": "Bacillus phage Page", "rank": "Species"}, "1406781": {"name": "Bacillus phage BigBertha", "rank": "Species"}, "1406780": {"name": "Acinetobacter phage Presley", "rank": "Species"}, "1406783": {"name": "Bacillus phage CampHawk", "rank": "Species"}, "1406782": {"name": "Bacillus phage Blastoid", "rank": "Species"}, "360807": {"name": "Roseburia inulinivorans", "rank": "Species"}, "1422044": {"name": "Mycobacterium tuberculosis TB_RSA128", "rank": "Strain"}, "985080": {"name": "Helicobacter pylori 2018", "rank": "Strain"}, "985081": {"name": "Helicobacter pylori 2017", "rank": "Strain"}, "80882": {"name": "Simplicispira psychrophila", "rank": "Species"}, "80880": {"name": "Hylemonella gracilis", "rank": "Species"}, "751994": {"name": "Gamma proteobacterium HIMB30", "rank": "Species"}, "870967": {"name": "Vibrio scophthalmi LMG 19158", "rank": "Strain"}, "870968": {"name": "Vibrio ichthyoenteri ATCC 700023", "rank": "Strain"}, "1422045": {"name": "Mycobacterium tuberculosis TB_RSA129", "rank": "Strain"}, "652017": {"name": "Nesterenkonia sp. AN1", "rank": "Species"}, "1322246": {"name": "Desulfovibrio piezophilus C1TLV30", "rank": "Strain"}, "141904": {"name": "Vibrio phage CTX", "rank": "Species"}, "694014": {"name": "Avian coronavirus", "rank": "Species"}, "1168059": {"name": "Xanthobacteraceae bacterium 501b", "rank": "Species"}, "362520": {"name": "Chitinilyticum aquatile", "rank": "Species"}, "1136133": {"name": "Porcine kobuvirus SH-W-CHN/2010/China", "rank": "Strain"}, "715451": {"name": "Alteromonas sp. SN2", "rank": "Species"}, "1136137": {"name": "Escherichia coli C166_11", "rank": "Strain"}, "1132497": {"name": "Sulfolobus islandicus M.16.2", "rank": "Strain"}, "1132496": {"name": "Pasteurella multocida subsp. multocida str. HN06", "rank": "Strain"}, "1132499": {"name": "Sulfolobus islandicus M.16.13", "rank": "Strain"}, "1132498": {"name": "Sulfolobus islandicus M.16.12", "rank": "Strain"}, "1136138": {"name": "Pseudomonas fragi B25", "rank": "Strain"}, "471858": {"name": "Helicobacter magdeburgensis", "rank": "Species"}, "1310604": {"name": "Acinetobacter baumannii 984213", "rank": "Strain"}, "1391490": {"name": "Enterococcus faecalis EnGen0420", "rank": "Strain"}, "1391491": {"name": "Enterococcus faecalis EnGen0421", "rank": "Strain"}, "1391492": {"name": "Enterococcus faecalis EnGen0422", "rank": "Strain"}, "471852": {"name": "Thermomonospora curvata DSM 43183", "rank": "Strain"}, "471855": {"name": "Slackia heliotrinireducens DSM 20476", "rank": "Strain"}, "471854": {"name": "Dyadobacter fermentans DSM 18053", "rank": "Strain"}, "1391496": {"name": "Enterococcus faecalis EnGen0426", "rank": "Strain"}, "1391497": {"name": "Enterococcus faecalis EnGen0427", "rank": "Strain"}, "1116105": {"name": "Escherichia coli 180600", "rank": "Strain"}, "1116104": {"name": "Escherichia coli 180200", "rank": "Strain"}, "1116107": {"name": "Escherichia coli 178200", "rank": "Strain"}, "1116100": {"name": "Escherichia coli p0305293.12", "rank": "Strain"}, "1116103": {"name": "Escherichia coli 180050", "rank": "Strain"}, "1116102": {"name": "Escherichia coli p0305293.15", "rank": "Strain"}, "1116109": {"name": "Escherichia coli 179550", "rank": "Strain"}, "1321939": {"name": "Helicobacter pylori UM037", "rank": "Strain"}, "1157018": {"name": "Staphylococcus aureus M0239", "rank": "Strain"}, "1157019": {"name": "Staphylococcus aureus M0252", "rank": "Strain"}, "357794": {"name": "Psychromonas ingrahamii", "rank": "Species"}, "1197477": {"name": "Mangrovimonas yunxiaonensis", "rank": "Species"}, "1157010": {"name": "Staphylococcus aureus M0102", "rank": "Strain"}, "1157011": {"name": "Staphylococcus aureus M0103", "rank": "Strain"}, "1157012": {"name": "Staphylococcus aureus M0150", "rank": "Strain"}, "1157013": {"name": "Staphylococcus aureus M0173", "rank": "Strain"}, "1157014": {"name": "Staphylococcus aureus M0192", "rank": "Strain"}, "1157015": {"name": "Staphylococcus aureus M0197", "rank": "Strain"}, "1157016": {"name": "Staphylococcus aureus M0221", "rank": "Strain"}, "1157017": {"name": "Staphylococcus aureus M0237", "rank": "Strain"}, "214888": {"name": "Entomoplasma luminosum", "rank": "Species"}, "12271": {"name": "Arabis mosaic virus", "rank": "Species"}, "131568": {"name": "Kineococcus radiotolerans", "rank": "Species"}, "131567": {"name": "Cellular organisms", "rank": "No rank"}, "366522": {"name": "Sulfurospirillum cavolei", "rank": "Species"}, "1422022": {"name": "Mycobacterium tuberculosis TB_RSA106", "rank": "Strain"}, "139390": {"name": "Plicaturopsis crispa", "rank": "Species"}, "264198": {"name": "Ralstonia eutropha JMP134", "rank": "Strain"}, "883154": {"name": "Myroides odoratimimus CIP 101113", "rank": "Strain"}, "883156": {"name": "Veillonella ratti ACS-216-V-Col6b", "rank": "Strain"}, "883151": {"name": "Myroides odoratimimus CCUG 12700", "rank": "Strain"}, "883150": {"name": "Myroides odoratimimus CCUG 10230", "rank": "Strain"}, "883153": {"name": "Myroides odoratimimus CCUG 3837", "rank": "Strain"}, "883152": {"name": "Myroides odoratimimus CCUG 12901", "rank": "Strain"}, "655815": {"name": "Zunongwangia profunda SM-A87", "rank": "Strain"}, "1597": {"name": "Lactobacillus paracasei", "rank": "Species"}, "213783": {"name": "Shewanella waksmanii", "rank": "Species"}, "1422024": {"name": "Mycobacterium tuberculosis TB_RSA108", "rank": "Strain"}, "1422457": {"name": "Staphylococcus aureus VET0133R", "rank": "Strain"}, "104388": {"name": "Anatid herpesvirus 1", "rank": "Species"}, "1422025": {"name": "Mycobacterium tuberculosis TB_RSA109", "rank": "Strain"}, "674082": {"name": "Klebsiella phage KP32", "rank": "Species"}, "674081": {"name": "Klebsiella phage KP34", "rank": "Species"}, "670506": {"name": "Mycobacterium abscessus subgroup", "rank": "Species subgroup"}, "1051981": {"name": "Streptococcus equi subsp. ruminatorum CECT 5772", "rank": "Strain"}, "1137131": {"name": "Staphylococcus aureus subsp. aureus 122051", "rank": "Strain"}, "12038": {"name": "Barley yellow dwarf virus-MAV", "rank": "Species"}, "1137130": {"name": "Staphylococcus aureus subsp. aureus 103564", "rank": "Strain"}, "12037": {"name": "Barley yellow dwarf virus", "rank": "Species"}, "12036": {"name": "Luteovirus", "rank": "Genus"}, "28452": {"name": "Leptospira alstonii", "rank": "Species"}, "28453": {"name": "Sphingobacterium", "rank": "Genus"}, "28450": {"name": "Burkholderia pseudomallei", "rank": "Species"}, "394098": {"name": "Bhargavaea cecembensis", "rank": "Species"}, "1242247": {"name": "Cellulosimicrobium cellulans LMG 16121", "rank": "Strain"}, "1137132": {"name": "Staphylococcus aureus subsp. aureus 112808A", "rank": "Strain"}, "500614": {"name": "Desmospora", "rank": "Genus"}, "49118": {"name": "Candidatus Arthromitus sp. SFB-mouse", "rank": "Species"}, "1105029": {"name": "Actinomyces sp. ICM39", "rank": "Species"}, "1150599": {"name": "Mycobacterium phlei RIVM601174", "rank": "Strain"}, "1095769": {"name": "Herbaspirillum massiliense JC206", "rank": "Strain"}, "1095768": {"name": "Enterobacter massiliensis JC163", "rank": "Strain"}, "1095767": {"name": "Cellulomonas massiliensis JC225", "rank": "Strain"}, "1150591": {"name": "Mycobacterium xenopi RIVM700367", "rank": "Strain"}, "545533": {"name": "Alishewanella jeotgali", "rank": "Species"}, "545534": {"name": "Carnobacterium jeotgali", "rank": "Species"}, "367299": {"name": "Phycicoccus jejuensis", "rank": "Species"}, "367298": {"name": "Phycicoccus", "rank": "Genus"}, "675068": {"name": "Betaflexiviridae", "rank": "Family"}, "675069": {"name": "Unassigned Betaflexiviridae", "rank": "No rank"}, "1010676": {"name": "Candidatus Tremblaya phenacola", "rank": "Species"}, "675062": {"name": "Mycoflexivirus", "rank": "Genus"}, "675063": {"name": "Tymovirales", "rank": "Order"}, "675061": {"name": "Gammaflexiviridae", "rank": "Family"}, "675066": {"name": "Sclerodarnavirus", "rank": "Genus"}, "675064": {"name": "Alphaflexiviridae", "rank": "Family"}, "675065": {"name": "Botrexvirus", "rank": "Genus"}, "103892": {"name": "Veillonella ratti", "rank": "Species"}, "717944": {"name": "Trametes versicolor FP-101664 SS1", "rank": "Strain"}, "1150621": {"name": "Sulfurospirillum multivorans DSM 12446", "rank": "Strain"}, "1150626": {"name": "Phaeospirillum molischianum DSM 120", "rank": "Strain"}, "39775": {"name": "Methylomicrobium album", "rank": "Species"}, "39774": {"name": "Methylomicrobium agile", "rank": "Species"}, "39777": {"name": "Veillonella atypica", "rank": "Species"}, "39770": {"name": "Methylobacter whittenburyi", "rank": "Species"}, "39773": {"name": "Methylomicrobium", "rank": "Genus"}, "64949": {"name": "Ilarvirus subgroup 2", "rank": "No rank"}, "39779": {"name": "Unclassified Clostridiales (miscellaneous)", "rank": "No rank"}, "39778": {"name": "Veillonella dispar", "rank": "Species"}, "455649": {"name": "Spiroplasma kunkelii virus SkV1_CR2-3x", "rank": "Species"}, "40091": {"name": "Helcococcus kunzii", "rank": "Species"}, "393283": {"name": "Pestalotiopsis fici", "rank": "Species"}, "1408310": {"name": "Prevotella sp. MA2016", "rank": "Species"}, "1408311": {"name": "Oribacterium sp. FC2011", "rank": "Species"}, "1408312": {"name": "Pseudobutyrivibrio sp. LB2011", "rank": "Species"}, "1408313": {"name": "Selenomonas sp. FC4001", "rank": "Species"}, "1408318": {"name": "Bartonella vinsonii subsp. berkhoffii ATCC 51672", "rank": "Strain"}, "1408319": {"name": "Lachnospiraceae bacterium AB2028", "rank": "Species"}, "1334565": {"name": "Listeria monocytogenes EGD", "rank": "Strain"}, "1334564": {"name": "Serratia marcescens SM39", "rank": "Strain"}, "1203465": {"name": "Candidatus Bacteroides timonensis AP1", "rank": "Strain"}, "1203460": {"name": "Streptomyces hygroscopicus subsp. jinggangensis TL01", "rank": "Strain"}, "1211819": {"name": "Holdemania massiliensis AP2", "rank": "Strain"}, "931202": {"name": "Candidatus Liberibacter asiaticus str. Ishi-1", "rank": "Strain"}, "1211813": {"name": "Candidatus Alistipes marseilloanorexicus AP11", "rank": "Strain"}, "1211817": {"name": "Candidatus Clostridium anorexicamassiliense AP5", "rank": "Strain"}, "1211815": {"name": "Candidatus Blastococcus massiliensis AP3", "rank": "Strain"}, "1211814": {"name": "Bacillus massilioanorexius AP8", "rank": "Strain"}, "180170": {"name": "Infectious spleen and kidney necrosis virus", "rank": "Species"}, "1166130": {"name": "Enterobacter sp. R4-368", "rank": "Species"}, "1040981": {"name": "Mesorhizobium ciceri WSM4083", "rank": "Strain"}, "1440059": {"name": "Streptomyces exfoliatus DSM 41693", "rank": "Strain"}, "63656": {"name": "Thiomicrospira chilensis", "rank": "Species"}, "1440053": {"name": "Streptomyces scopuliridis RB72", "rank": "Strain"}, "1440052": {"name": "Escherichia albertii KF1", "rank": "Strain"}, "125216": {"name": "Roseomonas", "rank": "Genus"}, "63658": {"name": "Thiomicrospira kuenenii", "rank": "Species"}, "632245": {"name": "Clostridium butyricum E4 str. BoNT E BL5262", "rank": "Strain"}, "54571": {"name": "Streptomyces venezuelae", "rank": "Species"}, "502105": {"name": "Bovine respiratory coronavirus bovine/US/OH-440-TC/1996", "rank": "Species"}, "502102": {"name": "Rat coronavirus Parker", "rank": "Strain"}, "1160228": {"name": "Brucella suis 63/261", "rank": "Strain"}, "1422812": {"name": "Staphylococcus aureus VET1956S", "rank": "Strain"}, "1235660": {"name": "Staphylococcus phage vB_SauM_Romulus", "rank": "Species"}, "1235661": {"name": "Pseudomonas phage UFV-P2", "rank": "Species"}, "1040964": {"name": "Lactobacillus ruminis SPM0211", "rank": "Strain"}, "452333": {"name": "Agaricomycetidae", "rank": "Subclass"}, "452332": {"name": "Dacrymycetes", "rank": "Class"}, "572480": {"name": "Arcobacter nitrofigilis DSM 7299", "rank": "Strain"}, "122291": {"name": "Kappapapillomavirus 1", "rank": "Species"}, "28112": {"name": "Tannerella forsythia", "rank": "Species"}, "1049771": {"name": "Leptospira borgpetersenii serovar Kenya", "rank": "Strain"}, "1049773": {"name": "Leptospira borgpetersenii serovar Kenya str. TE 0159", "rank": "Strain"}, "1049776": {"name": "Leptospira borgpetersenii serovar Mini str. 201000851", "rank": "Strain"}, "28117": {"name": "Alistipes putredinis", "rank": "Species"}, "1422810": {"name": "Staphylococcus aureus VET1950S", "rank": "Strain"}, "903928": {"name": "Acinetobacter sp. OIFC021", "rank": "Species"}, "28115": {"name": "Porphyromonas macacae", "rank": "Species"}, "28114": {"name": "Porphyromonas levii", "rank": "Species"}, "1005399": {"name": "Escherichia coli 89.0511", "rank": "Strain"}, "1005398": {"name": "Escherichia coli 88.1042", "rank": "Strain"}, "574559": {"name": "Hellea", "rank": "Genus"}, "391735": {"name": "Verminephrobacter eiseniae EF01-2", "rank": "Strain"}, "335058": {"name": "Pelomonas", "rank": "Genus"}, "574556": {"name": "Anaplasma centrale str. Israel", "rank": "Strain"}, "391738": {"name": "Lysobacter defluvii", "rank": "Species"}, "1005397": {"name": "Escherichia coli 88.0221", "rank": "Strain"}, "1005396": {"name": "Escherichia coli 88.1467", "rank": "Strain"}, "1005395": {"name": "Pseudomonas putida CSV86", "rank": "Strain"}, "315456": {"name": "Rickettsia felis URRWXCal2", "rank": "Strain"}, "208085": {"name": "Saccharomonospora paurometabolica", "rank": "Species"}, "208086": {"name": "Moroccan pepper virus", "rank": "Species"}, "489915": {"name": "Corynebacterium sputi", "rank": "Species"}, "1444186": {"name": "Escherichia coli 5-172-05_S3_C3", "rank": "Strain"}, "391574": {"name": "Vibrionales bacterium SWAT-3", "rank": "Species"}, "1005406": {"name": "Escherichia coli 95.0183", "rank": "Strain"}, "1158525": {"name": "Staphylococcus aureus M0363", "rank": "Strain"}, "1244122": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20111174", "rank": "Strain"}, "1168588": {"name": "Acinetobacter baumannii Ab11111", "rank": "Strain"}, "1158527": {"name": "Staphylococcus aureus M0374", "rank": "Strain"}, "1343110": {"name": "Magnaporthe oryzae chrysovirus 3", "rank": "Species"}, "1158526": {"name": "Staphylococcus aureus M0367", "rank": "Strain"}, "1158523": {"name": "Staphylococcus aureus M0350", "rank": "Strain"}, "1158522": {"name": "Staphylococcus aureus M0334", "rank": "Strain"}, "591020": {"name": "Shigella flexneri 2002017", "rank": "Strain"}, "1382306": {"name": "Thermogemmatispora sp. PM5", "rank": "Species"}, "1412469": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20120007", "rank": "Strain"}, "1412468": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20120005", "rank": "Strain"}, "1412461": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20090332", "rank": "Strain"}, "1412460": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20090135", "rank": "Strain"}, "1412463": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20090884", "rank": "Strain"}, "1412462": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20090531", "rank": "Strain"}, "1412467": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20120003", "rank": "Strain"}, "1412466": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20120002", "rank": "Strain"}, "1239789": {"name": "Streptococcus pneumoniae 1488", "rank": "Strain"}, "1122976": {"name": "Porphyromonas uenonis DSM 23387 = JCM 13868", "rank": "Strain"}, "1122975": {"name": "Porphyromonas somerae DSM 23386", "rank": "Strain"}, "1122974": {"name": "Porphyromonas macacae DSM 20710 = JCM 13914", "rank": "Strain"}, "1122973": {"name": "Porphyromonas levii DSM 23370", "rank": "Strain"}, "1122972": {"name": "Porphyromonas gulae DSM 15663", "rank": "Strain"}, "4910": {"name": "Kluyveromyces", "rank": "Genus"}, "1122970": {"name": "Porphyrobacter cryptus DSM 12079", "rank": "Strain"}, "1415606": {"name": "Bifidobacterium animalis subsp. lactis CECT 8145", "rank": "Strain"}, "446683": {"name": "Niabella soli", "rank": "Species"}, "1122979": {"name": "Prevotella amnii DSM 23384 = JCM 14753", "rank": "Strain"}, "1122978": {"name": "Prevotella albensis DSM 11370 = JCM 12258", "rank": "Strain"}, "1173487": {"name": "Halorubrum sp. AJ67", "rank": "Species"}, "939714": {"name": "Gemmatimonadetes bacterium SCGC AAA240-J22", "rank": "Species"}, "129385": {"name": "Basidiomycota incertae sedis", "rank": "No rank"}, "243232": {"name": "Methanocaldococcus jannaschii DSM 2661", "rank": "Strain"}, "401053": {"name": "Terriglobus saanensis SP1PR4", "rank": "Strain"}, "243230": {"name": "Deinococcus radiodurans R1", "rank": "Strain"}, "243231": {"name": "Geobacter sulfurreducens PCA", "rank": "Strain"}, "42399": {"name": "Vittaforma corneae", "rank": "Species"}, "42398": {"name": "Vittaforma", "rank": "Genus"}, "1163752": {"name": "Candidatus Portiera aleyrodidarum MED (Bemisia tabaci)", "rank": "Strain"}, "693974": {"name": "Shewanella baltica BA175", "rank": "Strain"}, "693977": {"name": "Deinococcus proteolyticus MRP", "rank": "Strain"}, "693970": {"name": "Shewanella baltica OS117", "rank": "Strain"}, "693971": {"name": "Shewanella baltica OS183", "rank": "Strain"}, "693972": {"name": "Shewanella baltica OS625", "rank": "Strain"}, "693973": {"name": "Shewanella baltica OS678", "rank": "Strain"}, "334107": {"name": "Conchiformibius", "rank": "Genus"}, "693978": {"name": "Riemerella anatipestifer ATCC 11845 = DSM 15868", "rank": "Strain"}, "693979": {"name": "Bacteroides helcogenes P 36-108", "rank": "Strain"}, "1285585": {"name": "Megasphaera sp. BL7", "rank": "Species"}, "882453": {"name": "Bacillus atrophaeus str. Dugway", "rank": "Strain"}, "882455": {"name": "Bacillus atrophaeus BACI051-E", "rank": "Strain"}, "334819": {"name": "Fusarium verticillioides 7600", "rank": "Strain"}, "184117": {"name": "Thermoproteus uzoniensis", "rank": "Species"}, "33981": {"name": "Kineococcus", "rank": "Genus"}, "1159090": {"name": "Streptococcus pneumoniae PNI0008", "rank": "Strain"}, "1159091": {"name": "Streptococcus pneumoniae PNI0009", "rank": "Strain"}, "1159096": {"name": "Streptococcus pneumoniae PNI0164", "rank": "Strain"}, "1159097": {"name": "Streptococcus pneumoniae PNI0197", "rank": "Strain"}, "1159094": {"name": "Streptococcus pneumoniae PNI0153", "rank": "Strain"}, "33987": {"name": "Exiguobacterium aurantiacum", "rank": "Species"}, "33988": {"name": "Rickettsieae", "rank": "Tribe"}, "33989": {"name": "Candidatus Rickettsia amblyommii", "rank": "Species"}, "1159098": {"name": "Streptococcus pneumoniae PNI0199", "rank": "Strain"}, "1159099": {"name": "Streptococcus pneumoniae PNI0212", "rank": "Strain"}, "1444037": {"name": "Escherichia coli 2-011-08_S1_C1", "rank": "Strain"}, "1444036": {"name": "Escherichia coli 2-005-03_S1_C1", "rank": "Strain"}, "1444039": {"name": "Escherichia coli 2-156-04_S1_C1", "rank": "Strain"}, "1444038": {"name": "Escherichia coli 2-052-05_S1_C1", "rank": "Strain"}, "121277": {"name": "Pyrobaculum arsenaticum", "rank": "Species"}, "29447": {"name": "Xanthomonas albilineans", "rank": "Species"}, "11007": {"name": "Totivirus", "rank": "Genus"}, "11006": {"name": "Totiviridae", "rank": "Family"}, "29442": {"name": "Pseudomonas tolaasii", "rank": "Species"}, "497739": {"name": "Streptococcus pneumoniae SV36", "rank": "Strain"}, "11002": {"name": "Infectious pancreatic necrosis virus", "rank": "Species"}, "497735": {"name": "Brevibacillus panacihumi", "rank": "Species"}, "11008": {"name": "Saccharomyces cerevisiae virus L-A", "rank": "Species"}, "29448": {"name": "Bradyrhizobium elkanii", "rank": "Species"}, "29449": {"name": "Rhizobium etli", "rank": "Species"}, "863643": {"name": "Thermincola potens", "rank": "Species"}, "1185714": {"name": "Xanthomonas axonopodis pv. manihotis str. UG45", "rank": "Strain"}, "1185715": {"name": "Xanthomonas axonopodis pv. manihotis str. UG51", "rank": "Strain"}, "1185711": {"name": "Xanthomonas axonopodis pv. manihotis str. UG39", "rank": "Strain"}, "1185712": {"name": "Xanthomonas axonopodis pv. manihotis str. UG43", "rank": "Strain"}, "1185713": {"name": "Xanthomonas axonopodis pv. manihotis str. UG44", "rank": "Strain"}, "1386090": {"name": "Ageratum latent virus", "rank": "Species"}, "1386092": {"name": "Cellulomonas carbonis", "rank": "Species"}, "1169186": {"name": "Salinispora pacifica CNS860", "rank": "Strain"}, "548485": {"name": "Lactobacillus reuteri MM4-1A", "rank": "Strain"}, "1036672": {"name": "Advenella kashmirensis WT001", "rank": "Strain"}, "489138": {"name": "Halarchaeum acidiphilum", "rank": "Species"}, "157822": {"name": "Lecanorineae", "rank": "Suborder"}, "765123": {"name": "Propionibacterium humerusii HL037PA2", "rank": "Strain"}, "332415": {"name": "Ehrlichia chaffeensis str. Sapulpa", "rank": "Strain"}, "645657": {"name": "Bacillus subtilis subsp. natto BEST195", "rank": "Strain"}, "1422259": {"name": "Staphylococcus aureus DAR1939", "rank": "Strain"}, "332410": {"name": "Exiguobacterium sibiricum", "rank": "Species"}, "1491393": {"name": "Jingmen tick virus", "rank": "Species"}, "1422255": {"name": "Staphylococcus aureus DAR1926", "rank": "Strain"}, "1422254": {"name": "Staphylococcus aureus DAR1890", "rank": "Strain"}, "1422257": {"name": "Staphylococcus aureus DAR1937", "rank": "Strain"}, "1422256": {"name": "Staphylococcus aureus DAR1936", "rank": "Strain"}, "1422251": {"name": "Staphylococcus aureus DAR1874", "rank": "Strain"}, "1422250": {"name": "Staphylococcus aureus DAR1862", "rank": "Strain"}, "1422253": {"name": "Staphylococcus aureus DAR1885", "rank": "Strain"}, "1422252": {"name": "Staphylococcus aureus DAR1883", "rank": "Strain"}, "1423323": {"name": "Flavobacterium sp. AED", "rank": "Species"}, "1423321": {"name": "Bacillus sp. SJS", "rank": "Species"}, "52996": {"name": "Dioscorea bacilliform virus", "rank": "Species"}, "319017": {"name": "Bradyrhizobium sp. WSM471", "rank": "Species"}, "35269": {"name": "Woodchuck hepatitis virus", "rank": "Species"}, "35268": {"name": "Retro-transcribing viruses", "rank": "No rank"}, "862514": {"name": "Pediococcus acidilactici DSM 20284", "rank": "Strain"}, "862515": {"name": "Prevotella marshii DSM 16973 = JCM 13450", "rank": "Strain"}, "936136": {"name": "Rhizobium leguminosarum bv. viciae 248", "rank": "Strain"}, "862517": {"name": "Peptoniphilus duerdenii ATCC BAA-1640", "rank": "Strain"}, "936139": {"name": "Mycoplasma hyorhinis MCLD", "rank": "Strain"}, "1365010": {"name": "Pseudomonas aeruginosa B3-20M", "rank": "Strain"}, "40933": {"name": "Bartonella vinsonii subsp. berkhoffii", "rank": "Subspecies"}, "1095000": {"name": "Candida albicans P78042", "rank": "Strain"}, "1095001": {"name": "Saccharomyces cerevisiae EC9-8", "rank": "Strain"}, "1427157": {"name": "Seal anellovirus 2", "rank": "Species"}, "1427156": {"name": "Seal anellovirus 3", "rank": "Species"}, "525268": {"name": "Corynebacterium striatum ATCC 6940", "rank": "Strain"}, "525264": {"name": "Corynebacterium pseudogenitalium ATCC 33035", "rank": "Strain"}, "525260": {"name": "Corynebacterium accolens ATCC 49725", "rank": "Strain"}, "525262": {"name": "Corynebacterium jeikeium ATCC 43734", "rank": "Strain"}, "525263": {"name": "Corynebacterium lipophiloflavum DSM 44291", "rank": "Strain"}, "36910": {"name": "Clavispora", "rank": "Genus"}, "36911": {"name": "Clavispora lusitaniae", "rank": "Species"}, "743973": {"name": "Taylorella equigenitalis ATCC 35865", "rank": "Strain"}, "1307958": {"name": "Sweet potato C6 virus", "rank": "Species"}, "300267": {"name": "Shigella dysenteriae Sd197", "rank": "Strain"}, "32205": {"name": "Leptonema", "rank": "Genus"}, "32207": {"name": "Rothia", "rank": "Genus"}, "300269": {"name": "Shigella sonnei Ss046", "rank": "Strain"}, "300268": {"name": "Shigella boydii Sb227", "rank": "Strain"}, "1307956": {"name": "Leucania separata nucleopolyhedrovirus", "rank": "Species"}, "1307957": {"name": "Clanis bilineata nucleopolyhedrovirus", "rank": "Species"}, "1307954": {"name": "Maruca vitrata nucleopolyhedrovirus", "rank": "Species"}, "1463902": {"name": "Streptomyces sp. NRRL S-350", "rank": "Species"}, "1463903": {"name": "Streptomyces sp. NRRL S-37", "rank": "Species"}, "1463900": {"name": "Streptomyces sp. NRRL S-337", "rank": "Species"}, "1463901": {"name": "Streptomyces sp. NRRL S-340", "rank": "Species"}, "869727": {"name": "Helicobacter pylori 908", "rank": "Strain"}, "869724": {"name": "Synechococcus phage S-RIM8 A.HR1", "rank": "Strain"}, "1463905": {"name": "Streptomyces sp. NRRL S-384", "rank": "Species"}, "679205": {"name": "Escherichia coli MS 124-1", "rank": "Strain"}, "1625": {"name": "Lactobacillus sanfranciscensis", "rank": "Species"}, "1624": {"name": "Lactobacillus salivarius", "rank": "Species"}, "1623": {"name": "Lactobacillus ruminis", "rank": "Species"}, "1622": {"name": "Lactobacillus murinus", "rank": "Species"}, "1035662": {"name": "Bdellovibrio phage phi1402", "rank": "Species"}, "417397": {"name": "Vibrio cholerae 623-39", "rank": "Strain"}, "417398": {"name": "Vibrio cholerae MZO-2", "rank": "Strain"}, "417399": {"name": "Vibrio cholerae NCTC 8457", "rank": "Strain"}, "563119": {"name": "Mycobacterium phage Fruitloop", "rank": "Species"}, "929793": {"name": "Campylobacter concisus UNSWCD", "rank": "Strain"}, "929794": {"name": "Bartonella senegalensis OS02", "rank": "Strain"}, "659693": {"name": "Oceanibaculum", "rank": "Genus"}, "1158491": {"name": "Staphylococcus aureus M1373", "rank": "Strain"}, "555079": {"name": "Thermosediminibacter oceani DSM 16646", "rank": "Strain"}, "373506": {"name": "Large single stranded RNA satellites", "rank": "No rank"}, "373507": {"name": "Single stranded RNA satellites", "rank": "No rank"}, "373508": {"name": "Small linear single stranded RNA satellites", "rank": "No rank"}, "377610": {"name": "Malvastrum leaf curl Guangdong virus", "rank": "Species"}, "377611": {"name": "Malvastrum yellow vein Yunnan virus satellite DNA beta", "rank": "Species"}, "243956": {"name": "Roseomonas gilardii subsp. rosea", "rank": "Subspecies"}, "83526": {"name": "Lactobacillus paralimentarius", "rank": "Species"}, "377618": {"name": "Gremmeniella abietina type B RNA virus XL", "rank": "Species"}, "64698": {"name": "Plautia stali intestine virus", "rank": "Species"}, "31749": {"name": "Obuda pepper virus", "rank": "Species"}, "88719": {"name": "Neisseria elongata subsp. glycolytica", "rank": "Subspecies"}, "31741": {"name": "Wheat streak mosaic virus", "rank": "Species"}, "31742": {"name": "Johnsongrass mosaic virus", "rank": "Species"}, "31743": {"name": "Sweet potato latent virus", "rank": "Species"}, "31744": {"name": "Rice yellow mottle virus", "rank": "Species"}, "871589": {"name": "Salmonella enterica subsp. enterica serovar Montevideo str. MB110209-0055", "rank": "Strain"}, "871588": {"name": "Salmonella enterica subsp. enterica serovar Montevideo str. MB102109-0047", "rank": "Strain"}, "871587": {"name": "Salmonella enterica subsp. enterica serovar Montevideo str. MB101509-0077", "rank": "Strain"}, "871586": {"name": "Salmonella enterica subsp. enterica serovar Montevideo str. 556152", "rank": "Strain"}, "219314": {"name": "Aeromicrobium marinum", "rank": "Species"}, "871584": {"name": "Clostridium phage phiCTP1", "rank": "Species"}, "236": {"name": "Brucella ovis", "rank": "Species"}, "237": {"name": "Flavobacterium", "rank": "Genus"}, "234": {"name": "Brucella", "rank": "Genus"}, "235": {"name": "Brucella abortus", "rank": "Species"}, "238": {"name": "Elizabethkingia meningoseptica", "rank": "Species"}, "1281006": {"name": "Escherichia coli HVH 61 (4-2736020)", "rank": "Strain"}, "131190": {"name": "SAR324 cluster", "rank": "No rank"}, "767434": {"name": "Frateuria aurantia DSM 6220", "rank": "Strain"}, "1288090": {"name": "Salinispora pacifica CNY239", "rank": "Strain"}, "914138": {"name": "Streptococcus pneumoniae 2081685", "rank": "Strain"}, "465518": {"name": "Salmonella enterica subsp. enterica serovar Weltevreden str. HI_N05-537", "rank": "Strain"}, "914130": {"name": "Streptococcus pneumoniae 2061617", "rank": "Strain"}, "914131": {"name": "Streptococcus pneumoniae 2070035", "rank": "Strain"}, "914132": {"name": "Streptococcus pneumoniae 2070109", "rank": "Strain"}, "914133": {"name": "Streptococcus pneumoniae 2070425", "rank": "Strain"}, "465515": {"name": "Micrococcus luteus NCTC 2665", "rank": "Strain"}, "914135": {"name": "Streptococcus pneumoniae 2071004", "rank": "Strain"}, "465517": {"name": "Salmonella enterica subsp. enterica serovar Virchow str. SL491", "rank": "Strain"}, "465516": {"name": "Salmonella enterica subsp. enterica serovar Hadar str. RI_05P066", "rank": "Strain"}, "431057": {"name": "Methylacidiphilum kamchatkense", "rank": "Species"}, "1120992": {"name": "Anaeromusa acidaminophila DSM 3853", "rank": "Strain"}, "1402661": {"name": "Staphylococcus aureus M1149", "rank": "Strain"}, "33013": {"name": "Clavibacter michiganensis subsp. michiganensis", "rank": "Subspecies"}, "999891": {"name": "Bacillus amyloliquefaciens TA208", "rank": "Strain"}, "999892": {"name": "Propionibacterium humerusii P08", "rank": "Strain"}, "33011": {"name": "Propionibacterium granulosum", "rank": "Species"}, "1291234": {"name": "Leptospira kirschneri serovar Mozdok 1 str. Vehlefans 3", "rank": "Strain"}, "1056511": {"name": "Photobacterium sp. AK15", "rank": "Species"}, "1056512": {"name": "Grimontia indica", "rank": "Species"}, "657445": {"name": "Francisella noatunensis", "rank": "Species"}, "665602": {"name": "Unclassified Henipavirus", "rank": "No rank"}, "205914": {"name": "Haemophilus somnus 129PT", "rank": "Strain"}, "1269201": {"name": "Salinarchaeum", "rank": "Genus"}, "144185": {"name": "Leifsonia aquatica", "rank": "Species"}, "1403858": {"name": "Staphylococcus aureus M1363", "rank": "Strain"}, "1403859": {"name": "Staphylococcus aureus M1365", "rank": "Strain"}, "1406820": {"name": "Escherichia coli GSK2023", "rank": "Strain"}, "1406821": {"name": "Escherichia coli GSK2024", "rank": "Strain"}, "1406822": {"name": "Cronobacter pulveris 1160", "rank": "Strain"}, "1406823": {"name": "Cronobacter pulveris 601", "rank": "Strain"}, "1403852": {"name": "Staphylococcus aureus M1356", "rank": "Strain"}, "1403853": {"name": "Staphylococcus aureus M1357", "rank": "Strain"}, "1403850": {"name": "Staphylococcus aureus M1354", "rank": "Strain"}, "1403851": {"name": "Staphylococcus aureus M1355", "rank": "Strain"}, "1403856": {"name": "Staphylococcus aureus M1361", "rank": "Strain"}, "1403857": {"name": "Staphylococcus aureus M1362", "rank": "Strain"}, "1403854": {"name": "Staphylococcus aureus M1358", "rank": "Strain"}, "1403855": {"name": "Staphylococcus aureus M1360", "rank": "Strain"}, "1418423": {"name": "Staphylococcus aureus T63897", "rank": "Strain"}, "871006": {"name": "Acidilobales", "rank": "Order"}, "871007": {"name": "Acidilobaceae", "rank": "Family"}, "1418422": {"name": "Staphylococcus aureus T59813", "rank": "Strain"}, "1154828": {"name": "Streptococcus agalactiae BSU188", "rank": "Strain"}, "1255374": {"name": "Planktothrix rubescens NIVA-CYA 407", "rank": "Strain"}, "992121": {"name": "Helicobacter pylori Hp M5", "rank": "Strain"}, "992120": {"name": "Helicobacter pylori Hp M4", "rank": "Strain"}, "85402": {"name": "Mannheimia granulomatis", "rank": "Species"}, "992122": {"name": "Helicobacter pylori Hp M6", "rank": "Strain"}, "85404": {"name": "Mannheimia varigena", "rank": "Species"}, "1051649": {"name": "Vibrio nigripulchritudo ATCC 27043", "rank": "Strain"}, "1051645": {"name": "Vibrio splendidus ATCC 33789", "rank": "Strain"}, "1051646": {"name": "Vibrio tubiashii ATCC 19109", "rank": "Strain"}, "1406817": {"name": "Escherichia coli GSK202B", "rank": "Strain"}, "1154829": {"name": "Streptococcus agalactiae BSU178", "rank": "Strain"}, "1151236": {"name": "Escherichia coli B90", "rank": "Strain"}, "295595": {"name": "Candidatus Hepatoplasma", "rank": "Genus"}, "295596": {"name": "Candidatus Hepatoplasma crinochetorum", "rank": "Species"}, "76891": {"name": "Asticcacaulis biprosthecium", "rank": "Species"}, "1388215": {"name": "Staphylococcus aureus M0323", "rank": "Strain"}, "1388216": {"name": "Staphylococcus aureus M0324", "rank": "Strain"}, "1388217": {"name": "Staphylococcus aureus M0325", "rank": "Strain"}, "1388210": {"name": "Staphylococcus aureus M0318", "rank": "Strain"}, "1388211": {"name": "Staphylococcus aureus M0319", "rank": "Strain"}, "1388212": {"name": "Staphylococcus aureus M0320", "rank": "Strain"}, "1388213": {"name": "Staphylococcus aureus M0321", "rank": "Strain"}, "1388218": {"name": "Staphylococcus aureus M0327", "rank": "Strain"}, "1388219": {"name": "Staphylococcus aureus M0331", "rank": "Strain"}, "1072672": {"name": "Paspalum striate mosaic virus", "rank": "Species"}, "1046581": {"name": "Chlamydia ibidis 10-1398/6", "rank": "Strain"}, "1235314": {"name": "Megavirus lba", "rank": "Species"}, "188711": {"name": "Thermodesulfobacteriaceae", "rank": "Family"}, "188710": {"name": "Thermodesulfobacteriales", "rank": "Order"}, "506591": {"name": "Leisingera caerulea", "rank": "Species"}, "1131731": {"name": "Bacillus azotoformans LMG 9581", "rank": "Strain"}, "1131730": {"name": "Bacillus vireti LMG 21834", "rank": "Strain"}, "374675": {"name": "Candidatus Sulcia muelleri str. Hc (Homalodisca coagulata)", "rank": "Strain"}, "148604": {"name": "Lactobacillus ingluviei", "rank": "Species"}, "148603": {"name": "Mycobacterium phage Bxb1", "rank": "Species"}, "1286832": {"name": "Variovorax sp. JGI 0001016-M12", "rank": "Species"}, "1417036": {"name": "Staphylococcus aureus T70944", "rank": "Strain"}, "375450": {"name": "Yersinia pestis FV-1", "rank": "Strain"}, "397544": {"name": "Squash vein yellowing virus", "rank": "Species"}, "168384": {"name": "Marvinbryantia formatexigens", "rank": "Species"}, "985780": {"name": "Unclassified Mimiviridae", "rank": "No rank"}, "985782": {"name": "Moumouvirus", "rank": "Species"}, "166939": {"name": "Allofustis seminis", "rank": "Species"}, "756892": {"name": "Acinetobacter indicus", "rank": "Species"}, "119484": {"name": "Syntrophobacter fumaroxidans", "rank": "Species"}, "1348": {"name": "Streptococcus parauberis", "rank": "Species"}, "1535248": {"name": "Ball python nidovirus", "rank": "Species"}, "38308": {"name": "Gluconobacter frateurii", "rank": "Species"}, "1337384": {"name": "Escherichia coli SCD1", "rank": "Strain"}, "1337385": {"name": "Escherichia coli SCD2", "rank": "Strain"}, "38305": {"name": "Corynebacterium vitaeruminis", "rank": "Species"}, "1343": {"name": "Streptococcus vestibularis", "rank": "Species"}, "38303": {"name": "Corynebacterium pseudogenitalium", "rank": "Species"}, "1345": {"name": "Streptococcus ferus", "rank": "Species"}, "1346": {"name": "Streptococcus iniae", "rank": "Species"}, "38300": {"name": "Streptomyces pristinaespiralis", "rank": "Species"}, "1257042": {"name": "Streptococcus mutans NCTC 11060", "rank": "Strain"}, "1257043": {"name": "Acinetobacter ursingii ANC 3649", "rank": "Strain"}, "1257040": {"name": "Streptococcus mutans AC4446", "rank": "Strain"}, "1257041": {"name": "Streptococcus mutans ATCC 25175", "rank": "Strain"}, "317619": {"name": "Prochlorothrix hollandica PCC 9006", "rank": "Strain"}, "505317": {"name": "Chelonobacter oris", "rank": "Species"}, "12148": {"name": "Tymovirus", "rank": "Genus"}, "232363": {"name": "Synechococcus sp. CB0205", "rank": "Species"}, "1441799": {"name": "Faba bean necrotic stunt alphasatellite 1", "rank": "Species"}, "1196662": {"name": "Rickettsia australis str. Phillips", "rank": "Strain"}, "0": {"name": "null", "rank": "n/a"}, "405917": {"name": "Bacillus cereus W", "rank": "Strain"}, "377461": {"name": "Malvastrum yellow mosaic alphasatellite", "rank": "Species"}, "146762": {"name": "Oat chlorotic stunt virus", "rank": "Species"}, "146761": {"name": "Avenavirus", "rank": "Genus"}, "237446": {"name": "Lactobacillus kitasatonis", "rank": "Species"}, "1114920": {"name": "Citrobacter freundii NBRC 12681", "rank": "Strain"}, "1114922": {"name": "Citrobacter farmeri GTC 1319", "rank": "Strain"}, "1448838": {"name": "Mycobacterium tuberculosis M13", "rank": "Strain"}, "1448835": {"name": "Mycobacterium tuberculosis M2898", "rank": "Strain"}, "1448834": {"name": "Mycobacterium tuberculosis M2828", "rank": "Strain"}, "1448837": {"name": "Mycobacterium tuberculosis M2350", "rank": "Strain"}, "1448836": {"name": "Mycobacterium tuberculosis M2346", "rank": "Strain"}, "1448831": {"name": "Mycobacterium tuberculosis H1964", "rank": "Strain"}, "1448830": {"name": "Mycobacterium tuberculosis H2398", "rank": "Strain"}, "1528098": {"name": "Rickettsiales bacterium Ac37b", "rank": "Species"}, "1449126": {"name": "Clostridiales bacterium DRI-13", "rank": "Species"}, "87650": {"name": "Facklamia sourekii", "rank": "Species"}, "1125643": {"name": "Escherichia coli P0302293.7", "rank": "Strain"}, "1144667": {"name": "Acinetobacter sp. CIP 102159", "rank": "Species"}, "1144666": {"name": "Acinetobacter sp. CIP 102143", "rank": "Species"}, "1144665": {"name": "Acinetobacter sp. CIP 102136", "rank": "Species"}, "1144664": {"name": "Acinetobacter sp. CIP 102129", "rank": "Species"}, "1144663": {"name": "Acinetobacter sp. CIP 102082", "rank": "Species"}, "1144662": {"name": "Acinetobacter sp. CIP 101966", "rank": "Species"}, "1144661": {"name": "Acinetobacter sp. CIP 101934", "rank": "Species"}, "994601": {"name": "Planktothrix phage PaV-LD", "rank": "Species"}, "314225": {"name": "Erythrobacter litoralis HTCC2594", "rank": "Strain"}, "1144669": {"name": "Acinetobacter sp. CIP 102637", "rank": "Species"}, "1144668": {"name": "Acinetobacter sp. CIP 102529", "rank": "Species"}, "1328421": {"name": "Klebsiella pneumoniae BIDMC 32", "rank": "Strain"}, "1445728": {"name": "Mycobacterium phage Saal", "rank": "Species"}, "1445729": {"name": "Mycobacterium phage 32HC", "rank": "Species"}, "1226322": {"name": "Oscillibacter sp. KLE 1728", "rank": "Species"}, "544911": {"name": "Massilia niastensis", "rank": "Species"}, "1445726": {"name": "Mycobacterium phage MichelleMyBell", "rank": "Species"}, "1445727": {"name": "Mycobacterium phage Oaker", "rank": "Species"}, "1154823": {"name": "Streptococcus agalactiae LMG 15094", "rank": "Strain"}, "1219084": {"name": "Thermotoga hypogea NBRC 106472", "rank": "Strain"}, "1226325": {"name": "Clostridium sp. KLE 1755", "rank": "Species"}, "1226324": {"name": "Blautia sp. KLE 1732", "rank": "Species"}, "1154824": {"name": "Streptococcus agalactiae LMG 15095", "rank": "Strain"}, "1413354": {"name": "Staphylococcus aureus 12-03481", "rank": "Strain"}, "1198133": {"name": "Myxococcus xanthus DZ2", "rank": "Strain"}, "1198136": {"name": "Tevenvirinae", "rank": "Subfamily"}, "1198137": {"name": "Schizot4likevirus", "rank": "Genus"}, "1198135": {"name": "Twortlikevirus", "rank": "Genus"}, "1198138": {"name": "Bcep78likevirus", "rank": "Genus"}, "1198139": {"name": "Bcepmulikevirus", "rank": "Genus"}, "399804": {"name": "Shewanella putrefaciens 200", "rank": "Strain"}, "1413355": {"name": "Staphylococcus aureus 09S00475", "rank": "Strain"}, "487732": {"name": "Corynebacterium ulceribovis", "rank": "Species"}, "83984": {"name": "Methanocorpusculum labreanum", "rank": "Species"}, "1154826": {"name": "Streptococcus agalactiae BSU442", "rank": "Strain"}, "1238993": {"name": "Mycoplasma pneumoniae M129-B7", "rank": "Strain"}, "1154827": {"name": "Streptococcus agalactiae BSU247", "rank": "Strain"}, "563990": {"name": "Francisella tularensis subsp. novicida FTG", "rank": "Strain"}, "28556": {"name": "Pleosporaceae", "rank": "Family"}, "312284": {"name": "Marine actinobacterium PHSC20C1", "rank": "Species"}, "253106": {"name": "Natronolimnobius", "rank": "Genus"}, "1402598": {"name": "Mycobacterium tuberculosis OFXR-29", "rank": "Strain"}, "1402599": {"name": "Mycobacterium tuberculosis OFXR-30", "rank": "Strain"}, "147547": {"name": "Lecanoromycetes", "rank": "Class"}, "147541": {"name": "Dothideomycetes", "rank": "Class"}, "1402590": {"name": "Mycobacterium tuberculosis OFXR-20", "rank": "Strain"}, "1402591": {"name": "Mycobacterium tuberculosis OFXR-21", "rank": "Strain"}, "1402592": {"name": "Mycobacterium tuberculosis OFXR-22", "rank": "Strain"}, "1402593": {"name": "Mycobacterium tuberculosis OFXR-23", "rank": "Strain"}, "1402595": {"name": "Mycobacterium tuberculosis OFXR-25", "rank": "Strain"}, "1402596": {"name": "Mycobacterium tuberculosis OFXR-26", "rank": "Strain"}, "1402597": {"name": "Mycobacterium tuberculosis OFXR-27", "rank": "Strain"}, "1218600": {"name": "Leptospira sp. P2653", "rank": "Species"}, "279383": {"name": "Phage phiJL001", "rank": "Species"}, "930965": {"name": "Chickpea chlorosis virus", "rank": "Species"}, "1088543": {"name": "Leptospira weilii str. LNT 1194", "rank": "Strain"}, "426430": {"name": "Staphylococcus aureus subsp. aureus str. Newman", "rank": "Strain"}, "72407": {"name": "Klebsiella pneumoniae subsp. pneumoniae", "rank": "Subspecies"}, "1280989": {"name": "Escherichia coli HVH 39 (4-2679949)", "rank": "Strain"}, "1280988": {"name": "Escherichia coli HVH 38 (4-2774682)", "rank": "Strain"}, "1005481": {"name": "Escherichia coli 93-001", "rank": "Strain"}, "1470345": {"name": "Candidatus Bacteroides timonensis", "rank": "Species"}, "1470347": {"name": "Candidatus Alistipes marseilloanorexicus", "rank": "Species"}, "1280983": {"name": "Escherichia coli HVH 32 (4-3773988)", "rank": "Strain"}, "1470349": {"name": "Candidatus Stoquefichus", "rank": "Genus"}, "1280981": {"name": "Escherichia coli HVH 30 (4-2661829)", "rank": "Strain"}, "1280980": {"name": "Escherichia coli HVH 29 (4-3418073)", "rank": "Strain"}, "1280987": {"name": "Escherichia coli HVH 37 (4-2773848)", "rank": "Strain"}, "1280986": {"name": "Escherichia coli HVH 36 (4-5675286)", "rank": "Strain"}, "1280985": {"name": "Escherichia coli HVH 35 (4-2962667)", "rank": "Strain"}, "1280984": {"name": "Escherichia coli HVH 33 (4-2174936)", "rank": "Strain"}, "1413488": {"name": "Staphylococcus aureus S69_POEL", "rank": "Strain"}, "866564": {"name": "Polaromonas glacialis", "rank": "Species"}, "1413484": {"name": "Staphylococcus aureus S56_POEL", "rank": "Strain"}, "1413485": {"name": "Staphylococcus aureus S62_POEL", "rank": "Strain"}, "1413486": {"name": "Staphylococcus aureus S63_POEL", "rank": "Strain"}, "1413487": {"name": "Staphylococcus aureus S64_POEL", "rank": "Strain"}, "1458470": {"name": "Staphylococcus epidermidis AG42", "rank": "Strain"}, "1458471": {"name": "Lachnoclostridium phytofermentans KNHs212", "rank": "Strain"}, "1458472": {"name": "Mycobacterium tuberculosis CWCFVRF MDRTB 670", "rank": "Strain"}, "1413483": {"name": "Staphylococcus aureus C3965", "rank": "Strain"}, "56877": {"name": "Helicobacter bizzozeronii", "rank": "Species"}, "56879": {"name": "Oat blue dwarf virus", "rank": "Species"}, "1123016": {"name": "Pseudomonas balearica DSM 6083", "rank": "Strain"}, "1123013": {"name": "Pseudoclavibacter soli DSM 23366", "rank": "Strain"}, "227334": {"name": "Coniophorineae", "rank": "Suborder"}, "1409740": {"name": "Staphylococcus aureus PLAC6055", "rank": "Strain"}, "1409741": {"name": "Staphylococcus aureus UCIM6146", "rank": "Strain"}, "1409742": {"name": "Staphylococcus aureus UCIM6147", "rank": "Strain"}, "1409743": {"name": "Staphylococcus aureus WAMC6080", "rank": "Strain"}, "1409744": {"name": "Staphylococcus aureus DAR948", "rank": "Strain"}, "1409745": {"name": "Staphylococcus aureus DAR1199", "rank": "Strain"}, "1409746": {"name": "Staphylococcus aureus DAR1280", "rank": "Strain"}, "1409747": {"name": "Staphylococcus aureus DAR1366", "rank": "Strain"}, "1409748": {"name": "Staphylococcus aureus DAR1503", "rank": "Strain"}, "1409749": {"name": "Staphylococcus aureus DAR3170", "rank": "Strain"}, "1281120": {"name": "Escherichia coli HVH 193 (4-3331423)", "rank": "Strain"}, "1281121": {"name": "Escherichia coli HVH 194 (4-2356805)", "rank": "Strain"}, "1069643": {"name": "Escherichia coli O104:H4 str. H112180283", "rank": "Strain"}, "1069642": {"name": "Bdellovibrio bacteriovorus str. Tiberius", "rank": "Strain"}, "1154880": {"name": "Streptococcus agalactiae MRI Z1-217", "rank": "Strain"}, "1281125": {"name": "Escherichia coli HVH 198 (4-3206106)", "rank": "Strain"}, "1422413": {"name": "Staphylococcus aureus VET0078R", "rank": "Strain"}, "1422412": {"name": "Staphylococcus aureus VET0077R", "rank": "Strain"}, "1422411": {"name": "Staphylococcus aureus VET0076R", "rank": "Strain"}, "1422410": {"name": "Staphylococcus aureus VET0075R", "rank": "Strain"}, "1422417": {"name": "Staphylococcus aureus VET0084R", "rank": "Strain"}, "1422416": {"name": "Staphylococcus aureus VET0083R", "rank": "Strain"}, "1422415": {"name": "Staphylococcus aureus VET0081R", "rank": "Strain"}, "1422414": {"name": "Staphylococcus aureus VET0080R", "rank": "Strain"}, "1422419": {"name": "Staphylococcus aureus VET0086R", "rank": "Strain"}, "1422418": {"name": "Staphylococcus aureus VET0085R", "rank": "Strain"}, "632955": {"name": "Acinetobacter rudis", "rank": "Species"}, "884612": {"name": "Pepper leaf curl Lahore Virus-Pakistan:Lahore1:2004", "rank": "Strain"}, "884610": {"name": "Pepper leaf curl Lahore virus", "rank": "Species"}, "862970": {"name": "Streptococcus anginosus C1051", "rank": "Strain"}, "266265": {"name": "Burkholderia xenovorans LB400", "rank": "Strain"}, "1411509": {"name": "Staphylococcus aureus F12856", "rank": "Strain"}, "575564": {"name": "Acinetobacter sp. RUH2624", "rank": "Strain"}, "575565": {"name": "Acinetobacter sp. SH024", "rank": "Strain"}, "203804": {"name": "Candidatus Blochmannia", "rank": "Genus"}, "1388743": {"name": "Brucella suis 04-0115", "rank": "Strain"}, "1423454": {"name": "Mycobacterium tuberculosis BTB06-467", "rank": "Strain"}, "1423455": {"name": "Mycobacterium tuberculosis BTB06-494", "rank": "Strain"}, "1423456": {"name": "Mycobacterium tuberculosis BTB07-001", "rank": "Strain"}, "1423457": {"name": "Mycobacterium tuberculosis BTB07-034", "rank": "Strain"}, "1423450": {"name": "Mycobacterium tuberculosis BTB05-650", "rank": "Strain"}, "1423451": {"name": "Mycobacterium tuberculosis BTB05-660", "rank": "Strain"}, "1423452": {"name": "Mycobacterium tuberculosis BTB06-001", "rank": "Strain"}, "1423453": {"name": "Mycobacterium tuberculosis BTB06-340", "rank": "Strain"}, "1423458": {"name": "Mycobacterium tuberculosis BTB07-070", "rank": "Strain"}, "1423459": {"name": "Mycobacterium tuberculosis BTB07-123", "rank": "Strain"}, "633701": {"name": "Prevotella saccharolytica", "rank": "Species"}, "640136": {"name": "Emilia yellow vein virus-associated DNA beta", "rank": "Species"}, "640131": {"name": "Klebsiella variicola At-22", "rank": "Strain"}, "640132": {"name": "Segniliparus rotundus DSM 44985", "rank": "Strain"}, "1231334": {"name": "Tomato leaf curl Hajipur betasatellite", "rank": "Species"}, "1231336": {"name": "Lactobacillus shenzhenensis LY-73", "rank": "Strain"}, "1231337": {"name": "Lactobacillus shenzhenensis", "rank": "Species"}, "1236102": {"name": "Klebsiella pneumoniae VA360", "rank": "Strain"}, "1236101": {"name": "Klebsiella pneumoniae JHCK1", "rank": "Strain"}, "13134": {"name": "Magnetospirillum", "rank": "Genus"}, "1126627": {"name": "Bradyrhizobium sp. DOA9", "rank": "Species"}, "1543704": {"name": "Niveispirillum", "rank": "Genus"}, "171632": {"name": "Mycoplasma ovis", "rank": "Species"}, "171631": {"name": "Fusarium oxysporum species complex", "rank": "No rank"}, "134681": {"name": "Cucurbit leaf crumple virus", "rank": "Species"}, "716923": {"name": "Unclassified Single stranded RNA satellites", "rank": "No rank"}, "113107": {"name": "Streptococcus australis", "rank": "Species"}, "1500757": {"name": "Pseudomonas phage phiPSA1", "rank": "Species"}, "1500756": {"name": "Pseudomonas phage phiPSA2", "rank": "Species"}, "1337997": {"name": "Escherichia coli IMT8073", "rank": "Strain"}, "1337996": {"name": "Burkholderia phenoliruptrix AC1100", "rank": "Strain"}, "997350": {"name": "Peptoniphilus indolicus ATCC 29427", "rank": "Strain"}, "135080": {"name": "Selenomonas flueggei", "rank": "Species"}, "135083": {"name": "Selenomonas noxia", "rank": "Species"}, "135082": {"name": "Selenomonas infelix", "rank": "Species"}, "561307": {"name": "Staphylococcus aureus subsp. aureus RN4220", "rank": "Strain"}, "561304": {"name": "Mycobacterium leprae Br4923", "rank": "Strain"}, "1087108": {"name": "Canine papillomavirus 9", "rank": "Species"}, "1087109": {"name": "Canine papillomavirus 10", "rank": "Species"}, "1346780": {"name": "Mycobacterium tuberculosis PanR0313", "rank": "Strain"}, "1346781": {"name": "Mycobacterium tuberculosis PanR0311", "rank": "Strain"}, "569154": {"name": "Prochlorococcus sp. W5", "rank": "Species"}, "569155": {"name": "Prochlorococcus sp. W6", "rank": "Species"}, "569152": {"name": "Prochlorococcus sp. W3", "rank": "Species"}, "569153": {"name": "Prochlorococcus sp. W4", "rank": "Species"}, "1346786": {"name": "Mycobacterium tuberculosis PanR0305", "rank": "Strain"}, "1346787": {"name": "Mycobacterium tuberculosis PanR0304", "rank": "Strain"}, "1346788": {"name": "Mycobacterium tuberculosis PanR0301", "rank": "Strain"}, "1346789": {"name": "Salmonella enterica subsp. salamae str. DMA-1", "rank": "Strain"}, "596309": {"name": "Rhodococcus erythropolis SK121", "rank": "Strain"}, "53335": {"name": "Pantoea", "rank": "Genus"}, "53332": {"name": "Desulfobulbus elongatus", "rank": "Species"}, "697329": {"name": "Ruminococcus albus 7 = DSM 20455", "rank": "Strain"}, "349221": {"name": "Micavibrio aeruginosavorus", "rank": "Species"}, "1347789": {"name": "Salmonella enterica subsp. enterica serovar Infantis str. 335-3", "rank": "Strain"}, "1230460": {"name": "Natronorubrum sulfidifaciens JCM 14089", "rank": "Strain"}, "1244203": {"name": "Bat coronavirus HKU10", "rank": "Species"}, "10565": {"name": "Deltapapillomavirus 1", "rank": "Species"}, "10564": {"name": "Deltapapillomavirus 2", "rank": "Species"}, "10567": {"name": "Iotapapillomavirus 1", "rank": "Species"}, "10566": {"name": "Human papillomavirus", "rank": "Species"}, "10561": {"name": "Xipapillomavirus 1", "rank": "Species"}, "10568": {"name": "Micromys minutus papillomavirus 1", "rank": "Strain"}, "1226994": {"name": "Pseudomonas nitroreducens TX1", "rank": "Strain"}, "373994": {"name": "Rivularia sp. PCC 7116", "rank": "Species"}, "295358": {"name": "Mycoplasma hyopneumoniae 232", "rank": "Strain"}, "436115": {"name": "Burkholderia mallei PRL-20", "rank": "Strain"}, "1165841": {"name": "Sulfurovum sp. AR", "rank": "Species"}, "326941": {"name": "Raspberry leaf mottle virus", "rank": "Species"}, "698959": {"name": "Gardnerella vaginalis 00703C2mash", "rank": "Strain"}, "698958": {"name": "Gardnerella vaginalis 00703Bmash", "rank": "Strain"}, "698953": {"name": "Gardnerella vaginalis 6420LIT", "rank": "Strain"}, "698952": {"name": "Gardnerella vaginalis 0288E", "rank": "Strain"}, "698951": {"name": "Gardnerella vaginalis 75712", "rank": "Strain"}, "698950": {"name": "Gardnerella vaginalis 284V", "rank": "Strain"}, "698957": {"name": "Gardnerella vaginalis 1500E", "rank": "Strain"}, "698956": {"name": "Gardnerella vaginalis 1400E", "rank": "Strain"}, "698955": {"name": "Gardnerella vaginalis 55152", "rank": "Strain"}, "698954": {"name": "Gardnerella vaginalis 6420B", "rank": "Strain"}, "1141141": {"name": "Enterobacteria phage vB_EcoM_ACG-C40", "rank": "Species"}, "1268319": {"name": "Proteobacteria bacterium JGI 0001002-H11", "rank": "Species"}, "1124485": {"name": "Vibrio cholerae O1 str. 2011V-1021", "rank": "Strain"}, "436114": {"name": "Sulfurihydrogenibium sp. YO3AOP1", "rank": "Species"}, "203119": {"name": "Ruminiclostridium thermocellum ATCC 27405", "rank": "Strain"}, "1124486": {"name": "Vibrio cholerae O1 str. 2010EL-2010H", "rank": "Strain"}, "1124481": {"name": "Vibrio cholerae O1 str. 2011EL-1089", "rank": "Strain"}, "1124480": {"name": "Vibrio cholerae O1 str. 2010EL-1961", "rank": "Strain"}, "1217704": {"name": "Acinetobacter sp. NIPH 284", "rank": "Species"}, "1124482": {"name": "Vibrio cholerae O1 str. 2011EL-1133", "rank": "Strain"}, "373665": {"name": "Yersinia pestis biovar Orientalis str. IP275", "rank": "Strain"}, "1047085": {"name": "Candidatus Paceibacter normanii SCGC AAA255-P19", "rank": "Strain"}, "1047081": {"name": "Cloacimonetes bacterium JGI 0000059-P11", "rank": "Species"}, "1047080": {"name": "Cloacimonetes bacterium JGI 0000059-P03", "rank": "Species"}, "864073": {"name": "Herbaspirillum frisingense GSF30", "rank": "Strain"}, "1422125": {"name": "Staphylococcus aureus DAR3548", "rank": "Strain"}, "42458": {"name": "Lichtheimia corymbifera", "rank": "Species"}, "491388": {"name": "Thalassobacter arenae", "rank": "Species"}, "1210450": {"name": "Brucella abortus bv. 2 str. BCB034", "rank": "Strain"}, "1210451": {"name": "Brucella abortus bv. 1 str. BCB013", "rank": "Strain"}, "1210452": {"name": "Brucella melitensis M5-10", "rank": "Strain"}, "1210453": {"name": "Brucella suis S2-30", "rank": "Strain"}, "1210454": {"name": "Brucella abortus 104M", "rank": "Strain"}, "797303": {"name": "Natrinema pellirubrum DSM 15624", "rank": "Strain"}, "38944": {"name": "Flammulina", "rank": "Genus"}, "11617": {"name": "Arenaviridae", "rank": "Family"}, "11611": {"name": "Tospovirus", "rank": "Genus"}, "11612": {"name": "Impatiens necrotic spot virus", "rank": "Species"}, "11613": {"name": "Tomato spotted wilt virus", "rank": "Species"}, "11618": {"name": "Arenavirus", "rank": "Genus"}, "11619": {"name": "Junin virus", "rank": "Species"}, "31959": {"name": "Amycolatopsis lurida", "rank": "Species"}, "31958": {"name": "Amycolatopsis orientalis", "rank": "Species"}, "31954": {"name": "Bifidobacterium pseudolongum subsp. pseudolongum", "rank": "Subspecies"}, "31957": {"name": "Propionibacteriaceae", "rank": "Family"}, "31953": {"name": "Bifidobacteriaceae", "rank": "Family"}, "488142": {"name": "Serratia sp. SCBI", "rank": "Species"}, "1422492": {"name": "Staphylococcus aureus VET0192R", "rank": "Strain"}, "1189617": {"name": "Xanthomonas axonopodis pv. manihotis str. CFBP1851", "rank": "Strain"}, "1265660": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 24.H.04", "rank": "Strain"}, "1354718": {"name": "Helicobacter pylori HP87hu", "rank": "Strain"}, "1265667": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 67.H.09", "rank": "Strain"}, "466088": {"name": "Acinetobacter sp. Ver3", "rank": "Species"}, "29363": {"name": "Clostridium paraputrificum", "rank": "Species"}, "29362": {"name": "Clostridium papyrosolvens", "rank": "Species"}, "29361": {"name": "Tyzzerella nexilis", "rank": "Species"}, "29360": {"name": "Cellulosilyticum lentocellum", "rank": "Species"}, "1265665": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 02.O.05", "rank": "Strain"}, "1265664": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 60.O.08", "rank": "Strain"}, "1462351": {"name": "Candidatus Aerophobus", "rank": "Genus"}, "1462352": {"name": "Candidatus Aerophobus profundus", "rank": "Species"}, "588673": {"name": "Solirubrobacterales", "rank": "Order"}, "1295400": {"name": "Campylobacter jejuni subsp. jejuni ICDCCJ07004", "rank": "Strain"}, "246273": {"name": "Wolbachia endosymbiont of Cimex lectularius", "rank": "Species"}, "246272": {"name": "Bacillus bogoriensis", "rank": "Species"}, "643562": {"name": "Desulfovibrio aespoeensis Aspo-2", "rank": "Strain"}, "1351751": {"name": "Parastagonospora", "rank": "Genus"}, "302099": {"name": "Tomato leaf curl Madagascar virus", "rank": "Species"}, "1111131": {"name": "Propionimicrobium sp. BV2F7", "rank": "Species"}, "363800": {"name": "Unclassified Leishmaniavirus", "rank": "No rank"}, "142661": {"name": "Canary circovirus", "rank": "Species"}, "149391": {"name": "Salmonella enterica subsp. enterica serovar Braenderup", "rank": "Strain"}, "61598": {"name": "Lamprocystis purpurea", "rank": "Species"}, "61592": {"name": "Corynebacterium durum", "rank": "Species"}, "585517": {"name": "Lactobacillus reuteri MM2-3", "rank": "Strain"}, "1438865": {"name": "Mycobacterium tuberculosis 2484AR", "rank": "Strain"}, "1438864": {"name": "Mycobacterium tuberculosis 2483AR", "rank": "Strain"}, "1438867": {"name": "Mycobacterium tuberculosis UT0119", "rank": "Strain"}, "1438866": {"name": "Mycobacterium tuberculosis 2485AR", "rank": "Strain"}, "878": {"name": "Desulfovibrio fructosivorans", "rank": "Species"}, "879": {"name": "Desulfovibrio gigas", "rank": "Species"}, "1438863": {"name": "Mycobacterium tuberculosis 2482AR", "rank": "Strain"}, "1438862": {"name": "Mycobacterium tuberculosis 2233BH", "rank": "Strain"}, "876": {"name": "Desulfovibrio desulfuricans", "rank": "Species"}, "870": {"name": "Dichelobacter nodosus", "rank": "Species"}, "1438868": {"name": "Mycobacterium tuberculosis 2541MS", "rank": "Strain"}, "872": {"name": "Desulfovibrio", "rank": "Genus"}, "873": {"name": "Desulfovibrio africanus", "rank": "Species"}, "33773": {"name": "Olive latent virus 2", "rank": "Species"}, "33771": {"name": "Halorubrum phage HF2", "rank": "Species"}, "1303782": {"name": "Staphylococcus aureus M1060", "rank": "Strain"}, "644548": {"name": "Gordonia neofelifaecis NRRL B-59395", "rank": "Strain"}, "1111130": {"name": "Prevotella sp. BV3P1", "rank": "Species"}, "1137129": {"name": "Staphylococcus aureus subsp. aureus 091751", "rank": "Strain"}, "1032526": {"name": "Pedosphaera", "rank": "Genus"}, "1032527": {"name": "Pedosphaera parvula", "rank": "Species"}, "675813": {"name": "Vibrio metschnikovii CIP 69.14", "rank": "Strain"}, "675812": {"name": "Grimontia hollisae CIP 101886", "rank": "Strain"}, "675811": {"name": "Vibrio furnissii CIP 102972", "rank": "Strain"}, "675810": {"name": "Vibrio sp. RC341", "rank": "Species"}, "675817": {"name": "Photobacterium damselae subsp. damselae CIP 102761", "rank": "Strain"}, "675816": {"name": "Vibrio orientalis CIP 102891 = ATCC 33934", "rank": "Strain"}, "675815": {"name": "Vibrio sp. RC586", "rank": "Species"}, "675814": {"name": "Vibrio coralliilyticus ATCC BAA-450", "rank": "Strain"}, "1218": {"name": "Prochlorococcus", "rank": "Genus"}, "1219": {"name": "Prochlorococcus marinus", "rank": "Species"}, "1212": {"name": "Prochlorales", "rank": "Order"}, "1217": {"name": "Prochlorococcaceae", "rank": "Family"}, "114529": {"name": "Haloferax alexandrinus", "rank": "Species"}, "388640": {"name": "Bartonella australis", "rank": "Species"}, "189515": {"name": "Cotton leaf curl virus betasatellite", "rank": "Species"}, "1517416": {"name": "Idiomarina sp. MCCC 1A10513", "rank": "Species"}, "1399798": {"name": "Actinomadura oligospora ATCC 43269", "rank": "Strain"}, "1399793": {"name": "Lactobacillus plantarum 19L3", "rank": "Strain"}, "1399797": {"name": "Entomoplasma lucivorax ATCC 49196", "rank": "Strain"}, "1399796": {"name": "Entomoplasma luminosum ATCC 49195", "rank": "Strain"}, "1399795": {"name": "Entomoplasma somnilux ATCC 49194", "rank": "Strain"}, "1399794": {"name": "Mycoplasma imitans ATCC 51306", "rank": "Strain"}, "1448703": {"name": "Mycobacterium tuberculosis M1559", "rank": "Strain"}, "1448702": {"name": "Mycobacterium tuberculosis M1545", "rank": "Strain"}, "1132574": {"name": "Unclassified Autographivirinae", "rank": "No rank"}, "1448700": {"name": "Mycobacterium tuberculosis M1520", "rank": "Strain"}, "1448707": {"name": "Mycobacterium tuberculosis M1638", "rank": "Strain"}, "1448706": {"name": "Mycobacterium tuberculosis M1615", "rank": "Strain"}, "1448705": {"name": "Mycobacterium tuberculosis M1570", "rank": "Strain"}, "1448704": {"name": "Mycobacterium tuberculosis M1560", "rank": "Strain"}, "1448709": {"name": "Mycobacterium tuberculosis M1703", "rank": "Strain"}, "1448708": {"name": "Mycobacterium tuberculosis M1702", "rank": "Strain"}, "184208": {"name": "Psathyrellaceae", "rank": "Family"}, "1263829": {"name": "Bibersteinia trehalosi USDA-ARS-USMARC-188", "rank": "Strain"}, "1167010": {"name": "Aggregatibacter actinomycetemcomitans serotype c str. AAS4A", "rank": "Strain"}, "320122": {"name": "Clostridium phage phiCD119", "rank": "Species"}, "1354303": {"name": "Psychrobacter aquaticus CMS 56", "rank": "Strain"}, "523796": {"name": "Staphylococcus aureus subsp. aureus ST398", "rank": "Strain"}, "1074183": {"name": "Streptococcus mutans TCI-289", "rank": "Strain"}, "1166948": {"name": "Halomonas xinjiangensis", "rank": "Species"}, "1354301": {"name": "Clostridium sp. BL8", "rank": "Species"}, "1354300": {"name": "Peptoniphilus sp. ChDC B134", "rank": "Species"}, "1449966": {"name": "Enterobacter sp. T1-1", "rank": "Species"}, "83171": {"name": "Methanocaldococcus fervens", "rank": "Species"}, "83174": {"name": "Valsa", "rank": "Genus"}, "1457300": {"name": "Escherichia coli E1728", "rank": "Strain"}, "1442082": {"name": "Candidatus Xenolissoclinum", "rank": "Genus"}, "1442083": {"name": "Candidatus Xenolissoclinum pacificiensis", "rank": "Species"}, "1217420": {"name": "Lactobacillus delbrueckii subsp. jakobsenii ZN7a-9 = DSM 26046", "rank": "Strain"}, "1121936": {"name": "Halalkalibacillus halophilus DSM 18494", "rank": "Strain"}, "1275968": {"name": "Haemophilus parasuis 12939", "rank": "Strain"}, "1328029": {"name": "Cellulophaga phage phi4:1", "rank": "Species"}, "684950": {"name": "Helicobacter pylori 52", "rank": "Strain"}, "997878": {"name": "Bacteroides fragilis CL03T00C08", "rank": "Strain"}, "70823": {"name": "Dulcamara mottle virus", "rank": "Species"}, "997874": {"name": "Bacteroides cellulosilyticus CL02T12C19", "rank": "Strain"}, "997875": {"name": "Bacteroides dorei CL02T00C15", "rank": "Strain"}, "997876": {"name": "Bacteroides dorei CL02T12C06", "rank": "Strain"}, "997877": {"name": "Bacteroides dorei CL03T12C01", "rank": "Strain"}, "997872": {"name": "Atopobium minutum 10063974", "rank": "Strain"}, "997873": {"name": "Bacteroides caccae CL03T12C61", "rank": "Strain"}, "46436": {"name": "Beet soil-borne virus", "rank": "Species"}, "12158": {"name": "Kennedya yellow mosaic virus", "rank": "Species"}, "5061": {"name": "Aspergillus niger", "rank": "Species"}, "12154": {"name": "Turnip yellow mosaic virus", "rank": "Species"}, "482234": {"name": "Streptococcus canis FSL Z3-227", "rank": "Strain"}, "12152": {"name": "Erysimum latent virus", "rank": "Species"}, "12153": {"name": "Ononis yellow mosaic virus", "rank": "Species"}, "764561": {"name": "Brochothrix phage NF5", "rank": "Species"}, "59562": {"name": "Mosquito-borne viruses", "rank": "Subgenus"}, "59563": {"name": "Ilheus virus", "rank": "Species"}, "1105121": {"name": "Streptococcus pneumoniae GA58771", "rank": "Strain"}, "1105120": {"name": "Streptococcus pneumoniae GA60190", "rank": "Strain"}, "345632": {"name": "Geobacter pickeringii", "rank": "Species"}, "454168": {"name": "Salmonella enterica subsp. enterica serovar Newport str. SL317", "rank": "Strain"}, "454169": {"name": "Salmonella enterica subsp. enterica serovar Heidelberg str. SL476", "rank": "Strain"}, "73029": {"name": "Dechloromonas", "rank": "Genus"}, "1117111": {"name": "Escherichia coli P4-NR", "rank": "Strain"}, "1117110": {"name": "Pseudomonas chlororaphis subsp. chlororaphis GP72", "rank": "Strain"}, "54307": {"name": "Planktothrix prolifica", "rank": "Species"}, "54306": {"name": "Planktothrix mougeotii", "rank": "Species"}, "38143": {"name": "Simian hemorrhagic fever virus", "rank": "Species"}, "881915": {"name": "Pantoea phage LIMElight", "rank": "Species"}, "1121938": {"name": "Halobacillus kuroshimensis DSM 18393", "rank": "Strain"}, "637616": {"name": "Methylophaga thiooxydans DMS010", "rank": "Strain"}, "1121939": {"name": "Halomonas anticariensis FP35 = DSM 16096", "rank": "Strain"}, "1124968": {"name": "Salmonella enterica subsp. enterica serovar Stanley str. ATCC 7308", "rank": "Strain"}, "1124962": {"name": "Salmonella enterica subsp. enterica serovar Poona str. ATCC BAA-1673", "rank": "Strain"}, "1124963": {"name": "Salmonella enterica subsp. enterica serovar Muenster str. 660", "rank": "Strain"}, "1124961": {"name": "Salmonella enterica subsp. enterica serovar Panama str. ATCC 7378", "rank": "Strain"}, "1124966": {"name": "Salmonella enterica subsp. enterica serovar Senftenberg str. 604314", "rank": "Strain"}, "1124967": {"name": "Salmonella enterica subsp. enterica serovar Soerenga str. 695", "rank": "Strain"}, "1124964": {"name": "Salmonella enterica subsp. enterica serovar Saintpaul str. 9712", "rank": "Strain"}, "1158538": {"name": "Staphylococcus aureus M0586", "rank": "Strain"}, "1158539": {"name": "Staphylococcus aureus M0633", "rank": "Strain"}, "1475143": {"name": "Mink circovirus", "rank": "Species"}, "600645": {"name": "Aeromonas piscicola", "rank": "Species"}, "1158533": {"name": "Staphylococcus aureus M0510", "rank": "Strain"}, "1158530": {"name": "Staphylococcus aureus M0424", "rank": "Strain"}, "1158531": {"name": "Staphylococcus aureus M0438", "rank": "Strain"}, "1158536": {"name": "Staphylococcus aureus M0571", "rank": "Strain"}, "1158537": {"name": "Staphylococcus aureus M0584", "rank": "Strain"}, "1158534": {"name": "Staphylococcus aureus M0513", "rank": "Strain"}, "1158535": {"name": "Staphylococcus aureus M0562", "rank": "Strain"}, "701770": {"name": "Angel-like phages", "rank": "No rank"}, "47740": {"name": "Groundnut rosette virus", "rank": "Species"}, "388038": {"name": "Cucumber mottle virus", "rank": "Species"}, "483547": {"name": "Geoalkalibacter subterraneus", "rank": "Species"}, "932920": {"name": "Listeria monocytogenes SLCC2372", "rank": "Strain"}, "1096756": {"name": "Arthrobacter sp. PAO19", "rank": "Species"}, "141454": {"name": "Streptomyces wadayamensis", "rank": "Species"}, "1338534": {"name": "Helicobacter pylori HPARG63", "rank": "Strain"}, "1338533": {"name": "Staphylococcus aureus 917", "rank": "Strain"}, "568208": {"name": "Nocardiopsis dassonvillei subsp. dassonvillei", "rank": "Subspecies"}, "932071": {"name": "Abutilon mosaic Bolivia virus", "rank": "Species"}, "932070": {"name": "Sida mosaic Bolivia virus 2", "rank": "Species"}, "932073": {"name": "Solanum mosaic Bolivia virus", "rank": "Species"}, "568206": {"name": "Bacillus anthracis str. CDC 684", "rank": "Strain"}, "136187": {"name": "Equine coronavirus", "rank": "Strain"}, "42817": {"name": "Corynebacterium argentoratense", "rank": "Species"}, "391587": {"name": "Kordia algicida OT-1", "rank": "Strain"}, "55079": {"name": "Aneurinibacillus", "rank": "Genus"}, "882627": {"name": "Sphaerotilus natans subsp. natans", "rank": "Subspecies"}, "95659": {"name": "Ureaplasma urealyticum serovar 5", "rank": "Strain"}, "527005": {"name": "Yersinia ruckeri ATCC 29473", "rank": "Strain"}, "908285": {"name": "Necropsobacter rosorum", "rank": "Species"}, "908284": {"name": "Necropsobacter", "rank": "Genus"}, "259536": {"name": "Psychrobacter arcticus 273-4", "rank": "Strain"}, "259537": {"name": "Dechloromonas aromatica", "rank": "Species"}, "333968": {"name": "Dolichos yellow mosaic virus", "rank": "Species"}, "1532558": {"name": "Rhizobium sp. YS-1r", "rank": "Species"}, "28084": {"name": "Legionella cherrii", "rank": "Species"}, "180255": {"name": "Iltovirus", "rank": "Genus"}, "1532556": {"name": "Serratia sp. Ag2", "rank": "Species"}, "1532557": {"name": "Achromobacter sp. RTa", "rank": "Species"}, "28087": {"name": "Legionella sainthelensi", "rank": "Species"}, "180252": {"name": "Mardivirus", "rank": "Genus"}, "1315159": {"name": "Acinetobacter baumannii TG22150", "rank": "Strain"}, "1315158": {"name": "Acinetobacter baumannii TG22148", "rank": "Strain"}, "869688": {"name": "Escherichia coli 2.3916", "rank": "Strain"}, "1315151": {"name": "Acinetobacter baumannii TG20546", "rank": "Strain"}, "1315150": {"name": "Acinetobacter baumannii TG20277", "rank": "Strain"}, "459515": {"name": "Nakamurella lactea", "rank": "Species"}, "1315155": {"name": "Acinetobacter baumannii TG22112", "rank": "Strain"}, "1315154": {"name": "Acinetobacter baumannii TG22110", "rank": "Strain"}, "1315157": {"name": "Acinetobacter baumannii TG22146", "rank": "Strain"}, "1315156": {"name": "Acinetobacter baumannii TG22142", "rank": "Strain"}, "264688": {"name": "Trichormus", "rank": "Genus"}, "319795": {"name": "Deinococcus geothermalis DSM 11300", "rank": "Strain"}, "1403390": {"name": "Staphylococcus phage phiRS7", "rank": "Species"}, "1448682": {"name": "Mycobacterium tuberculosis M1425", "rank": "Strain"}, "1448683": {"name": "Mycobacterium tuberculosis M1429", "rank": "Strain"}, "396588": {"name": "Thioalkalivibrio sulfidiphilus HL-EbGr7", "rank": "Strain"}, "630527": {"name": "Lactobacillus gasseri 202-4", "rank": "Strain"}, "1448680": {"name": "Mycobacterium tuberculosis M1422", "rank": "Strain"}, "1448681": {"name": "Mycobacterium tuberculosis M1424", "rank": "Strain"}, "687364": {"name": "Torque teno virus 25", "rank": "Species"}, "687365": {"name": "Torque teno virus 26", "rank": "Species"}, "687366": {"name": "Torque teno virus 27", "rank": "Species"}, "869680": {"name": "Escherichia coli 93.0624", "rank": "Strain"}, "43675": {"name": "Rothia mucilaginosa", "rank": "Species"}, "687369": {"name": "Torque teno mini virus 1", "rank": "Species"}, "43676": {"name": "Promicromonospora", "rank": "Genus"}, "43670": {"name": "Cellulomonas cellasea", "rank": "Species"}, "43673": {"name": "Jonesia", "rank": "Genus"}, "1448687": {"name": "Mycobacterium tuberculosis M1441", "rank": "Strain"}, "1448684": {"name": "Mycobacterium tuberculosis M1431", "rank": "Strain"}, "869685": {"name": "Escherichia coli 9.1649", "rank": "Strain"}, "1448685": {"name": "Mycobacterium tuberculosis M1438", "rank": "Strain"}, "335797": {"name": "Burkholderia phage KS9", "rank": "Species"}, "335795": {"name": "Unclassified Lambda-like viruses", "rank": "No rank"}, "1420587": {"name": "Pseudomonas syringae KCTC 12500", "rank": "Strain"}, "869687": {"name": "Escherichia coli 4.0967", "rank": "Strain"}, "869686": {"name": "Escherichia coli 9.0111", "rank": "Strain"}, "1157944": {"name": "Arthrobacter sp. 131MFCol6.1", "rank": "Species"}, "1095660": {"name": "Vibrio cholerae O1 str. 95412", "rank": "Strain"}, "502394": {"name": "Deinococcus gobiensis", "rank": "Species"}, "436308": {"name": "Nitrosopumilus maritimus SCM1", "rank": "Strain"}, "92645": {"name": "Herbaspirillum frisingense", "rank": "Species"}, "136273": {"name": "Kocuria polaris", "rank": "Species"}, "1334191": {"name": "Lactobacillus brevis BSO 464", "rank": "Strain"}, "1334193": {"name": "Enterobacter lignolyticus", "rank": "Species"}, "272568": {"name": "Gluconacetobacter diazotrophicus PA1 5", "rank": "Strain"}, "272569": {"name": "Haloarcula marismortui ATCC 43049", "rank": "Strain"}, "272564": {"name": "Desulfitobacterium hafniense DCB-2", "rank": "Strain"}, "272562": {"name": "Clostridium acetobutylicum ATCC 824", "rank": "Strain"}, "272563": {"name": "Peptoclostridium difficile 630", "rank": "Strain"}, "272560": {"name": "Burkholderia pseudomallei K96243", "rank": "Strain"}, "272561": {"name": "Chlamydia trachomatis D/UW-3/CX", "rank": "Strain"}, "1095661": {"name": "Vibrio cholerae O1 str. 116059", "rank": "Strain"}, "301953": {"name": "Caldicellulosiruptor acetigenus", "rank": "Species"}, "223769": {"name": "Grapevine Anatolian ringspot virus", "rank": "Species"}, "1129873": {"name": "Valsa ceratosperma hypovirus 1", "rank": "Species"}, "1413400": {"name": "Staphylococcus aureus 88088-2", "rank": "Strain"}, "1095666": {"name": "Neisseria meningitidis 70030", "rank": "Strain"}, "109262": {"name": "Halothiobacillus", "rank": "Genus"}, "1327766": {"name": "Mycobacterium phage Newman", "rank": "Species"}, "656913": {"name": "Haemophilus influenzae NT127", "rank": "Strain"}, "656912": {"name": "Haemophilus influenzae RdAW", "rank": "Strain"}, "904732": {"name": "Staphylococcus aureus subsp. aureus 21202", "rank": "Strain"}, "904731": {"name": "Staphylococcus aureus subsp. aureus 21201", "rank": "Strain"}, "1121456": {"name": "Desulfovibrio longus DSM 6739", "rank": "Strain"}, "904737": {"name": "Staphylococcus aureus subsp. aureus 21232", "rank": "Strain"}, "904736": {"name": "Staphylococcus aureus subsp. aureus 21230", "rank": "Strain"}, "904735": {"name": "Staphylococcus aureus subsp. aureus 21209", "rank": "Strain"}, "904734": {"name": "Staphylococcus aureus subsp. aureus 21205", "rank": "Strain"}, "904739": {"name": "Staphylococcus aureus subsp. aureus 21236", "rank": "Strain"}, "904738": {"name": "Staphylococcus aureus subsp. aureus 21235", "rank": "Strain"}, "1121459": {"name": "Desulfovibrio oxyclinae DSM 11498", "rank": "Strain"}, "450851": {"name": "Phenylobacterium zucineum HLK1", "rank": "Strain"}, "743035": {"name": "Ageratum leaf curl Cameroon alphasatellite", "rank": "Species"}, "300825": {"name": "Bacillus lehensis", "rank": "Species"}, "1281214": {"name": "Escherichia coli UMEA 3201-1", "rank": "Strain"}, "1281215": {"name": "Escherichia coli UMEA 3203-1", "rank": "Strain"}, "1281216": {"name": "Escherichia coli UMEA 3206-1", "rank": "Strain"}, "97478": {"name": "Lactobacillus mucosae", "rank": "Species"}, "1281217": {"name": "Escherichia coli UMEA 3208-1", "rank": "Strain"}, "1046402": {"name": "Potato virus H", "rank": "Species"}, "1046403": {"name": "Brassica yellows virus", "rank": "Species"}, "1409436": {"name": "Staphylococcus aureus OCMM6048", "rank": "Strain"}, "97477": {"name": "Anaerobaculum mobile", "rank": "Species"}, "1281211": {"name": "Escherichia coli UMEA 3193-1", "rank": "Strain"}, "887308": {"name": "Campylobacter coli LMG 9860", "rank": "Strain"}, "887309": {"name": "Campylobacter coli H6", "rank": "Strain"}, "887304": {"name": "Campylobacter coli LMG 23341", "rank": "Strain"}, "887305": {"name": "Campylobacter coli LMG 23342", "rank": "Strain"}, "887306": {"name": "Campylobacter coli LMG 23344", "rank": "Strain"}, "887307": {"name": "Campylobacter coli LMG 9853", "rank": "Strain"}, "887300": {"name": "Campylobacter coli 317/04", "rank": "Strain"}, "887301": {"name": "Campylobacter coli 37/05", "rank": "Strain"}, "887302": {"name": "Campylobacter coli LMG 9854", "rank": "Strain"}, "887303": {"name": "Campylobacter coli LMG 23336", "rank": "Strain"}, "933845": {"name": "Bathycoccus sp. RCC1105 virus BpV", "rank": "Species"}, "354260": {"name": "Lactococcus phage P335 sensu lato", "rank": "Species"}, "11290": {"name": "Infectious hematopoietic necrosis virus", "rank": "Species"}, "11292": {"name": "Rabies virus", "rank": "Species"}, "1087068": {"name": "Aspergillus foetidus dsRNA mycovirus", "rank": "Species"}, "1423833": {"name": "Lactobacillus sakei subsp. sakei DSM 20017 = JCM 1157", "rank": "Strain"}, "1042402": {"name": "Lactococcus lactis subsp. lactis CNCM I-1631", "rank": "Strain"}, "1042403": {"name": "Bifidobacterium animalis subsp. lactis CNCM I-2494", "rank": "Strain"}, "1042400": {"name": "Lactobacillus delbrueckii subsp. bulgaricus CNCM I-1519", "rank": "Strain"}, "1042404": {"name": "Streptococcus thermophilus CNCM I-1630", "rank": "Strain"}, "1225790": {"name": "Pseudomonas phage MPK7", "rank": "Species"}, "1225794": {"name": "Lactobacillus phage ATCC 8014-B1", "rank": "Species"}, "131079": {"name": "Limnobacter", "rank": "Genus"}, "170673": {"name": "Vibrio kanaloae", "rank": "Species"}, "170674": {"name": "Vibrio pacinii", "rank": "Species"}, "272951": {"name": "Rickettsia sibirica 246", "rank": "Strain"}, "1336206": {"name": "Escherichia coli O127:H6 str. E2348/69 substr. UMD753", "rank": "Strain"}, "1336207": {"name": "Pseudomonas sp. P818", "rank": "Species"}, "1336205": {"name": "Escherichia coli O127:H6 str. E2348/69 substr. CVDNalr", "rank": "Strain"}, "1336203": {"name": "Pseudomonas aeruginosa MH38", "rank": "Strain"}, "693851": {"name": "Halogranum salarium", "rank": "Species"}, "1336208": {"name": "Roseomonas gilardii subsp. rosea ATCC BAA-691", "rank": "Strain"}, "175950": {"name": "Salmonella phage ST64B", "rank": "Species"}, "1033840": {"name": "Exophiala aquamarina", "rank": "Species"}, "28184": {"name": "Leptospira weilii", "rank": "Species"}, "28186": {"name": "Acetohalobium", "rank": "Genus"}, "28187": {"name": "Acetohalobium arabaticum", "rank": "Species"}, "28182": {"name": "Leptospira noguchii", "rank": "Species"}, "28183": {"name": "Leptospira santarosai", "rank": "Species"}, "28188": {"name": "Capnocytophaga canimorsus", "rank": "Species"}, "28189": {"name": "Capnocytophaga cynodegmi", "rank": "Species"}, "1080228": {"name": "Synechocystis sp. PCC 6803 substr. GT-I", "rank": "Strain"}, "1080229": {"name": "Synechocystis sp. PCC 6803 substr. PCC-N", "rank": "Strain"}, "1444114": {"name": "Escherichia coli 6-175-07_S1_C3", "rank": "Strain"}, "1444115": {"name": "Escherichia coli 6-319-05_S1_C3", "rank": "Strain"}, "1444112": {"name": "Escherichia coli 3-373-03_S1_C3", "rank": "Strain"}, "1444113": {"name": "Escherichia coli 4-203-08_S1_C3", "rank": "Strain"}, "1444110": {"name": "Escherichia coli 3-105-05_S1_C3", "rank": "Strain"}, "1444111": {"name": "Escherichia coli 3-267-03_S1_C3", "rank": "Strain"}, "1294029": {"name": "Tropheryma whipplei str. Dig10", "rank": "Strain"}, "1294028": {"name": "Tropheryma whipplei str. Dig7", "rank": "Strain"}, "1444118": {"name": "Escherichia coli 2-011-08_S3_C1", "rank": "Strain"}, "1444119": {"name": "Escherichia coli 2-052-05_S3_C1", "rank": "Strain"}, "348818": {"name": "Streptacidiphilus oryzae", "rank": "Species"}, "11746": {"name": "Jaagsiekte sheep retrovirus", "rank": "Species"}, "11741": {"name": "Visna/maedi virus", "rank": "Species"}, "29581": {"name": "Janthinobacterium lividum", "rank": "Species"}, "29580": {"name": "Janthinobacterium", "rank": "Genus"}, "35323": {"name": "Thogotovirus", "rank": "Genus"}, "520708": {"name": "Acinetobacter sp. NIPH 817", "rank": "Species"}, "520709": {"name": "Acinetobacter sp. NIPH 973", "rank": "Species"}, "396808": {"name": "Andreprevotia chitinilytica", "rank": "Species"}, "903945": {"name": "Acinetobacter sp. WC-743", "rank": "Species"}, "861360": {"name": "Arthrobacter arilaitensis Re117", "rank": "Strain"}, "1203602": {"name": "Atopobium sp. oral taxon 199 str. F0494", "rank": "Strain"}, "1203605": {"name": "Propionibacterium sp. oral taxon 192 str. F0372", "rank": "Strain"}, "1203606": {"name": "Butyricicoccus pullicaecorum 1.2", "rank": "Strain"}, "1203608": {"name": "Bacteroides nordii WAL 11050 = JCM 12987", "rank": "Strain"}, "381764": {"name": "Fervidobacterium nodosum Rt17-B1", "rank": "Strain"}, "157924": {"name": "Streptococcus phage SM1", "rank": "Species"}, "157920": {"name": "Cellulosimicrobium", "rank": "Genus"}, "66797": {"name": "Bacillus phage SPbeta", "rank": "Species"}, "426226": {"name": "Flavobacterium subsaxonicum", "rank": "Species"}, "1191479": {"name": "Magnetococcaceae", "rank": "Family"}, "1136417": {"name": "Salinispora pacifica CNT003", "rank": "Strain"}, "1136416": {"name": "Salinispora pacifica CNT001", "rank": "Strain"}, "1297591": {"name": "Penicillium chrysogenum NCPC10086", "rank": "Strain"}, "1136419": {"name": "Salinispora pacifica CNT084", "rank": "Strain"}, "1136418": {"name": "Salinispora pacifica CNT029", "rank": "Strain"}, "1159489": {"name": "Cronobacter sakazakii 2151", "rank": "Strain"}, "5543": {"name": "Trichoderma", "rank": "Genus"}, "5540": {"name": "Thermomyces", "rank": "Genus"}, "5541": {"name": "Thermomyces lanuginosus", "rank": "Species"}, "658623": {"name": "Chelonobacter", "rank": "Genus"}, "12211": {"name": "Plum pox virus", "rank": "Species"}, "12210": {"name": "Pepper severe mosaic virus", "rank": "Species"}, "5548": {"name": "Trichoderma longibrachiatum", "rank": "Species"}, "12215": {"name": "Potato virus A", "rank": "Species"}, "12216": {"name": "Potato virus Y", "rank": "Species"}, "1281153": {"name": "Escherichia coli KOEGE 3 (4a)", "rank": "Strain"}, "1281152": {"name": "Escherichia coli HVH 228 (4-7787030)", "rank": "Strain"}, "1281151": {"name": "Escherichia coli HVH 227 (4-2277670)", "rank": "Strain"}, "493376": {"name": "Chryseobacterium palustre", "rank": "Species"}, "1422048": {"name": "Mycobacterium tuberculosis TB_RSA132", "rank": "Strain"}, "1444253": {"name": "Escherichia coli 3-475-03_S4_C2", "rank": "Strain"}, "1154874": {"name": "Streptococcus agalactiae MRI Z1-211", "rank": "Strain"}, "479833": {"name": "Peptoclostridium difficile QCD-97b34", "rank": "Strain"}, "479832": {"name": "Peptoclostridium difficile QCD-76w55", "rank": "Strain"}, "479831": {"name": "Peptoclostridium difficile QCD-63q42", "rank": "Strain"}, "1422043": {"name": "Mycobacterium tuberculosis TB_RSA127", "rank": "Strain"}, "106146": {"name": "Pelistega", "rank": "Genus"}, "762983": {"name": "Succinatimonas hippei YIT 12066", "rank": "Strain"}, "1422046": {"name": "Mycobacterium tuberculosis TB_RSA130", "rank": "Strain"}, "1422047": {"name": "Mycobacterium tuberculosis TB_RSA131", "rank": "Strain"}, "31537": {"name": "Lactococcus phage c2", "rank": "Species"}, "1239788": {"name": "Streptococcus pneumoniae 1542", "rank": "Strain"}, "31535": {"name": "Pseudomonas phage D3", "rank": "Species"}, "83378": {"name": "Streptomyces ruber", "rank": "Species"}, "31532": {"name": "Lactococcus phage sk1", "rank": "Strain"}, "1034768": {"name": "Gordonia polyisoprenivorans HW436", "rank": "Strain"}, "1034769": {"name": "Paenibacillus sp. HW567", "rank": "Species"}, "1281154": {"name": "Escherichia coli KOEGE 7 (16a)", "rank": "Strain"}, "167021": {"name": "Pelargonium chlorotic ring pattern virus", "rank": "Species"}, "52280": {"name": "Chilli veinal mottle virus", "rank": "Species"}, "1227465": {"name": "Halorubrum californiensis DSM 19288", "rank": "Strain"}, "991982": {"name": "Vibrio cholerae HC-67A1", "rank": "Strain"}, "1463846": {"name": "Streptomyces sp. NRRL F-3213", "rank": "Species"}, "1463845": {"name": "Streptomyces sp. NRRL F-2890", "rank": "Species"}, "1463844": {"name": "Streptomyces sp. NRRL F-2799", "rank": "Species"}, "1463843": {"name": "Streptomyces sp. NRRL F-2747", "rank": "Species"}, "991987": {"name": "Vibrio cholerae HC-77A1", "rank": "Strain"}, "1463841": {"name": "Streptomyces sp. NRRL F-2580", "rank": "Species"}, "1463840": {"name": "Streptomyces sp. NRRL F-2305", "rank": "Species"}, "991988": {"name": "Vibrio cholerae HC-80A1", "rank": "Strain"}, "991989": {"name": "Vibrio cholerae HFU-02", "rank": "Strain"}, "1463849": {"name": "Streptomyces sp. NRRL F-3307", "rank": "Species"}, "512565": {"name": "Actinoplanes missouriensis 431", "rank": "Strain"}, "512564": {"name": "Mycoplasma crocodyli MP145", "rank": "Strain"}, "512566": {"name": "Streptococcus pneumoniae G54", "rank": "Strain"}, "251095": {"name": "Nanoviridae", "rank": "Family"}, "1158146": {"name": "Thioalkalivibrio sp. ALJT", "rank": "Species"}, "693075": {"name": "Caldisericum exile", "rank": "Species"}, "693074": {"name": "Caldisericum", "rank": "Genus"}, "381899": {"name": "Paramecium bursaria Chlorella virus A1", "rank": "Species"}, "269796": {"name": "Rhodospirillum rubrum ATCC 11170", "rank": "Strain"}, "693071": {"name": "Caldisericia", "rank": "Class"}, "693073": {"name": "Caldisericaceae", "rank": "Family"}, "693072": {"name": "Caldisericales", "rank": "Order"}, "53988": {"name": "Microplitis demolitor bracovirus", "rank": "Species"}, "1076136": {"name": "Mycobacterium phage Perseus", "rank": "Species"}, "269799": {"name": "Geobacter metallireducens GS-15", "rank": "Strain"}, "269798": {"name": "Cytophaga hutchinsonii ATCC 33406", "rank": "Strain"}, "1388072": {"name": "Staphylococcus aureus M0120", "rank": "Strain"}, "245174": {"name": "Wallemia ichthyophaga", "rank": "Species"}, "731": {"name": "Histophilus somni", "rank": "Species"}, "1410621": {"name": "Lachnospiraceae bacterium AD3010", "rank": "Species"}, "1199245": {"name": "Secondary endosymbiont of Ctenarytaina eucalypti", "rank": "Species"}, "675524": {"name": "Methylocaldum szegediense O-12", "rank": "Strain"}, "675523": {"name": "Mycobacterium tuberculosis SUMu012", "rank": "Strain"}, "675522": {"name": "Mycobacterium tuberculosis SUMu011", "rank": "Strain"}, "675521": {"name": "Mycobacterium tuberculosis SUMu010", "rank": "Strain"}, "675520": {"name": "Mycobacterium tuberculosis SUMu009", "rank": "Strain"}, "735": {"name": "Haemophilus parahaemolyticus", "rank": "Species"}, "536056": {"name": "Escherichia coli DH1", "rank": "Strain"}, "1409776": {"name": "Staphylococcus aureus SCLE6100", "rank": "Strain"}, "439846": {"name": "Salmonella enterica subsp. enterica serovar Saintpaul str. SARA23", "rank": "Strain"}, "1229203": {"name": "Actinobacterium LLX17", "rank": "Species"}, "33034": {"name": "Anaerococcus prevotii", "rank": "Species"}, "33035": {"name": "Blautia producta", "rank": "Species"}, "33036": {"name": "Anaerococcus tetradius", "rank": "Species"}, "33037": {"name": "Anaerococcus vaginalis", "rank": "Species"}, "33030": {"name": "Peptoniphilus indolicus", "rank": "Species"}, "33031": {"name": "Peptoniphilus lacrimalis", "rank": "Species"}, "33032": {"name": "Anaerococcus lactolyticus", "rank": "Species"}, "33033": {"name": "Parvimonas micra", "rank": "Species"}, "33038": {"name": "Ruminococcus gnavus", "rank": "Species"}, "33039": {"name": "Ruminococcus torques", "rank": "Species"}, "290053": {"name": "Bacteroides helcogenes", "rank": "Species"}, "45596": {"name": "Candida tenuis", "rank": "Species"}, "320324": {"name": "Formosa agariphila", "rank": "Species"}, "1388075": {"name": "Staphylococcus aureus M0124", "rank": "Strain"}, "1301419": {"name": "Gyalolechia flavorubescens", "rank": "Species"}, "164330": {"name": "Thauera aminoaromatica", "rank": "Species"}, "1380365": {"name": "Dyella japonica UNC79MFTsu3.2", "rank": "Strain"}, "1380367": {"name": "Sulfitobacter sp. 20_GPM-1509m", "rank": "Species"}, "1380362": {"name": "Ralstonia sp. UNC404CL21Col", "rank": "Species"}, "1380363": {"name": "Shewanella sp. 38A_GOM-205m", "rank": "Species"}, "1513201": {"name": "Hepandensovirus", "rank": "Genus"}, "1380369": {"name": "Pseudomonas umsongensis UNC430CL58Col", "rank": "Strain"}, "1513202": {"name": "Decapod hepandensovirus 1", "rank": "Species"}, "325240": {"name": "Shewanella baltica OS155", "rank": "Strain"}, "1273103": {"name": "Megasphaera sp. NM10", "rank": "Species"}, "298965": {"name": "Beet black scorch virus satellite RNA", "rank": "Species"}, "1410616": {"name": "Pseudobutyrivibrio sp. MD2005", "rank": "Species"}, "360094": {"name": "Xanthomonas oryzae pv. oryzae PXO99A", "rank": "Strain"}, "360095": {"name": "Bartonella bacilliformis KC583", "rank": "Strain"}, "1387986": {"name": "Staphylococcus aureus M0004", "rank": "Strain"}, "360099": {"name": "Yersinia pestis biovar Antiqua str. E1979001", "rank": "Strain"}, "1267897": {"name": "Klebsiella pneumoniae hvKP1", "rank": "Strain"}, "1421551": {"name": "Borrelia garinii SZ", "rank": "Strain"}, "453454": {"name": "Cotton leaf curl Gezira beta", "rank": "Species"}, "367840": {"name": "Salinicoccus luteus", "rank": "Species"}, "1310983": {"name": "Acinetobacter baumannii 44467_9", "rank": "Strain"}, "57579": {"name": "Adeno-associated virus - 4", "rank": "Strain"}, "1310982": {"name": "Acinetobacter baumannii 44467_8", "rank": "Strain"}, "1141519": {"name": "Escherichia phage phiKT", "rank": "Species"}, "1037908": {"name": "Klebsiella pneumoniae 1162281", "rank": "Strain"}, "1412758": {"name": "Staphylococcus aureus M13065", "rank": "Strain"}, "206379": {"name": "Nitrosomonadaceae", "rank": "Family"}, "997329": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. 33944", "rank": "Strain"}, "582345": {"name": "Pseudomonas phage KPP10", "rank": "Species"}, "664980": {"name": "Tomato leaf curl Hainan virus", "rank": "Species"}, "1262914": {"name": "Phascolarctobacterium sp. CAG:207", "rank": "Species"}, "1262915": {"name": "Phascolarctobacterium sp. CAG:266", "rank": "Species"}, "1105327": {"name": "Vibrio phage VCY-phi", "rank": "Species"}, "1291358": {"name": "Leptospira interrogans serovar Pyrogenes str. Sri Lanka 14", "rank": "Strain"}, "1291359": {"name": "Leptospira interrogans serovar Pomona str. 2006006962", "rank": "Strain"}, "1291354": {"name": "Leptospira interrogans serovar Pyrogenes str. Sri Lanka 46", "rank": "Strain"}, "1291355": {"name": "Leptospira interrogans serovar Pyrogenes str. Sri Lanka 39", "rank": "Strain"}, "1291356": {"name": "Leptospira interrogans serovar Pyrogenes str. Sri Lanka 30", "rank": "Strain"}, "1291357": {"name": "Leptospira interrogans serovar Pyrogenes str. 2006006973", "rank": "Strain"}, "1291351": {"name": "Leptospira interrogans serovar Icterohaemorrhagiae str. RGA", "rank": "Strain"}, "1291352": {"name": "Leptospira interrogans serovar Icterohaemorrhagiae str. 201100516", "rank": "Strain"}, "1291353": {"name": "Leptospira interrogans serovar Icterohaemorrhagiae str. Kantorowic", "rank": "Strain"}, "996634": {"name": "Corynebacterium ulcerans 0102", "rank": "Strain"}, "996637": {"name": "Streptomyces griseoaurantiacus M045", "rank": "Strain"}, "111970": {"name": "Kyuri green mottle mosaic virus", "rank": "Species"}, "996633": {"name": "Salmonella enterica subsp. enterica serovar Typhimurium str. L-3553", "rank": "Strain"}, "1265641": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 34.H.09", "rank": "Strain"}, "1265640": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 29.O.08", "rank": "Strain"}, "1265643": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 11.A.05", "rank": "Strain"}, "1265642": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 06.O.05", "rank": "Strain"}, "1265645": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 27.O.98", "rank": "Strain"}, "1265644": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 18.H.07", "rank": "Strain"}, "1265647": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 39.O.03", "rank": "Strain"}, "1265646": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 32.A.00", "rank": "Strain"}, "1265648": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 42.E.09", "rank": "Strain"}, "1045778": {"name": "Helicoverpa armigera densovirus", "rank": "Strain"}, "322019": {"name": "Acanthocystis turfacea Chlorella virus 1", "rank": "Species"}, "1412754": {"name": "Staphylococcus aureus H87668", "rank": "Strain"}, "1485922": {"name": "Beauveria bassiana victorivirus NZL/1980", "rank": "Species"}, "1094491": {"name": "Bartonella bovis 91-4", "rank": "Strain"}, "1239786": {"name": "Streptococcus pneumoniae 801", "rank": "Strain"}, "796732": {"name": "Salmonella enterica subsp. enterica serovar Newport str. CVM 22513", "rank": "Strain"}, "796733": {"name": "Salmonella enterica subsp. enterica serovar Newport str. CVM 21550", "rank": "Strain"}, "796730": {"name": "Salmonella enterica subsp. enterica serovar Newport str. CVM 22425", "rank": "Strain"}, "796731": {"name": "Salmonella enterica subsp. enterica serovar Newport str. CVM 21538", "rank": "Strain"}, "796736": {"name": "Salmonella enterica subsp. enterica serovar Newport str. CVM 19449", "rank": "Strain"}, "796737": {"name": "Salmonella enterica subsp. enterica serovar Newport str. CVM 19447", "rank": "Strain"}, "796734": {"name": "Salmonella enterica subsp. enterica serovar Newport str. CVM 35202", "rank": "Strain"}, "796735": {"name": "Salmonella enterica subsp. enterica serovar Newport str. CVM 19567", "rank": "Strain"}, "213633": {"name": "Providence virus", "rank": "Species"}, "213631": {"name": "Planktothrix agardhii NIVA-CYA 34", "rank": "Strain"}, "757421": {"name": "Mycobacterium tuberculosis H37RvLP", "rank": "Strain"}, "757425": {"name": "Campylobacter jejuni subsp. jejuni ICDCCJ07001", "rank": "Strain"}, "757424": {"name": "Herbaspirillum seropedicae SmR1", "rank": "Strain"}, "1159058": {"name": "Helicobacter pylori GAM96Ai", "rank": "Strain"}, "1159059": {"name": "Helicobacter pylori GAMchJs106B", "rank": "Strain"}, "1385727": {"name": "Bacillus amyloliquefaciens subsp. plantarum NAU-B3", "rank": "Strain"}, "1159057": {"name": "Helicobacter pylori GAM93Bi", "rank": "Strain"}, "1449353": {"name": "Streptacidiphilus oryzae TH49", "rank": "Strain"}, "1449352": {"name": "Streptacidiphilus albus JL83", "rank": "Strain"}, "1449351": {"name": "Roseivivax isoporae LMG 25204", "rank": "Strain"}, "1449350": {"name": "Roseivivax halodurans JCM 10272", "rank": "Strain"}, "1449357": {"name": "Thermus tengchongensis YIM 77401", "rank": "Strain"}, "1187128": {"name": "Acinetobacter bacteriophage AP22", "rank": "Species"}, "1449355": {"name": "Streptomyces yeochonensis CN732", "rank": "Strain"}, "1159052": {"name": "Helicobacter pylori GAM42Ai", "rank": "Strain"}, "1449358": {"name": "Vibrio parahaemolyticus M0605", "rank": "Strain"}, "33941": {"name": "Geobacillus thermoleovorans", "rank": "Species"}, "1159050": {"name": "Helicobacter pylori GAM268Bii", "rank": "Strain"}, "1159051": {"name": "Helicobacter pylori GAM270ASi", "rank": "Strain"}, "1182193": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN000963", "rank": "Strain"}, "1182192": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN000962", "rank": "Strain"}, "1197174": {"name": "Alishewanella aestuarii B11", "rank": "Strain"}, "1182191": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN000961", "rank": "Strain"}, "1331217": {"name": "Bordetella bronchiseptica M435/02/3", "rank": "Strain"}, "361050": {"name": "Rubritalea", "rank": "Genus"}, "361055": {"name": "Rubritalea marina", "rank": "Species"}, "869816": {"name": "Staphylococcus aureus subsp. aureus JKD6159", "rank": "Strain"}, "1357713": {"name": "Bacillus phage phiCM3", "rank": "Species"}, "169690": {"name": "Chilli leaf curl betasatellite", "rank": "Species"}, "666363": {"name": "Drosophila melanogaster sigmavirus AP30", "rank": "Strain"}, "397864": {"name": "Barnesiella", "rank": "Genus"}, "1408": {"name": "Bacillus pumilus", "rank": "Species"}, "1402": {"name": "Bacillus licheniformis", "rank": "Species"}, "104366": {"name": "Pleurotaceae", "rank": "Family"}, "1407": {"name": "Bacillus psychrosaccharolyticus", "rank": "Species"}, "1406": {"name": "Paenibacillus polymyxa", "rank": "Species"}, "1405": {"name": "Bacillus mycoides", "rank": "Species"}, "1404": {"name": "Bacillus megaterium", "rank": "Species"}, "1175445": {"name": "Methanocella arvoryzae", "rank": "Species"}, "317735": {"name": "Enterococcus caccae", "rank": "Species"}, "86795": {"name": "Marmoricola", "rank": "Genus"}, "457398": {"name": "Desulfovibrio sp. 3_1_syn3", "rank": "Species"}, "457396": {"name": "Clostridium sp. 7_2_43FAA", "rank": "Species"}, "457394": {"name": "Bacteroides sp. 4_3_47FAA", "rank": "Species"}, "457395": {"name": "Bacteroides sp. 9_1_42FAA", "rank": "Species"}, "543372": {"name": "Thermoanaerobacterales Family IV. Incertae Sedis", "rank": "Family"}, "457393": {"name": "Bacteroides sp. 4_1_36", "rank": "Species"}, "457390": {"name": "Bacteroides sp. 3_1_23", "rank": "Species"}, "543371": {"name": "Thermoanaerobacterales Family III. Incertae Sedis", "rank": "Family"}, "83560": {"name": "Chlamydia muridarum", "rank": "Species"}, "1423466": {"name": "Mycobacterium tuberculosis BTB07-246", "rank": "Strain"}, "1158688": {"name": "Staphylococcus aureus M0580", "rank": "Strain"}, "1158689": {"name": "Staphylococcus aureus M0602", "rank": "Strain"}, "1158684": {"name": "Staphylococcus aureus M0536", "rank": "Strain"}, "1158685": {"name": "Staphylococcus aureus M0539", "rank": "Strain"}, "1158686": {"name": "Staphylococcus aureus M0547", "rank": "Strain"}, "1158687": {"name": "Staphylococcus aureus M0565", "rank": "Strain"}, "1158680": {"name": "Pseudomonas phage NH-4", "rank": "Species"}, "1158682": {"name": "Staphylococcus aureus M0528", "rank": "Strain"}, "1158683": {"name": "Staphylococcus aureus M0531", "rank": "Strain"}, "437329": {"name": "Burkholderia phage BcepGomr", "rank": "Species"}, "880447": {"name": "Mycoplasma leachii PG50", "rank": "Strain"}, "870903": {"name": "Terriglobus saanensis", "rank": "Species"}, "1159023": {"name": "Helicobacter pylori GAM112Ai", "rank": "Strain"}, "480119": {"name": "Acinetobacter baumannii AB0057", "rank": "Strain"}, "998820": {"name": "Lactobacillus casei BD-II", "rank": "Strain"}, "998829": {"name": "Zalophus californianus papillomavirus 1", "rank": "Strain"}, "118140": {"name": "Porcine teschovirus", "rank": "Species"}, "1194404": {"name": "Pseudomonas syringae pv. actinidiae ICMP 18807", "rank": "Strain"}, "1144311": {"name": "Brevibacillus sp. CF112", "rank": "Species"}, "1194402": {"name": "Pseudomonas syringae pv. actinidiae ICMP 18883", "rank": "Strain"}, "1194401": {"name": "Pseudomonas syringae pv. actinidiae ICMP 19094", "rank": "Strain"}, "182102": {"name": "Williamsiaceae", "rank": "Family"}, "1194409": {"name": "Pseudomonas syringae pv. actinidiae ICMP 19104", "rank": "Strain"}, "1561068": {"name": "Acinetobacter sp. neg1", "rank": "Species"}, "1159022": {"name": "Helicobacter pylori GAM105Ai", "rank": "Strain"}, "1395574": {"name": "Klebsiella pneumoniae subsp. pneumoniae KpQ24", "rank": "Strain"}, "1395572": {"name": "Streptomyces albulus PD-1", "rank": "Strain"}, "1395571": {"name": "Pseudomonas taeanensis MS-3", "rank": "Strain"}, "1395579": {"name": "Enterobacter sp. DC3", "rank": "Species"}, "1194423": {"name": "Pseudomonas syringae pv. actinidiae ICMP 19071", "rank": "Strain"}, "453228": {"name": "Desulfarculaceae", "rank": "Family"}, "327817": {"name": "Desulfotomaculum carboxydivorans", "rank": "Species"}, "39718": {"name": "Unclassified Bunyaviridae", "rank": "No rank"}, "367189": {"name": "Haladaptatus paucihalophilus", "rank": "Species"}, "367188": {"name": "Haladaptatus", "rank": "Genus"}, "1449080": {"name": "Thermus sp. YIM 77409", "rank": "Species"}, "1321951": {"name": "Lactobacillus casei LcY", "rank": "Strain"}, "457570": {"name": "Natranaerobius thermophilus JW/NM-WN-LF", "rank": "Strain"}, "1159020": {"name": "Helicobacter pylori GAM101Biv", "rank": "Strain"}, "451344": {"name": "Unclassified archaeal viruses", "rank": "No rank"}, "180882": {"name": "Bacillus thuringiensis serovar monterrey", "rank": "Strain"}, "1388594": {"name": "Staphylococcus aureus M0808", "rank": "Strain"}, "366586": {"name": "Ruania albidiflava", "rank": "Species"}, "404900": {"name": "Geminicoccus roseus", "rank": "Species"}, "1358440": {"name": "Lutibaculum baratangense", "rank": "Species"}, "71388": {"name": "Vibrio halioticoli", "rank": "Species"}, "367459": {"name": "Peptoclostridium difficile QCD-32g58", "rank": "Strain"}, "883130": {"name": "Staphylococcus epidermidis BVS058A4", "rank": "Strain"}, "1212557": {"name": "Salmonella enterica subsp. enterica serovar Hartford str. 06-0676", "rank": "Strain"}, "1212554": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. 06-0784", "rank": "Strain"}, "1212559": {"name": "Salmonella enterica subsp. enterica serovar Hadar str. 2011K-0112", "rank": "Strain"}, "443150": {"name": "Mycobacterium tuberculosis CCDC5180", "rank": "Strain"}, "443152": {"name": "Marinobacter algicola DG893", "rank": "Strain"}, "545264": {"name": "Thioalkalivibrio sp. AKL11", "rank": "Species"}, "12059": {"name": "Enterovirus", "rank": "Genus"}, "12058": {"name": "Picornaviridae", "rank": "Family"}, "12051": {"name": "Marafivirus", "rank": "Genus"}, "12050": {"name": "Waikavirus", "rank": "Genus"}, "12057": {"name": "Sequivirus", "rank": "Genus"}, "12056": {"name": "Tobacco necrosis virus D", "rank": "Species"}, "12055": {"name": "Tobacco necrosis virus A", "rank": "Species"}, "1236954": {"name": "Bacillus mannanilyticus JCM 10596", "rank": "Strain"}, "1236957": {"name": "Kordiimonas gwangyangensis JCM 12864", "rank": "Strain"}, "1337093": {"name": "Loktanella cinnabarina LL-001", "rank": "Strain"}, "1236959": {"name": "Methylobacillus glycogenes JCM 2850", "rank": "Strain"}, "1136105": {"name": "Tolypothrix campylonemoides", "rank": "Species"}, "436447": {"name": "Brevicoryne brassicae picorna-like virus", "rank": "Species"}, "45667": {"name": "Halobacillus", "rank": "Genus"}, "881893": {"name": "Fulvivirga imtechensis", "rank": "Species"}, "1202716": {"name": "Rhodomicrobium udaipurense", "rank": "Species"}, "45663": {"name": "Desulfohalobium retbaense", "rank": "Species"}, "1095701": {"name": "Neisseria meningitidis NM422", "rank": "Strain"}, "265729": {"name": "Bacillus cibi", "rank": "Species"}, "1155766": {"name": "Enterococcus faecium Aus0004", "rank": "Strain"}, "45669": {"name": "Salinicoccus", "rank": "Genus"}, "235899": {"name": "Nautiliales", "rank": "Order"}, "1448674": {"name": "Mycobacterium tuberculosis M1404", "rank": "Strain"}, "939922": {"name": "Unclassified Victorivirus", "rank": "No rank"}, "939923": {"name": "Tolypocladium cylindrosporum virus 1", "rank": "Species"}, "939920": {"name": "Verrucomicrobia bacterium SCGC AAA300-N18", "rank": "Species"}, "939921": {"name": "Verrucomicrobia bacterium SCGC AAA300-O17", "rank": "Species"}, "1316932": {"name": "Mannheimia haemolytica M42548", "rank": "Strain"}, "1316933": {"name": "Lactobacillus rhamnosus LOCK900", "rank": "Strain"}, "1316930": {"name": "Mycoplasma bovis CQ-W70", "rank": "Strain"}, "1316931": {"name": "Clostridium butyricum DSM 10702", "rank": "Strain"}, "1316936": {"name": "Phaeospirillum fulvum MGU-K5", "rank": "Strain"}, "1316937": {"name": "Clostridium diolis DSM 15410", "rank": "Strain"}, "1316934": {"name": "Pseudomonas fuscovaginae SE-1", "rank": "Strain"}, "1316935": {"name": "Thermus thermophilus ATCC 33923", "rank": "Strain"}, "1316938": {"name": "Klebsiella pneumoniae ATCC 25955", "rank": "Strain"}, "1316939": {"name": "Klebsiella pneumoniae G5-2", "rank": "Strain"}, "146922": {"name": "Streptomyces griseofuscus", "rank": "Species"}, "221029": {"name": "Enterobacteria phage ST104", "rank": "Species"}, "221027": {"name": "Treponema putidum", "rank": "Species"}, "307240": {"name": "Bacillus phage GIL16c", "rank": "Species"}, "519050": {"name": "Lactobacillus sucicola", "rank": "Species"}, "390978": {"name": "Mannheimia phage phiMHaA1", "rank": "Species"}, "948": {"name": "Anaplasma phagocytophilum", "rank": "Species"}, "419015": {"name": "Alloscardovia omnicolens", "rank": "Species"}, "419014": {"name": "Alloscardovia", "rank": "Genus"}, "944": {"name": "Ehrlichia canis", "rank": "Species"}, "945": {"name": "Ehrlichia chaffeensis", "rank": "Species"}, "644223": {"name": "Komagataella pastoris GS115", "rank": "Strain"}, "940": {"name": "Hydrogenobacter thermophilus", "rank": "Species"}, "942": {"name": "Anaplasmataceae", "rank": "Family"}, "943": {"name": "Ehrlichia", "rank": "Genus"}, "1431453": {"name": "Ralstonia solanacearum P673", "rank": "Strain"}, "1431456": {"name": "Hunnivirus", "rank": "Genus"}, "44001": {"name": "Caldicellulosiruptor saccharolyticus", "rank": "Species"}, "44000": {"name": "Caldicellulosiruptor", "rank": "Genus"}, "1413580": {"name": "Staphylococcus aureus DICM09/01587-13HST", "rank": "Strain"}, "44009": {"name": "Enterococcus dispar", "rank": "Species"}, "44008": {"name": "Enterococcus cecorum", "rank": "Species"}, "585154": {"name": "Staphylococcus aureus subsp. aureus EMRSA16", "rank": "Strain"}, "1204414": {"name": "Corynebacterium glutamicum K051", "rank": "Strain"}, "585150": {"name": "Staphylococcus aureus subsp. aureus C160", "rank": "Strain"}, "1038870": {"name": "Burkholderia mimosarum STM 3621", "rank": "Strain"}, "1409605": {"name": "Staphylococcus aureus UCIM6075", "rank": "Strain"}, "1409604": {"name": "Staphylococcus aureus OCMM6071", "rank": "Strain"}, "1409607": {"name": "Staphylococcus aureus MISS6134", "rank": "Strain"}, "1409606": {"name": "Staphylococcus aureus UCIM6077", "rank": "Strain"}, "1409601": {"name": "Staphylococcus aureus FVRH6022", "rank": "Strain"}, "1444210": {"name": "Escherichia coli 2-474-04_S4_C1", "rank": "Strain"}, "1409603": {"name": "Staphylococcus aureus KINW6019", "rank": "Strain"}, "1444212": {"name": "Escherichia coli 5-366-08_S4_C1", "rank": "Strain"}, "1281027": {"name": "Escherichia coli HVH 90 (4-3191362)", "rank": "Strain"}, "1069985": {"name": "Pedobacter kyungheensis", "rank": "Species"}, "1281025": {"name": "Escherichia coli HVH 88 (4-5854636)", "rank": "Strain"}, "1281024": {"name": "Escherichia coli HVH 87 (4-5977630)", "rank": "Strain"}, "1409609": {"name": "Staphylococcus aureus UCIM6080", "rank": "Strain"}, "1409608": {"name": "Staphylococcus aureus KINB6009", "rank": "Strain"}, "1281021": {"name": "Escherichia coli HVH 84 (4-1021478)", "rank": "Strain"}, "1281020": {"name": "Escherichia coli HVH 83 (4-2051087)", "rank": "Strain"}, "1422530": {"name": "Staphylococcus aureus VET0247R", "rank": "Strain"}, "1422531": {"name": "Staphylococcus aureus VET0249R", "rank": "Strain"}, "1422532": {"name": "Staphylococcus aureus VET0251R", "rank": "Strain"}, "1422533": {"name": "Staphylococcus aureus VET0252R", "rank": "Strain"}, "1422534": {"name": "Staphylococcus aureus VET0253R", "rank": "Strain"}, "1422535": {"name": "Staphylococcus aureus VET0254R", "rank": "Strain"}, "1422536": {"name": "Staphylococcus aureus VET0256R", "rank": "Strain"}, "1422537": {"name": "Staphylococcus aureus VET0259R", "rank": "Strain"}, "629742": {"name": "Staphylococcus hominis SK119", "rank": "Strain"}, "1422539": {"name": "Staphylococcus aureus VET0261R", "rank": "Strain"}, "629741": {"name": "Kingella oralis ATCC 51147", "rank": "Strain"}, "645578": {"name": "Methylovulum miyakonense", "rank": "Species"}, "549169": {"name": "Pseudogulbenkiania ferrooxidans", "rank": "Species"}, "1333550": {"name": "Pseudomonas aeruginosa str. E2UoS", "rank": "Strain"}, "34035": {"name": "Unclassified Epsilonproteobacteria", "rank": "No rank"}, "34037": {"name": "Rahnella", "rank": "Genus"}, "34031": {"name": "Desulfobacter vibrioformis", "rank": "Species"}, "1286084": {"name": "Yersinia pseudotuberculosis B-6796", "rank": "Strain"}, "1286085": {"name": "Yersinia pseudotuberculosis B-6862", "rank": "Strain"}, "1286086": {"name": "Yersinia pseudotuberculosis B-6863", "rank": "Strain"}, "1286087": {"name": "Yersinia pseudotuberculosis B-6864", "rank": "Strain"}, "1286088": {"name": "Yersinia pseudotuberculosis B-6865", "rank": "Strain"}, "1286089": {"name": "Yersinia pseudotuberculosis B-6866", "rank": "Strain"}, "248496": {"name": "Sulfolobus virus Kamchatka 1", "rank": "Species"}, "683173": {"name": "Astrovirus VA2", "rank": "Species"}, "1250006": {"name": "Polaribacter sp. Hel_I_88", "rank": "Species"}, "119066": {"name": "Unclassified Betaproteobacteria", "rank": "No rank"}, "187878": {"name": "Thermococcus gammatolerans", "rank": "Species"}, "270473": {"name": "Pneumonia virus of mice J3666", "rank": "Strain"}, "270478": {"name": "Zantedeschia mild mosaic virus", "rank": "Species"}, "11885": {"name": "Fujinami sarcoma virus", "rank": "Species"}, "11884": {"name": "Y73 sarcoma virus", "rank": "Species"}, "11886": {"name": "Rous sarcoma virus", "rank": "Species"}, "59376": {"name": "Ectropis obliqua nucleopolyhedrovirus", "rank": "Species"}, "170187": {"name": "Streptococcus pneumoniae TIGR4", "rank": "Strain"}, "257313": {"name": "Bordetella pertussis Tohama I", "rank": "Strain"}, "890402": {"name": "Bifidobacterium longum subsp. longum BBMN68", "rank": "Strain"}, "242703": {"name": "Acidilobus saccharovorans", "rank": "Species"}, "1337877": {"name": "Paenibacillus phage phiIBB_Pl23", "rank": "Species"}, "1439874": {"name": "Bacillus anthracis CZC5", "rank": "Strain"}, "371401": {"name": "Siegesbeckia yellow vein virus", "rank": "Species"}, "439220": {"name": "Streptococcus caballi", "rank": "Species"}, "321846": {"name": "Pseudomonas simiae", "rank": "Species"}, "1282664": {"name": "Streptococcus tigurinus AZ_3a", "rank": "Strain"}, "183980": {"name": "Archaeoglobi", "rank": "Class"}, "552525": {"name": "Bacillus phage IEBH", "rank": "Species"}, "406562": {"name": "Streptococcus pneumoniae SP19-BS75", "rank": "Strain"}, "406561": {"name": "Streptococcus pneumoniae SP18-BS74", "rank": "Strain"}, "552526": {"name": "Streptococcus equi subsp. zooepidemicus MGCS10565", "rank": "Strain"}, "1427301": {"name": "Mycobacterium tuberculosis XTB13-230", "rank": "Strain"}, "1427302": {"name": "Mycobacterium tuberculosis XTB13-231", "rank": "Strain"}, "1427303": {"name": "Mycobacterium tuberculosis XTB13-232", "rank": "Strain"}, "1430411": {"name": "Mycobacterium phage HufflyPuff", "rank": "Species"}, "70791": {"name": "Nectria haematococca mpVI", "rank": "Strain"}, "926035": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. 77-2659", "rank": "Strain"}, "926036": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. 78-1757", "rank": "Strain"}, "926037": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. 22510-1", "rank": "Strain"}, "926030": {"name": "Escherichia coli O55:H7 str. USDA 5905", "rank": "Strain"}, "926032": {"name": "Escherichia coli O157:H7 str. LSU-61", "rank": "Strain"}, "1427305": {"name": "Mycobacterium tuberculosis XTB13-234", "rank": "Strain"}, "592010": {"name": "Abiotrophia defectiva ATCC 49176", "rank": "Strain"}, "592015": {"name": "Anaerobaculum hydrogeniformans ATCC BAA-1850", "rank": "Strain"}, "592014": {"name": "Acinetobacter baumannii 6013113", "rank": "Strain"}, "1427307": {"name": "Mycobacterium tuberculosis XTB13-237", "rank": "Strain"}, "1070842": {"name": "Enterobacter cloacae IIT-BT 08", "rank": "Strain"}, "1234381": {"name": "Thauera aminoaromatica S2", "rank": "Strain"}, "69781": {"name": "Penicillium oxalicum", "rank": "Species"}, "1527770": {"name": "Rhizobium phage vB_RleM_P10VF", "rank": "Species"}, "1386079": {"name": "Alcaligenes sp. EGD-AK7", "rank": "Species"}, "541000": {"name": "Ruminococcaceae", "rank": "Family"}, "1422294": {"name": "Staphylococcus aureus DAR3179", "rank": "Strain"}, "367479": {"name": "Unclassified Sulfolobales", "rank": "No rank"}, "183405": {"name": "Rotavirus F", "rank": "Species"}, "183407": {"name": "Rotavirus G", "rank": "Species"}, "1226633": {"name": "Fusobacterium necrophorum subsp. funduliforme B35", "rank": "Strain"}, "1002672": {"name": "Candidatus Pelagibacter sp. IMCC9063", "rank": "Species"}, "134277": {"name": "Primary endosymbiont of Heteropsylla cubana", "rank": "Strain"}, "1075768": {"name": "Janthinobacterium sp. CG3", "rank": "Species"}, "156454": {"name": "Anaeroglobus", "rank": "Genus"}, "443218": {"name": "Amycolicicoccus subflavus DQS3-9A1", "rank": "Strain"}, "156456": {"name": "Anaeroglobus geminatus", "rank": "Species"}, "10334": {"name": "Felid herpesvirus 1", "rank": "Species"}, "10335": {"name": "Human herpesvirus 3", "rank": "Species"}, "1122917": {"name": "Paenibacillus daejeonensis DSM 15491", "rank": "Strain"}, "1122916": {"name": "Paenibacillus assamensis DSM 18201", "rank": "Strain"}, "1122919": {"name": "Paenibacillus ginsengihumi DSM 21568", "rank": "Strain"}, "1122918": {"name": "Paenibacillus fonticola DSM 21315", "rank": "Strain"}, "1173427": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN000189", "rank": "Strain"}, "1173426": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN000188", "rank": "Strain"}, "1173425": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN000185", "rank": "Strain"}, "1173424": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN000181", "rank": "Strain"}, "1173422": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN000229", "rank": "Strain"}, "1173421": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN000226", "rank": "Strain"}, "1173420": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN000222", "rank": "Strain"}, "1301080": {"name": "Candidatus Nasuia", "rank": "Genus"}, "1301086": {"name": "Bacillus sp. GeD10", "rank": "Species"}, "1301087": {"name": "Sphingobium japonicum BiD32", "rank": "Strain"}, "1173429": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN000193", "rank": "Strain"}, "1173428": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN000190", "rank": "Strain"}, "128708": {"name": "His 1 virus", "rank": "Species"}, "1172205": {"name": "Bordetella holmesii 44057", "rank": "Strain"}, "376686": {"name": "Flavobacterium johnsoniae UW101", "rank": "Strain"}, "1302616": {"name": "Salmonella enterica subsp. enterica serovar Aqua str. NVSL2001", "rank": "Strain"}, "1389959": {"name": "Mycobacterium bovis AN5", "rank": "Strain"}, "1389955": {"name": "Escherichia coli ATCC 35150", "rank": "Strain"}, "187977": {"name": "Wild potato mosaic virus", "rank": "Species"}, "42373": {"name": "Ophiostoma novo-ulmi", "rank": "Species"}, "1302614": {"name": "Nanoarchaeota archaeon SCGC AAA011-J2", "rank": "Species"}, "324685": {"name": "Duck circovirus", "rank": "Species"}, "765874": {"name": "Corynebacterium pseudotuberculosis FRC41", "rank": "Strain"}, "765873": {"name": "Ectothiorhodospira haloalkaliphila ATCC 51935", "rank": "Strain"}, "36064": {"name": "Cantharellales", "rank": "Order"}, "1302613": {"name": "Desulfobulbus sp. oral taxon 041 str. Dsb4", "rank": "Strain"}, "326069": {"name": "Gramella portivictoriae", "rank": "Species"}, "422608": {"name": "Unclassified Herpotrichiellaceae", "rank": "No rank"}, "53363": {"name": "Brevibacterium mcbrellneri", "rank": "Species"}, "43761": {"name": "Barfin flounder nervous necrosis virus", "rank": "Species"}, "312008": {"name": "Citrus sudden death-associated virus", "rank": "Species"}, "1233170": {"name": "Clostridium bifermentans ATCC 19299", "rank": "Strain"}, "5970": {"name": "Exophiala dermatitidis", "rank": "Species"}, "462910": {"name": "Pontibacillus yanchengensis", "rank": "Species"}, "38062": {"name": "Cassava vein mosaic virus", "rank": "Species"}, "38063": {"name": "Unclassified Halobacteriales", "rank": "No rank"}, "1490": {"name": "Clostridium bifermentans", "rank": "Species"}, "559189": {"name": "Clostridium phage phiCD27", "rank": "Species"}, "1491": {"name": "Clostridium botulinum", "rank": "Species"}, "550673": {"name": "Escherichia coli B108", "rank": "Strain"}, "550672": {"name": "Escherichia coli B088", "rank": "Strain"}, "559180": {"name": "Stretch Lagoon orbivirus", "rank": "Species"}, "550677": {"name": "Escherichia coli B354", "rank": "Strain"}, "550676": {"name": "Escherichia coli B185", "rank": "Strain"}, "550674": {"name": "Escherichia coli B093", "rank": "Strain"}, "11060": {"name": "Dengue virus 2", "rank": "Strain"}, "29423": {"name": "Legionella oakridgensis", "rank": "Species"}, "11069": {"name": "Dengue virus 3", "rank": "Strain"}, "1086800": {"name": "Mycobacterium phage Violet", "rank": "Species"}, "981539": {"name": "Streptococcus gallolyticus subsp. gallolyticus ATCC 43143", "rank": "Strain"}, "1493858": {"name": "Goose calicivirus", "rank": "Species"}, "656405": {"name": "Escherichia coli H494", "rank": "Strain"}, "1157392": {"name": "Enterococcus faecalis EnGen0206", "rank": "Strain"}, "981540": {"name": "Streptococcus pasteurianus ATCC 43144", "rank": "Strain"}, "1157418": {"name": "Enterococcus faecium EnGen0124", "rank": "Strain"}, "1157419": {"name": "Enterococcus faecium EnGen0125", "rank": "Strain"}, "1262518": {"name": "Leuconostoc phage phiLN25", "rank": "Species"}, "1157416": {"name": "Enterococcus faecium EnGen0131", "rank": "Strain"}, "1157417": {"name": "Enterococcus hirae EnGen0127", "rank": "Strain"}, "1157410": {"name": "Enterococcus faecalis EnGen0224", "rank": "Strain"}, "1157411": {"name": "Enterococcus faecalis EnGen0225", "rank": "Strain"}, "1157412": {"name": "Enterococcus faecalis EnGen0226", "rank": "Strain"}, "1157396": {"name": "Enterococcus faecalis EnGen0210", "rank": "Strain"}, "2148": {"name": "Acholeplasma laidlawii", "rank": "Species"}, "2147": {"name": "Acholeplasma", "rank": "Genus"}, "2146": {"name": "Acholeplasmataceae", "rank": "Family"}, "2145": {"name": "Spiroplasma taiwanense", "rank": "Species"}, "2144": {"name": "Spiroplasma mirum", "rank": "Species"}, "1133852": {"name": "Escherichia coli O104:H4 str. 2011C-3493", "rank": "Strain"}, "1133853": {"name": "Escherichia coli O104:H4 str. 2009EL-2071", "rank": "Strain"}, "1133850": {"name": "Streptomyces hygroscopicus subsp. jinggangensis 5008", "rank": "Strain"}, "764101": {"name": "Saccharomyces cerevisiae FostersO", "rank": "Strain"}, "598659": {"name": "Nautilia profundicola AmH", "rank": "Strain"}, "1330039": {"name": "Acinetobacter gyllenbergii MTCC 11365", "rank": "Strain"}, "1330038": {"name": "Acinetobacter guillouiae MSP4-18", "rank": "Strain"}, "35718": {"name": "Chaetomiaceae", "rank": "Family"}, "1498499": {"name": "Legionella norrlandica", "rank": "Species"}, "1330037": {"name": "Acinetobacter gerneri MTCC 9824", "rank": "Strain"}, "1330036": {"name": "Osedax symbiont Rs1", "rank": "Species"}, "1330035": {"name": "Osedax symbiont Rs2", "rank": "Species"}, "1170703": {"name": "Brucella suis 01-5744", "rank": "Strain"}, "1388739": {"name": "Brucella suis 06-988-1656", "rank": "Strain"}, "332470": {"name": "Unclassified Potyvirus", "rank": "No rank"}, "1385521": {"name": "Knoellia subterranea KCTC 19937", "rank": "Strain"}, "1385520": {"name": "Knoellia sinensis KCTC 19936", "rank": "Strain"}, "655606": {"name": "Leptospirillum sp. Group I", "rank": "Species group"}, "1388734": {"name": "Staphylococcus aureus M0974", "rank": "Strain"}, "1388733": {"name": "Staphylococcus aureus M0973", "rank": "Strain"}, "1388732": {"name": "Staphylococcus aureus M0972", "rank": "Strain"}, "1388731": {"name": "Staphylococcus aureus M0971", "rank": "Strain"}, "655603": {"name": "Human klassevirus 1", "rank": "Strain"}, "1411558": {"name": "Staphylococcus aureus M74952", "rank": "Strain"}, "1411559": {"name": "Staphylococcus aureus T23068", "rank": "Strain"}, "392733": {"name": "Terriglobus", "rank": "Genus"}, "722911": {"name": "Bifidobacterium longum subsp. longum F8", "rank": "Strain"}, "1411555": {"name": "Staphylococcus aureus M68467", "rank": "Strain"}, "1411556": {"name": "Staphylococcus aureus M68475", "rank": "Strain"}, "1411557": {"name": "Staphylococcus aureus M71813", "rank": "Strain"}, "1411550": {"name": "Staphylococcus aureus M28112", "rank": "Strain"}, "158683": {"name": "Diadromus pulchellus ascovirus 4a", "rank": "Species"}, "1411552": {"name": "Staphylococcus aureus M39841", "rank": "Strain"}, "1411553": {"name": "Staphylococcus aureus M59498", "rank": "Strain"}, "1240759": {"name": "Escherichia coli O104:H4 str. Ec11-9941", "rank": "Strain"}, "749927": {"name": "Amycolatopsis mediterranei U32", "rank": "Strain"}, "75788": {"name": "Unclassified Rhodocyclaceae", "rank": "No rank"}, "240411": {"name": "Chitinimonas", "rank": "Genus"}, "1403540": {"name": "Halomonas sp. BC04", "rank": "Species"}, "1403542": {"name": "Lactobacillus plantarum LP91", "rank": "Strain"}, "393123": {"name": "Listeria monocytogenes FSL N1-017", "rank": "Strain"}, "1439132": {"name": "Streptococcus pyogenes ABC020044173", "rank": "Strain"}, "1194526": {"name": "Staphylococcus warneri SG1", "rank": "Strain"}, "526067": {"name": "Haloglycomyces albus", "rank": "Species"}, "1439135": {"name": "Streptococcus pyogenes ABC020044203", "rank": "Strain"}, "1439136": {"name": "Streptococcus pyogenes ABC020044412", "rank": "Strain"}, "1439137": {"name": "Streptococcus pyogenes ABC020046158", "rank": "Strain"}, "1439139": {"name": "Streptococcus pyogenes ABC020046230", "rank": "Strain"}, "1073986": {"name": "Halobellus", "rank": "Genus"}, "1073985": {"name": "Escherichia coli O104:H4 str. GOS1", "rank": "Strain"}, "320799": {"name": "Gordonia soli", "rank": "Species"}, "71548": {"name": "Sugarcane streak Egypt virus", "rank": "Species"}, "400122": {"name": "Finch circovirus", "rank": "Species"}, "223332": {"name": "Tobacco leaf curl Japan virus", "rank": "Species"}, "1649": {"name": "Kurthia", "rank": "Genus"}, "1648": {"name": "Erysipelothrix rhusiopathiae", "rank": "Species"}, "1583100": {"name": "Myroides sp. A21", "rank": "Species"}, "1645": {"name": "Renibacterium", "rank": "Genus"}, "1647": {"name": "Erysipelothrix", "rank": "Genus"}, "1646": {"name": "Renibacterium salmoninarum", "rank": "Species"}, "1641": {"name": "Listeria grayi", "rank": "Species"}, "1640": {"name": "Listeria seeligeri", "rank": "Species"}, "1643": {"name": "Listeria welshimeri", "rank": "Species"}, "1642": {"name": "Listeria innocua", "rank": "Species"}, "1453289": {"name": "Candidatus Ruthia magnifica UCD-CM", "rank": "Strain"}, "1095727": {"name": "Streptococcus sp. SK643", "rank": "Species"}, "1158183": {"name": "Thioalkalivibrio sp. ARh5", "rank": "Species"}, "1095726": {"name": "Streptococcus sp. SK140", "rank": "Species"}, "210592": {"name": "Unclassified Rickettsiales", "rank": "No rank"}, "464980": {"name": "Canine papillomavirus 4", "rank": "Strain"}, "1412707": {"name": "Staphylococcus aureus W75113", "rank": "Strain"}, "1236976": {"name": "Paenibacillus pini JCM 16418", "rank": "Strain"}, "397865": {"name": "Barnesiella viscericola", "rank": "Species"}, "469618": {"name": "Fusobacterium varium ATCC 27725", "rank": "Strain"}, "483913": {"name": "Bacillus subtilis subsp. inaquosorum", "rank": "Subspecies"}, "1392015": {"name": "Staphylococcus aureus M0987", "rank": "Strain"}, "1392014": {"name": "Staphylococcus aureus M0985", "rank": "Strain"}, "1392017": {"name": "Staphylococcus aureus M0989", "rank": "Strain"}, "1392016": {"name": "Staphylococcus aureus M0988", "rank": "Strain"}, "1392011": {"name": "Staphylococcus aureus M0982", "rank": "Strain"}, "1392010": {"name": "Staphylococcus aureus M0981", "rank": "Strain"}, "1392013": {"name": "Staphylococcus aureus M0984", "rank": "Strain"}, "1392012": {"name": "Staphylococcus aureus M0983", "rank": "Strain"}, "1392019": {"name": "Staphylococcus aureus M0992", "rank": "Strain"}, "1392018": {"name": "Staphylococcus aureus M0991", "rank": "Strain"}, "1412709": {"name": "Staphylococcus aureus W75132", "rank": "Strain"}, "1421921": {"name": "Mycobacterium tuberculosis TB_RSA05", "rank": "Strain"}, "129862": {"name": "Phage Gifsy-2", "rank": "Species"}, "129861": {"name": "Phage Gifsy-1", "rank": "Species"}, "565537": {"name": "Human papillomavirus type 108", "rank": "Strain"}, "356114": {"name": "Hepatitis C virus genotype 3", "rank": "Strain"}, "217219": {"name": "Meganema perideroedes", "rank": "Species"}, "910027": {"name": "Unclassified candidate division BRC1", "rank": "No rank"}, "665937": {"name": "Anaerostipes sp. 3_2_56FAA", "rank": "Species"}, "665939": {"name": "Campylobacter sp. 10_1_50", "rank": "Species"}, "665938": {"name": "Bacteroides sp. 2_1_56FAA", "rank": "Species"}, "871521": {"name": "Sida golden mosaic Florida virus-Malvastrum", "rank": "Strain"}, "1388393": {"name": "Staphylococcus aureus M0593", "rank": "Strain"}, "428128": {"name": "Eubacterium siraeum DSM 15702", "rank": "Strain"}, "428127": {"name": "Eubacterium dolichum DSM 3991", "rank": "Strain"}, "428126": {"name": "Clostridium spiroforme DSM 1552", "rank": "Strain"}, "428125": {"name": "Clostridium leptum DSM 753", "rank": "Strain"}, "1086053": {"name": "Rhizoctonia solani AG-3", "rank": "Strain"}, "167161": {"name": "Strawberry mottle virus", "rank": "Species"}, "167160": {"name": "Subgroup C", "rank": "No rank"}, "405441": {"name": "Xylella fastidiosa M23", "rank": "Strain"}, "239935": {"name": "Akkermansia muciniphila", "rank": "Species"}, "1217908": {"name": "Octadecabacter antarcticus", "rank": "Species"}, "113366": {"name": "Heliothis virescens ascovirus 3a", "rank": "Species"}, "1158184": {"name": "Thioalkalivibrio sp. ALM2T", "rank": "Species"}, "1402475": {"name": "Mycobacterium tuberculosis SK-C", "rank": "Strain"}, "857148": {"name": "Streptococcus mutans 2ST1", "rank": "Strain"}, "408719": {"name": "Sida yellow mosaic Yucatan virus", "rank": "Species"}, "1455288": {"name": "Mycobacterium tuberculosis NRITLD14", "rank": "Strain"}, "1455289": {"name": "Mycobacterium tuberculosis NRITLD15", "rank": "Strain"}, "479431": {"name": "Nakamurella multipartita DSM 44233", "rank": "Strain"}, "1455284": {"name": "Mycobacterium tuberculosis NRITLD10", "rank": "Strain"}, "1455285": {"name": "Mycobacterium tuberculosis NRITLD11", "rank": "Strain"}, "1455286": {"name": "Mycobacterium tuberculosis NRITLD12", "rank": "Strain"}, "1455287": {"name": "Mycobacterium tuberculosis NRITLD13", "rank": "Strain"}, "1455283": {"name": "Mycobacterium tuberculosis NRITLD09", "rank": "Strain"}, "717231": {"name": "Flexistipes sinusarabici DSM 4947", "rank": "Strain"}, "908010": {"name": "Bhendi yellow vein India betasatellite India:Aurangabad:OY164:2006", "rank": "Strain"}, "38804": {"name": "Yaba monkey tumor virus", "rank": "Species"}, "213118": {"name": "Desulfobacterales", "rank": "Order"}, "213119": {"name": "Desulfobacteraceae", "rank": "Family"}, "213116": {"name": "Desulfomicrobiaceae", "rank": "Family"}, "213117": {"name": "Desulfohalobiaceae", "rank": "Family"}, "754255": {"name": "Actinobacillus pleuropneumoniae serovar 4 str. M62", "rank": "Strain"}, "213115": {"name": "Desulfovibrionales", "rank": "Order"}, "213113": {"name": "Desulfurellales", "rank": "Order"}, "504937": {"name": "Haloterrigena salina", "rank": "Species"}, "585143": {"name": "Staphylococcus aureus subsp. aureus 55/2053", "rank": "Strain"}, "1236608": {"name": "Moraxella catarrhalis BBH18", "rank": "Strain"}, "550537": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. P125109", "rank": "Strain"}, "550538": {"name": "Salmonella enterica subsp. enterica serovar Gallinarum str. 287/91", "rank": "Strain"}, "49546": {"name": "Flavobacteriaceae", "rank": "Family"}, "1397881": {"name": "Mycobacterium tuberculosis TKK_02_0063", "rank": "Strain"}, "1397880": {"name": "Mycobacterium tuberculosis TKK_02_0062", "rank": "Strain"}, "1397883": {"name": "Mycobacterium tuberculosis TKK_02_0069", "rank": "Strain"}, "1397882": {"name": "Mycobacterium tuberculosis TKK_02_0068", "rank": "Strain"}, "1397885": {"name": "Mycobacterium tuberculosis TKK_02_0071", "rank": "Strain"}, "1310607": {"name": "Acinetobacter baumannii 625974", "rank": "Strain"}, "1397887": {"name": "Mycobacterium tuberculosis TKK_02_0077", "rank": "Strain"}, "1397886": {"name": "Mycobacterium tuberculosis TKK_02_0073", "rank": "Strain"}, "1397889": {"name": "Mycobacterium tuberculosis TKK_03_0018", "rank": "Strain"}, "1397888": {"name": "Mycobacterium tuberculosis TKK_02_0067", "rank": "Strain"}, "1169215": {"name": "Brucella abortus 84/26", "rank": "Strain"}, "1169214": {"name": "Brucella abortus 80/28", "rank": "Strain"}, "1169213": {"name": "Brucella abortus 78/14", "rank": "Strain"}, "1169212": {"name": "Brucella abortus 67/93", "rank": "Strain"}, "1169211": {"name": "Brucella abortus 65/63", "rank": "Strain"}, "1150398": {"name": "Arthrobacter sp. 9MFCol3.1", "rank": "Species"}, "1408868": {"name": "Borrelia burgdorferi IPT51", "rank": "Strain"}, "355276": {"name": "Leptospira borgpetersenii serovar Hardjo-bovis str. L550", "rank": "Strain"}, "355277": {"name": "Leptospira borgpetersenii serovar Hardjo-bovis str. JB197", "rank": "Strain"}, "1406840": {"name": "Flavobacterium beibuense F44-8", "rank": "Strain"}, "1408862": {"name": "Borrelia burgdorferi IPT26", "rank": "Strain"}, "1408863": {"name": "Borrelia burgdorferi IPT27", "rank": "Strain"}, "355278": {"name": "Leptospira biflexa serovar Patoc strain 'Patoc 1 (Ames)'", "rank": "Strain"}, "1408861": {"name": "Borrelia burgdorferi IPT24", "rank": "Strain"}, "1408866": {"name": "Borrelia burgdorferi IPT48", "rank": "Strain"}, "1408864": {"name": "Borrelia burgdorferi IPT35", "rank": "Strain"}, "419257": {"name": "Yersinia massiliensis", "rank": "Species"}, "253702": {"name": "Opuntia virus X", "rank": "Species"}, "253701": {"name": "Zygocactus virus X", "rank": "Species"}, "253700": {"name": "Schlumbergera virus X", "rank": "Species"}, "1051629": {"name": "Mycobacterium avium subsp. paratuberculosis JQ5", "rank": "Strain"}, "203168": {"name": "Grapevine leafroll-associated virus 6", "rank": "Species"}, "752555": {"name": "Prevotella bryantii B14", "rank": "Strain"}, "712461": {"name": "Prevotella sp. oral taxon 306", "rank": "Species"}, "712469": {"name": "Prevotella sp. oral taxon 473", "rank": "Species"}, "1388276": {"name": "Staphylococcus aureus M0416", "rank": "Strain"}, "1388277": {"name": "Staphylococcus aureus M0417", "rank": "Strain"}, "1388274": {"name": "Staphylococcus aureus M0413", "rank": "Strain"}, "1388275": {"name": "Staphylococcus aureus M0414", "rank": "Strain"}, "1388272": {"name": "Staphylococcus aureus M0411", "rank": "Strain"}, "1388273": {"name": "Staphylococcus aureus M0412", "rank": "Strain"}, "1388270": {"name": "Staphylococcus aureus M0409", "rank": "Strain"}, "1388271": {"name": "Staphylococcus aureus M0410", "rank": "Strain"}, "1388278": {"name": "Staphylococcus aureus M0419", "rank": "Strain"}, "1388279": {"name": "Staphylococcus aureus M0420", "rank": "Strain"}, "1390084": {"name": "Streptococcus pyogenes SP10-LAU", "rank": "Strain"}, "402650": {"name": "Actinomycetospora chiangmaiensis", "rank": "Species"}, "1244101": {"name": "Streptococcus agalactiae SGBS022", "rank": "Strain"}, "1244100": {"name": "Streptococcus agalactiae SGBS021", "rank": "Strain"}, "1390080": {"name": "Streptococcus pyogenes SP5-LAU", "rank": "Strain"}, "1390081": {"name": "Streptococcus pyogenes SP6-LAU", "rank": "Strain"}, "1390082": {"name": "Streptococcus pyogenes SP7-LAU", "rank": "Strain"}, "1390083": {"name": "Streptococcus pyogenes SP8-LAU", "rank": "Strain"}, "76875": {"name": "Broad bean wilt virus 2", "rank": "Species"}, "939316": {"name": "Alpha proteobacterium SCGC AAA288-E13", "rank": "Species"}, "43220": {"name": "Capronia", "rank": "Genus"}, "217215": {"name": "Mesoplasma grammopterae", "rank": "Species"}, "1168563": {"name": "Stenotrophomonas phage Smp131", "rank": "Species"}, "378534": {"name": "Pseudomonas sp. Eur1 9.41", "rank": "Species"}, "862720": {"name": "Acidovorax oryzae", "rank": "Species"}, "145259": {"name": "Leptospira biflexa serovar Patoc", "rank": "Strain"}, "1193058": {"name": "Leptospira santarosai str. 200403458", "rank": "Strain"}, "1193059": {"name": "Leptospira santarosai str. CBC1416", "rank": "Strain"}, "1193054": {"name": "Leptospira noguchii str. Cascata", "rank": "Strain"}, "1193055": {"name": "Leptospira noguchii str. Hook", "rank": "Strain"}, "1193056": {"name": "Leptospira santarosai str. AIM", "rank": "Strain"}, "1193057": {"name": "Leptospira santarosai str. JET", "rank": "Strain"}, "1193050": {"name": "Leptospira kirschneri str. H2", "rank": "Strain"}, "1193051": {"name": "Leptospira meyeri serovar Hardjo str. Went 5", "rank": "Strain"}, "1193053": {"name": "Leptospira noguchii str. 2001034031", "rank": "Strain"}, "754521": {"name": "Rhizobium leguminosarum bv. trifolii TA1", "rank": "Strain"}, "881616": {"name": "Herbiconiux", "rank": "Genus"}, "1354131": {"name": "Mycobacterium tuberculosis MAL020156", "rank": "Strain"}, "1215084": {"name": "Peptoclostridium difficile T10", "rank": "Strain"}, "1215085": {"name": "Peptoclostridium difficile T14", "rank": "Strain"}, "1215086": {"name": "Peptoclostridium difficile T61", "rank": "Strain"}, "1215087": {"name": "Pseudomonas putida S12", "rank": "Strain"}, "1215080": {"name": "Peptoclostridium difficile E28", "rank": "Strain"}, "1215081": {"name": "Peptoclostridium difficile E23", "rank": "Strain"}, "1215082": {"name": "Peptoclostridium difficile E12", "rank": "Strain"}, "633405": {"name": "Lacticigenium", "rank": "Genus"}, "1354133": {"name": "Mycobacterium tuberculosis MAL020160", "rank": "Strain"}, "1215088": {"name": "Pseudomonas putida HB3267", "rank": "Strain"}, "1215089": {"name": "Planococcus halocryophilus", "rank": "Species"}, "296051": {"name": "Terrimonas", "rank": "Genus"}, "203470": {"name": "Tepidiphilus", "rank": "Genus"}, "203471": {"name": "Tepidiphilus margaritifer", "rank": "Species"}, "1030009": {"name": "Listeria monocytogenes M7", "rank": "Strain"}, "1030006": {"name": "Salmonella enterica subsp. enterica serovar Heidelberg str. N19992", "rank": "Strain"}, "1030005": {"name": "Salmonella enterica subsp. enterica serovar Heidelberg str. N418", "rank": "Strain"}, "1030003": {"name": "Salmonella enterica subsp. enterica serovar Heidelberg str. 640151-11", "rank": "Strain"}, "1030001": {"name": "Salmonella enterica subsp. enterica serovar Heidelberg str. RI-11-014319", "rank": "Strain"}, "1402767": {"name": "Staphylococcus aureus M1279", "rank": "Strain"}, "1402766": {"name": "Staphylococcus aureus M1278", "rank": "Strain"}, "1402765": {"name": "Staphylococcus aureus M1276", "rank": "Strain"}, "1402764": {"name": "Staphylococcus aureus M1274", "rank": "Strain"}, "1402763": {"name": "Staphylococcus aureus M1273", "rank": "Strain"}, "1402762": {"name": "Staphylococcus aureus M1272", "rank": "Strain"}, "1402761": {"name": "Staphylococcus aureus M1271", "rank": "Strain"}, "1402760": {"name": "Staphylococcus aureus M1270", "rank": "Strain"}, "1402769": {"name": "Staphylococcus aureus M1281", "rank": "Strain"}, "1402768": {"name": "Staphylococcus aureus M1280", "rank": "Strain"}, "1446495": {"name": "Mycoplasma ovipneumoniae NM2010", "rank": "Strain"}, "1446494": {"name": "Lactobacillus paracasei N1115", "rank": "Strain"}, "1446497": {"name": "Escherichia coli O104:H21 str. 94-3025", "rank": "Strain"}, "1446490": {"name": "Escherichia phage vB_EcoM_FFH2", "rank": "Species"}, "1446492": {"name": "Salmonella phage vB_SalM_SJ3", "rank": "Species"}, "1121002": {"name": "Aneurinibacillus terranovensis DSM 18919", "rank": "Strain"}, "1446499": {"name": "Escherichia coli O121:H19 str. F6714", "rank": "Strain"}, "1446498": {"name": "Escherichia coli O111:H8 str. F6627", "rank": "Strain"}, "1121004": {"name": "Aquaspirillum serpens DSM 68", "rank": "Strain"}, "878329": {"name": "Turkey adenovirus 1", "rank": "Strain"}, "930275": {"name": "Cotia virus SPAn232", "rank": "Strain"}, "1579368": {"name": "Archaeon GW2011_AR6", "rank": "Species"}, "1579369": {"name": "Archaeon GW2011_AR9", "rank": "Species"}, "1579366": {"name": "Archaeon GW2011_AR4", "rank": "Species"}, "1579367": {"name": "Archaeon GW2011_AR5", "rank": "Species"}, "1579364": {"name": "Archaeon GW2011_AR1", "rank": "Species"}, "1579365": {"name": "Archaeon GW2011_AR3", "rank": "Species"}, "242605": {"name": "Luteibacter", "rank": "Genus"}, "879630": {"name": "Aeromonas phage phiAS5", "rank": "Species"}, "1287117": {"name": "Mesorhizobium sp. L2C085B000", "rank": "Species"}, "1379305": {"name": "Candidatus Hydrogenedens terephthalicus JGI OTU-1", "rank": "Strain"}, "1379303": {"name": "Candidatus Calescibacterium nevadense OTU 1", "rank": "Strain"}, "740710": {"name": "Avian paramyxovirus 5", "rank": "Species"}, "208226": {"name": "Alkaliphilus metalliredigens", "rank": "Species"}, "340921": {"name": "Kelp fly virus", "rank": "Species"}, "301541": {"name": "Leptospira broomii", "rank": "Species"}, "1226344": {"name": "Dickeya solani GBBC 2040", "rank": "Strain"}, "1328409": {"name": "Klebsiella pneumoniae BIDMC 13", "rank": "Strain"}, "1328408": {"name": "Klebsiella pneumoniae BIDMC 12C", "rank": "Strain"}, "1226343": {"name": "Dickeya dianthicola GBBC 2039", "rank": "Strain"}, "1328403": {"name": "Klebsiella pneumoniae BIDMC 7B", "rank": "Strain"}, "1328402": {"name": "Klebsiella pneumoniae BIDMC 7A", "rank": "Strain"}, "1328401": {"name": "Klebsiella pneumoniae BIDMC 5", "rank": "Strain"}, "1328400": {"name": "Klebsiella pneumoniae BIDMC 4", "rank": "Strain"}, "1328407": {"name": "Klebsiella pneumoniae BIDMC 12B", "rank": "Strain"}, "1328406": {"name": "Klebsiella pneumoniae BIDMC 12A", "rank": "Strain"}, "1328405": {"name": "Klebsiella pneumoniae BIDMC 11", "rank": "Strain"}, "1328404": {"name": "Klebsiella pneumoniae BIDMC 10", "rank": "Strain"}, "1233245": {"name": "Staphylococcus aureus M2", "rank": "Strain"}, "106331": {"name": "Callitrichine herpesvirus 3", "rank": "Species"}, "106333": {"name": "Porcine enteric sapovirus", "rank": "Strain"}, "1334631": {"name": "Staphylococcus aureus SA_ST125_MupR", "rank": "Strain"}, "1334630": {"name": "Enterobacter cloacae EC_38VIM1", "rank": "Strain"}, "28314": {"name": "Aleutian mink disease virus", "rank": "Strain"}, "28311": {"name": "Human papillomavirus type 63", "rank": "Strain"}, "879090": {"name": "Listeria monocytogenes SLCC7179", "rank": "Strain"}, "1046972": {"name": "Cloacimonetes bacterium SCGC AAA252-P10", "rank": "Species"}, "1046970": {"name": "Cloacimonetes bacterium SCGC AAA252-O17", "rank": "Species"}, "225447": {"name": "Yaniella", "rank": "Genus"}, "1421976": {"name": "Mycobacterium tuberculosis TB_RSA60", "rank": "Strain"}, "1046971": {"name": "Cloacimonetes bacterium SCGC AAA252-P02", "rank": "Species"}, "483074": {"name": "Baudoinia", "rank": "Genus"}, "1434209": {"name": "Burkholderia pseudomallei ABCPW 91", "rank": "Strain"}, "1434208": {"name": "Burkholderia pseudomallei ABCPW 30", "rank": "Strain"}, "259931": {"name": "Ross's goose hepatitis B virus", "rank": "Species"}, "1434205": {"name": "Burkholderia pseudomallei MSHR4462", "rank": "Strain"}, "1434204": {"name": "Burkholderia pseudomallei TSV 31", "rank": "Strain"}, "1434207": {"name": "Burkholderia sp. ABCPW 1", "rank": "Species"}, "114102": {"name": "Frog adenovirus 1", "rank": "Strain"}, "1434201": {"name": "Burkholderia pseudomallei MSHR4299", "rank": "Strain"}, "1434200": {"name": "Burkholderia pseudomallei MSHR4377", "rank": "Strain"}, "1434203": {"name": "Burkholderia pseudomallei MSHR3960", "rank": "Strain"}, "1434202": {"name": "Burkholderia pseudomallei TSV 43", "rank": "Strain"}, "352248": {"name": "Operophtera brumata reovirus", "rank": "Species"}, "10875": {"name": "Plectrovirus", "rank": "Genus"}, "90153": {"name": "Chromobacterium group", "rank": "No rank"}, "106591": {"name": "Ensifer", "rank": "Genus"}, "106590": {"name": "Cupriavidus necator", "rank": "Species"}, "106592": {"name": "Ensifer adhaerens", "rank": "Species"}, "1427290": {"name": "Mycobacterium tuberculosis XTB13-213", "rank": "Strain"}, "907965": {"name": "Encephalitozoon hellem ATCC 50504", "rank": "Strain"}, "1116113": {"name": "Escherichia coli BCE007_MS-11", "rank": "Strain"}, "1116111": {"name": "Escherichia coli MP021017.12", "rank": "Strain"}, "1295773": {"name": "Mycobacterium tuberculosis TKK_02_0057", "rank": "Strain"}, "1232195": {"name": "Peptoclostridium difficile F548", "rank": "Strain"}, "1232194": {"name": "Peptoclostridium difficile F525", "rank": "Strain"}, "1232197": {"name": "Peptoclostridium difficile F665", "rank": "Strain"}, "1232196": {"name": "Peptoclostridium difficile F601", "rank": "Strain"}, "1232193": {"name": "Peptoclostridium difficile F480", "rank": "Strain"}, "1192124": {"name": "Burkholderia sp. lig30", "rank": "Species"}, "221216": {"name": "Parcubacteria", "rank": "Phylum"}, "422440": {"name": "Stenoxybacter", "rank": "Genus"}, "422441": {"name": "Stenoxybacter acetivorans", "rank": "Species"}, "1121918": {"name": "Geopsychrobacter electrodiphilus DSM 16401", "rank": "Strain"}, "1408452": {"name": "Mycobacterium genavense ATCC 51234", "rank": "Strain"}, "1408451": {"name": "Methylobacter tundripaludum 31/32", "rank": "Strain"}, "1408450": {"name": "Methylobacter tundripaludum 21/22", "rank": "Strain"}, "1408457": {"name": "Mycoplasma columbinum ATCC 29257", "rank": "Strain"}, "1408456": {"name": "Mycoplasma collis ATCC 35278", "rank": "Strain"}, "1408455": {"name": "Mycoplasma cloacale ATCC 35276", "rank": "Strain"}, "1408454": {"name": "Mycoplasma anseris ATCC 49234", "rank": "Strain"}, "1121910": {"name": "Gallibacterium anatis DSM 16844 = F 149", "rank": "Strain"}, "1408459": {"name": "Mycoplasma elephantis ATCC 51980", "rank": "Strain"}, "1408458": {"name": "Mycoplasma columborale ATCC 29258", "rank": "Strain"}, "1121914": {"name": "Gemella cuniculi DSM 15828", "rank": "Strain"}, "1121915": {"name": "Geoalkalibacter ferrihydriticus DSM 17813", "rank": "Strain"}, "1121917": {"name": "Caldibacillus debilis DSM 16016", "rank": "Strain"}, "1233178": {"name": "Unclassified Dyoiotapapillomavirus", "rank": "No rank"}, "1116375": {"name": "Vibrio sp. EJY3", "rank": "Species"}, "764098": {"name": "Saccharomyces cerevisiae Lalvin QA23", "rank": "Strain"}, "764099": {"name": "Saccharomyces cerevisiae Vin13", "rank": "Strain"}, "12466": {"name": "Barley mild mosaic virus", "rank": "Species"}, "764097": {"name": "Saccharomyces cerevisiae AWRI796", "rank": "Strain"}, "12465": {"name": "Barley yellow mosaic virus", "rank": "Species"}, "12461": {"name": "Hepatitis E virus", "rank": "Species"}, "2433": {"name": "Roseobacter", "rank": "Genus"}, "2434": {"name": "Roseobacter denitrificans", "rank": "Species"}, "109790": {"name": "Lactobacillus jensenii", "rank": "Species"}, "1409414": {"name": "Staphylococcus aureus PLAC6017", "rank": "Strain"}, "1409415": {"name": "Staphylococcus aureus PLAC6019", "rank": "Strain"}, "1409416": {"name": "Staphylococcus aureus CHOC6045", "rank": "Strain"}, "1409417": {"name": "Staphylococcus aureus SJUD6086", "rank": "Strain"}, "1409410": {"name": "Staphylococcus aureus WMCS6019", "rank": "Strain"}, "1409411": {"name": "Staphylococcus aureus MISS6103", "rank": "Strain"}, "1409412": {"name": "Staphylococcus aureus TUSH6001", "rank": "Strain"}, "1409413": {"name": "Staphylococcus aureus HOAG6068", "rank": "Strain"}, "1123070": {"name": "Rubritalea marina DSM 17716", "rank": "Strain"}, "1123073": {"name": "Rudaea cellulosilytica DSM 22992", "rank": "Strain"}, "1123072": {"name": "Rubritepida flocculans DSM 14296", "rank": "Strain"}, "1123075": {"name": "Ruminococcus gauvreauii DSM 19829", "rank": "Strain"}, "1409419": {"name": "Staphylococcus aureus COAS6038", "rank": "Strain"}, "1123077": {"name": "Runella limosa DSM 17973", "rank": "Strain"}, "1422747": {"name": "Staphylococcus aureus VET1911R", "rank": "Strain"}, "262728": {"name": "Haemophilus influenzae R2866", "rank": "Strain"}, "1422745": {"name": "Staphylococcus aureus VET1909R", "rank": "Strain"}, "1422744": {"name": "Staphylococcus aureus VET1908R", "rank": "Strain"}, "1422743": {"name": "Staphylococcus aureus VET1907R", "rank": "Strain"}, "1422742": {"name": "Staphylococcus aureus VET1906R", "rank": "Strain"}, "1422741": {"name": "Staphylococcus aureus VET1905R", "rank": "Strain"}, "1422740": {"name": "Staphylococcus aureus VET1904R", "rank": "Strain"}, "262723": {"name": "Mycoplasma synoviae 53", "rank": "Strain"}, "262722": {"name": "Mycoplasma hyopneumoniae 7448", "rank": "Strain"}, "262724": {"name": "Thermus thermophilus HB27", "rank": "Strain"}, "262727": {"name": "Haemophilus influenzae R2846", "rank": "Strain"}, "1422748": {"name": "Staphylococcus aureus VET1912R", "rank": "Strain"}, "648998": {"name": "Penguinpox virus", "rank": "Species"}, "648999": {"name": "Micromonospora sp. L5", "rank": "Species"}, "648996": {"name": "Thermovibrio ammonificans HB-1", "rank": "Strain"}, "452471": {"name": "Candidatus Amoebophilus asiaticus 5a2", "rank": "Strain"}, "452475": {"name": "Squirrel monkey polyomavirus", "rank": "Species"}, "564416": {"name": "Chlamydia trachomatis 6276", "rank": "Strain"}, "564417": {"name": "Chlamydia trachomatis 6276s", "rank": "Strain"}, "564418": {"name": "Chlamydia trachomatis 70", "rank": "Strain"}, "564419": {"name": "Chlamydia trachomatis 70s", "rank": "Strain"}, "1473546": {"name": "Lysinibacillus sp. BF-4", "rank": "Species"}, "1246444": {"name": "Nocardiopsis halotolerans DSM 44410", "rank": "Strain"}, "1069628": {"name": "Streptococcus pneumoniae GA08825", "rank": "Strain"}, "766": {"name": "Rickettsiales", "rank": "Order"}, "1281187": {"name": "Escherichia coli UMEA 3122-1", "rank": "Strain"}, "1281180": {"name": "Escherichia coli UMEA 3087-1", "rank": "Strain"}, "1281181": {"name": "Escherichia coli UMEA 3088-1", "rank": "Strain"}, "1281182": {"name": "Escherichia coli UMEA 3097-1", "rank": "Strain"}, "1281183": {"name": "Escherichia coli UMEA 3108-1", "rank": "Strain"}, "1069621": {"name": "Neisseria meningitidis NM3081", "rank": "Strain"}, "1069620": {"name": "Neisseria meningitidis NM2795", "rank": "Strain"}, "1069623": {"name": "Streptococcus pneumoniae GA05578", "rank": "Strain"}, "1069622": {"name": "Neisseria meningitidis NM3001", "rank": "Strain"}, "1069625": {"name": "Streptococcus pneumoniae England14-9", "rank": "Strain"}, "1069624": {"name": "Streptococcus pneumoniae GA04216", "rank": "Strain"}, "1069627": {"name": "Streptococcus pneumoniae GA04672", "rank": "Strain"}, "1069626": {"name": "Streptococcus pneumoniae GA02506", "rank": "Strain"}, "1127516": {"name": "Pectobacterium phage ZF40", "rank": "Species"}, "1127514": {"name": "Aeromonas phage vB_AsaM-56", "rank": "Species"}, "1127515": {"name": "Bdellovibrio phage phi1422", "rank": "Species"}, "1127518": {"name": "Vibrio phage vB_VchM-138", "rank": "Species"}, "1444239": {"name": "Escherichia coli 5-172-05_S4_C2", "rank": "Strain"}, "1409628": {"name": "Staphylococcus aureus AMMC6114", "rank": "Strain"}, "207343": {"name": "Bovine foamy virus", "rank": "Species"}, "207340": {"name": "Roseomonas mucosa", "rank": "Species"}, "1444237": {"name": "Escherichia coli 2-460-02_S4_C2", "rank": "Strain"}, "1444236": {"name": "Escherichia coli 2-427-07_S4_C2", "rank": "Strain"}, "1409625": {"name": "Staphylococcus aureus UCIM6084", "rank": "Strain"}, "541865": {"name": "Clostridium phage phiCP39-O", "rank": "Species"}, "1248402": {"name": "Campylobacter jejuni subsp. jejuni BIGS0022", "rank": "Strain"}, "1248403": {"name": "Campylobacter coli BIGS0025", "rank": "Strain"}, "1248400": {"name": "Campylobacter jejuni subsp. jejuni BIGS0013", "rank": "Strain"}, "1444234": {"name": "Escherichia coli 2-222-05_S4_C2", "rank": "Strain"}, "1248404": {"name": "Campylobacter jejuni subsp. jejuni BIGS0030", "rank": "Strain"}, "244592": {"name": "Labrenzia alexandrii DFL-11", "rank": "Strain"}, "1409623": {"name": "Staphylococcus aureus KINW6027", "rank": "Strain"}, "244590": {"name": "Sulfolobus spindle-shaped virus 2", "rank": "Species"}, "244596": {"name": "Hoeflea phototrophica", "rank": "Species"}, "1407462": {"name": "Helicobacter pylori BM012A", "rank": "Strain"}, "1240657": {"name": "Herpotrichiellaceae sp. UM238", "rank": "Species"}, "135487": {"name": "Nocardia cyriacigeorgica", "rank": "Species"}, "1409621": {"name": "Staphylococcus aureus MISS6132", "rank": "Strain"}, "286104": {"name": "Winogradskyella", "rank": "Genus"}, "1444230": {"name": "Escherichia coli 2-052-05_S4_C2", "rank": "Strain"}, "223275": {"name": "East African cassava mosaic Zanzibar virus", "rank": "Species"}, "1412829": {"name": "Escherichia coli 27A", "rank": "Strain"}, "96345": {"name": "Flavobacterium psychrophilum", "rank": "Species"}, "1412821": {"name": "Escherichia coli 85B", "rank": "Strain"}, "1129704": {"name": "Kyrpidia", "rank": "Genus"}, "1412822": {"name": "Escherichia coli 328", "rank": "Strain"}, "1412824": {"name": "Escherichia coli 597", "rank": "Strain"}, "1412827": {"name": "Escherichia coli 1A", "rank": "Strain"}, "1412826": {"name": "Escherichia coli 668", "rank": "Strain"}, "1286619": {"name": "Florida woods cockroach-associated cyclovirus", "rank": "Species"}, "1411526": {"name": "Staphylococcus aureus H27872", "rank": "Strain"}, "1566011": {"name": "Seal anellovirus 4", "rank": "Species"}, "461281": {"name": "Ogataea", "rank": "Genus"}, "1410805": {"name": "Staphylococcus aureus M20894", "rank": "Strain"}, "1081735": {"name": "Unclassified Listeriaceae", "rank": "No rank"}, "1081736": {"name": "Listeria fleischmannii subsp. coloradonensis", "rank": "Subspecies"}, "1423502": {"name": "Mycobacterium tuberculosis BTB09-151", "rank": "Strain"}, "1423503": {"name": "Mycobacterium tuberculosis BTB09-157", "rank": "Strain"}, "1423500": {"name": "Mycobacterium tuberculosis BTB09-086", "rank": "Strain"}, "1423501": {"name": "Mycobacterium tuberculosis BTB09-091", "rank": "Strain"}, "1423506": {"name": "Mycobacterium tuberculosis BTB09-377", "rank": "Strain"}, "1423507": {"name": "Mycobacterium tuberculosis BTB09-382", "rank": "Strain"}, "1089108": {"name": "Mycobacterium phage Vista", "rank": "Species"}, "1089109": {"name": "Mycobacterium phage Acadian", "rank": "Species"}, "1347386": {"name": "Anaerosalibacter", "rank": "Genus"}, "1423508": {"name": "Mycobacterium tuberculosis BTB09-453", "rank": "Strain"}, "1423509": {"name": "Mycobacterium tuberculosis BTB09-485", "rank": "Strain"}, "1334117": {"name": "Melioribacteraceae", "rank": "Family"}, "376147": {"name": "Unclassified Parechovirus", "rank": "No rank"}, "535025": {"name": "Bacillus subtilis subsp. subtilis str. JH642", "rank": "Strain"}, "1193420": {"name": "Goose aviadenovirus A", "rank": "Species"}, "1301213": {"name": "Caloplacoideae", "rank": "Subfamily"}, "1354721": {"name": "Helicobacter pylori HP87P7tlpDRI", "rank": "Strain"}, "1345528": {"name": "Helicobacter pylori SA233C", "rank": "Strain"}, "206039": {"name": "Amphibian retroviruses", "rank": "No rank"}, "1345525": {"name": "Helicobacter pylori SA37C", "rank": "Strain"}, "1345524": {"name": "Helicobacter pylori SA37A", "rank": "Strain"}, "1345527": {"name": "Helicobacter pylori SA40C", "rank": "Strain"}, "1345526": {"name": "Helicobacter pylori SA40A", "rank": "Strain"}, "1345521": {"name": "Helicobacter pylori SA227C", "rank": "Strain"}, "1345520": {"name": "Helicobacter pylori SA227A", "rank": "Strain"}, "1345523": {"name": "Helicobacter pylori SA36C", "rank": "Strain"}, "1345522": {"name": "Helicobacter pylori SA233A", "rank": "Strain"}, "1287252": {"name": "Mesorhizobium sp. LNHC252B00", "rank": "Species"}, "1497679": {"name": "Listeriaceae bacterium FSL A5-0209", "rank": "Species"}, "1287256": {"name": "Mesorhizobium sp. LNJC372A00", "rank": "Species"}, "508767": {"name": "Clostridium botulinum E3 str. Alaska E43", "rank": "Strain"}, "155919": {"name": "Xylella fastidiosa Dixon", "rank": "Strain"}, "420952": {"name": "Burkholderia bryophila", "rank": "Species"}, "1287258": {"name": "Mesorhizobium sp. LNJC374B00", "rank": "Species"}, "941435": {"name": "Escherichia coli O157:H7 str. EC1212", "rank": "Strain"}, "53460": {"name": "Nakamurella", "rank": "Genus"}, "1263547": {"name": "Oscillibacter ruminantium", "rank": "Species"}, "191217": {"name": "Cereal yellow dwarf virus-RPV", "rank": "Species"}, "171549": {"name": "Bacteroidales", "rank": "Order"}, "191218": {"name": "Bacillus anthracis str. A2012", "rank": "Strain"}, "1138429": {"name": "Haemophilus parasuis gx033", "rank": "Strain"}, "981219": {"name": "Helicobacter pylori NQ367", "rank": "Strain"}, "939296": {"name": "Alpha proteobacterium SCGC AAA015-N04", "rank": "Species"}, "981218": {"name": "Helicobacter pylori NQ4060", "rank": "Strain"}, "551790": {"name": "Ralstonia phage RSB1", "rank": "Species"}, "325455": {"name": "Gammapapillomavirus", "rank": "Genus"}, "325454": {"name": "Deltapapillomavirus", "rank": "Genus"}, "325457": {"name": "Kappapapillomavirus", "rank": "Genus"}, "325456": {"name": "Iotapapillomavirus", "rank": "Genus"}, "983917": {"name": "Rubrivivax gelatinosus IL144", "rank": "Strain"}, "325459": {"name": "Epsilonpapillomavirus", "rank": "Genus"}, "325458": {"name": "Etapapillomavirus", "rank": "Genus"}, "51673": {"name": "Wissadula golden mosaic virus", "rank": "Species"}, "745004": {"name": "SAR92 clade", "rank": "No rank"}, "51677": {"name": "Xestia c-nigrum granulovirus", "rank": "Species"}, "981212": {"name": "Helicobacter pylori NQ315", "rank": "Strain"}, "981211": {"name": "Helicobacter pylori 8A3", "rank": "Strain"}, "585144": {"name": "Staphylococcus aureus subsp. aureus 58-424", "rank": "Strain"}, "1128948": {"name": "Klebsiella pneumoniae subsp. pneumoniae KPNIH14", "rank": "Strain"}, "981210": {"name": "Helicobacter pylori BCS100H1", "rank": "Strain"}, "364733": {"name": "Endocarpon pusillum", "rank": "Species"}, "981217": {"name": "Helicobacter pylori NQ1707", "rank": "Strain"}, "1298531": {"name": "Sulfolobales Mexican fusellovirus 1", "rank": "Species"}, "1128946": {"name": "Klebsiella pneumoniae subsp. pneumoniae KPNIH12", "rank": "Strain"}, "1436884": {"name": "Campylobacter jejuni subsp. jejuni 81-176-DRH212", "rank": "Strain"}, "1333577": {"name": "Streptococcus agalactiae MC633", "rank": "Strain"}, "981215": {"name": "Helicobacter pylori NQ1701", "rank": "Strain"}, "1333576": {"name": "Streptococcus agalactiae MC632", "rank": "Strain"}, "981214": {"name": "Helicobacter pylori NQ352", "rank": "Strain"}, "1412690": {"name": "Staphylococcus aureus T20142", "rank": "Strain"}, "643473": {"name": "Microchaete sp. PCC 7126", "rank": "Species"}, "1412691": {"name": "Staphylococcus aureus T23868", "rank": "Strain"}, "1412696": {"name": "Staphylococcus aureus T37840", "rank": "Strain"}, "1124627": {"name": "Brettanomyces bruxellensis AWRI1499", "rank": "Strain"}, "1412697": {"name": "Staphylococcus aureus T37849", "rank": "Strain"}, "1173743": {"name": "Listeria phage LP-030-2", "rank": "Species"}, "1412694": {"name": "Staphylococcus aureus T34011", "rank": "Strain"}, "1173745": {"name": "Listeria phage LP-026", "rank": "Species"}, "10477": {"name": "Lipothrixviridae", "rank": "Family"}, "407032": {"name": "Nitrospinaceae", "rank": "Family"}, "10475": {"name": "Alphafusellovirus", "rank": "Genus"}, "10474": {"name": "Fuselloviridae", "rank": "Family"}, "10473": {"name": "Plasmavirus", "rank": "Genus"}, "10472": {"name": "Plasmaviridae", "rank": "Family"}, "1121367": {"name": "Corynebacterium propinquum DSM 44285", "rank": "Strain"}, "1121366": {"name": "Corynebacterium pilosum DSM 20521", "rank": "Strain"}, "1121365": {"name": "Corynebacterium mastitidis DSM 44356", "rank": "Strain"}, "1121364": {"name": "Corynebacterium massiliense DSM 45435", "rank": "Strain"}, "1121363": {"name": "Corynebacterium lubricantis DSM 45231", "rank": "Strain"}, "1121362": {"name": "Corynebacterium halotolerans YIM 70093 = DSM 44683", "rank": "Strain"}, "1121360": {"name": "Corynebacterium freiburgense DSM 45254", "rank": "Strain"}, "1121368": {"name": "Corynebacterium pseudodiphtheriticum DSM 44287", "rank": "Strain"}, "1122201": {"name": "Marinobacterium litorale DSM 23545", "rank": "Strain"}, "42234": {"name": "Streptomyces acidiscabies", "rank": "Species"}, "42235": {"name": "Streptomyces bottropensis", "rank": "Species"}, "762906": {"name": "Hyperthermophilic Archaeal Virus 2", "rank": "Species"}, "762905": {"name": "Hyperthermophilic Archaeal Virus 1", "rank": "Species"}, "762903": {"name": "Pedobacter saltans DSM 12145", "rank": "Strain"}, "2749": {"name": "Carnobacterium gallinarum", "rank": "Species"}, "89013": {"name": "Mitosporic Sporidiobolales", "rank": "No rank"}, "386043": {"name": "Listeria welshimeri serovar 6b str. SLCC5334", "rank": "Strain"}, "1132442": {"name": "Bacillus sp. 37MA", "rank": "Species"}, "1132443": {"name": "Methylosarcina fibrata AML-C10", "rank": "Strain"}, "1132441": {"name": "Arthrobacter sp. 35W", "rank": "Species"}, "1411887": {"name": "Zamilon virophage", "rank": "Species"}, "1132444": {"name": "Methylocystis rosea SV97", "rank": "Strain"}, "1260624": {"name": "Idiomarina sp. 28-8", "rank": "Species"}, "1260626": {"name": "Pseudomonas syringae pv. syringae B64", "rank": "Strain"}, "1463156": {"name": "Flavihumibacter sp. ZG627", "rank": "Species"}, "1177594": {"name": "Microbacterium sp. C448", "rank": "Species"}, "1073566": {"name": "Saccharomyces pastorianus CBS 1513", "rank": "Strain"}, "913183": {"name": "Ralstonia phage RSB2", "rank": "Species"}, "1073569": {"name": "Streptococcus thermophilus MTCC 5460", "rank": "Strain"}, "29503": {"name": "Desulfomicrobium escambiense", "rank": "Species"}, "1181728": {"name": "Escherichia coli KTE182", "rank": "Strain"}, "29501": {"name": "Mycoplasma haemofelis", "rank": "Species"}, "29507": {"name": "Leptospira kirschneri", "rank": "Species"}, "29506": {"name": "Leptospira inadai", "rank": "Species"}, "29508": {"name": "Leptospira meyeri", "rank": "Species"}, "1181725": {"name": "Escherichia coli KTE175", "rank": "Strain"}, "1181724": {"name": "Escherichia coli KTE173", "rank": "Strain"}, "1181727": {"name": "Escherichia coli KTE181", "rank": "Strain"}, "1181726": {"name": "Escherichia coli KTE178", "rank": "Strain"}, "1188007": {"name": "Kingella kingae 11220434", "rank": "Strain"}, "104175": {"name": "Oscillochloris", "rank": "Genus"}, "119532": {"name": "Microcoleus vaginatus", "rank": "Species"}, "363886": {"name": "Unclassified Xanthobacteraceae", "rank": "No rank"}, "672795": {"name": "Candidatus Hamiltonella defensa (Bemisia tabaci)", "rank": "Strain"}, "1157359": {"name": "Enterococcus faecalis EnGen0112", "rank": "Strain"}, "1312872": {"name": "Mesoniviridae", "rank": "Family"}, "1157357": {"name": "Enterococcus faecalis EnGen0096", "rank": "Strain"}, "1157356": {"name": "Enterococcus faecalis EnGen0095", "rank": "Strain"}, "1157355": {"name": "Enterococcus faecalis EnGen0094", "rank": "Strain"}, "1157354": {"name": "Enterococcus faecalis EnGen0093", "rank": "Strain"}, "1157353": {"name": "Enterococcus faecalis EnGen0119", "rank": "Strain"}, "1157352": {"name": "Enterococcus faecalis EnGen0111", "rank": "Strain"}, "1157351": {"name": "Enterococcus faecalis EnGen0085", "rank": "Strain"}, "1157350": {"name": "Enterococcus faecalis EnGen0092", "rank": "Strain"}, "416001": {"name": "Nodosilinea nodulosa", "rank": "Species"}, "2060": {"name": "Tsukamurella", "rank": "Genus"}, "2061": {"name": "Tsukamurella paurometabola", "rank": "Species"}, "2062": {"name": "Streptomycetaceae", "rank": "Family"}, "2063": {"name": "Kitasatospora", "rank": "Genus"}, "2065": {"name": "Kitasatospora phosalacinea", "rank": "Species"}, "2066": {"name": "Kitasatospora setae", "rank": "Species"}, "1312875": {"name": "Unclassified Mesoniviridae", "rank": "No rank"}, "35619": {"name": "Streptomyces griseoflavus", "rank": "Species"}, "35612": {"name": "Vesicular exanthema of swine virus", "rank": "Species"}, "35617": {"name": "Mycobacterium indicus pranii", "rank": "Species"}, "1438685": {"name": "Escherichia coli CHS 69", "rank": "Strain"}, "1438684": {"name": "Escherichia coli CHS 68", "rank": "Strain"}, "1438687": {"name": "Escherichia coli MGH 57", "rank": "Strain"}, "1388679": {"name": "Staphylococcus aureus M0907", "rank": "Strain"}, "1438681": {"name": "Escherichia coli BIDMC 77", "rank": "Strain"}, "1438680": {"name": "Escherichia coli BIDMC 76", "rank": "Strain"}, "1438683": {"name": "Escherichia coli BIDMC 79", "rank": "Strain"}, "1438682": {"name": "Escherichia coli BIDMC 78", "rank": "Strain"}, "1388672": {"name": "Staphylococcus aureus M0899", "rank": "Strain"}, "1388673": {"name": "Staphylococcus aureus M0901", "rank": "Strain"}, "1388670": {"name": "Staphylococcus aureus M0897", "rank": "Strain"}, "1388671": {"name": "Staphylococcus aureus M0898", "rank": "Strain"}, "1388676": {"name": "Staphylococcus aureus M0904", "rank": "Strain"}, "66712": {"name": "Propionibacterium freudenreichii subsp. freudenreichii", "rank": "Subspecies"}, "1388674": {"name": "Staphylococcus aureus M0902", "rank": "Strain"}, "1388675": {"name": "Staphylococcus aureus M0903", "rank": "Strain"}, "1299321": {"name": "Mycobacterium abscessus subsp. bolletii 1513", "rank": "Strain"}, "1299323": {"name": "Mycobacterium abscessus 1948", "rank": "Strain"}, "1299322": {"name": "Mycobacterium chelonae 1518", "rank": "Strain"}, "1299325": {"name": "Mycobacterium abscessus subsp. bolletii 103", "rank": "Strain"}, "1299324": {"name": "Mycobacterium abscessus 21", "rank": "Strain"}, "1299327": {"name": "Mycobacterium kansasii 732", "rank": "Strain"}, "1299326": {"name": "Mycobacterium kansasii 662", "rank": "Strain"}, "1299329": {"name": "Mycobacterium avium subsp. avium 2285 (S)", "rank": "Strain"}, "1299328": {"name": "Mycobacterium kansasii 824", "rank": "Strain"}, "703352": {"name": "Brucella melitensis M5-90", "rank": "Strain"}, "1184387": {"name": "Mesotoga prima", "rank": "Species"}, "1482558": {"name": "Streptomyces albovinaceus subgroup", "rank": "No rank"}, "1117244": {"name": "Xanthobacter sp. 91", "rank": "Species"}, "1194208": {"name": "Streptococcus massiliensis 4401825", "rank": "Strain"}, "1095773": {"name": "Gordonia alkanivorans s104", "rank": "Strain"}, "1112770": {"name": "Actinidia virus B", "rank": "Species"}, "913600": {"name": "Papaya leaf crumple virus-Panipat 8 India:Panipat:Papaya:2008", "rank": "Strain"}, "1032851": {"name": "Corynebacterium nuruki", "rank": "Species"}, "86104": {"name": "Arenibacter latericius", "rank": "Species"}, "86105": {"name": "Endosymbiont of Acanthamoeba sp. UWC36", "rank": "Species"}, "86106": {"name": "Endosymbiont of Acanthamoeba sp. UWC8", "rank": "Species"}, "115987": {"name": "Aeromonas phage 44RR2.8t", "rank": "Species"}, "37762": {"name": "Escherichia coli B", "rank": "Strain"}, "115981": {"name": "Salmonella enterica subsp. enterica serovar Montevideo", "rank": "Strain"}, "1721": {"name": "Corynebacterium callunae", "rank": "Species"}, "1727": {"name": "Corynebacterium variabile", "rank": "Species"}, "64001": {"name": "Nevskia", "rank": "Genus"}, "64003": {"name": "Grapevine leafroll-associated virus 2", "rank": "Species"}, "64002": {"name": "Nevskia ramosa", "rank": "Species"}, "991903": {"name": "Polymorphum", "rank": "No rank"}, "991904": {"name": "Polymorphum gilvum", "rank": "Species"}, "991905": {"name": "Polymorphum gilvum SL003B-26A1", "rank": "Strain"}, "315749": {"name": "Bacillus cytotoxicus NVH 391-98", "rank": "Strain"}, "582472": {"name": "Wohlfahrtiimonas", "rank": "Genus"}, "1138897": {"name": "Enterococcus faecium EnGen0020", "rank": "Strain"}, "1138896": {"name": "Enterococcus faecium EnGen0009", "rank": "Strain"}, "1138895": {"name": "Enterococcus faecium EnGen0021", "rank": "Strain"}, "1138894": {"name": "Enterococcus faecium EnGen0016", "rank": "Strain"}, "1138893": {"name": "Enterococcus faecium EnGen0006", "rank": "Strain"}, "1138892": {"name": "Enterococcus faecium EnGen0004", "rank": "Strain"}, "1138891": {"name": "Enterococcus faecium EnGen0011", "rank": "Strain"}, "1138890": {"name": "Enterococcus faecium EnGen0002", "rank": "Strain"}, "165697": {"name": "Sphingopyxis", "rank": "Genus"}, "1138899": {"name": "Enterococcus faecium EnGen0018", "rank": "Strain"}, "1138898": {"name": "Enterococcus faecium EnGen0001", "rank": "Strain"}, "1428684": {"name": "Exiguobacterium alkaliphilum", "rank": "Species"}, "398736": {"name": "Vibrio rhizosphaerae", "rank": "Species"}, "1091501": {"name": "Mycobacterium tuberculosis RGTB423", "rank": "Strain"}, "1091500": {"name": "Mycobacterium tuberculosis RGTB327", "rank": "Strain"}, "1042209": {"name": "Pseudomonas fluorescens HK44", "rank": "Strain"}, "1388730": {"name": "Staphylococcus aureus M0970", "rank": "Strain"}, "123783": {"name": "Natrialba hulunbeirensis", "rank": "Species"}, "76114": {"name": "Aromatoleum aromaticum EbN1", "rank": "Strain"}, "622416": {"name": "Avian paramyxovirus 7", "rank": "Species"}, "76112": {"name": "Thauera linaloolentis", "rank": "Species"}, "169292": {"name": "Corynebacterium aurimucosum", "rank": "Species"}, "1221267": {"name": "Acinetobacter baumannii AB_908-13", "rank": "Strain"}, "1306947": {"name": "Candidate division TM6 bacterium JCVI TM6SC1", "rank": "Species"}, "1221265": {"name": "Acinetobacter baumannii AB_515-8", "rank": "Strain"}, "279238": {"name": "Novosphingobium aromaticivorans DSM 12444", "rank": "Strain"}, "1221263": {"name": "Acinetobacter baumannii AB_2009-04-01-7", "rank": "Strain"}, "1221262": {"name": "Acinetobacter baumannii AB_2008-23-07-01-7", "rank": "Strain"}, "1221261": {"name": "Acinetobacter baumannii AB_2008-23-01-01-7", "rank": "Strain"}, "1221260": {"name": "Acinetobacter baumannii AB_2008-15-71", "rank": "Strain"}, "1221269": {"name": "Acinetobacter baumannii AB_909-01-7", "rank": "Strain"}, "1221268": {"name": "Acinetobacter baumannii AB_908-14-7", "rank": "Strain"}, "31604": {"name": "Peste-des-petits-ruminants virus", "rank": "Species"}, "31600": {"name": "Indian cassava mosaic virus", "rank": "Species"}, "31602": {"name": "Bean calico mosaic virus", "rank": "Species"}, "67575": {"name": "Rheinheimera", "rank": "Genus"}, "67576": {"name": "Rheinheimera baltica", "rank": "Species"}, "67571": {"name": "Endosymbiont phage APSE-1", "rank": "Species"}, "67572": {"name": "Psychromonas", "rank": "Genus"}, "1296662": {"name": "Paenibacillus phage Davies", "rank": "Species"}, "587370": {"name": "Rudbeckia flower distortion virus", "rank": "Species"}, "1438838": {"name": "Mycobacterium tuberculosis 1430BH", "rank": "Strain"}, "944580": {"name": "TGP Carmovirus 1", "rank": "Species"}, "1400168": {"name": "Klebsiella pneumoniae BIDMC 52", "rank": "Strain"}, "1438836": {"name": "Mycobacterium tuberculosis UT0054", "rank": "Strain"}, "47879": {"name": "Pseudomonas corrugata", "rank": "Species"}, "1268238": {"name": "Escherichia coli O5:K4(L):H4 str. ATCC 23502", "rank": "Strain"}, "1438837": {"name": "Mycobacterium tuberculosis 1429BH", "rank": "Strain"}, "405566": {"name": "Lactobacillus helveticus DPC 4571", "rank": "Strain"}, "47872": {"name": "Micromonospora purpureochromogenes", "rank": "Species"}, "47877": {"name": "Pseudomonas amygdali", "rank": "Species"}, "1268236": {"name": "Aeromonas molluscorum 848", "rank": "Strain"}, "1438835": {"name": "Mycobacterium tuberculosis 1173CS", "rank": "Strain"}, "1149871": {"name": "New World begomovirus associated satellite DNA isolate 177H3", "rank": "Strain"}, "1438832": {"name": "Mycobacterium tuberculosis UT0073", "rank": "Strain"}, "1438833": {"name": "Mycobacterium tuberculosis 1010SM", "rank": "Strain"}, "40069": {"name": "Unclassified Poxviridae", "rank": "No rank"}, "40068": {"name": "Unclassified Orbivirus", "rank": "No rank"}, "78219": {"name": "Mamestra brassicae multiple nucleopolyhedrovirus", "rank": "Species"}, "40061": {"name": "Wallal virus", "rank": "Species"}, "40060": {"name": "Umatilla virus", "rank": "Species"}, "165179": {"name": "Prevotella copri", "rank": "Species"}, "1365636": {"name": "Helicobacter pylori UM023", "rank": "Strain"}, "98383": {"name": "Plutella xylostella granulovirus", "rank": "Species"}, "53368": {"name": "Hamadaea tsunoensis", "rank": "Species"}, "58712": {"name": "Salmonella enterica subsp. enterica serovar Anatum", "rank": "Strain"}, "1300258": {"name": "Alteromonas macleodii str. 'Ionian Sea UM7'", "rank": "Strain"}, "1300259": {"name": "Alteromonas macleodii str. 'Ionian Sea UM4b'", "rank": "Strain"}, "1046996": {"name": "Parcubacteria bacterium SCGC AAA010-E09", "rank": "Species"}, "1300253": {"name": "Alteromonas macleodii str. 'English Channel 615'", "rank": "Strain"}, "1300254": {"name": "Alteromonas macleodii str. 'Aegean Sea MED64'", "rank": "Strain"}, "1300255": {"name": "Alteromonas macleodii str. 'Ionian Sea U4'", "rank": "Strain"}, "1300256": {"name": "Alteromonas macleodii str. 'Ionian Sea U7'", "rank": "Strain"}, "1300257": {"name": "Alteromonas macleodii str. 'Ionian Sea U8'", "rank": "Strain"}, "1402978": {"name": "Bartonella quintana BQ2-D70", "rank": "Strain"}, "1402979": {"name": "Bartonella henselae JK 41", "rank": "Strain"}, "1402976": {"name": "Bartonella quintana JK 73", "rank": "Strain"}, "1402977": {"name": "Bartonella quintana JK 73rel", "rank": "Strain"}, "1402974": {"name": "Bartonella quintana JK 7", "rank": "Strain"}, "1402975": {"name": "Bartonella quintana JK 12", "rank": "Strain"}, "1394628": {"name": "Vibrio parahaemolyticus S088", "rank": "Strain"}, "1394621": {"name": "Vibrio parahaemolyticus S078", "rank": "Strain"}, "1394623": {"name": "Vibrio parahaemolyticus S081", "rank": "Strain"}, "1560346": {"name": "Simian adenovirus DM-2014", "rank": "Species"}, "1394625": {"name": "Vibrio parahaemolyticus S083", "rank": "Strain"}, "1394626": {"name": "Vibrio parahaemolyticus S086", "rank": "Strain"}, "1394627": {"name": "Vibrio parahaemolyticus S087", "rank": "Strain"}, "1236524": {"name": "Escherichia coli JCM 20135", "rank": "Strain"}, "59196": {"name": "Rickettsiella grylli", "rank": "Species"}, "1236526": {"name": "Porphyromonas gingivicanis JCM 15907", "rank": "Strain"}, "1236527": {"name": "Escherichia coli JCM 5491", "rank": "Strain"}, "1236520": {"name": "Porphyromonas cangingivalis JCM 15983", "rank": "Strain"}, "1236521": {"name": "Porphyromonas macacae JCM 15984", "rank": "Strain"}, "1236522": {"name": "Escherichia coli JCM 18426", "rank": "Strain"}, "1236523": {"name": "Salmonella enterica subsp. enterica serovar Typhimurium str. JCM 1652", "rank": "Strain"}, "157": {"name": "Treponema", "rank": "Genus"}, "1169318": {"name": "Escherichia coli KTE13", "rank": "Strain"}, "1169319": {"name": "Citrobacter sp. KTE30", "rank": "Species"}, "74426": {"name": "Collinsella aerofaciens", "rank": "Species"}, "1169313": {"name": "Enterococcus faecalis EnGen0338", "rank": "Strain"}, "1169310": {"name": "Enterococcus faecalis EnGen0367", "rank": "Strain"}, "1169311": {"name": "Enterococcus faecalis ATCC 6055", "rank": "Strain"}, "1169316": {"name": "Escherichia coli KTE3", "rank": "Strain"}, "1169317": {"name": "Escherichia coli KTE7", "rank": "Strain"}, "1169314": {"name": "Enterococcus faecalis EnGen0339", "rank": "Strain"}, "1169315": {"name": "Escherichia coli KTE1", "rank": "Strain"}, "1408945": {"name": "Mycobacterium tuberculosis UT0079", "rank": "Strain"}, "1408944": {"name": "Mycobacterium tuberculosis UT0077", "rank": "Strain"}, "1408947": {"name": "Mycobacterium tuberculosis UT0082", "rank": "Strain"}, "1408946": {"name": "Mycobacterium tuberculosis UT0080", "rank": "Strain"}, "1310769": {"name": "Acinetobacter baumannii 1276470-86", "rank": "Strain"}, "1408940": {"name": "Mycobacterium tuberculosis UT0069", "rank": "Strain"}, "1408943": {"name": "Mycobacterium tuberculosis UT0075", "rank": "Strain"}, "1408942": {"name": "Mycobacterium tuberculosis UT0071", "rank": "Strain"}, "1310765": {"name": "Acinetobacter baumannii 1294222", "rank": "Strain"}, "1310764": {"name": "Acinetobacter baumannii 826659", "rank": "Strain"}, "1310767": {"name": "Acinetobacter baumannii 1237202", "rank": "Strain"}, "437898": {"name": "Sutterella parvirubra", "rank": "Species"}, "1408949": {"name": "Mycobacterium tuberculosis UT0084", "rank": "Strain"}, "1310760": {"name": "Acinetobacter baumannii 1406589", "rank": "Strain"}, "1310763": {"name": "Acinetobacter baumannii 213697", "rank": "Strain"}, "1310762": {"name": "Acinetobacter baumannii 1391434", "rank": "Strain"}, "1398017": {"name": "Staphylococcus aureus M1396", "rank": "Strain"}, "1398016": {"name": "Staphylococcus aureus M1395", "rank": "Strain"}, "983644": {"name": "Cordyceps militaris CM01", "rank": "Strain"}, "1398014": {"name": "Staphylococcus aureus M1391", "rank": "Strain"}, "1398013": {"name": "Staphylococcus aureus M1390", "rank": "Strain"}, "1398012": {"name": "Staphylococcus aureus M1388", "rank": "Strain"}, "1398011": {"name": "Staphylococcus aureus M1387", "rank": "Strain"}, "1398010": {"name": "Staphylococcus aureus M1386", "rank": "Strain"}, "1398019": {"name": "Staphylococcus aureus M1398", "rank": "Strain"}, "1398018": {"name": "Staphylococcus aureus M1397", "rank": "Strain"}, "1334": {"name": "Streptococcus dysgalactiae", "rank": "Species"}, "182899": {"name": "Persephonella", "rank": "Genus"}, "69657": {"name": "Hyphomonadaceae", "rank": "Family"}, "1399949": {"name": "Staphylococcus phage YMC/09/04/R1988", "rank": "Species"}, "1399942": {"name": "Lactobacillus phage phiLdb", "rank": "Species"}, "1399941": {"name": "Lactobacillus phage phiJB", "rank": "Species"}, "394734": {"name": "Nocardioides insulae", "rank": "Species"}, "92950": {"name": "Cladosporium sphaerospermum", "rank": "Species"}, "938639": {"name": "Alpha proteobacterium SCGC AAA028-C07", "rank": "Species"}, "992028": {"name": "Helicobacter pylori NQ4044", "rank": "Strain"}, "992029": {"name": "Helicobacter pylori NQ4076", "rank": "Strain"}, "992024": {"name": "Helicobacter pylori NQ4200", "rank": "Strain"}, "992025": {"name": "Helicobacter pylori NQ4228", "rank": "Strain"}, "992026": {"name": "Helicobacter pylori NQ4099", "rank": "Strain"}, "992027": {"name": "Helicobacter pylori NQ4053", "rank": "Strain"}, "992020": {"name": "Helicobacter pylori CPY6271", "rank": "Strain"}, "992022": {"name": "Helicobacter pylori CPY6311", "rank": "Strain"}, "992023": {"name": "Helicobacter pylori NQ4216", "rank": "Strain"}, "1175629": {"name": "Aerococcus viridans LL1", "rank": "Strain"}, "1157462": {"name": "Enterococcus faecium EnGen0167", "rank": "Strain"}, "1388531": {"name": "Staphylococcus aureus M0492", "rank": "Strain"}, "1388530": {"name": "Staphylococcus aureus M0473", "rank": "Strain"}, "1388533": {"name": "Staphylococcus aureus M0253", "rank": "Strain"}, "1388532": {"name": "Staphylococcus aureus M0243", "rank": "Strain"}, "1388535": {"name": "Staphylococcus aureus M0284", "rank": "Strain"}, "1388534": {"name": "Staphylococcus aureus M0268", "rank": "Strain"}, "1388537": {"name": "Staphylococcus aureus M0311", "rank": "Strain"}, "1388536": {"name": "Staphylococcus aureus M0299", "rank": "Strain"}, "1388539": {"name": "Staphylococcus aureus M0343", "rank": "Strain"}, "1388538": {"name": "Staphylococcus aureus M0332", "rank": "Strain"}, "46468": {"name": "Orenia", "rank": "Genus"}, "1112271": {"name": "Chlamydia psittaci 09DC80", "rank": "Strain"}, "1245026": {"name": "Bacillus coagulans XZL9", "rank": "Strain"}, "75379": {"name": "Thiomonas intermedia K12", "rank": "Strain"}, "76936": {"name": "Helicobacter typhlonius", "rank": "Species"}, "68298": {"name": "Syntrophomonadaceae", "rank": "Family"}, "68295": {"name": "Thermoanaerobacterales", "rank": "Order"}, "1316408": {"name": "Streptococcus sp. HSISM1", "rank": "Species"}, "68297": {"name": "Dictyoglomi", "rank": "Phylum"}, "184431": {"name": "Coprinopsis", "rank": "Genus"}, "712258": {"name": "Desulfobulbus sp. oral taxon 041", "rank": "Species"}, "1388024": {"name": "Staphylococcus aureus M0054", "rank": "Strain"}, "46839": {"name": "Colorado tick fever virus", "rank": "Species"}, "1054942": {"name": "Candidatus Arthromitus sp. SFB-1", "rank": "Species"}, "1054943": {"name": "Candidatus Arthromitus sp. SFB-2", "rank": "Species"}, "1054944": {"name": "Candidatus Arthromitus sp. SFB-3", "rank": "Species"}, "1054945": {"name": "Candidatus Arthromitus sp. SFB-4", "rank": "Species"}, "1054946": {"name": "Candidatus Arthromitus sp. SFB-5", "rank": "Species"}, "1054947": {"name": "Candidatus Arthromitus sp. SFB-co", "rank": "Species"}, "640512": {"name": "Burkholderia sp. CCGE1003", "rank": "Species"}, "397288": {"name": "Lachnospiraceae bacterium 3-1", "rank": "Species"}, "640510": {"name": "Burkholderia sp. CCGE1001", "rank": "Species"}, "640511": {"name": "Burkholderia sp. CCGE1002", "rank": "Species"}, "1178016": {"name": "Encephalitozoon romaleae SJ-2008", "rank": "Strain"}, "869896": {"name": "Halonotius", "rank": "Genus"}, "1429917": {"name": "Salmonella enterica subsp. enterica serovar Bovismorbificans str. Sal185", "rank": "Strain"}, "1429916": {"name": "Afipia sp. P52-10", "rank": "Species"}, "1429912": {"name": "Mycobacterium phage Jovo", "rank": "Species"}, "397287": {"name": "Lachnospiraceae bacterium 28-4", "rank": "Species"}, "1234679": {"name": "Carnobacterium maltaromaticum LMA28", "rank": "Strain"}, "680197": {"name": "Thalassospira permensis", "rank": "Species"}, "10677": {"name": "Enterobacteria phage Mu", "rank": "Species"}, "10679": {"name": "Enterobacteria phage P2", "rank": "Species"}, "10678": {"name": "Enterobacteria phage P1", "rank": "Species"}, "680198": {"name": "Streptomyces scabiei 87.22", "rank": "Strain"}, "1234671": {"name": "Acetobacter papayae JCM 25143", "rank": "Strain"}, "948669": {"name": "Rodent herpesvirus Peru", "rank": "Species"}, "1500865": {"name": "Drosophila subobscura Nora virus", "rank": "Species"}, "1421850": {"name": "Staphylococcus aureus H47139", "rank": "Strain"}, "1446590": {"name": "Escherichia coli O145:NM str. 2010C-3510", "rank": "Strain"}, "1446591": {"name": "Escherichia coli O145:NM str. 2010C-3511", "rank": "Strain"}, "1446592": {"name": "Escherichia coli O145:NM str. 2010C-3516", "rank": "Strain"}, "1446593": {"name": "Escherichia coli O145:NM str. 2010C-3517", "rank": "Strain"}, "1446594": {"name": "Escherichia coli O145:NM str. 2010C-3518", "rank": "Strain"}, "1446595": {"name": "Escherichia coli O145:NM str. 2010C-3521", "rank": "Strain"}, "1446596": {"name": "Escherichia coli O145:NM str. 2010C-3526", "rank": "Strain"}, "1446597": {"name": "Escherichia coli O145:NM str. 2010C-4557C2", "rank": "Strain"}, "1446598": {"name": "Escherichia coli O146:H21", "rank": "Strain"}, "1446599": {"name": "Escherichia coli O146:H21 str. 2010C-3325", "rank": "Strain"}, "47049": {"name": "Kluyvera phage Kvp1", "rank": "Species"}, "55968": {"name": "Leucobacter", "rank": "Genus"}, "688699": {"name": "Sandfly fever Turkey virus", "rank": "Strain"}, "1158604": {"name": "Enterococcus villorum ATCC 700913", "rank": "Strain"}, "1158606": {"name": "Enterococcus asini ATCC 700915", "rank": "Strain"}, "1158607": {"name": "Enterococcus pallens ATCC BAA-351", "rank": "Strain"}, "1158600": {"name": "Enterococcus faecium ATCC 8459", "rank": "Strain"}, "1158601": {"name": "Enterococcus malodoratus ATCC 43197", "rank": "Strain"}, "1158602": {"name": "Enterococcus raffinosus ATCC 49464", "rank": "Strain"}, "1158603": {"name": "Enterococcus flavescens ATCC 49996", "rank": "Strain"}, "1158608": {"name": "Enterococcus haemoperoxidus ATCC BAA-382", "rank": "Strain"}, "1158609": {"name": "Enterococcus moraviensis ATCC BAA-383", "rank": "Strain"}, "859655": {"name": "Ralstonia solanacearum CMR15", "rank": "Strain"}, "859654": {"name": "Candidatus Blochmannia vafer str. BVAF", "rank": "Strain"}, "859657": {"name": "Ralstonia solanacearum PSI07", "rank": "Strain"}, "859656": {"name": "Ralstonia solanacearum CFBP2957", "rank": "Strain"}, "859651": {"name": "Rosellinia necatrix partitivirus 2", "rank": "Species"}, "859650": {"name": "Turnip curly top virus", "rank": "Species"}, "859653": {"name": "Alpha proteobacterium HIMB5", "rank": "Species"}, "115778": {"name": "Leuconostoc gelidum subsp. gasicomitatum", "rank": "Subspecies"}, "1435296": {"name": "Gluconobacter oxydans DSM 2003", "rank": "Strain"}, "1446628": {"name": "Escherichia coli O157:H7 str. 2011EL-2094", "rank": "Strain"}, "1446629": {"name": "Escherichia coli O157:H7 str. 2011EL-2096", "rank": "Strain"}, "1446626": {"name": "Escherichia coli O157:H7 str. 2011EL-2092", "rank": "Strain"}, "1446627": {"name": "Escherichia coli O157:H7 str. 2011EL-2093", "rank": "Strain"}, "1446624": {"name": "Escherichia coli O157:H7 str. 2011EL-2090", "rank": "Strain"}, "1446625": {"name": "Escherichia coli O157:H7 str. 2011EL-2091", "rank": "Strain"}, "1446622": {"name": "Escherichia coli O157:H7 str. 2010C-4979C1", "rank": "Strain"}, "1446623": {"name": "Escherichia coli O157:H7 str. 2011EL-1107", "rank": "Strain"}, "1446620": {"name": "Escherichia coli O157:H7 str. 2009EL1913", "rank": "Strain"}, "1446621": {"name": "Escherichia coli O157:H7 str. 2009EL2109", "rank": "Strain"}, "1161906": {"name": "Weissella phage phiYS61", "rank": "Species"}, "1161904": {"name": "Bifidobacterium longum subsp. longum 35B", "rank": "Strain"}, "1161903": {"name": "Pseudomonas phage MP42", "rank": "Species"}, "1161902": {"name": "Eubacterium nodatum ATCC 33099", "rank": "Strain"}, "1161901": {"name": "Bacillus phage PBC1", "rank": "Species"}, "663275": {"name": "Fibrisoma limi", "rank": "Species"}, "410359": {"name": "Pyrobaculum calidifontis JCM 11548", "rank": "Strain"}, "410358": {"name": "Methanocorpusculum labreanum Z", "rank": "Strain"}, "1469948": {"name": "Clostridium sp. KNHs209", "rank": "Species"}, "11588": {"name": "Rift Valley fever virus", "rank": "Species"}, "1233320": {"name": "Bovine hungarovirus", "rank": "Species"}, "1471480": {"name": "Prochlorococcus sp. scB243_496G15", "rank": "Species"}, "1471481": {"name": "Prochlorococcus sp. scB243_496M6", "rank": "Species"}, "1471482": {"name": "Prochlorococcus sp. scB243_496N4", "rank": "Species"}, "1471483": {"name": "Prochlorococcus sp. scB243_497E17", "rank": "Species"}, "1471484": {"name": "Prochlorococcus sp. scB243_497I20", "rank": "Species"}, "1471485": {"name": "Prochlorococcus sp. scB243_497J18", "rank": "Species"}, "1471486": {"name": "Prochlorococcus sp. scB243_497N18", "rank": "Species"}, "1471487": {"name": "Prochlorococcus sp. scB243_498A3", "rank": "Species"}, "1471488": {"name": "Prochlorococcus sp. scB243_498B22", "rank": "Species"}, "1471489": {"name": "Prochlorococcus sp. scB243_498B23", "rank": "Species"}, "28213": {"name": "Sphingomonas parapaucimobilis", "rank": "Species"}, "28216": {"name": "Betaproteobacteria", "rank": "Class"}, "159": {"name": "Brachyspira hyodysenteriae", "rank": "Species"}, "10986": {"name": "Rice gall dwarf virus", "rank": "Species"}, "10985": {"name": "Phytoreovirus", "rank": "Genus"}, "395095": {"name": "Mycobacterium tuberculosis str. Haarlem", "rank": "Strain"}, "10981": {"name": "Cypovirus", "rank": "Genus"}, "936476": {"name": "Marinomonas posidonica", "rank": "Species"}, "10988": {"name": "Fijivirus", "rank": "Genus"}, "90961": {"name": "Australian bat lyssavirus", "rank": "Species"}, "544686": {"name": "Epirus cherry virus", "rank": "Species"}, "90963": {"name": "Guinea pig Chlamydia phage", "rank": "Species"}, "90964": {"name": "Staphylococcaceae", "rank": "Family"}, "183925": {"name": "Methanobacteria", "rank": "Class"}, "183924": {"name": "Thermoprotei", "rank": "Class"}, "158": {"name": "Treponema denticola", "rank": "Species"}, "388449": {"name": "Ktedonobacteraceae", "rank": "Family"}, "388448": {"name": "Ktedonobacterales", "rank": "Order"}, "997893": {"name": "Clostridium bolteae 90A5", "rank": "Strain"}, "388447": {"name": "Ktedonobacteria", "rank": "Class"}, "887712": {"name": "Chlamydia trachomatis L2c", "rank": "Strain"}, "1434128": {"name": "Shigella flexneri Shi06AH66", "rank": "Strain"}, "1434129": {"name": "Shigella flexneri Shi06GS43", "rank": "Strain"}, "1391700": {"name": "Pseudozyma aphidis DSM 70725", "rank": "Strain"}, "1391702": {"name": "Tomato mottle mosaic virus", "rank": "Species"}, "1045858": {"name": "Brachyspira intermedia PWS/A", "rank": "Strain"}, "233413": {"name": "Mycobacterium bovis AF2122/97", "rank": "Strain"}, "233412": {"name": "Haemophilus ducreyi 35000HP", "rank": "Strain"}, "762296": {"name": "Methylovulum", "rank": "Genus"}, "1042804": {"name": "Escherichia coli O104:H4 str. H112180280", "rank": "Strain"}, "1045854": {"name": "Weissella koreensis KACC 15510", "rank": "Strain"}, "1042803": {"name": "Escherichia coli O104:H4 str. 01-09591", "rank": "Strain"}, "659660": {"name": "Japanese holly fern mottle virus", "rank": "Species"}, "1045857": {"name": "Cronobacter sakazakii ES713", "rank": "Strain"}, "126070": {"name": "Columbid circovirus", "rank": "Species"}, "107709": {"name": "Opitutus terrae", "rank": "Species"}, "107707": {"name": "Unclassified Verrucomicrobiales", "rank": "No rank"}, "185294": {"name": "Prevotella paludivivens", "rank": "Species"}, "185293": {"name": "Prevotella oryzae", "rank": "Species"}, "185291": {"name": "Unclassified Bacteroidales (miscellaneous)", "rank": "No rank"}, "133453": {"name": "Caldilinea aerophila", "rank": "Species"}, "573199": {"name": "Murine adenovirus 3", "rank": "Strain"}, "1150353": {"name": "Gentian Kobu-sho-associated virus", "rank": "Species"}, "575606": {"name": "Lactobacillus jensenii 27-2-CHN", "rank": "Strain"}, "336963": {"name": "Uncinocarpus reesii 1704", "rank": "Strain"}, "336962": {"name": "Unclassified Avastrovirus", "rank": "No rank"}, "574899": {"name": "Haloferula", "rank": "Genus"}, "1203261": {"name": "Prochlorococcus sp. W2", "rank": "Species"}, "1203260": {"name": "Riemerella anatipestifer RA-SG", "rank": "Strain"}, "32067": {"name": "Leptotrichia", "rank": "Genus"}, "766145": {"name": "Shigella flexneri VA-6", "rank": "Strain"}, "100953": {"name": "Atadenovirus", "rank": "Genus"}, "12585": {"name": "Banana bunchy top virus", "rank": "Species"}, "349742": {"name": "Sedimenticola", "rank": "Genus"}, "349741": {"name": "Akkermansia muciniphila ATCC BAA-835", "rank": "Strain"}, "1427232": {"name": "Mycobacterium tuberculosis XTB13-143", "rank": "Strain"}, "349747": {"name": "Yersinia pseudotuberculosis IP 31758", "rank": "Strain"}, "349746": {"name": "Yersinia pestis Angola", "rank": "Strain"}, "565040": {"name": "Bifidobacterium longum subsp. infantis 157F", "rank": "Strain"}, "565042": {"name": "Bifidobacterium longum subsp. longum JCM 1217", "rank": "Strain"}, "1306174": {"name": "Kineosporia aurantiaca JCM 3230", "rank": "Strain"}, "565045": {"name": "Luminiphilus syltensis NOR5-1B", "rank": "Strain"}, "52698": {"name": "Actinopolyspora iraqiensis", "rank": "Species"}, "692420": {"name": "Bacillus amyloliquefaciens DSM 7", "rank": "Strain"}, "1303334": {"name": "Human polyomavirus 12", "rank": "Species"}, "208973": {"name": "Choristoneura fumiferana multiple nucleopolyhedrovirus", "rank": "Species"}, "655097": {"name": "Pseudomonas phage LUZ7", "rank": "Species"}, "44088": {"name": "Canarypox virus", "rank": "Species"}, "655098": {"name": "Pseudomonas phage LIT1", "rank": "Species"}, "282132": {"name": "Candidatus Protochlamydia", "rank": "Genus"}, "632516": {"name": "Caldicellulosiruptor lactoaceticus 6A", "rank": "Strain"}, "661478": {"name": "Fimbriimonas ginsengisoli Gsoil 348", "rank": "Strain"}, "632518": {"name": "Caldicellulosiruptor owensensis OL", "rank": "Strain"}, "286802": {"name": "Segniliparus rotundus", "rank": "Species"}, "2268": {"name": "Thermofilum", "rank": "Genus"}, "286801": {"name": "Segniliparus", "rank": "Genus"}, "286804": {"name": "Segniliparus rugosus", "rank": "Species"}, "2263": {"name": "Thermococcus", "rank": "Genus"}, "2260": {"name": "Pyrococcus", "rank": "Genus"}, "2261": {"name": "Pyrococcus furiosus", "rank": "Species"}, "2266": {"name": "Thermoproteales", "rank": "Order"}, "2267": {"name": "Thermoproteaceae", "rank": "Family"}, "2265": {"name": "Thermococcus litoralis", "rank": "Species"}, "5250": {"name": "Ceratobasidiaceae", "rank": "Family"}, "266264": {"name": "Cupriavidus metallidurans CH34", "rank": "Strain"}, "5257": {"name": "Ustilaginomycetes", "rank": "Class"}, "5254": {"name": "Dacrymycetaceae", "rank": "Family"}, "273121": {"name": "Wolinella succinogenes DSM 1740", "rank": "Strain"}, "273123": {"name": "Yersinia pseudotuberculosis IP 32953", "rank": "Strain"}, "525146": {"name": "Desulfovibrio desulfuricans subsp. desulfuricans str. ATCC 27774", "rank": "Strain"}, "205948": {"name": "Cenarchaeales", "rank": "Order"}, "331992": {"name": "Kamptonema formosum", "rank": "Species"}, "1200792": {"name": "Brevibacillus brevis X23", "rank": "Strain"}, "1200793": {"name": "Streptococcus salivarius K12", "rank": "Strain"}, "594679": {"name": "Francisella guangzhouensis", "rank": "Species"}, "1409689": {"name": "Staphylococcus aureus UCIM6126", "rank": "Strain"}, "1409688": {"name": "Staphylococcus aureus UCIM6123", "rank": "Strain"}, "1409685": {"name": "Staphylococcus aureus OCMM6109", "rank": "Strain"}, "1409684": {"name": "Staphylococcus aureus OCMM6114", "rank": "Strain"}, "1409687": {"name": "Staphylococcus aureus OCMM6115", "rank": "Strain"}, "1409686": {"name": "Staphylococcus aureus OCMM6110", "rank": "Strain"}, "1409681": {"name": "Staphylococcus aureus WMCA6086", "rank": "Strain"}, "1444290": {"name": "Clostridium novyi A str. 4570", "rank": "Strain"}, "1409683": {"name": "Staphylococcus aureus WAMC6102", "rank": "Strain"}, "1409682": {"name": "Staphylococcus aureus WMCA6084", "rank": "Strain"}, "57119": {"name": "Bean yellow dwarf virus", "rank": "Species"}, "1412678": {"name": "Staphylococcus aureus M70073", "rank": "Strain"}, "1412679": {"name": "Staphylococcus aureus M70099", "rank": "Strain"}, "1121870": {"name": "Epilithonimonas tenax DSM 16811", "rank": "Strain"}, "1412670": {"name": "Staphylococcus aureus M46077", "rank": "Strain"}, "1121877": {"name": "Ferrimicrobium acidiphilum DSM 19497", "rank": "Strain"}, "1412672": {"name": "Staphylococcus aureus M53327", "rank": "Strain"}, "1412673": {"name": "Staphylococcus aureus M53356", "rank": "Strain"}, "1412674": {"name": "Staphylococcus aureus M56985", "rank": "Strain"}, "1412675": {"name": "Staphylococcus aureus M62699", "rank": "Strain"}, "1412676": {"name": "Staphylococcus aureus M66661", "rank": "Strain"}, "1412677": {"name": "Staphylococcus aureus M66673", "rank": "Strain"}, "1417040": {"name": "Staphylococcus aureus F63704", "rank": "Strain"}, "1040980": {"name": "Mesorhizobium ciceri CMG6", "rank": "Strain"}, "1040983": {"name": "Mesorhizobium loti USDA 3471", "rank": "Strain"}, "1040982": {"name": "Mesorhizobium loti CJ3sym", "rank": "Strain"}, "1040985": {"name": "Mesorhizobium sp. WSM2561", "rank": "Species"}, "1040984": {"name": "Mesorhizobium sp. WSM1293", "rank": "Species"}, "1040987": {"name": "Mesorhizobium sp. WSM3626", "rank": "Species"}, "1417047": {"name": "Staphylococcus aureus T74154", "rank": "Strain"}, "1417048": {"name": "Staphylococcus aureus T74060", "rank": "Strain"}, "1040988": {"name": "Bradyrhizobium sp. WSM4349", "rank": "Species"}, "132490": {"name": "Unclassified Burkholderiaceae", "rank": "No rank"}, "1543375": {"name": "Aeromonas sp. 4287D", "rank": "Species"}, "1462428": {"name": "Candidatus Aenigmarchaeum subterraneum", "rank": "Species"}, "1241582": {"name": "Burkholderia thailandensis 2002721723", "rank": "Strain"}, "1462422": {"name": "Parvarchaeota", "rank": "Phylum"}, "470314": {"name": "Xanthomonas phage Xop411", "rank": "Species"}, "1462427": {"name": "Candidatus Aenigmarchaeum", "rank": "Genus"}, "33188": {"name": "Uncinocarpus reesii", "rank": "Species"}, "1159899": {"name": "Salmonella enterica subsp. enterica serovar Typhimurium str. LT2-4", "rank": "Strain"}, "33183": {"name": "Onygenales", "rank": "Order"}, "33184": {"name": "Onygenaceae", "rank": "Family"}, "33187": {"name": "Uncinocarpus", "rank": "Genus"}, "56448": {"name": "Xanthomonas arboricola", "rank": "Species"}, "245876": {"name": "Nitratireductor", "rank": "Genus"}, "553611": {"name": "Photobacterium leiognathi", "rank": "Species"}, "324602": {"name": "Chloroflexus aurantiacus J-10-fl", "rank": "Strain"}, "1125747": {"name": "Glaciecola agarilytica NO2", "rank": "Strain"}, "89583": {"name": "Gluconacetobacter", "rank": "Genus"}, "195041": {"name": "Streptococcus oligofermentans", "rank": "Species"}, "749222": {"name": "Nitratifractor salsuginis DSM 16511", "rank": "Strain"}, "1341693": {"name": "Klebsiella pneumoniae subsp. pneumoniae MP14", "rank": "Strain"}, "1341692": {"name": "Clostridium autoethanogenum DSM 10061", "rank": "Strain"}, "1341695": {"name": "Bifidobacterium bombi DSM 19703", "rank": "Strain"}, "1341694": {"name": "Bifidobacterium indicum LMG 11587 = DSM 20214", "rank": "Strain"}, "1151754": {"name": "Pseudozyma antarctica T-34", "rank": "Strain"}, "155892": {"name": "Caulobacter vibrioides", "rank": "Species"}, "320839": {"name": "Staphylococcus phage 47", "rank": "Strain"}, "1094989": {"name": "Candida albicans P78048", "rank": "Strain"}, "526225": {"name": "Geodermatophilus obscurus DSM 43160", "rank": "Strain"}, "526224": {"name": "Brachyspira murdochii DSM 12563", "rank": "Strain"}, "526227": {"name": "Meiothermus silvanus DSM 9946", "rank": "Strain"}, "526226": {"name": "Gordonia bronchialis DSM 43247", "rank": "Strain"}, "526221": {"name": "Verticillium alfalfae VaMs.102", "rank": "Strain"}, "320835": {"name": "Staphylococcus phage 53", "rank": "Strain"}, "320836": {"name": "Staphylococcus phage 2638A", "rank": "Species"}, "526222": {"name": "Desulfovibrio salexigens DSM 2638", "rank": "Strain"}, "1414737": {"name": "Rhizobium phage vB_RleS_L338C", "rank": "Species"}, "1414736": {"name": "Lactobacillus phage J-1", "rank": "Species"}, "1547444": {"name": "Pseudoalteromonas sp. PLSV", "rank": "Species"}, "1547445": {"name": "Francisella sp. FSC1006", "rank": "Species"}, "1235659": {"name": "Staphylococcus phage vB_SauM_Remus", "rank": "Species"}, "1414739": {"name": "Vibrio phage SHOU24", "rank": "Species"}, "1414738": {"name": "Shigella phage pSb-1", "rank": "Species"}, "1031710": {"name": "Oligotropha carboxidovorans OM4", "rank": "Strain"}, "997296": {"name": "Bacillus methanolicus PB1", "rank": "Strain"}, "1496688": {"name": "Cyanobium sp. CACIAM 14", "rank": "Species"}, "1401685": {"name": "Candidatus Xenolissoclinum pacificiensis L6", "rank": "Strain"}, "56": {"name": "Sorangium cellulosum", "rank": "Species"}, "51": {"name": "Chondromyces apiculatus", "rank": "Species"}, "50": {"name": "Chondromyces", "rank": "Genus"}, "59": {"name": "Vitreoscilla", "rank": "Genus"}, "1347086": {"name": "Bacillus sp. EB01", "rank": "Species"}, "198804": {"name": "Buchnera aphidicola str. Sg (Schizaphis graminum)", "rank": "Strain"}, "1131271": {"name": "Verrucomicrobia bacterium SCGC AB-629-E09", "rank": "Species"}, "1131272": {"name": "Chloroflexi bacterium SCGC AB-629-P13", "rank": "Species"}, "1131273": {"name": "Marinimicrobia bacterium SCGC AB-629-J13", "rank": "Species"}, "999151": {"name": "Methylophaga lonarensis", "rank": "Species"}, "1131275": {"name": "Gamma proteobacterium SCGC AB-629-K02", "rank": "Species"}, "1410708": {"name": "Staphylococcus aureus F48584", "rank": "Strain"}, "1131277": {"name": "Alpha proteobacterium SCGC AB-629-F11", "rank": "Species"}, "1131278": {"name": "SAR324 cluster bacterium SCGC AB-629-J17", "rank": "Species"}, "1131279": {"name": "SAR324 cluster bacterium SCGC AB-629-O05", "rank": "Species"}, "1410704": {"name": "Staphylococcus aureus S30087", "rank": "Strain"}, "1410705": {"name": "Staphylococcus aureus H83536", "rank": "Strain"}, "1410702": {"name": "Staphylococcus aureus H90284", "rank": "Strain"}, "1211023": {"name": "Porphyromonas gingivalis SJD2", "rank": "Strain"}, "1410700": {"name": "Staphylococcus aureus W31862", "rank": "Strain"}, "1234593": {"name": "Staphylococcus sp. E463", "rank": "Species"}, "318836": {"name": "Kotonkan virus", "rank": "Species"}, "1218077": {"name": "Burkholderia fungorum NBRC 102489", "rank": "Strain"}, "318834": {"name": "Berrimah virus", "rank": "Species"}, "1235655": {"name": "Propionibacterium phage PHL113M01", "rank": "Species"}, "1234597": {"name": "Ochrobactrum intermedium M86", "rank": "Strain"}, "1235654": {"name": "Propionibacterium phage PHL112N00", "rank": "Species"}, "1421829": {"name": "Staphylococcus aureus F22648", "rank": "Strain"}, "1234596": {"name": "Borrelia garinii NMJW1", "rank": "Strain"}, "219181": {"name": "Ottowia", "rank": "Genus"}, "1389488": {"name": "Listeria monocytogenes serotype 4bV str. LS644", "rank": "Strain"}, "1389489": {"name": "Leifsonia xyli subsp. cynodontis DSM 46306", "rank": "Strain"}, "1389486": {"name": "Listeria monocytogenes serotype 4bV str. LS643", "rank": "Strain"}, "292477": {"name": "Pepper yellow leaf curl Indonesia virus", "rank": "Species"}, "1389485": {"name": "Listeria monocytogenes serotype 4bV str. LS642", "rank": "Strain"}, "446660": {"name": "Adlercreutzia equolifaciens", "rank": "Species"}, "591019": {"name": "Staphylothermus hellenicus DSM 12710", "rank": "Strain"}, "613026": {"name": "Helicobacter bilis ATCC 43879", "rank": "Strain"}, "361688": {"name": "Single stranded DNA satellites", "rank": "No rank"}, "70803": {"name": "Salmonella enterica subsp. enterica serovar Minnesota", "rank": "Strain"}, "1418237": {"name": "Pseudomonas aeruginosa BWH051", "rank": "Strain"}, "1321772": {"name": "Aggregatibacter sp. oral taxon 458 str. W10330", "rank": "Strain"}, "197310": {"name": "Enterobacteria phage RB14", "rank": "Species"}, "1007119": {"name": "Gamma proteobacterium SCGC AAA076-P13", "rank": "Species"}, "1007118": {"name": "Gamma proteobacterium SCGC AAA076-P09", "rank": "Species"}, "1156721": {"name": "Halorubrum pleomorphic virus 6", "rank": "Species"}, "1156720": {"name": "Halorubrum pleomorphic virus 3", "rank": "Species"}, "240495": {"name": "Pseudonocardia dioxanivorans", "rank": "Species"}, "10317": {"name": "Cercopithecine herpesvirus 2", "rank": "Species"}, "1007113": {"name": "Alpha proteobacterium SCGC AAA160-J14", "rank": "Species"}, "1007112": {"name": "Alpha proteobacterium SCGC AAA158-M15", "rank": "Species"}, "1007111": {"name": "Alpha proteobacterium SCGC AAA158-B04", "rank": "Species"}, "1007110": {"name": "Alpha proteobacterium SCGC AAA076-E06", "rank": "Species"}, "1007117": {"name": "Gamma proteobacterium SCGC AAA076-F14", "rank": "Species"}, "1007116": {"name": "Gamma proteobacterium SCGC AAA076-E13", "rank": "Species"}, "1007115": {"name": "Gamma proteobacterium SCGC AAA076-D13", "rank": "Species"}, "1007114": {"name": "Gamma proteobacterium SCGC AAA076-D02", "rank": "Species"}, "584708": {"name": "Aminomonas paucivorans DSM 12260", "rank": "Strain"}, "1302848": {"name": "Chickpea chlorosis Australia virus", "rank": "Species"}, "1321773": {"name": "Atopobium sp. oral taxon 810 str. F0209", "rank": "Strain"}, "1418283": {"name": "Staphylococcus aureus F42559", "rank": "Strain"}, "4952": {"name": "Yarrowia lipolytica", "rank": "Species"}, "1418281": {"name": "Staphylococcus aureus F32629", "rank": "Strain"}, "1418280": {"name": "Staphylococcus aureus W89581", "rank": "Strain"}, "1418287": {"name": "Staphylococcus aureus F42582", "rank": "Strain"}, "1418286": {"name": "Staphylococcus aureus F42580", "rank": "Strain"}, "1418285": {"name": "Staphylococcus aureus F42579", "rank": "Strain"}, "1418284": {"name": "Staphylococcus aureus F42568", "rank": "Strain"}, "1072685": {"name": "Basilea psittacipulmonis DSM 24701", "rank": "Strain"}, "1418288": {"name": "Staphylococcus aureus F45759", "rank": "Strain"}, "1122931": {"name": "Parabacteroides gordonii DSM 23371", "rank": "Strain"}, "1072681": {"name": "Candidatus Haloredivivus sp. G17", "rank": "Species"}, "359110": {"name": "Pseudomonas extremaustralis", "rank": "Species"}, "1122936": {"name": "Pasteurella pneumotropica DSM 21403", "rank": "Strain"}, "1451190": {"name": "Mycobacterium fortuitum Z58", "rank": "Strain"}, "1451191": {"name": "Mycobacterium kansasii Z61", "rank": "Strain"}, "1588049": {"name": "Tadarida brasiliensis polyomavirus 2", "rank": "Species"}, "1588048": {"name": "Tadarida brasiliensis polyomavirus 1", "rank": "Species"}, "945434": {"name": "Escherichia coli EC4100B", "rank": "Strain"}, "945433": {"name": "Escherichia coli WV_060327", "rank": "Strain"}, "415426": {"name": "Hyperthermus butylicus DSM 5456", "rank": "Strain"}, "1511600": {"name": "Desulfovibrio africanus subsp. africanus", "rank": "Subspecies"}, "941322": {"name": "Escherichia coli O25b:H4-ST131 str. EC958", "rank": "Strain"}, "438": {"name": "Acetobacter pasteurianus", "rank": "Species"}, "434": {"name": "Acetobacter", "rank": "Genus"}, "435": {"name": "Acetobacter aceti", "rank": "Species"}, "436": {"name": "Komagataeibacter hansenii", "rank": "Species"}, "364106": {"name": "Escherichia coli UTI89", "rank": "Strain"}, "433": {"name": "Acetobacteraceae", "rank": "Family"}, "1032488": {"name": "Neisseria shayeganii 871", "rank": "Strain"}, "1340851": {"name": "Pseudomonas aeruginosa RP73", "rank": "Strain"}, "1057002": {"name": "Ensifer sp. BR816", "rank": "Species"}, "1032480": {"name": "Microlunatus phosphovorus NM-1", "rank": "Strain"}, "883081": {"name": "Alloiococcus otitis ATCC 51267", "rank": "Strain"}, "883080": {"name": "Afipia felis ATCC 53690", "rank": "Strain"}, "1262454": {"name": "Pseudomonas fluorescens Pf29Arp", "rank": "Strain"}, "1262456": {"name": "Ralstonia solanacearum FQY_4", "rank": "Strain"}, "1157490": {"name": "Tumebacillus flagellatus", "rank": "Species"}, "1262450": {"name": "Ophiostoma piceae UAMH 11346", "rank": "Strain"}, "1262452": {"name": "Streptomyces sp. 769", "rank": "Species"}, "1399": {"name": "Bacillus firmus", "rank": "Species"}, "1398": {"name": "Bacillus coagulans", "rank": "Species"}, "5062": {"name": "Aspergillus oryzae", "rank": "Species"}, "1393": {"name": "Brevibacillus brevis", "rank": "Species"}, "1392": {"name": "Bacillus anthracis", "rank": "Species"}, "1391": {"name": "Aneurinibacillus aneurinilyticus", "rank": "Species"}, "1390": {"name": "Bacillus amyloliquefaciens", "rank": "Species"}, "1310818": {"name": "Acinetobacter baumannii 121738", "rank": "Strain"}, "1310816": {"name": "Acinetobacter baumannii 1571545", "rank": "Strain"}, "1310815": {"name": "Acinetobacter baumannii 756476", "rank": "Strain"}, "1310813": {"name": "Acinetobacter baumannii 722310", "rank": "Strain"}, "1310812": {"name": "Acinetobacter baumannii 1552389", "rank": "Strain"}, "1310811": {"name": "Acinetobacter baumannii 458282", "rank": "Strain"}, "1310810": {"name": "Acinetobacter baumannii 7893", "rank": "Strain"}, "1438722": {"name": "Klebsiella pneumoniae CHS 16", "rank": "Strain"}, "1210046": {"name": "Janibacter hoylei PVAS-1", "rank": "Strain"}, "1210045": {"name": "Streptomyces sp. AA0539", "rank": "Species"}, "1210043": {"name": "Shigella flexneri S5644", "rank": "Strain"}, "1438727": {"name": "Klebsiella pneumoniae CHS 21", "rank": "Strain"}, "1210041": {"name": "Streptococcus pyogenes 06BA18369", "rank": "Strain"}, "1438725": {"name": "Klebsiella pneumoniae CHS 19", "rank": "Strain"}, "1438728": {"name": "Klebsiella pneumoniae CHS 22", "rank": "Strain"}, "1438729": {"name": "Klebsiella pneumoniae CHS 23", "rank": "Strain"}, "36355": {"name": "Pseudaletia unipuncta granulovirus", "rank": "Species"}, "234826": {"name": "Anaplasma marginale str. St. Maries", "rank": "Strain"}, "1021": {"name": "Beggiatoa", "rank": "Genus"}, "1023": {"name": "Microscilla", "rank": "Genus"}, "1022": {"name": "Beggiatoa alba", "rank": "Species"}, "1027": {"name": "Microscilla marina", "rank": "Species"}, "52972": {"name": "Polaromonas", "rank": "Genus"}, "52979": {"name": "Lactobacillus phage phig1e", "rank": "Species"}, "1280958": {"name": "Escherichia coli HVH 3 (4-7276001)", "rank": "Strain"}, "1280959": {"name": "Escherichia coli HVH 4 (4-7276109)", "rank": "Strain"}, "1280954": {"name": "Hyphomonas polymorpha PS728", "rank": "Strain"}, "225762": {"name": "Nocardiopsis alkaliphila", "rank": "Species"}, "1280957": {"name": "Escherichia coli HVH 2 (4-6943160)", "rank": "Strain"}, "1280950": {"name": "Hyphomonas johnsonii MHS-2", "rank": "Strain"}, "1280951": {"name": "Hyphomonas hirschiana VP5", "rank": "Strain"}, "1280952": {"name": "Hyphomonas jannaschiana VP2", "rank": "Strain"}, "1280953": {"name": "Hyphomonas oceanitis SCH89", "rank": "Strain"}, "39487": {"name": "Atopobium fossor", "rank": "Species"}, "39486": {"name": "Dorea formicigenerans", "rank": "Species"}, "39485": {"name": "Eubacterium eligens", "rank": "Species"}, "39484": {"name": "Eubacterium desmolans", "rank": "Species"}, "39483": {"name": "Faecalitalea cylindroides", "rank": "Species"}, "317025": {"name": "Thiomicrospira crunogena XCL-2", "rank": "Strain"}, "317027": {"name": "Allium virus X", "rank": "Species"}, "39488": {"name": "Eubacterium hallii", "rank": "Species"}, "1259798": {"name": "Pseudomonas sp. LAMO17WK12:I2", "rank": "Species"}, "1348623": {"name": "Bacillus megaterium NBRC 15308 = ATCC 14581", "rank": "Strain"}, "1344959": {"name": "Citrobacter freundii complex", "rank": "No rank"}, "1259795": {"name": "Coprothermobacter platensis DSM 11748", "rank": "Strain"}, "1259797": {"name": "Pseudomonas sp. URMO17WK12:I12", "rank": "Species"}, "309512": {"name": "Dinoroseobacter", "rank": "Genus"}, "1401669": {"name": "Erwinia phage PhiEaH1", "rank": "Species"}, "1438701": {"name": "Klebsiella pneumoniae BIDMC 68", "rank": "Strain"}, "153057": {"name": "Alpharetrovirus", "rank": "Genus"}, "1079994": {"name": "Leucobacter chromiiresistens", "rank": "Species"}, "137779": {"name": "Pseudoalteromonas flavipulchra", "rank": "Species"}, "511755": {"name": "Human TMEV-like cardiovirus", "rank": "Strain"}, "1193576": {"name": "Staphylococcus aureus subsp. aureus CN1", "rank": "Strain"}, "1079998": {"name": "Synechococcus phage ACG-2014c", "rank": "Species"}, "1079999": {"name": "Synechococcus phage metaG-MbCM1", "rank": "Species"}, "684364": {"name": "Batrachochytrium dendrobatidis JAM81", "rank": "Strain"}, "1427199": {"name": "Mycobacterium tuberculosis XTB13-107", "rank": "Strain"}, "1151263": {"name": "Peptoclostridium difficile CD40", "rank": "Strain"}, "1441611": {"name": "Vibrio parahaemolyticus TUMSAT_H03_S5", "rank": "Strain"}, "1078029": {"name": "Escherichia coli O113:H21 str. CL-3", "rank": "Strain"}, "573236": {"name": "Bifidobacterium animalis subsp. lactis V9", "rank": "Strain"}, "1078021": {"name": "Escherichia coli O113:H21", "rank": "Strain"}, "1078020": {"name": "Mycobacterium thermoresistibile ATCC 19527", "rank": "Strain"}, "1151264": {"name": "Peptoclostridium difficile CD41", "rank": "Strain"}, "257003": {"name": "Sphingomonas phyllosphaerae", "rank": "Species"}, "1352346": {"name": "Helicobacter pylori UM077", "rank": "Strain"}, "261524": {"name": "Mycobacterium liflandii", "rank": "Species"}, "1410791": {"name": "Staphylococcus aureus H18809", "rank": "Strain"}, "1427196": {"name": "Mycobacterium tuberculosis XTB13-104", "rank": "Strain"}, "1311068": {"name": "Acinetobacter baumannii 26016_1", "rank": "Strain"}, "1392091": {"name": "Staphylococcus aureus M1100", "rank": "Strain"}, "1392090": {"name": "Staphylococcus aureus M1099", "rank": "Strain"}, "1392093": {"name": "Staphylococcus aureus M1102", "rank": "Strain"}, "1392092": {"name": "Staphylococcus aureus M1101", "rank": "Strain"}, "1117322": {"name": "Haemophilus parasuis str. Nagasaki", "rank": "Strain"}, "1117320": {"name": "Pseudoalteromonas undina NCIMB 2128", "rank": "Strain"}, "302481": {"name": "Halobacillus kuroshimensis", "rank": "Species"}, "334856": {"name": "Stenotrophomonas phage phiSMA9", "rank": "Species"}, "1284658": {"name": "Planktomarina temperata", "rank": "Species"}, "1284657": {"name": "Planktomarina", "rank": "Genus"}, "302485": {"name": "Phaeobacter", "rank": "Genus"}, "334852": {"name": "Methylobacterium oryzae", "rank": "Species"}, "58123": {"name": "Spirillospora albida", "rank": "Species"}, "58122": {"name": "Spirillospora", "rank": "Genus"}, "653667": {"name": "Schizosaccharomyces cryophilus OY26", "rank": "Strain"}, "1472912": {"name": "Nitrincola phage 1M3-16", "rank": "Species"}, "1472911": {"name": "Porcine parvovirus 6", "rank": "Species"}, "81412": {"name": "Aminomonas paucivorans", "rank": "Species"}, "81411": {"name": "Aminomonas", "rank": "Genus"}, "81416": {"name": "Methanofollis", "rank": "Genus"}, "198215": {"name": "Shigella flexneri 2a str. 2457T", "rank": "Strain"}, "198214": {"name": "Shigella flexneri 2a str. 301", "rank": "Strain"}, "1398970": {"name": "Acinetobacter baumannii UH3807", "rank": "Strain"}, "1398971": {"name": "Acinetobacter baumannii UH5107", "rank": "Strain"}, "1398972": {"name": "Acinetobacter baumannii UH5207", "rank": "Strain"}, "1398973": {"name": "Acinetobacter baumannii UH5307", "rank": "Strain"}, "1398974": {"name": "Acinetobacter baumannii UH5707", "rank": "Strain"}, "1398975": {"name": "Acinetobacter baumannii UH6107", "rank": "Strain"}, "1398976": {"name": "Acinetobacter baumannii UH6207", "rank": "Strain"}, "1398977": {"name": "Acinetobacter baumannii UH6507", "rank": "Strain"}, "1398978": {"name": "Acinetobacter baumannii UH6907", "rank": "Strain"}, "1398979": {"name": "Acinetobacter baumannii UH7007", "rank": "Strain"}, "1167738": {"name": "Burkholderia sp. JGI 001012-B17", "rank": "Species"}, "1167739": {"name": "Burkholderia sp. JGI 001013-G13", "rank": "Species"}, "985762": {"name": "Staphylococcus agnetis", "rank": "Species"}, "634458": {"name": "Acetobacter pasteurianus IFO 3283-01-42C", "rank": "Strain"}, "634459": {"name": "Acetobacter pasteurianus IFO 3283-12", "rank": "Strain"}, "935641": {"name": "Dyoetapapillomavirus", "rank": "Genus"}, "1398202": {"name": "Xenorhabdus bovienii str. oregonense", "rank": "Strain"}, "1398203": {"name": "Xenorhabdus bovienii str. kraussei Quebec", "rank": "Strain"}, "1398200": {"name": "Xenorhabdus bovienii str. feltiae Moldova", "rank": "Strain"}, "1398201": {"name": "Xenorhabdus bovienii str. puntauvense", "rank": "Strain"}, "634452": {"name": "Acetobacter pasteurianus IFO 3283-01", "rank": "Strain"}, "634453": {"name": "Acetobacter pasteurianus IFO 3283-03", "rank": "Strain"}, "634454": {"name": "Acetobacter pasteurianus IFO 3283-07", "rank": "Strain"}, "634455": {"name": "Acetobacter pasteurianus IFO 3283-22", "rank": "Strain"}, "634456": {"name": "Acetobacter pasteurianus IFO 3283-26", "rank": "Strain"}, "1343043": {"name": "Saccharomyces sp. EDRL", "rank": "Strain"}, "1236689": {"name": "Candidatus Methanomethylophilus alvus Mx1201", "rank": "Strain"}, "679536": {"name": "Cotton leaf curl Gezira alphasatellite", "rank": "Species"}, "1169297": {"name": "Enterococcus faecalis EnGen0365", "rank": "Strain"}, "1169296": {"name": "Enterococcus faecalis EnGen0337", "rank": "Strain"}, "336633": {"name": "Unclassified Cripavirus", "rank": "No rank"}, "1169294": {"name": "Enterococcus faecalis EnGen0351", "rank": "Strain"}, "336635": {"name": "Unclassified Dicistroviridae", "rank": "No rank"}, "1169292": {"name": "Enterococcus faecalis EnGen0350", "rank": "Strain"}, "1169291": {"name": "Enterococcus faecalis EnGen0364", "rank": "Strain"}, "1169290": {"name": "Enterococcus faecalis ATCC 35038", "rank": "Strain"}, "1169299": {"name": "Enterococcus faecalis EnGen0354", "rank": "Strain"}, "1169298": {"name": "Enterococcus faecalis EnGen0342", "rank": "Strain"}, "349101": {"name": "Rhodobacter sphaeroides ATCC 17029", "rank": "Strain"}, "349102": {"name": "Rhodobacter sphaeroides ATCC 17025", "rank": "Strain"}, "349106": {"name": "Psychrobacter sp. PRwf-1", "rank": "Species"}, "452227": {"name": "Umbilicariales", "rank": "Order"}, "406101": {"name": "Asaia sp. SF2.1", "rank": "Species"}, "184869": {"name": "Varibaculum", "rank": "Genus"}, "347966": {"name": "Bacillus phage Cherry", "rank": "Species"}, "316625": {"name": "Saccharophagus", "rank": "Genus"}, "141390": {"name": "Chromohalobacter israelensis", "rank": "Species"}, "141391": {"name": "Candidatus Mycoplasma haemolamae", "rank": "Species"}, "1293921": {"name": "Brucella ovis IntaBari-2006-46-348", "rank": "Strain"}, "1293920": {"name": "Brucella ovis IntaBari-1993-758", "rank": "Strain"}, "1293922": {"name": "Brucella ovis IntaBari-2006-46-332", "rank": "Strain"}, "596085": {"name": "Prevotella aurantiaca", "rank": "Species"}, "185880": {"name": "Unclassified Densovirinae", "rank": "No rank"}, "307502": {"name": "Wolbachia endosymbiont of Drosophila ananassae", "rank": "Species"}, "1239307": {"name": "Sodalis sp. HS1", "rank": "Species"}, "189753": {"name": "Bradyrhizobium sp. Ec3.3", "rank": "Species"}, "1053177": {"name": "Bacillus cereus BAG2O-2", "rank": "Strain"}, "2423": {"name": "Fervidobacterium islandicum", "rank": "Species"}, "100379": {"name": "Onion yellows phytoplasma", "rank": "Species"}, "376351": {"name": "Gordonia shandongensis", "rank": "Species"}, "939390": {"name": "Alpha proteobacterium SCGC AAA300-J04", "rank": "Species"}, "38945": {"name": "Flammulina velutipes", "rank": "Species"}, "754040": {"name": "Synechococcus phage S-RIP2", "rank": "Species"}, "930946": {"name": "Fructobacillus fructosus KCTC 3544", "rank": "Strain"}, "1005469": {"name": "Escherichia coli 10.0821", "rank": "Strain"}, "1042876": {"name": "Pseudomonas putida S16", "rank": "Strain"}, "391623": {"name": "Thermococcus barophilus MP", "rank": "Strain"}, "1288359": {"name": "Grass carp rhabdovirus V76", "rank": "Species"}, "1448549": {"name": "Mycobacterium tuberculosis TKK_05SA_0047", "rank": "Strain"}, "1448548": {"name": "Mycobacterium tuberculosis TKK_05SA_0046", "rank": "Strain"}, "391626": {"name": "Octadecabacter antarcticus 307", "rank": "Strain"}, "1448545": {"name": "Mycobacterium tuberculosis TKK_05SA_0042", "rank": "Strain"}, "1448544": {"name": "Mycobacterium tuberculosis TKK_05SA_0041", "rank": "Strain"}, "1005463": {"name": "Escherichia coli 8.0416", "rank": "Strain"}, "1005462": {"name": "Escherichia coli 8.0566", "rank": "Strain"}, "1448540": {"name": "Mycobacterium tuberculosis TKK_05SA_0031", "rank": "Strain"}, "1005467": {"name": "Escherichia coli 10.0869", "rank": "Strain"}, "1448542": {"name": "Mycobacterium tuberculosis TKK_05SA_0036", "rank": "Strain"}, "187764": {"name": "Enterobacteria phage K1-5", "rank": "Species"}, "1158699": {"name": "Staphylococcus aureus M0823", "rank": "Strain"}, "49893": {"name": "Holospora obtusa", "rank": "Species"}, "49891": {"name": "Pirital virus", "rank": "Species"}, "1427236": {"name": "Mycobacterium tuberculosis XTB13-147", "rank": "Strain"}, "597359": {"name": "Kiloniellaceae", "rank": "Family"}, "597358": {"name": "Kiloniellales", "rank": "Order"}, "938518": {"name": "Actinobacterium SCGC AAA044-D11", "rank": "Species"}, "1104580": {"name": "Nanoarchaeota archaeon SCGC AAA011-L15", "rank": "Species"}, "930769": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. 8b-1", "rank": "Strain"}, "930768": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. CVM_69-4941", "rank": "Strain"}, "649739": {"name": "Actinomyces sp. oral taxon 848", "rank": "Species"}, "386429": {"name": "Pseudoalteromonas sp. BSi20495", "rank": "Species"}, "543526": {"name": "Haloterrigena turkmenica DSM 5511", "rank": "Strain"}, "1400931": {"name": "Mycobacterium tuberculosis KT-0096", "rank": "Strain"}, "1315135": {"name": "Acinetobacter baumannii TG02011", "rank": "Strain"}, "1400933": {"name": "Mycobacterium tuberculosis KT-0099", "rank": "Strain"}, "5199": {"name": "Cladonia", "rank": "Genus"}, "272843": {"name": "Pasteurella multocida subsp. multocida str. Pm70", "rank": "Strain"}, "1121086": {"name": "Bacillus aurantiacus DSM 18675", "rank": "Strain"}, "272844": {"name": "Pyrococcus abyssi GE5", "rank": "Strain"}, "225999": {"name": "Mesoplasma syrphidae", "rank": "Species"}, "1121085": {"name": "Bacillus aidingensis DSM 18341", "rank": "Strain"}, "759390": {"name": "Sida golden mottle virus", "rank": "Species"}, "1121088": {"name": "Bacillus coagulans DSM 1 = ATCC 7050", "rank": "Strain"}, "11046": {"name": "Arterivirus", "rank": "Genus"}, "225991": {"name": "Comamonas aquatica", "rank": "Species"}, "5198": {"name": "Cladoniaceae", "rank": "Family"}, "1120935": {"name": "Actinokineospora inagensis DSM 44258", "rank": "Strain"}, "1120934": {"name": "Actinokineospora enzanensis DSM 44649", "rank": "Strain"}, "1120937": {"name": "Actinomadura rifamycini DSM 43936", "rank": "Strain"}, "1120936": {"name": "Actinomadura atramentaria DSM 43919", "rank": "Strain"}, "1120931": {"name": "Actinobacillus capsulatus DSM 19761", "rank": "Strain"}, "1120930": {"name": "Actinoalloteichus cyanogriseus DSM 43889", "rank": "Strain"}, "1120933": {"name": "Actinobaculum urinale DSM 15805", "rank": "Strain"}, "1120932": {"name": "Actinobaculum schaalii DSM 15541", "rank": "Strain"}, "1120938": {"name": "Actinomadura flavalba", "rank": "Species"}, "907272": {"name": "Chlamydia trachomatis J/6276tet1", "rank": "Strain"}, "907271": {"name": "Chlamydia trachomatis RC-J/966", "rank": "Strain"}, "907270": {"name": "Chlamydia trachomatis RC-J(s)/122", "rank": "Strain"}, "1390372": {"name": "Bacillus amyloliquefaciens EGD-AQ14", "rank": "Strain"}, "1390373": {"name": "Lactobacillus plantarum WHE 92", "rank": "Strain"}, "1390370": {"name": "Pseudomonas mendocina EGD-AQ5", "rank": "Strain"}, "1390371": {"name": "Pseudomonas fluorescens EGD-AQ6", "rank": "Strain"}, "1403328": {"name": "Listeria monocytogenes Lm19860", "rank": "Strain"}, "460265": {"name": "Methylobacterium nodulans ORS 2060", "rank": "Strain"}, "1219066": {"name": "Vibrio parahaemolyticus NBRC 12711", "rank": "Strain"}, "1219067": {"name": "Vibrio natriegens NBRC 15636 = ATCC 14048 = DSM 759", "rank": "Strain"}, "1219065": {"name": "Vibrio proteolyticus NBRC 13287", "rank": "Strain"}, "303317": {"name": "Rabbit vesivirus", "rank": "Species"}, "885581": {"name": "Desulfosporosinus acidiphilus", "rank": "Species"}, "380021": {"name": "Pseudomonas protegens", "rank": "Species"}, "67799": {"name": "Thermodesulfobacteria", "rank": "Class"}, "1284352": {"name": "Paenibacillus sp. A9", "rank": "Species"}, "150172": {"name": "Flavobacterium tegetincola", "rank": "Species"}, "10820": {"name": "Chloris striate mosaic virus", "rank": "Species"}, "10821": {"name": "Maize streak virus", "rank": "Species"}, "10825": {"name": "Miscanthus streak virus", "rank": "Species"}, "10826": {"name": "Panicum streak virus", "rank": "Species"}, "10827": {"name": "Potato yellow mosaic virus", "rank": "Species"}, "10829": {"name": "Squash leaf curl virus", "rank": "Species"}, "1069494": {"name": "Trueperella", "rank": "Genus"}, "1069495": {"name": "Escherichia coli XH001", "rank": "Strain"}, "1176125": {"name": "Mycobacterium abscessus M152", "rank": "Strain"}, "439184": {"name": "Escherichia coli RS218", "rank": "Strain"}, "11157": {"name": "Mononegavirales", "rank": "Order"}, "11155": {"name": "Torovirus", "rank": "Genus"}, "11152": {"name": "Turkey coronavirus", "rank": "Strain"}, "11159": {"name": "Paramyxovirinae", "rank": "Subfamily"}, "11158": {"name": "Paramyxoviridae", "rank": "Family"}, "198538": {"name": "Streptococcus pyogenes phage 315.1", "rank": "Species"}, "198539": {"name": "Streptococcus pyogenes phage 315.2", "rank": "Species"}, "283494": {"name": "Begomovirus-associated alphasatellites", "rank": "No rank"}, "240302": {"name": "Halobacillus dabanensis", "rank": "Species"}, "349933": {"name": "Clostridium hydrogeniformans", "rank": "Species"}, "437507": {"name": "Robiginitomaculum antarcticum", "rank": "Species"}, "1333854": {"name": "Pseudomonas alcaligenes OT 69", "rank": "Strain"}, "1203033": {"name": "Lactobacillus hominis", "rank": "Species"}, "1333856": {"name": "Pseudomonas stutzeri MF28", "rank": "Strain"}, "1333857": {"name": "Microbacterium maritypicum MF109", "rank": "Strain"}, "1333850": {"name": "Enterobacter cloacae ECNIH2", "rank": "Strain"}, "1333851": {"name": "Enterobacter cloacae ECNIH3", "rank": "Strain"}, "1333852": {"name": "Klebsiella oxytoca KONIH1", "rank": "Strain"}, "1333853": {"name": "Stenotrophomonas maltophilia MF89", "rank": "Strain"}, "1333859": {"name": "Paenibacillus massiliensis T7", "rank": "Strain"}, "727962": {"name": "Bat adeno-associated virus YNM", "rank": "Species"}, "12390": {"name": "Lactococcus phage phiLC3", "rank": "Species"}, "1173032": {"name": "Chamaesiphon minutus", "rank": "Species"}, "616674": {"name": "Cyanophage SS120-1", "rank": "Species"}, "486620": {"name": "Bacillus anthracis str. A0465", "rank": "Strain"}, "1154924": {"name": "Streptococcus agalactiae GB00614", "rank": "Strain"}, "486622": {"name": "Bacillus anthracis str. A0174", "rank": "Strain"}, "1154926": {"name": "Streptococcus agalactiae GB00651", "rank": "Strain"}, "1154921": {"name": "Streptococcus agalactiae GB00561", "rank": "Strain"}, "1175849": {"name": "Gammapapillomavirus 7", "rank": "Species"}, "1175848": {"name": "Gammapapillomavirus 6", "rank": "Species"}, "891423": {"name": "Salmonella enterica subsp. enterica serovar Typhimurium str. CDC_2009K1277", "rank": "Strain"}, "1538096": {"name": "Alteromonas sp. LTR", "rank": "Species"}, "1413466": {"name": "Staphylococcus aureus C1655", "rank": "Strain"}, "1413467": {"name": "Staphylococcus aureus C2706", "rank": "Strain"}, "1413461": {"name": "Staphylococcus aureus C1842", "rank": "Strain"}, "1154928": {"name": "Streptococcus agalactiae GB00654", "rank": "Strain"}, "528353": {"name": "Neisseria gonorrhoeae FA6140", "rank": "Strain"}, "528352": {"name": "Neisseria gonorrhoeae FA19", "rank": "Strain"}, "528351": {"name": "Neisseria gonorrhoeae F62", "rank": "Strain"}, "1281275": {"name": "Escherichia coli UMEA 3899-1", "rank": "Strain"}, "528357": {"name": "Neisseria gonorrhoeae PID24-1", "rank": "Strain"}, "528356": {"name": "Neisseria gonorrhoeae PID18", "rank": "Strain"}, "528355": {"name": "Neisseria gonorrhoeae PID1", "rank": "Strain"}, "528354": {"name": "Neisseria gonorrhoeae MS11", "rank": "Strain"}, "1137247": {"name": "Salinispora tropica CNB476", "rank": "Strain"}, "528359": {"name": "Neisseria gonorrhoeae SK-92-679", "rank": "Strain"}, "528358": {"name": "Neisseria gonorrhoeae PID332", "rank": "Strain"}, "1281278": {"name": "Escherichia coli UMEA 4076-1", "rank": "Strain"}, "1281279": {"name": "Escherichia coli UMEA 4207-1", "rank": "Strain"}, "1169413": {"name": "Pseudomonas aeruginosa XMG", "rank": "Strain"}, "1200567": {"name": "Ruminobacter sp. RM87", "rank": "Species"}, "1033854": {"name": "Thioalkalivibrio sulfidiphilus", "rank": "Species"}, "760812": {"name": "Streptococcus pneumoniae GA41437", "rank": "Strain"}, "760813": {"name": "Streptococcus pneumoniae GA41538", "rank": "Strain"}, "760810": {"name": "Streptococcus pneumoniae GA41317", "rank": "Strain"}, "760811": {"name": "Streptococcus pneumoniae GA41410", "rank": "Strain"}, "760816": {"name": "Streptococcus pneumoniae GA43257", "rank": "Strain"}, "760817": {"name": "Streptococcus pneumoniae GA43264", "rank": "Strain"}, "760814": {"name": "Streptococcus pneumoniae GA41565", "rank": "Strain"}, "760815": {"name": "Streptococcus pneumoniae GA41688", "rank": "Strain"}, "760818": {"name": "Streptococcus pneumoniae GA43265", "rank": "Strain"}, "760819": {"name": "Streptococcus pneumoniae GA43380", "rank": "Strain"}, "1538549": {"name": "Ethiopian tobacco bushy top virus", "rank": "Species"}, "867904": {"name": "Methanomethylovorans hollandica DSM 15978", "rank": "Strain"}, "867900": {"name": "Cellulophaga lytica DSM 7489", "rank": "Strain"}, "867902": {"name": "Ornithobacterium rhinotracheale DSM 15997", "rank": "Strain"}, "867903": {"name": "Thermaerobacter subterraneus DSM 13965", "rank": "Strain"}, "644610": {"name": "Nyamanini nyavirus", "rank": "Species"}, "229731": {"name": "Halobiforma lacisalsi", "rank": "Species"}, "66858": {"name": "Streptomyces globisporus subsp. globisporus", "rank": "Subspecies"}, "66851": {"name": "Methanobrevibacter oralis", "rank": "Species"}, "83201": {"name": "Vibrio phage fs2", "rank": "Species"}, "996860": {"name": "Leptospira interrogans serovar Copenhageni str. Fiocruz R83", "rank": "Strain"}, "996861": {"name": "Leptospira interrogans serovar Copenhageni str. R066", "rank": "Strain"}, "996862": {"name": "Leptospira interrogans serovar Copenhageni str. HAI0156", "rank": "Strain"}, "12663": {"name": "Feline coronavirus", "rank": "Strain"}, "318846": {"name": "Ngaingan virus", "rank": "Species"}, "555387": {"name": "Synechococcus phage S-RSM4", "rank": "Species"}, "1422216": {"name": "Staphylococcus aureus DAR1084", "rank": "Strain"}, "491893": {"name": "Abalone shriveling syndrome-associated virus", "rank": "Species"}, "1410912": {"name": "Staphylococcus aureus T12805", "rank": "Strain"}, "1410911": {"name": "Staphylococcus aureus F81035", "rank": "Strain"}, "1410910": {"name": "Staphylococcus aureus F31094", "rank": "Strain"}, "1410917": {"name": "Salmonella enterica subsp. enterica serovar Cerro str. CFSAN001674", "rank": "Strain"}, "1410916": {"name": "Salmonella enterica subsp. enterica serovar Cerro str. CFSAN001588", "rank": "Strain"}, "1410915": {"name": "Staphylococcus aureus T16117", "rank": "Strain"}, "1410914": {"name": "Staphylococcus aureus S39411", "rank": "Strain"}, "1332074": {"name": "Pantoea ananatis BRT175", "rank": "Strain"}, "1410919": {"name": "Salmonella enterica subsp. enterica serovar Cerro str. CFSAN001589", "rank": "Strain"}, "1410918": {"name": "Salmonella enterica subsp. enterica serovar Cerro str. CFSAN001587", "rank": "Strain"}, "1332071": {"name": "Serratia fonticola AU-AP2C", "rank": "Strain"}, "1332070": {"name": "Serratia fonticola AU-P3(3)", "rank": "Strain"}, "1332072": {"name": "Pantoea agglomerans Tx10", "rank": "Strain"}, "207678": {"name": "Unclassified Parvovirinae", "rank": "No rank"}, "1123347": {"name": "Tenacibaculum ovolyticum DSM 18103", "rank": "Strain"}, "360118": {"name": "Burkholderia pseudomallei 406e", "rank": "Strain"}, "1354158": {"name": "Mycobacterium tuberculosis MAL010121", "rank": "Strain"}, "1354159": {"name": "Mycobacterium tuberculosis MAL010124", "rank": "Strain"}, "1354156": {"name": "Mycobacterium tuberculosis MAL020102", "rank": "Strain"}, "360112": {"name": "Campylobacter jejuni subsp. jejuni HB93-13", "rank": "Strain"}, "360111": {"name": "Campylobacter jejuni subsp. jejuni CF93-6", "rank": "Strain"}, "360110": {"name": "Campylobacter jejuni subsp. jejuni 84-25", "rank": "Strain"}, "360117": {"name": "Coxiella burnetii Q321", "rank": "Strain"}, "360116": {"name": "Coxiella burnetii 'MSU Goat Q177'", "rank": "Strain"}, "360115": {"name": "Coxiella burnetii RSA 331", "rank": "Strain"}, "1412473": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. SA19970510", "rank": "Strain"}, "1216295": {"name": "Acinetobacter baumannii 53264", "rank": "Strain"}, "501497": {"name": "Thermodesulfatator atlanticus", "rank": "Species"}, "501496": {"name": "Porphyromonas bennonis", "rank": "Species"}, "996285": {"name": "Pseudomonas stutzeri DSM 4166", "rank": "Strain"}, "611301": {"name": "Xanthomonas citri subsp. citri", "rank": "Subspecies"}, "611303": {"name": "Mycobacterium tuberculosis CPHL_A", "rank": "Strain"}, "611302": {"name": "Mycobacterium tuberculosis T46", "rank": "Strain"}, "195102": {"name": "Clostridium perfringens str. 13", "rank": "Strain"}, "611304": {"name": "Mycobacterium africanum K85", "rank": "Strain"}, "1305590": {"name": "Kingella kingae KK101", "rank": "Strain"}, "1305591": {"name": "Kingella kingae KK88", "rank": "Strain"}, "1305592": {"name": "Kingella kingae KK83", "rank": "Strain"}, "1305593": {"name": "Kingella kingae KK145", "rank": "Strain"}, "1000570": {"name": "Streptococcus anginosus SK52 = DSM 20563", "rank": "Strain"}, "1305595": {"name": "Kingella kingae KK274", "rank": "Strain"}, "1305596": {"name": "Kingella kingae KK141", "rank": "Strain"}, "1305598": {"name": "Staphylococcus aureus M1", "rank": "Strain"}, "1438785": {"name": "Klebsiella pneumoniae MGH 60", "rank": "Strain"}, "1268080": {"name": "Aeromonas hydrophila 277", "rank": "Strain"}, "1173850": {"name": "Salmonella enterica subsp. enterica serovar Indiana str. ATCC 51959", "rank": "Strain"}, "1438783": {"name": "Klebsiella pneumoniae MGH 52", "rank": "Strain"}, "911239": {"name": "Pseudomonas sp. CF149", "rank": "Species"}, "1341151": {"name": "Laceyella sacchari 1-1", "rank": "Strain"}, "1341154": {"name": "Flavobacterium cauense R2A-7", "rank": "Strain"}, "1341155": {"name": "Flavobacterium saliperosum S13", "rank": "Strain"}, "1341156": {"name": "Ruminococcus albus SY3", "rank": "Strain"}, "1341157": {"name": "Ruminococcus flavefaciens 007c", "rank": "Strain"}, "498743": {"name": "Borrelia garinii PBr", "rank": "Strain"}, "1522316": {"name": "Bacterium YEK0313", "rank": "Species"}, "261964": {"name": "Kangiella koreensis", "rank": "Species"}, "747369": {"name": "Mycobacterium tuberculosis R1207", "rank": "Strain"}, "747368": {"name": "Mycobacterium tuberculosis X122", "rank": "Strain"}, "747367": {"name": "Mycobacterium tuberculosis HN878", "rank": "Strain"}, "747365": {"name": "Thermodesulfobium narugense DSM 14796", "rank": "Strain"}, "261963": {"name": "Kangiella", "rank": "Genus"}, "1260132": {"name": "Streptococcus parauberis KCTC 11980BP", "rank": "Strain"}, "561966": {"name": "Aliagarivorans taiwanensis", "rank": "Species"}, "1268668": {"name": "Escherichia coli O174:H21", "rank": "Strain"}, "452340": {"name": "Gloeophyllaceae", "rank": "Family"}, "1357669": {"name": "Mycobacterium phage DrDrey", "rank": "Species"}, "1074000": {"name": "Cronobacter universalis NCTC 9529", "rank": "Strain"}, "117187": {"name": "Fusarium verticillioides", "rank": "Species"}, "61858": {"name": "Natronorubrum bangense", "rank": "Species"}, "1145138": {"name": "Neisseria meningitidis 2004085", "rank": "Strain"}, "1145139": {"name": "Neisseria meningitidis 2003022", "rank": "Strain"}, "1145134": {"name": "Neisseria meningitidis 97027", "rank": "Strain"}, "1145135": {"name": "Neisseria meningitidis 96024", "rank": "Strain"}, "1145136": {"name": "Neisseria meningitidis 97008", "rank": "Strain"}, "1145137": {"name": "Neisseria meningitidis 98005", "rank": "Strain"}, "1145130": {"name": "Neisseria meningitidis 61106", "rank": "Strain"}, "1145131": {"name": "Neisseria meningitidis 70082", "rank": "Strain"}, "1145132": {"name": "Neisseria meningitidis 65012", "rank": "Strain"}, "1145133": {"name": "Neisseria meningitidis 64182", "rank": "Strain"}, "299583": {"name": "Francisella noatunensis subsp. orientalis", "rank": "Subspecies"}, "5476": {"name": "Candida albicans", "rank": "Species"}, "913969": {"name": "Knoellia flava", "rank": "Species"}, "880633": {"name": "Lactobacillus helveticus R0052", "rank": "Strain"}, "319003": {"name": "Bradyrhizobium sp. WSM1253", "rank": "Species"}, "1049982": {"name": "Leptospira santarosai str. HAI1380", "rank": "Strain"}, "291589": {"name": "Trichechus manatus papillomavirus 1", "rank": "Strain"}, "28222": {"name": "Desulfobacula", "rank": "Genus"}, "664662": {"name": "Borrelia bavariensis", "rank": "Species"}, "1427239": {"name": "Mycobacterium tuberculosis XTB13-153", "rank": "Strain"}, "1511810": {"name": "Deltapartitivirus", "rank": "Genus"}, "1511811": {"name": "Gammapartitivirus", "rank": "Genus"}, "1388342": {"name": "Staphylococcus aureus M0518", "rank": "Strain"}, "1388343": {"name": "Staphylococcus aureus M0519", "rank": "Strain"}, "1388340": {"name": "Staphylococcus aureus M0515", "rank": "Strain"}, "1388341": {"name": "Staphylococcus aureus M0516", "rank": "Strain"}, "1388346": {"name": "Staphylococcus aureus M0523", "rank": "Strain"}, "1427235": {"name": "Mycobacterium tuberculosis XTB13-146", "rank": "Strain"}, "1388344": {"name": "Staphylococcus aureus M0520", "rank": "Strain"}, "1388345": {"name": "Staphylococcus aureus M0522", "rank": "Strain"}, "1151440": {"name": "Peptoclostridium difficile P77", "rank": "Strain"}, "1009712": {"name": "Flavobacterium sp. SCGC AAA536-P05", "rank": "Species"}, "1005551": {"name": "Escherichia coli EC1866", "rank": "Strain"}, "1188795": {"name": "Xanthomonas citri phage CP2", "rank": "Species"}, "1188794": {"name": "Xanthomonas phage CP1", "rank": "Species"}, "1418368": {"name": "Staphylococcus aureus W45750", "rank": "Strain"}, "1418369": {"name": "Staphylococcus aureus W52294", "rank": "Strain"}, "1049970": {"name": "Leptospira kmetyi serovar Malaysia str. Bejo-Iso9", "rank": "Strain"}, "1418360": {"name": "Staphylococcus aureus W32014", "rank": "Strain"}, "1418361": {"name": "Staphylococcus aureus W35455", "rank": "Strain"}, "1418362": {"name": "Staphylococcus aureus W38532", "rank": "Strain"}, "1418363": {"name": "Staphylococcus aureus W42196", "rank": "Strain"}, "1418364": {"name": "Staphylococcus aureus W42255", "rank": "Strain"}, "1418365": {"name": "Staphylococcus aureus W42270", "rank": "Strain"}, "1418366": {"name": "Staphylococcus aureus W42298_110712", "rank": "Strain"}, "1418367": {"name": "Staphylococcus aureus W45747", "rank": "Strain"}, "1454023": {"name": "Dragonfly larvae associated circular virus-2", "rank": "Species"}, "1454022": {"name": "Dragonfly larvae associated circular virus-10", "rank": "Species"}, "1454021": {"name": "Dragonfly larvae associated circular virus-1", "rank": "Species"}, "1454027": {"name": "Dragonfly larvae associated circular virus-6", "rank": "Species"}, "1454026": {"name": "Dragonfly larvae associated circular virus-5", "rank": "Species"}, "1454025": {"name": "Dragonfly larvae associated circular virus-4", "rank": "Species"}, "1302712": {"name": "Pyrenophora seminiperda CCB06", "rank": "Strain"}, "1454029": {"name": "Dragonfly larvae associated circular virus-8", "rank": "Species"}, "1454028": {"name": "Dragonfly larvae associated circular virus-7", "rank": "Species"}, "1116178": {"name": "Escherichia coli P0304816.2", "rank": "Strain"}, "1404260": {"name": "Streptococcus mutans PKUSS-LG01", "rank": "Strain"}, "1404261": {"name": "Escherichia coli ATCC BAA-2192", "rank": "Strain"}, "1404262": {"name": "Escherichia coli ATCC BAA-2193", "rank": "Strain"}, "1241957": {"name": "Porcine parvovirus 5", "rank": "Species"}, "1245275": {"name": "Mycobacterium tuberculosis FJ05194", "rank": "Strain"}, "320583": {"name": "Conexibacteraceae", "rank": "Family"}, "537209": {"name": "Mycobacterium tuberculosis GM 1503", "rank": "Strain"}, "891968": {"name": "Anaerobaculum mobile DSM 13181", "rank": "Strain"}, "82979": {"name": "Budvicia aquatica", "rank": "Species"}, "82978": {"name": "Budvicia", "rank": "Genus"}, "82977": {"name": "Buttiauxella agrestis", "rank": "Species"}, "82976": {"name": "Buttiauxella", "rank": "Genus"}, "1412548": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20120219", "rank": "Strain"}, "1217737": {"name": "Bacillus thuringiensis HD-789", "rank": "Strain"}, "87270": {"name": "Umbilicaria", "rank": "Genus"}, "1310918": {"name": "Acinetobacter baumannii 25766_4", "rank": "Strain"}, "1310919": {"name": "Acinetobacter baumannii 25766_5", "rank": "Strain"}, "1310912": {"name": "Acinetobacter baumannii 25977_8", "rank": "Strain"}, "1310913": {"name": "Acinetobacter baumannii 25977_9", "rank": "Strain"}, "1310910": {"name": "Acinetobacter baumannii 25977_6", "rank": "Strain"}, "1310911": {"name": "Acinetobacter baumannii 25977_7", "rank": "Strain"}, "1310916": {"name": "Acinetobacter baumannii 25766_2", "rank": "Strain"}, "1384084": {"name": "Mycobacterium bovis 04-303", "rank": "Strain"}, "1310914": {"name": "Acinetobacter baumannii 25977_10", "rank": "Strain"}, "1310915": {"name": "Acinetobacter baumannii 25766_1", "rank": "Strain"}, "1227489": {"name": "Haloterrigena thermotolerans DSM 11522", "rank": "Strain"}, "1227488": {"name": "Haloterrigena salina JCM 13891", "rank": "Strain"}, "1227481": {"name": "Halorubrum hochstenium ATCC 700873", "rank": "Strain"}, "1227480": {"name": "Halorubrum hochstenium", "rank": "Species"}, "1227483": {"name": "Halorubrum litoreum JCM 13561", "rank": "Strain"}, "1227482": {"name": "Halorubrum lipolyticum DSM 21995", "rank": "Strain"}, "1078483": {"name": "Haemophilus sputorum HK 2154", "rank": "Strain"}, "1227484": {"name": "Halorubrum saccharovorum DSM 1137", "rank": "Strain"}, "1227487": {"name": "Halosarcina pallida JCM 14848", "rank": "Strain"}, "556287": {"name": "Candidatus Liberibacter solanacearum", "rank": "Species"}, "36410": {"name": "Cetacean morbillivirus", "rank": "Species"}, "1449044": {"name": "Arthrobacter sp. UNC362MFTsu5.1", "rank": "Species"}, "1106": {"name": "Chloroflexaceae", "rank": "Family"}, "1107": {"name": "Chloroflexus", "rank": "Genus"}, "1102": {"name": "Prosthecochloris aestuarii", "rank": "Species"}, "1100": {"name": "Pelodictyon luteolum", "rank": "Species"}, "1101": {"name": "Prosthecochloris", "rank": "Genus"}, "1262666": {"name": "Desulfovibrio africanus PCS", "rank": "Strain"}, "1367847": {"name": "Paracoccus aminophilus JCM 7686", "rank": "Strain"}, "1262664": {"name": "Burkholderia pseudomallei NCTC 13392", "rank": "Strain"}, "353800": {"name": "Halostagnicola larsenii", "rank": "Species"}, "1262663": {"name": "Pseudomonas aeruginosa VRFPA01", "rank": "Strain"}, "1108": {"name": "Chloroflexus aurantiacus", "rank": "Species"}, "1009714": {"name": "Pseudomonas aeruginosa PAK", "rank": "Strain"}, "314267": {"name": "Sulfitobacter sp. NAS-14.1", "rank": "Species"}, "1026955": {"name": "Synechococcus phage S-CRM01", "rank": "Species"}, "1268989": {"name": "Escherichia coli 907889", "rank": "Strain"}, "1268988": {"name": "Escherichia coli 907779", "rank": "Strain"}, "1268985": {"name": "Escherichia coli 907710", "rank": "Strain"}, "1268984": {"name": "Escherichia coli 907701", "rank": "Strain"}, "1268987": {"name": "Escherichia coli 907715", "rank": "Strain"}, "1268986": {"name": "Escherichia coli 907713", "rank": "Strain"}, "1268981": {"name": "Escherichia coli 907446", "rank": "Strain"}, "1268980": {"name": "Escherichia coli 907391", "rank": "Strain"}, "1268983": {"name": "Escherichia coli 907700", "rank": "Strain"}, "1268982": {"name": "Escherichia coli 907672", "rank": "Strain"}, "454586": {"name": "Pedobacter agri", "rank": "Species"}, "270256": {"name": "Eggplant mottled crinkle virus", "rank": "Species"}, "1280699": {"name": "Butyrivibrio fibrisolvens WTE3004", "rank": "Strain"}, "470150": {"name": "Pseudomonas taiwanensis", "rank": "Species"}, "431554": {"name": "Spirosoma spitsbergense", "rank": "Species"}, "1280696": {"name": "Butyrivibrio fibrisolvens ND3005", "rank": "Strain"}, "1280695": {"name": "Clostridium clostridioforme AGR2157", "rank": "Strain"}, "1280694": {"name": "Pseudobutyrivibrio ruminis AD2017", "rank": "Strain"}, "1280693": {"name": "Clostridium butyricum AGR2140", "rank": "Strain"}, "1266850": {"name": "Carnobacterium sp. WN1374", "rank": "Species"}, "1280691": {"name": "Blautia wexlerae AGR2146", "rank": "Strain"}, "431553": {"name": "Spirosoma luteum", "rank": "Species"}, "265429": {"name": "Silanimonas lenta", "rank": "Species"}, "265426": {"name": "Pontibacillus chungwhensis", "rank": "Species"}, "265425": {"name": "Salinimonas chungwhensis", "rank": "Species"}, "608506": {"name": "Caldicellulosiruptor obsidiansis OB47", "rank": "Strain"}, "85982": {"name": "Serpula lacrymans", "rank": "Species"}, "1391429": {"name": "Mycobacterium phage Artemis2UCLA", "rank": "Species"}, "1391428": {"name": "Enterobacteria phage 4MG", "rank": "Species"}, "43687": {"name": "Metallosphaera sedula", "rank": "Species"}, "270250": {"name": "Bartonella rattimassiliensis", "rank": "Species"}, "118882": {"name": "Brucellaceae", "rank": "Family"}, "118883": {"name": "Sulfolobaceae", "rank": "Family"}, "1439273": {"name": "Streptococcus pyogenes ABC020056884", "rank": "Strain"}, "1439272": {"name": "Streptococcus pyogenes ABC020056883", "rank": "Strain"}, "1439271": {"name": "Streptococcus pyogenes ABC020056794", "rank": "Strain"}, "1439277": {"name": "Streptococcus pyogenes ABC020056898", "rank": "Strain"}, "1439276": {"name": "Streptococcus pyogenes ABC020056894", "rank": "Strain"}, "1439275": {"name": "Streptococcus pyogenes ABC020056891", "rank": "Strain"}, "1439274": {"name": "Streptococcus pyogenes ABC020056885", "rank": "Strain"}, "86182": {"name": "Curvibacter lanceolatus", "rank": "Species"}, "43682": {"name": "Ascoviridae", "rank": "Family"}, "86187": {"name": "Phaseolibacter flectens", "rank": "Species"}, "86188": {"name": "Pseudomonas geniculata", "rank": "Species"}, "943335": {"name": "Pantoea phage LIMEzero", "rank": "Species"}, "1027397": {"name": "Erwinia amylovora ACW56400", "rank": "Strain"}, "1027396": {"name": "Listeria monocytogenes str. Scott A", "rank": "Strain"}, "1217688": {"name": "Acinetobacter sp. NIPH 542", "rank": "Species"}, "35833": {"name": "Bilophila wadsworthia", "rank": "Species"}, "1401068": {"name": "Prevotella bivia DNF00320", "rank": "Strain"}, "1401065": {"name": "Oligella urethralis DNF00040", "rank": "Strain"}, "1401064": {"name": "Corynebacterium tuscaniense DNF00037", "rank": "Strain"}, "1401067": {"name": "Veillonella montpellierensis DNF00314", "rank": "Strain"}, "1401066": {"name": "Prevotella amnii DNF00058", "rank": "Strain"}, "88058": {"name": "Treponema primitia", "rank": "Species"}, "1401063": {"name": "Arthrobacter albus DNF00011", "rank": "Strain"}, "1401062": {"name": "Prevotella timonensis S9-PR14", "rank": "Strain"}, "1161392": {"name": "Staphylococcus aureus NN54", "rank": "Strain"}, "910475": {"name": "Burkholderia phage KS14", "rank": "Species"}, "910474": {"name": "Burkholderia phage KL3", "rank": "Species"}, "1400824": {"name": "Enterococcus faecium UC8733", "rank": "Strain"}, "1400825": {"name": "Enterococcus faecium UC10237", "rank": "Strain"}, "1400822": {"name": "Enterococcus faecium UC8668", "rank": "Strain"}, "1400823": {"name": "Enterococcus faecium UC7256", "rank": "Strain"}, "1400820": {"name": "Helicobacter pylori E48", "rank": "Strain"}, "1400821": {"name": "Helicobacter pylori H13-1", "rank": "Strain"}, "241192": {"name": "Thermodesulfatator", "rank": "Genus"}, "224399": {"name": "Adoxophyes honmai nucleopolyhedrovirus", "rank": "Species"}, "1028423": {"name": "Ceratocystidaceae", "rank": "Family"}, "58050": {"name": "Moritella", "rank": "Genus"}, "768738": {"name": "Elephant endotheliotropic herpesvirus 5", "rank": "Species"}, "46506": {"name": "Bacteroides stercoris", "rank": "Species"}, "482300": {"name": "Microcystis aeruginosa SPC777", "rank": "Strain"}, "342113": {"name": "Burkholderia oklahomensis", "rank": "Species"}, "321327": {"name": "Synechococcus sp. JA-3-3Ab", "rank": "Species"}, "500640": {"name": "Citrobacter youngae ATCC 29220", "rank": "Strain"}, "1482592": {"name": "Streptomyces fimicarius subgroup", "rank": "No rank"}, "1482593": {"name": "Streptomyces flavovirens subgroup", "rank": "No rank"}, "1482596": {"name": "Streptomyces griseus subgroup", "rank": "No rank"}, "1482599": {"name": "Streptomyces halstedii subgroup", "rank": "No rank"}, "170617": {"name": "Adoxophyes orana granulovirus", "rank": "Species"}, "511145": {"name": "Escherichia coli str. K-12 substr. MG1655", "rank": "Strain"}, "217731": {"name": "Mesoplasma photuris", "rank": "Species"}, "1324128": {"name": "Habenaria mosaic virus", "rank": "Species"}, "1158203": {"name": "Botrytis porri RNA virus 1", "rank": "Species"}, "1323580": {"name": "Salmonella enterica subsp. enterica serovar Oranienburg str. S-76", "rank": "Strain"}, "39": {"name": "Cystobacteraceae", "rank": "Family"}, "34": {"name": "Myxococcus xanthus", "rank": "Species"}, "33": {"name": "Myxococcus fulvus", "rank": "Species"}, "32": {"name": "Myxococcus", "rank": "Genus"}, "31": {"name": "Myxococcaceae", "rank": "Family"}, "1505866": {"name": "Candidatus Schmidhempelia bombi", "rank": "Species"}, "633149": {"name": "Brevundimonas subvibrioides ATCC 15264", "rank": "Strain"}, "633148": {"name": "Thermosphaera aggregans DSM 11486", "rank": "Strain"}, "62153": {"name": "Vibrio shilonii", "rank": "Species"}, "992": {"name": "Flexibacter", "rank": "Genus"}, "991": {"name": "Flavobacterium hydatis", "rank": "Species"}, "997": {"name": "Flexibacter elegans", "rank": "Species"}, "996": {"name": "Flavobacterium columnare", "rank": "Species"}, "633145": {"name": "Dehalococcoides mccartyi GT", "rank": "Strain"}, "385682": {"name": "Thermophagus xiamenensis", "rank": "Species"}, "348776": {"name": "Mycobacterium tuberculosis C", "rank": "Strain"}, "348771": {"name": "Unclassified Tymovirus", "rank": "No rank"}, "59748": {"name": "Candidatus Phytoplasma australiense", "rank": "Species"}, "765765": {"name": "Colwellia phage 9A", "rank": "Species"}, "1104326": {"name": "Enterobacter cloacae subsp. dissolvens SDM", "rank": "Strain"}, "1104324": {"name": "Pyrobaculum sp. 1860", "rank": "Species"}, "1104325": {"name": "Enterococcus faecium NRRL B-2354", "rank": "Strain"}, "1104322": {"name": "Lactococcus lactis subsp. cremoris A76", "rank": "Strain"}, "1104320": {"name": "Brucella abortus A13334", "rank": "Strain"}, "1104321": {"name": "Brucella canis HSK A52141", "rank": "Strain"}, "454167": {"name": "Salmonella enterica subsp. enterica serovar Javiana str. GA_MM04042433", "rank": "Strain"}, "264449": {"name": "Pseudomonas syringae group pathovars incertae sedis", "rank": "Strain"}, "1211844": {"name": "Candidatus Stoquefichus massiliensis AP9", "rank": "Strain"}, "1211847": {"name": "Xylella fastidiosa 6c", "rank": "Strain"}, "432198": {"name": "Enterobacteria phage HK106", "rank": "Species"}, "1211843": {"name": "Candidatus Soleaferrea massiliensis AP7", "rank": "Strain"}, "337330": {"name": "Lactobacillus plantarum subsp. plantarum", "rank": "Subspecies"}, "767806": {"name": "Enterococcus phage EFRM31", "rank": "Species"}, "565659": {"name": "Enterococcus faecium 1,141,733", "rank": "Strain"}, "565658": {"name": "Enterococcus faecium 1,231,501", "rank": "Strain"}, "1046714": {"name": "Gayadomonas joobiniege G7", "rank": "Strain"}, "1089439": {"name": "Fangia hongkongensis FSC776 = DSM 21703", "rank": "Strain"}, "565655": {"name": "Enterococcus casseliflavus EC20", "rank": "Strain"}, "1182535": {"name": "Candida albicans A67", "rank": "Strain"}, "565657": {"name": "Enterococcus faecium 1,231,502", "rank": "Strain"}, "565656": {"name": "Enterococcus faecium 1,230,933", "rank": "Strain"}, "565651": {"name": "Enterococcus faecalis ARO1/DG", "rank": "Strain"}, "565650": {"name": "Enterococcus faecalis D6", "rank": "Strain"}, "565653": {"name": "Enterococcus gallinarum EG2", "rank": "Strain"}, "565652": {"name": "Enterococcus casseliflavus EC30", "rank": "Strain"}, "331635": {"name": "Chlamydophila pecorum E58", "rank": "Strain"}, "331636": {"name": "Chlamydia psittaci 6BC", "rank": "Strain"}, "419665": {"name": "Methanococcus aeolicus Nankai-3", "rank": "Strain"}, "1169392": {"name": "Escherichia coli KTE150", "rank": "Strain"}, "1169393": {"name": "Escherichia coli KTE153", "rank": "Strain"}, "1169390": {"name": "Escherichia coli KTE145", "rank": "Strain"}, "1169391": {"name": "Escherichia coli KTE148", "rank": "Strain"}, "1169396": {"name": "Escherichia coli KTE163", "rank": "Strain"}, "404692": {"name": "Coccidioides immitis RMSCC 2394", "rank": "Strain"}, "1169394": {"name": "Escherichia coli KTE157", "rank": "Strain"}, "1169395": {"name": "Escherichia coli KTE160", "rank": "Strain"}, "92486": {"name": "Unclassified Thiotrichales", "rank": "No rank"}, "1169399": {"name": "Escherichia coli KTE168", "rank": "Strain"}, "1315978": {"name": "Pseudomonas aeruginosa VRFPA02", "rank": "Strain"}, "911117": {"name": "Methanobrevibacter smithii TS145B", "rank": "Strain"}, "452342": {"name": "Russulales", "rank": "Order"}, "1315976": {"name": "Plesiomonas shigelloides 302-73", "rank": "Strain"}, "1315975": {"name": "Bacillus subtilis PS216", "rank": "Strain"}, "304901": {"name": "Actinospica robiniae", "rank": "Species"}, "95901": {"name": "Candidate division TM6", "rank": "No rank"}, "392589": {"name": "Perlucidibaca piscinae", "rank": "Species"}, "1339351": {"name": "Bacteroides vulgatus str. 3775 SR(B) 19", "rank": "Strain"}, "1339350": {"name": "Bacteroides vulgatus str. 3775 SL(B) 10 (iv)", "rank": "Strain"}, "1339352": {"name": "Bacteroides vulgatus str. 3975 RP4", "rank": "Strain"}, "1450525": {"name": "Flavobacterium succinicans LMG 10402", "rank": "Strain"}, "262325": {"name": "Lysobacter concretionis", "rank": "Species"}, "1336803": {"name": "Polaribacter sp. Hel1_33_49", "rank": "Species"}, "1298914": {"name": "Proteobacteria bacterium JGI 0001009-D17", "rank": "Species"}, "1298917": {"name": "Salmonella enterica subsp. enterica serovar Pullorum str. S06004", "rank": "Strain"}, "447471": {"name": "Simiduia agarivorans", "rank": "Species"}, "1298911": {"name": "Lentisphaerae bacterium SCGC AAA283-D08", "rank": "Species"}, "1298913": {"name": "Comamonadaceae bacterium URHA0028", "rank": "Species"}, "1298919": {"name": "Salinispora arenicola CNR425", "rank": "Strain"}, "1298918": {"name": "Salinispora arenicola CNR416", "rank": "Strain"}, "686617": {"name": "Unassigned viruses", "rank": "No rank"}, "686616": {"name": "Unassigned Tombusviridae", "rank": "No rank"}, "686612": {"name": "Unassigned Chordopoxvirinae", "rank": "No rank"}, "686611": {"name": "Unassigned Potyviridae", "rank": "No rank"}, "1240471": {"name": "Candidatus Blochmannia chromaiodes str. 640", "rank": "Strain"}, "314288": {"name": "Vibrio alginolyticus 12G01", "rank": "Strain"}, "314289": {"name": "Vibrio sp. AND4", "rank": "Species"}, "314285": {"name": "Congregibacter litoralis KT71", "rank": "Strain"}, "314287": {"name": "Gamma proteobacterium HTCC2207", "rank": "Species"}, "314280": {"name": "Photobacterium profundum 3TCK", "rank": "Strain"}, "490899": {"name": "Desulfurococcus kamchatkensis 1221n", "rank": "Strain"}, "314282": {"name": "Psychromonas sp. CNPT3", "rank": "Species"}, "314283": {"name": "Reinekea blandensis MED297", "rank": "Strain"}, "68213": {"name": "Streptomyces griseoaurantiacus", "rank": "Species"}, "1469245": {"name": "Thioalkalivibrio sp. HK1", "rank": "Species"}, "68219": {"name": "Streptomyces iakyrus", "rank": "Species"}, "382454": {"name": "Algiphilus aromaticivorans", "rank": "Species"}, "763998": {"name": "Pseudomonas phage KPP12", "rank": "Species"}, "457933": {"name": "Elioraea", "rank": "Genus"}, "457934": {"name": "Elioraea tepidiphila", "rank": "Species"}, "1286329": {"name": "Escherichia coli TOP379", "rank": "Strain"}, "529086": {"name": "Chitinilyticum litopenaei DSM 21440", "rank": "Strain"}, "748170": {"name": "Guar leaf curl alphasatellite", "rank": "Species"}, "680113": {"name": "Unassigned Secoviridae", "rank": "No rank"}, "680116": {"name": "Spbetalikevirus", "rank": "Genus"}, "1235798": {"name": "Dorea sp. 5-2", "rank": "Species"}, "680114": {"name": "I3likevirus", "rank": "Genus"}, "680115": {"name": "Phikzlikevirus", "rank": "Genus"}, "2340": {"name": "Solemya velum gill symbiont", "rank": "Species"}, "1033810": {"name": "Haloplasma contractile SSD-17B", "rank": "Strain"}, "1033813": {"name": "Escherichia coli NA114", "rank": "Strain"}, "1226680": {"name": "Klebsiella pneumoniae subsp. pneumoniae Ecl8", "rank": "Strain"}, "1446518": {"name": "Escherichia coli O111:NM str. 2010C-3977", "rank": "Strain"}, "1446519": {"name": "Escherichia coli O111:NM str. 2010C-4086", "rank": "Strain"}, "1443590": {"name": "Ferriphaselus", "rank": "Genus"}, "1446510": {"name": "Escherichia coli O111:H8 str. 2011C-3453", "rank": "Strain"}, "1446511": {"name": "Escherichia coli O111:NM str. 2010C-3053", "rank": "Strain"}, "1446512": {"name": "Escherichia coli O111:NM str. 01-3076", "rank": "Strain"}, "1446513": {"name": "Escherichia coli O111:NM str. 03-3484", "rank": "Strain"}, "1446514": {"name": "Escherichia coli O111:NM str. 04-3211", "rank": "Strain"}, "1446515": {"name": "Escherichia coli O111:NM str. 08-4487", "rank": "Strain"}, "1446516": {"name": "Escherichia coli O111:NM str. 2009C-4006", "rank": "Strain"}, "1446517": {"name": "Escherichia coli O111:NM str. 2009C-4052", "rank": "Strain"}, "390437": {"name": "Kudzu mosaic virus", "rank": "Species"}, "390436": {"name": "Corchorus golden mosaic virus", "rank": "Species"}, "390439": {"name": "Spilanthes yellow vein virus", "rank": "Species"}, "390438": {"name": "Clerodendron golden mosaic virus", "rank": "Species"}, "496496": {"name": "Viridibacillus", "rank": "Genus"}, "1156940": {"name": "Xanthomonas citri pv. mangiferaeindicae LMG 941", "rank": "Strain"}, "1357279": {"name": "Pseudomonas syringae CC1557", "rank": "Strain"}, "228955": {"name": "Arenibacter certesii", "rank": "Species"}, "748280": {"name": "Pseudogulbenkiania sp. NH8B", "rank": "Species"}, "12506": {"name": "Dobrava-Belgrade virus", "rank": "Species"}, "1154762": {"name": "Pseudomonas syringae pv. avellanae str. ISPaVe037", "rank": "Strain"}, "1154761": {"name": "Pseudomonas syringae pv. avellanae str. ISPaVe013", "rank": "Strain"}, "1357273": {"name": "Pseudomonas syringae CC1458", "rank": "Strain"}, "35238": {"name": "Mycoplasma phage P1", "rank": "Species"}, "452863": {"name": "Arthrobacter chlorophenolicus A6", "rank": "Strain"}, "1299297": {"name": "Quadrivirus", "rank": "Genus"}, "1299296": {"name": "Quadriviridae", "rank": "Family"}, "35232": {"name": "Pleistophoridae", "rank": "Family"}, "35235": {"name": "Vavraia", "rank": "Genus"}, "1177757": {"name": "Phipapillomavirus 1", "rank": "Species"}, "35237": {"name": "DsDNA viruses, no RNA stage", "rank": "No rank"}, "451707": {"name": "Bacillus cereus NVH0597-99", "rank": "Strain"}, "51160": {"name": "Treponema maltophilum", "rank": "Species"}, "451709": {"name": "Bacillus cereus 03BB108", "rank": "Strain"}, "451708": {"name": "Bacillus cereus H3081.97", "rank": "Strain"}, "33970": {"name": "Melissococcus plutonius", "rank": "Species"}, "33973": {"name": "Acidobacterium", "rank": "Genus"}, "1159060": {"name": "Helicobacter pylori GAMchJs114i", "rank": "Strain"}, "1159067": {"name": "Helicobacter pylori HP250AFiii", "rank": "Strain"}, "33974": {"name": "Unclassified Firmicutes sensu stricto", "rank": "No rank"}, "1159065": {"name": "Helicobacter pylori HP116Bi", "rank": "Strain"}, "1159064": {"name": "Helicobacter pylori GAMchJs136i", "rank": "Strain"}, "1159069": {"name": "Helicobacter pylori HP250ASi", "rank": "Strain"}, "1159068": {"name": "Helicobacter pylori HP250AFiV", "rank": "Strain"}, "1308858": {"name": "Sigmavirus", "rank": "Genus"}, "1444062": {"name": "Escherichia coli 6-319-05_S1_C1", "rank": "Strain"}, "1444063": {"name": "Escherichia coli 6-537-08_S1_C1", "rank": "Strain"}, "1444060": {"name": "Escherichia coli 4-203-08_S1_C1", "rank": "Strain"}, "1444061": {"name": "Escherichia coli 6-175-07_S1_C1", "rank": "Strain"}, "1444067": {"name": "Escherichia coli 2-156-04_S1_C2", "rank": "Strain"}, "1444064": {"name": "Escherichia coli 2-005-03_S1_C2", "rank": "Strain"}, "1444065": {"name": "Escherichia coli 2-011-08_S1_C2", "rank": "Strain"}, "1444068": {"name": "Escherichia coli 2-177-06_S1_C2", "rank": "Strain"}, "1444069": {"name": "Escherichia coli 2-210-07_S1_C2", "rank": "Strain"}, "1046251": {"name": "Maraba virus", "rank": "Species"}, "366650": {"name": "Xanthomonas alfalfae", "rank": "Species"}, "559173": {"name": "Fructobacillus", "rank": "Genus"}, "559170": {"name": "Helicoverpa armigera multiple nucleopolyhedrovirus", "rank": "Species"}, "487492": {"name": "Mikania micrantha mosaic virus", "rank": "Strain"}, "1081889": {"name": "Escherichia coli 09BKT076207", "rank": "Strain"}, "1081888": {"name": "Escherichia coli 08BKT055439", "rank": "Strain"}, "526524": {"name": "Erysipelotrichia", "rank": "Class"}, "526525": {"name": "Erysipelotrichales", "rank": "Order"}, "586220": {"name": "Leuconostoc mesenteroides subsp. cremoris ATCC 19254", "rank": "Strain"}, "1459800": {"name": "Hibiscus bacilliform virus GD1", "rank": "Species"}, "36658": {"name": "Volvariella", "rank": "Genus"}, "762212": {"name": "Bifidobacterium biavatii", "rank": "Species"}, "1459804": {"name": "Finegoldia magna ALB8", "rank": "Strain"}, "762211": {"name": "Bifidobacterium stellenboschense", "rank": "Species"}, "36651": {"name": "Penicillium digitatum", "rank": "Species"}, "36657": {"name": "Pluteaceae", "rank": "Family"}, "177399": {"name": "Anaerophaga", "rank": "Genus"}, "300740": {"name": "Mint virus 1", "rank": "Species"}, "67817": {"name": "Aminicenantes", "rank": "Phylum"}, "2198": {"name": "Methanoculleus marisnigri", "rank": "Species"}, "2194": {"name": "Methanomicrobiaceae", "rank": "Family"}, "2190": {"name": "Methanocaldococcus jannaschii", "rank": "Species"}, "2191": {"name": "Methanomicrobiales", "rank": "Order"}, "2192": {"name": "Methanocorpusculum", "rank": "Genus"}, "67814": {"name": "Caldiserica", "rank": "Phylum"}, "67812": {"name": "Omnitrophica", "rank": "Phylum"}, "11307": {"name": "Sonchus yellow net virus", "rank": "Species"}, "1290773": {"name": "Bacillus subtilis E1", "rank": "Strain"}, "465817": {"name": "Erwinia tasmaniensis Et1/99", "rank": "Strain"}, "185218": {"name": "African oil palm ringspot virus", "rank": "Species"}, "54265": {"name": "Carboxydothermus ferrireducens", "rank": "Species"}, "1422288": {"name": "Staphylococcus aureus DAR3166", "rank": "Strain"}, "54261": {"name": "Ferroglobus placidus", "rank": "Species"}, "1422286": {"name": "Staphylococcus aureus DAR3162", "rank": "Strain"}, "1422287": {"name": "Staphylococcus aureus DAR3163", "rank": "Strain"}, "1422284": {"name": "Staphylococcus aureus DAR3156", "rank": "Strain"}, "1422285": {"name": "Staphylococcus aureus DAR3157", "rank": "Strain"}, "1422282": {"name": "Staphylococcus aureus DAR3152", "rank": "Strain"}, "1422283": {"name": "Staphylococcus aureus DAR3153", "rank": "Strain"}, "1422280": {"name": "Staphylococcus aureus DAR3148", "rank": "Strain"}, "1422281": {"name": "Staphylococcus aureus DAR3150", "rank": "Strain"}, "393662": {"name": "Congregibacter litoralis", "rank": "Species"}, "630626": {"name": "Shimwellia blattae DSM 4481 = NBRC 105725", "rank": "Strain"}, "416269": {"name": "Actinobacillus pleuropneumoniae serovar 5b str. L20", "rank": "Strain"}, "227720": {"name": "Yersinia phage phiA1122", "rank": "Species"}, "652620": {"name": "Rickettsia japonica YH", "rank": "Strain"}, "67294": {"name": "Streptomyces filamentosus", "rank": "Species"}, "1413541": {"name": "Staphylococcus aureus Rd.51", "rank": "Strain"}, "1413540": {"name": "Staphylococcus aureus Rd.40", "rank": "Strain"}, "1413543": {"name": "Staphylococcus aureus 22(2K81-5)", "rank": "Strain"}, "1413542": {"name": "Staphylococcus aureus Rd.60", "rank": "Strain"}, "1413545": {"name": "Staphylococcus aureus 25(2889)", "rank": "Strain"}, "1413544": {"name": "Staphylococcus aureus 28(3K2-5)", "rank": "Strain"}, "1413547": {"name": "Staphylococcus aureus 45(2607)", "rank": "Strain"}, "1310597": {"name": "Acinetobacter baumannii 1247182", "rank": "Strain"}, "1413549": {"name": "Staphylococcus aureus Chi-10", "rank": "Strain"}, "200795": {"name": "Chloroflexi", "rank": "Phylum"}, "305719": {"name": "Prevotella baroniae", "rank": "Species"}, "1310595": {"name": "Acinetobacter baumannii 29280", "rank": "Strain"}, "67298": {"name": "Streptomyces flavidovirens", "rank": "Species"}, "578833": {"name": "Pseudomonas stutzeri subgroup", "rank": "Species subgroup"}, "32613": {"name": "Ephemerovirus", "rank": "Genus"}, "615": {"name": "Serratia marcescens", "rank": "Species"}, "1548417": {"name": "Pigeon aviadenovirus A", "rank": "Species"}, "884200": {"name": "Rotavirus D chicken/05V0049/DEU/2005", "rank": "Strain"}, "884204": {"name": "Burkholderia pseudomallei 1026b", "rank": "Strain"}, "1335483": {"name": "Shimwellia", "rank": "Genus"}, "126346": {"name": "Cellvibrio mixtus subsp. mixtus", "rank": "Subspecies"}, "1140003": {"name": "Enterococcus sulfureus ATCC 49903", "rank": "Strain"}, "866790": {"name": "Methanothermobacter thermautotrophicus CaT2", "rank": "Strain"}, "1310599": {"name": "Acinetobacter baumannii 781407", "rank": "Strain"}, "1140001": {"name": "Enterococcus durans ATCC 6056", "rank": "Strain"}, "430914": {"name": "Halorhabdus tiamatea", "rank": "Species"}, "941824": {"name": "Thermobrachium celere DSM 8682", "rank": "Strain"}, "430911": {"name": "Penaeus vannamei nodavirus", "rank": "Species"}, "119060": {"name": "Burkholderiaceae", "rank": "Family"}, "114871": {"name": "Zygosaccharomyces bailii virus Z", "rank": "Species"}, "431317": {"name": "Triticum mosaic virus", "rank": "Species"}, "379896": {"name": "Paenibacillus fonticola", "rank": "Species"}, "379891": {"name": "Plutella xylostella multiple nucleopolyhedrovirus", "rank": "Species"}, "379892": {"name": "Passiflora latent carlavirus", "rank": "Species"}, "1126950": {"name": "Bacillus phage BCP78", "rank": "Species"}, "521719": {"name": "Pseudomonas caeni DSM 24390", "rank": "Strain"}, "168169": {"name": "Candidatus Ishikawaella capsulata", "rank": "Species"}, "315953": {"name": "Acidianus two-tailed virus", "rank": "Species"}, "1410818": {"name": "Staphylococcus aureus T71872", "rank": "Strain"}, "1410819": {"name": "Staphylococcus aureus T71888", "rank": "Strain"}, "1410816": {"name": "Staphylococcus aureus M27449", "rank": "Strain"}, "1410817": {"name": "Staphylococcus aureus T71868", "rank": "Strain"}, "1410814": {"name": "Staphylococcus aureus M24400", "rank": "Strain"}, "1410815": {"name": "Staphylococcus aureus M24390", "rank": "Strain"}, "1410812": {"name": "Staphylococcus aureus F55987", "rank": "Strain"}, "1410813": {"name": "Staphylococcus aureus F65057", "rank": "Strain"}, "1410810": {"name": "Staphylococcus aureus H27761", "rank": "Strain"}, "1410811": {"name": "Staphylococcus aureus H27777", "rank": "Strain"}, "309800": {"name": "Haloferax volcanii DS2", "rank": "Strain"}, "580332": {"name": "Sideroxydans lithotrophicus ES-1", "rank": "Strain"}, "580331": {"name": "Thermoanaerobacter italicus Ab9", "rank": "Strain"}, "309801": {"name": "Thermomicrobium roseum DSM 5159", "rank": "Strain"}, "309803": {"name": "Thermotoga neapolitana DSM 4359", "rank": "Strain"}, "205957": {"name": "Cenarchaeaceae", "rank": "Family"}, "471511": {"name": "Bifidobacterium bombi", "rank": "Species"}, "1170320": {"name": "Candidatus Nitrosopumilus salaria", "rank": "Species"}, "1203544": {"name": "Klebsiella pneumoniae subsp. pneumoniae WGLW1", "rank": "Strain"}, "119067": {"name": "Unclassified Methylophilaceae", "rank": "No rank"}, "656899": {"name": "Schlesneria", "rank": "Genus"}, "1383068": {"name": "Campylobacter jejuni subsp. jejuni 00-2544", "rank": "Strain"}, "1383069": {"name": "Pseudomonas fluorescens S12", "rank": "Strain"}, "1383066": {"name": "Legionella pneumophila str. Leg01/11", "rank": "Strain"}, "1383064": {"name": "Legionella pneumophila str. Leg01/20", "rank": "Strain"}, "1383065": {"name": "Legionella pneumophila str. Leg01/53", "rank": "Strain"}, "1353979": {"name": "Staphylococcus xylosus DMB3-Bh1", "rank": "Strain"}, "1383063": {"name": "Legionella pneumophila str. 121004", "rank": "Strain"}, "1383060": {"name": "Candidatus Fervidibacter sacchari JGI OTU-1", "rank": "Strain"}, "1305708": {"name": "Clostridium phage vB_CpeS-CP51", "rank": "Species"}, "379728": {"name": "Siegesbeckia yellow vein Guangxi virus", "rank": "Species"}, "381543": {"name": "Atlantic salmon paramyxovirus", "rank": "Species"}, "1385385": {"name": "Streptococcus phage TP-778L", "rank": "Species"}, "220814": {"name": "Cucurbita yellow vein virus-associated DNA beta", "rank": "Species"}, "904306": {"name": "Streptococcus vestibularis F0396", "rank": "Strain"}, "220813": {"name": "Zinnia leaf curl virus-associated DNA beta", "rank": "Species"}, "220812": {"name": "Tomato leaf curl betasatellite", "rank": "Species"}, "1151278": {"name": "Peptoclostridium difficile CD90", "rank": "Strain"}, "1151279": {"name": "Peptoclostridium difficile CD92", "rank": "Strain"}, "1260277": {"name": "Enterobacter cancerogenus YZ1", "rank": "Strain"}, "1352357": {"name": "Helicobacter pylori SouthAfrica50", "rank": "Strain"}, "1151274": {"name": "Peptoclostridium difficile CD69", "rank": "Strain"}, "1352355": {"name": "Pseudomonas aeruginosa c7447m", "rank": "Strain"}, "1151272": {"name": "Peptoclostridium difficile CD51", "rank": "Strain"}, "1151273": {"name": "Peptoclostridium difficile CD68", "rank": "Strain"}, "1151270": {"name": "Peptoclostridium difficile CD47", "rank": "Strain"}, "1151271": {"name": "Peptoclostridium difficile CD49", "rank": "Strain"}, "121163": {"name": "Actinomyces suimastitidis", "rank": "Species"}, "1410787": {"name": "Staphylococcus aureus W42929", "rank": "Strain"}, "1410784": {"name": "Staphylococcus aureus M12714", "rank": "Strain"}, "1410785": {"name": "Staphylococcus aureus M12717", "rank": "Strain"}, "1410782": {"name": "Staphylococcus aureus M12703", "rank": "Strain"}, "1410783": {"name": "Staphylococcus aureus M12709", "rank": "Strain"}, "1311078": {"name": "Acinetobacter baumannii 44298_1", "rank": "Strain"}, "1311079": {"name": "Acinetobacter baumannii 44298_2", "rank": "Strain"}, "1311076": {"name": "Acinetobacter baumannii 26016_9", "rank": "Strain"}, "1311077": {"name": "Acinetobacter baumannii 26016_10", "rank": "Strain"}, "1311074": {"name": "Acinetobacter baumannii 26016_7", "rank": "Strain"}, "1311075": {"name": "Acinetobacter baumannii 26016_8", "rank": "Strain"}, "1311072": {"name": "Acinetobacter baumannii 26016_5", "rank": "Strain"}, "290732": {"name": "Aminiphilus circumscriptus", "rank": "Species"}, "290731": {"name": "Aminiphilus", "rank": "Genus"}, "1311071": {"name": "Acinetobacter baumannii 26016_4", "rank": "Strain"}, "1182757": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. 2010K-0669", "rank": "Strain"}, "1182756": {"name": "Staphylococcus aureus subsp. aureus str. Newbould 305", "rank": "Strain"}, "1182759": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. 08-0047", "rank": "Strain"}, "1182758": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. 2010K-2599", "rank": "Strain"}, "1181310": {"name": "Sclerotinia sclerotiorum dsRNA mycovirus-L", "rank": "Species"}, "1521255": {"name": "Candidatus Paracaedibacter", "rank": "Genus"}, "181073": {"name": "Carnobacterium pleistocenium", "rank": "Species"}, "112008": {"name": "Ignatzschineria", "rank": "Genus"}, "112009": {"name": "Ignatzschineria larvae", "rank": "Species"}, "1222003": {"name": "Helicobacter pylori Sahul64", "rank": "Strain"}, "1230478": {"name": "Thermotoga sp. TBGT1766", "rank": "Species"}, "410330": {"name": "Calyptogena okutanii thioautotrophic gill symbiont", "rank": "Species"}, "1145276": {"name": "Lysinibacillus varians", "rank": "Species"}, "1422458": {"name": "Staphylococcus aureus VET0134R", "rank": "Strain"}, "62319": {"name": "Halococcus saccharolyticus", "rank": "Species"}, "467093": {"name": "Ilumatobacter nonamiensis", "rank": "Species"}, "410332": {"name": "Gordonia malaquae", "rank": "Species"}, "368405": {"name": "Glaciecola chathamensis", "rank": "Species"}, "467094": {"name": "Ilumatobacter coccineus", "rank": "Species"}, "414371": {"name": "Aureimonas", "rank": "Genus"}, "1327763": {"name": "Mycobacterium phage Breezona", "rank": "Species"}, "1114970": {"name": "Pseudomonas fluorescens F113", "rank": "Strain"}, "1537504": {"name": "Porphyromonas sp. COT-108 OH1349", "rank": "Species"}, "1194717": {"name": "Sinorhizobium meliloti C0431A", "rank": "Strain"}, "1194714": {"name": "Sinorhizobium meliloti AE608H", "rank": "Strain"}, "1194715": {"name": "Sinorhizobium meliloti AK11", "rank": "Strain"}, "1441744": {"name": "Babu- and nanovirus-associated alphasatellites", "rank": "No rank"}, "1194718": {"name": "Sinorhizobium meliloti C0438LL", "rank": "Strain"}, "1422450": {"name": "Staphylococcus aureus VET0125R", "rank": "Strain"}, "40988": {"name": "Saccharomonospora azurea", "rank": "Species"}, "103782": {"name": "Pariacoto virus", "rank": "Species"}, "1385657": {"name": "Unclassified Gokushovirinae", "rank": "No rank"}, "1169408": {"name": "Staphylococcus aureus subsp. aureus PSP1996", "rank": "Strain"}, "1169409": {"name": "Pasteurella multocida subsp. gallicida P1059", "rank": "Strain"}, "1169402": {"name": "Escherichia coli KTE177", "rank": "Strain"}, "1169403": {"name": "Escherichia coli KTE179", "rank": "Strain"}, "1169400": {"name": "Escherichia coli KTE174", "rank": "Strain"}, "1169401": {"name": "Escherichia coli KTE176", "rank": "Strain"}, "1517681": {"name": "Vibrio sp. ER1A", "rank": "Species"}, "1517683": {"name": "Chryseobacterium sp. P1-3", "rank": "Species"}, "1517682": {"name": "Porphyromonadaceae bacterium COT-184 OH4590", "rank": "Species"}, "904328": {"name": "Staphylococcus epidermidis VCU105", "rank": "Strain"}, "1438774": {"name": "Klebsiella pneumoniae CHS 70", "rank": "Strain"}, "1516080": {"name": "HCBI9.212 virus", "rank": "Species"}, "549205": {"name": "Cycad leaf necrosis virus", "rank": "Species"}, "237727": {"name": "Erythrobacter sp. NAP1", "rank": "Species"}, "797418": {"name": "Fenneropenaeus chinensis hepandensovirus", "rank": "Strain"}, "1294142": {"name": "Clostridium intestinale URNW", "rank": "Strain"}, "1294143": {"name": "Pseudomonas denitrificans ATCC 13867", "rank": "Strain"}, "1294140": {"name": "Klebsiella pneumoniae KP1-I", "rank": "Strain"}, "1294141": {"name": "Klebsiella pneumoniae KP2-R", "rank": "Strain"}, "1410032": {"name": "Enterobacter cloacae MRSN 11489", "rank": "Strain"}, "1388153": {"name": "Staphylococcus aureus M0231", "rank": "Strain"}, "1388152": {"name": "Staphylococcus aureus M0230", "rank": "Strain"}, "1388151": {"name": "Staphylococcus aureus M0229", "rank": "Strain"}, "1388150": {"name": "Staphylococcus aureus M0228", "rank": "Strain"}, "1388157": {"name": "Staphylococcus aureus M0241", "rank": "Strain"}, "1388156": {"name": "Staphylococcus aureus M0236", "rank": "Strain"}, "1388155": {"name": "Staphylococcus aureus M0234", "rank": "Strain"}, "1388154": {"name": "Staphylococcus aureus M0232", "rank": "Strain"}, "159150": {"name": "Shamonda virus", "rank": "Species"}, "159153": {"name": "Planococcus citri densovirus", "rank": "Strain"}, "92245": {"name": "Thioalkalimicrobium aerophilum", "rank": "Species"}, "1486413": {"name": "Listeria phage LMTA-148", "rank": "Species"}, "1186051": {"name": "Blattabacterium sp. (Blaberus giganteus)", "rank": "Species"}, "686985": {"name": "Simian sapelovirus", "rank": "Species"}, "686984": {"name": "Porcine sapelovirus", "rank": "Species"}, "686983": {"name": "Avian sapelovirus", "rank": "Species"}, "686982": {"name": "Sapelovirus", "rank": "Genus"}, "1111120": {"name": "Acidaminococcus sp. BV3L6", "rank": "Species"}, "1111121": {"name": "Atopobium sp. BV3Ac4", "rank": "Species"}, "1317": {"name": "Streptococcus downei", "rank": "Species"}, "1314": {"name": "Streptococcus pyogenes", "rank": "Species"}, "1313": {"name": "Streptococcus pneumoniae", "rank": "Species"}, "1311": {"name": "Streptococcus agalactiae", "rank": "Species"}, "1310": {"name": "Streptococcus sobrinus", "rank": "Species"}, "1217671": {"name": "Acinetobacter parvus NIPH 1103", "rank": "Strain"}, "1217670": {"name": "Acinetobacter nosocomialis NIPH 2119", "rank": "Strain"}, "1217673": {"name": "Acinetobacter pittii ANC 3678", "rank": "Strain"}, "1217672": {"name": "Acinetobacter pittii CIP 70.29", "rank": "Strain"}, "1217675": {"name": "Acinetobacter schindleri NIPH 900", "rank": "Strain"}, "475609": {"name": "Escherichia coli chi7122", "rank": "Strain"}, "1217677": {"name": "Acinetobacter soli NIPH 2899", "rank": "Strain"}, "1318": {"name": "Streptococcus parasanguinis", "rank": "Species"}, "1310897": {"name": "Acinetobacter baumannii 45002_3", "rank": "Strain"}, "1310894": {"name": "Acinetobacter baumannii 44895_10", "rank": "Strain"}, "1310893": {"name": "Acinetobacter baumannii 44895_9", "rank": "Strain"}, "367121": {"name": "Grapevine leafroll-associated virus 10", "rank": "Species"}, "1310890": {"name": "Acinetobacter baumannii 44895_6", "rank": "Strain"}, "1310899": {"name": "Acinetobacter baumannii 45002_5", "rank": "Strain"}, "1310898": {"name": "Acinetobacter baumannii 45002_4", "rank": "Strain"}, "114403": {"name": "Zymobacter group", "rank": "No rank"}, "1388628": {"name": "Staphylococcus aureus M0857", "rank": "Strain"}, "685727": {"name": "Rhodococcus equi 103S", "rank": "Strain"}, "1444080": {"name": "Escherichia coli 1-250-04_S1_C2", "rank": "Strain"}, "298163": {"name": "Patulibacter minatonensis", "rank": "Species"}, "138119": {"name": "Desulfitobacterium hafniense Y51", "rank": "Strain"}, "1207544": {"name": "Streptococcus parauberis KRS-02109", "rank": "Strain"}, "1207545": {"name": "Streptococcus parauberis KRS-02083", "rank": "Strain"}, "409998": {"name": "Leptospira wolffii", "rank": "Species"}, "930406": {"name": "Escherichia coli O157:H16", "rank": "Strain"}, "83231": {"name": "Prevotella brevis", "rank": "Species"}, "1244106": {"name": "Streptococcus agalactiae SGBS030", "rank": "Strain"}, "83233": {"name": "Coriolaceae", "rank": "Family"}, "1321822": {"name": "Porphyromonas gingivalis F0566", "rank": "Strain"}, "1116052": {"name": "Escherichia coli P0299917.6", "rank": "Strain"}, "1116051": {"name": "Escherichia coli P0299917.5", "rank": "Strain"}, "1116050": {"name": "Escherichia coli P0299917.4", "rank": "Strain"}, "940834": {"name": "Equus caballus papillomavirus 3", "rank": "Strain"}, "1116056": {"name": "Escherichia coli P0299917.10", "rank": "Strain"}, "1116055": {"name": "Escherichia coli P0299917.9", "rank": "Strain"}, "1116054": {"name": "Escherichia coli P0299917.8", "rank": "Strain"}, "1116059": {"name": "Escherichia coli MP021017.3", "rank": "Strain"}, "1116058": {"name": "Escherichia coli MP021017.2", "rank": "Strain"}, "1423496": {"name": "Mycobacterium tuberculosis BTB09-001", "rank": "Strain"}, "1423497": {"name": "Mycobacterium tuberculosis BTB09-036", "rank": "Strain"}, "1437857": {"name": "Phaeomoniella chlamydospora RR-HG1", "rank": "Strain"}, "1437856": {"name": "Mycobacterium tuberculosis H37RvSiena", "rank": "Strain"}, "1218146": {"name": "Salmonella enterica subsp. enterica serovar Typhimurium str. STm4", "rank": "Strain"}, "858619": {"name": "Corynebacterium variabile DSM 44702", "rank": "Strain"}, "718255": {"name": "Roseburia intestinalis XB6B4", "rank": "Strain"}, "216778": {"name": "Stenotrophomonas rhizophila", "rank": "Species"}, "5144": {"name": "Podospora", "rank": "Genus"}, "5145": {"name": "Podospora anserina", "rank": "Species"}, "1244104": {"name": "Streptococcus agalactiae SGBS027", "rank": "Strain"}, "5140": {"name": "Neurospora", "rank": "Genus"}, "5148": {"name": "Sordariaceae", "rank": "Family"}, "5149": {"name": "Chaetomium", "rank": "Genus"}, "926567": {"name": "Thermanaerovibrio velox DSM 12556", "rank": "Strain"}, "477974": {"name": "Candidatus Desulforudis audaxviator MP104C", "rank": "Strain"}, "477976": {"name": "Calditerrivibrio nitroreducens", "rank": "Species"}, "1432311": {"name": "Candidatus Latescibacter", "rank": "Genus"}, "926564": {"name": "Promicromonospora kroppenstedtii DSM 19349", "rank": "Strain"}, "1432313": {"name": "Candidatus Latescibacter anaerobius", "rank": "Species"}, "508869": {"name": "Bradyrhizobium genosp. SA-4", "rank": "Species"}, "45462": {"name": "Brevibacillus borstelensis", "rank": "Species"}, "1422449": {"name": "Staphylococcus aureus VET0124R", "rank": "Strain"}, "391937": {"name": "Nitratireductor pacificus pht-3B", "rank": "Strain"}, "391936": {"name": "Alcanivorax pacificus W11-5", "rank": "Strain"}, "1422444": {"name": "Staphylococcus aureus VET0116R", "rank": "Strain"}, "1422445": {"name": "Staphylococcus aureus VET0117R", "rank": "Strain"}, "40492": {"name": "Stereum hirsutum", "rank": "Species"}, "1422447": {"name": "Staphylococcus aureus VET0120R", "rank": "Strain"}, "1470591": {"name": "Sphingomonas sp. RIT328", "rank": "Species"}, "1470590": {"name": "Stenotrophomonas sp. RIT309", "rank": "Species"}, "1470593": {"name": "Pseudomonas sp. RIT357", "rank": "Species"}, "1470592": {"name": "Exiguobacterium sp. RIT341", "rank": "Species"}, "63128": {"name": "Natronorubrum tibetense", "rank": "Species"}, "1124849": {"name": "Pseudomonas phage OBP", "rank": "Species"}, "1207055": {"name": "Sphingobium sp. C100", "rank": "Species"}, "347257": {"name": "Mycoplasma agalactiae PG2", "rank": "Strain"}, "347256": {"name": "Mycoplasma hominis ATCC 23114", "rank": "Strain"}, "347255": {"name": "Rickettsia africae ESF-5", "rank": "Strain"}, "1207058": {"name": "Hyphomonas sp. L-53-1-40", "rank": "Species"}, "1402529": {"name": "Pseudomonas aeruginosa BWHPSA037", "rank": "Strain"}, "1402528": {"name": "Pseudomonas aeruginosa BWHPSA028", "rank": "Strain"}, "1095677": {"name": "Neisseria meningitidis 2004090", "rank": "Strain"}, "1095676": {"name": "Neisseria meningitidis 96023", "rank": "Strain"}, "1379676": {"name": "Xenorhabdus bovienii str. Jollieti", "rank": "Strain"}, "1379677": {"name": "Xenorhabdus bovienii str. Intermedium", "rank": "Strain"}, "1095673": {"name": "Neisseria meningitidis 97020", "rank": "Strain"}, "1095672": {"name": "Neisseria meningitidis 69096", "rank": "Strain"}, "1402521": {"name": "Pseudomonas aeruginosa BWHPSA021", "rank": "Strain"}, "1402520": {"name": "Pseudomonas aeruginosa BWHPSA020", "rank": "Strain"}, "1402523": {"name": "Pseudomonas aeruginosa BWHPSA023", "rank": "Strain"}, "1402522": {"name": "Pseudomonas aeruginosa BWHPSA022", "rank": "Strain"}, "1402525": {"name": "Pseudomonas aeruginosa BWHPSA025", "rank": "Strain"}, "1402524": {"name": "Pseudomonas aeruginosa BWHPSA024", "rank": "Strain"}, "1402527": {"name": "Pseudomonas aeruginosa BWHPSA027", "rank": "Strain"}, "1402526": {"name": "Pseudomonas aeruginosa BWHPSA026", "rank": "Strain"}, "1324281": {"name": "Mycobacterium tuberculosis TKK-01-0073", "rank": "Strain"}, "1324280": {"name": "Mycobacterium tuberculosis TKK-01-0071", "rank": "Strain"}, "1324283": {"name": "Mycobacterium tuberculosis TKK-01-0075", "rank": "Strain"}, "1324282": {"name": "Mycobacterium tuberculosis TKK-01-0074", "rank": "Strain"}, "1324285": {"name": "Mycobacterium tuberculosis TKK-01-0077", "rank": "Strain"}, "1324284": {"name": "Mycobacterium tuberculosis TKK-01-0076", "rank": "Strain"}, "1324287": {"name": "Mycobacterium tuberculosis TKK-01-0079", "rank": "Strain"}, "1324286": {"name": "Mycobacterium tuberculosis TKK-01-0078", "rank": "Strain"}, "1324289": {"name": "Mycobacterium tuberculosis TKK-01-0082", "rank": "Strain"}, "1324288": {"name": "Mycobacterium tuberculosis TKK-01-0081", "rank": "Strain"}, "749506": {"name": "Enterococcus faecalis TX0411", "rank": "Strain"}, "348582": {"name": "Propionicicella superfundia", "rank": "Species"}, "1231387": {"name": "Porcine associated stool circular virus", "rank": "Species"}, "348581": {"name": "Propionicicella", "rank": "Genus"}, "1231383": {"name": "Staphylococcus aureus KT/314250", "rank": "Strain"}, "1231382": {"name": "Staphylococcus aureus KT/Y21", "rank": "Strain"}, "1231389": {"name": "Streptococcus agalactiae SA20-06", "rank": "Strain"}, "1354719": {"name": "Helicobacter pylori HP87P7", "rank": "Strain"}, "1344577": {"name": "Staphylococcus aureus S1", "rank": "Strain"}, "573977": {"name": "Human bocavirus 2", "rank": "Species"}, "90728": {"name": "Desulfatiglans anilini", "rank": "Species"}, "1344579": {"name": "Staphylococcus aureus S123", "rank": "Strain"}, "1344578": {"name": "Staphylococcus aureus S130", "rank": "Strain"}, "1423717": {"name": "Lactobacillus acidophilus DSM 20079 = JCM 1132 = NBRC 13951", "rank": "Strain"}, "1105254": {"name": "Streptococcus agalactiae CCUG 28551", "rank": "Strain"}, "1052821": {"name": "Candidate division pMC2A384", "rank": "No rank"}, "1052823": {"name": "Aigarchaeota archaeon SCGC AAA471-A16", "rank": "Species"}, "1052825": {"name": "Aigarchaeota archaeon SCGC AAA471-B22", "rank": "Species"}, "1052827": {"name": "Aigarchaeota archaeon SCGC AAA471-E14", "rank": "Species"}, "679896": {"name": "Corynebacterium pseudotuberculosis 1002", "rank": "Strain"}, "1052829": {"name": "Aigarchaeota archaeon SCGC AAA471-F17", "rank": "Species"}, "1052828": {"name": "Aigarchaeota archaeon SCGC AAA471-E16", "rank": "Species"}, "1234595": {"name": "Alpha proteobacterium JLT2015", "rank": "Species"}, "553577": {"name": "Staphylococcus aureus A8796", "rank": "Strain"}, "230871": {"name": "Streptococcus phage C1", "rank": "Species"}, "765086": {"name": "Propionibacterium acnes HL092PA1", "rank": "Strain"}, "765087": {"name": "Propionibacterium acnes HL083PA1", "rank": "Strain"}, "765084": {"name": "Propionibacterium acnes HL060PA1", "rank": "Strain"}, "765085": {"name": "Propionibacterium acnes HL038PA1", "rank": "Strain"}, "765082": {"name": "Propionibacterium acnes HL087PA2", "rank": "Strain"}, "765083": {"name": "Propionibacterium acnes HL087PA3", "rank": "Strain"}, "765080": {"name": "Propionibacterium acnes HL110PA4", "rank": "Strain"}, "765081": {"name": "Propionibacterium acnes HL087PA1", "rank": "Strain"}, "765088": {"name": "Propionibacterium acnes HL083PA2", "rank": "Strain"}, "765089": {"name": "Propionibacterium acnes HL025PA1", "rank": "Strain"}, "1203573": {"name": "Propionibacterium sp. KPL1844", "rank": "Species"}, "1203572": {"name": "Propionibacterium sp. KPL1838", "rank": "Species"}, "1203571": {"name": "Propionibacterium sp. HGH0353", "rank": "Species"}, "1203577": {"name": "Propionibacterium sp. KPL1854", "rank": "Species"}, "1203576": {"name": "Propionibacterium sp. KPL1852", "rank": "Species"}, "1203575": {"name": "Propionibacterium sp. KPL1849", "rank": "Species"}, "1203574": {"name": "Propionibacterium sp. KPL1847", "rank": "Species"}, "1203578": {"name": "Pseudomonas sp. HPB0071", "rank": "Species"}, "1169161": {"name": "Streptomyces sp. CNY243", "rank": "Species"}, "529122": {"name": "Bacillus thuringiensis YBT-1518", "rank": "Strain"}, "1169163": {"name": "Salinispora arenicola CNT859", "rank": "Strain"}, "529120": {"name": "Alteromonas macleodii ATCC 27126", "rank": "Strain"}, "1169165": {"name": "Salinispora arenicola CNY234", "rank": "Strain"}, "1169164": {"name": "Salinispora arenicola CNY282", "rank": "Strain"}, "1169167": {"name": "Salinispora arenicola CNR107", "rank": "Strain"}, "1169166": {"name": "Salinispora arenicola CNY256", "rank": "Strain"}, "1169169": {"name": "Salinispora arenicola CNX481", "rank": "Strain"}, "1169168": {"name": "Salinispora arenicola CNS744", "rank": "Strain"}, "1223542": {"name": "Gordonia malaquae NBRC 108250", "rank": "Strain"}, "1422593": {"name": "Staphylococcus aureus VET0333R", "rank": "Strain"}, "28885": {"name": "Hydrogenovibrio marinus", "rank": "Species"}, "28884": {"name": "Hydrogenovibrio", "rank": "Genus"}, "28883": {"name": "Caudovirales", "rank": "Order"}, "28882": {"name": "Ustilago maydis virus H1", "rank": "Species"}, "28889": {"name": "Crenarchaeota", "rank": "Phylum"}, "166486": {"name": "Roseburia intestinalis", "rank": "Species"}, "461322": {"name": "Ursus maritimus papillomavirus 1", "rank": "Strain"}, "1468411": {"name": "Enterobacteria phage 9g", "rank": "Species"}, "1468410": {"name": "Delftia sp. RIT313", "rank": "Species"}, "1468413": {"name": "Bacillus massilioanorexius", "rank": "Species"}, "1412784": {"name": "Staphylococcus aureus T54280", "rank": "Strain"}, "1412785": {"name": "Staphylococcus aureus T54283", "rank": "Strain"}, "1412786": {"name": "Staphylococcus aureus T54294", "rank": "Strain"}, "1412787": {"name": "Staphylococcus aureus T57397", "rank": "Strain"}, "1412780": {"name": "Staphylococcus aureus T44830", "rank": "Strain"}, "1412781": {"name": "Staphylococcus aureus T44834", "rank": "Strain"}, "1412782": {"name": "Staphylococcus aureus T51001", "rank": "Strain"}, "1155079": {"name": "Staphylococcus aureus subsp. aureus DR10", "rank": "Strain"}, "1218173": {"name": "Bacillus alcalophilus ATCC 27647", "rank": "Strain"}, "1218177": {"name": "Streptomyces sp. GBA 94-10", "rank": "Species"}, "1218176": {"name": "Chlamydia psittaci 84/55", "rank": "Strain"}, "1218175": {"name": "Bacillus thuringiensis HD-771", "rank": "Strain"}, "348097": {"name": "Unclassified Totivirus", "rank": "No rank"}, "641876": {"name": "Elusimicrobiaceae", "rank": "Family"}, "396317": {"name": "Haloarcula amylolytica", "rank": "Species"}, "39831": {"name": "Klebsiella pneumoniae subsp. rhinoscleromatis", "rank": "Subspecies"}, "1565314": {"name": "Sulfurospirillum sp. MES", "rank": "Species"}, "1502289": {"name": "Marine Group I thaumarchaeote SCGC AAA799-B03", "rank": "Species"}, "1427318": {"name": "Mycobacterium tuberculosis XTB13-250", "rank": "Strain"}, "1047058": {"name": "Marinimicrobia bacterium JGI 0000039-O11", "rank": "Species"}, "1047059": {"name": "Marinimicrobia bacterium JGI 0000059-D20", "rank": "Species"}, "1047056": {"name": "Marinimicrobia bacterium JGI 0000039-E15", "rank": "Species"}, "1047054": {"name": "Marinimicrobia bacterium SCGC AAA257-N23", "rank": "Species"}, "1047055": {"name": "Marinimicrobia bacterium JGI 0000039-D08", "rank": "Species"}, "1047052": {"name": "Atribacteria bacterium SCGC AAA255-N14", "rank": "Species"}, "1047053": {"name": "Atribacteria bacterium JGI 0000059-I14", "rank": "Species"}, "1047050": {"name": "Atribacteria bacterium SCGC AAA255-E04", "rank": "Species"}, "1047051": {"name": "Atribacteria bacterium SCGC AAA255-G05", "rank": "Species"}, "579537": {"name": "Pseudoalteromonas sp. S3431", "rank": "Species"}, "539000": {"name": "Clostridiales Family XVII. Incertae Sedis", "rank": "Family"}, "412438": {"name": "Chryseobacterium daeguense", "rank": "Species"}, "379529": {"name": "Glossina pallidipes salivary gland hypertrophy virus", "rank": "Strain"}, "1239384": {"name": "Enterobacter phage IME11", "rank": "Species"}, "1239381": {"name": "Streptococcus phage phiNJ2", "rank": "Species"}, "1340502": {"name": "Cetobacterium sp. ZWU0022", "rank": "Species"}, "1239382": {"name": "Stenotrophomonas phage IME15", "rank": "Species"}, "301092": {"name": "Marinococcus halotolerans", "rank": "Species"}, "29330": {"name": "Alicyclobacillus", "rank": "Genus"}, "29331": {"name": "Amphibacillus", "rank": "Genus"}, "713091": {"name": "Cotton leaf curl Burewala alphasatellite", "rank": "Species"}, "713092": {"name": "Cotton leaf curl Burewala betasatellite", "rank": "Species"}, "29337": {"name": "Bacillus thuringiensis serovar finitimus", "rank": "Strain"}, "29338": {"name": "Bacillus thuringiensis serovar galleriae", "rank": "Strain"}, "29339": {"name": "Bacillus thuringiensis serovar kurstaki", "rank": "Strain"}, "1269010": {"name": "Escherichia coli 910096-2", "rank": "Strain"}, "307677": {"name": "Apricot pseudo-chlorotic leaf spot virus", "rank": "Species"}, "571949": {"name": "Encephalitozoon romaleae", "rank": "Species"}, "1154864": {"name": "Streptococcus agalactiae MRI Z1-022", "rank": "Strain"}, "41950": {"name": "Candidatus Microthrix parvicella", "rank": "Species"}, "39101": {"name": "Simian T-lymphotropic virus 3", "rank": "Strain"}, "225917": {"name": "Paenibacillus massiliensis", "rank": "Species"}, "1476887": {"name": "Lactococcus phage P092", "rank": "Species"}, "1476886": {"name": "Lactococcus phage P078", "rank": "Species"}, "1476889": {"name": "Lactococcus phage P162", "rank": "Species"}, "1476888": {"name": "Lactococcus phage P118", "rank": "Species"}, "101192": {"name": "Methanomethylovorans hollandica", "rank": "Species"}, "536233": {"name": "Clostridium botulinum E1 str. 'BoNT E Beluga'", "rank": "Strain"}, "536232": {"name": "Clostridium botulinum A2 str. Kyoto", "rank": "Strain"}, "536231": {"name": "Roseburia intestinalis L1-82", "rank": "Strain"}, "536230": {"name": "Burkholderia pseudomallei MSHR346", "rank": "Strain"}, "1495285": {"name": "Escherichia phage e11/2", "rank": "Species"}, "134386": {"name": "Cotton leaf curl betasatellite", "rank": "Species"}, "1094928": {"name": "Bacillus sp. JGI 0001002-E22", "rank": "Species"}, "1094929": {"name": "Bradyrhizobium sp. JGI 0001002-A22", "rank": "Species"}, "1447540": {"name": "Pseudomonas aeruginosa BWH032", "rank": "Strain"}, "1447541": {"name": "Pseudomonas aeruginosa BWH033", "rank": "Strain"}, "1447543": {"name": "Pseudomonas aeruginosa BWH035", "rank": "Strain"}, "1447544": {"name": "Pseudomonas aeruginosa BWH036", "rank": "Strain"}, "281920": {"name": "Porphyromonas uenonis", "rank": "Species"}, "1074060": {"name": "Streptococcus sobrinus TCI-61", "rank": "Strain"}, "645127": {"name": "Corynebacterium kroppenstedtii DSM 44385", "rank": "Strain"}, "1402616": {"name": "Staphylococcus aureus M1389", "rank": "Strain"}, "33720": {"name": "Epizootic hemorrhagic disease virus 1", "rank": "Strain"}, "150247": {"name": "Anoxybacillus", "rank": "Genus"}, "1232449": {"name": "Clostridiales bacterium VE202-08", "rank": "Species"}, "1232448": {"name": "Clostridiales bacterium VE202-07", "rank": "Species"}, "33724": {"name": "Nilaparvata lugens reovirus", "rank": "Species"}, "33726": {"name": "Mungbean yellow mosaic virus", "rank": "Species"}, "1232443": {"name": "Clostridiales bacterium VE202-13", "rank": "Species"}, "72": {"name": "Simonsiella muelleri", "rank": "Species"}, "71": {"name": "Simonsiella", "rank": "Genus"}, "28068": {"name": "Rubrivivax gelatinosus", "rank": "Species"}, "1232447": {"name": "Clostridiales bacterium VE202-09", "rank": "Species"}, "1232446": {"name": "Clostridiales bacterium VE202-18", "rank": "Species"}, "75": {"name": "Caulobacter", "rank": "Genus"}, "1232444": {"name": "Clostridiales bacterium VE202-15", "rank": "Species"}, "1154860": {"name": "Streptococcus agalactiae LMG 14747", "rank": "Strain"}, "365348": {"name": "Pelosinus", "rank": "Genus"}, "365343": {"name": "Chryseobacterium caeni", "rank": "Species"}, "332161": {"name": "Solibacteraceae", "rank": "Family"}, "268747": {"name": "Prochlorococcus phage P-SSM4", "rank": "Species"}, "11665": {"name": "Equine infectious anemia virus", "rank": "Species"}, "386656": {"name": "Yersinia pestis Pestoides F", "rank": "Strain"}, "653733": {"name": "Desulfurispirillum indicum S5", "rank": "Strain"}, "11663": {"name": "Ovine lentivirus", "rank": "Species"}, "576712": {"name": "Mouse parvovirus 4a", "rank": "Strain"}, "576714": {"name": "Mouse parvovirus 5a", "rank": "Species"}, "273526": {"name": "Serratia marcescens subsp. marcescens Db11", "rank": "Strain"}, "235443": {"name": "Cryptococcus neoformans var. grubii H99", "rank": "Strain"}, "413479": {"name": "Solimonas soli", "rank": "Species"}, "64279": {"name": "Drosophila C virus", "rank": "Species"}, "2383": {"name": "Epulopiscium", "rank": "Genus"}, "60961": {"name": "Shewanella woodyi", "rank": "Species"}, "1027360": {"name": "Edwardsiella ictaluri ATCC 33202", "rank": "Strain"}, "66692": {"name": "Bacillus clausii KSM-K16", "rank": "Strain"}, "693628": {"name": "Sulfolobus spindle-shaped virus 7", "rank": "Species"}, "693629": {"name": "Acidianus spindle-shaped virus 1", "rank": "Species"}, "693626": {"name": "Unclassified Fuselloviridae", "rank": "No rank"}, "693627": {"name": "Sulfolobus spindle-shaped virus 6", "rank": "Species"}, "398037": {"name": "Segetibacter koreensis", "rank": "Species"}, "12315": {"name": "Tomato aspermy virus", "rank": "Species"}, "12316": {"name": "Ilarvirus", "rank": "Genus"}, "12317": {"name": "Tobacco streak virus", "rank": "Species"}, "12313": {"name": "Peanut stunt virus", "rank": "Species"}, "12319": {"name": "Apple mosaic virus", "rank": "Species"}, "1010838": {"name": "Mycobacterium avium subsp. paratuberculosis S397", "rank": "Strain"}, "620914": {"name": "Aquimarina agarilytica ZC1", "rank": "Strain"}, "1422169": {"name": "Staphylococcus aureus DAR3788", "rank": "Strain"}, "1422168": {"name": "Staphylococcus aureus DAR3782", "rank": "Strain"}, "1385412": {"name": "Cryptococcus gattii CBS 7750", "rank": "Strain"}, "1422163": {"name": "Staphylococcus aureus DAR3769", "rank": "Strain"}, "1422162": {"name": "Staphylococcus aureus DAR3767", "rank": "Strain"}, "1422161": {"name": "Staphylococcus aureus DAR3765", "rank": "Strain"}, "1422160": {"name": "Staphylococcus aureus DAR3762", "rank": "Strain"}, "1422167": {"name": "Staphylococcus aureus DAR3781", "rank": "Strain"}, "1422166": {"name": "Staphylococcus aureus DAR3779", "rank": "Strain"}, "1422165": {"name": "Staphylococcus aureus DAR3776", "rank": "Strain"}, "1422164": {"name": "Staphylococcus aureus DAR3772", "rank": "Strain"}, "868189": {"name": "Escherichia coli DEC11D", "rank": "Strain"}, "868188": {"name": "Escherichia coli DEC11C", "rank": "Strain"}, "868181": {"name": "Escherichia coli DEC10B", "rank": "Strain"}, "868180": {"name": "Escherichia coli DEC10A", "rank": "Strain"}, "868183": {"name": "Escherichia coli DEC10D", "rank": "Strain"}, "868182": {"name": "Escherichia coli DEC10C", "rank": "Strain"}, "868185": {"name": "Escherichia coli DEC10F", "rank": "Strain"}, "868184": {"name": "Escherichia coli DEC10E", "rank": "Strain"}, "868187": {"name": "Escherichia coli DEC11B", "rank": "Strain"}, "868186": {"name": "Escherichia coli DEC11A", "rank": "Strain"}, "51330": {"name": "Cucurbit yellow stunting disorder virus", "rank": "Species"}, "1241306": {"name": "Exiguobacterium sp. OS-77", "rank": "Species"}, "1888": {"name": "Streptomyces albus", "rank": "Species"}, "1886": {"name": "Streptomyces albidoflavus", "rank": "Species"}, "1883": {"name": "Streptomyces", "rank": "Genus"}, "1422500": {"name": "Staphylococcus aureus VET0200R", "rank": "Strain"}, "525378": {"name": "Staphylococcus caprae M23864:W1", "rank": "Strain"}, "525379": {"name": "Streptococcus equinus ATCC 9812", "rank": "Strain"}, "525372": {"name": "Sphingobacterium spiritivorum ATCC 33300", "rank": "Strain"}, "525373": {"name": "Sphingobacterium spiritivorum ATCC 33861", "rank": "Strain"}, "525370": {"name": "Rhodococcus equi ATCC 33707", "rank": "Strain"}, "525371": {"name": "Roseomonas cervicalis ATCC 49957", "rank": "Strain"}, "525376": {"name": "Staphylococcus epidermidis W23144", "rank": "Strain"}, "525377": {"name": "Staphylococcus lugdunensis M23590", "rank": "Strain"}, "525374": {"name": "Staphylococcus epidermidis BCM-HMP0060", "rank": "Strain"}, "525375": {"name": "Staphylococcus epidermidis M23864:W2(grey)", "rank": "Strain"}, "198608": {"name": "Satellites of Trichomonas vaginalis T1 virus", "rank": "Species"}, "1439048": {"name": "Streptococcus pyogenes ABC020026946", "rank": "Strain"}, "222543": {"name": "Hypocreomycetidae", "rank": "Subclass"}, "651143": {"name": "Fibrella aestuarina", "rank": "Species"}, "553220": {"name": "Campylobacter gracilis RM3268", "rank": "Strain"}, "198600": {"name": "Satellite Viruses", "rank": "No rank"}, "198601": {"name": "Satellite Nucleic Acids", "rank": "No rank"}, "111142": {"name": "Alishewanella", "rank": "Genus"}, "198607": {"name": "Double-stranded RNA satellites", "rank": "No rank"}, "1439042": {"name": "Streptococcus pyogenes ABC020025676", "rank": "Strain"}, "1439043": {"name": "Streptococcus pyogenes ABC020026287", "rank": "Strain"}, "1307800": {"name": "Pegivirus A", "rank": "Species"}, "1138918": {"name": "Enterococcus faecium EnGen0044", "rank": "Strain"}, "1138919": {"name": "Enterococcus faecium EnGen0043", "rank": "Strain"}, "1307804": {"name": "Escherichia phage Lw1", "rank": "Species"}, "1138913": {"name": "Enterococcus faecium EnGen0036", "rank": "Strain"}, "1138910": {"name": "Enterococcus faecium EnGen0040", "rank": "Strain"}, "36841": {"name": "Terrisporobacter glycolicus", "rank": "Species"}, "1138916": {"name": "Enterococcus faecium EnGen0033", "rank": "Strain"}, "1138917": {"name": "Enterococcus faecium EnGen0026", "rank": "Strain"}, "1138914": {"name": "Enterococcus faecium EnGen0042", "rank": "Strain"}, "1138915": {"name": "Enterococcus faecium EnGen0024", "rank": "Strain"}, "37131": {"name": "Dolphin morbillivirus", "rank": "Strain"}, "37133": {"name": "Tula virus", "rank": "Species"}, "1147161": {"name": "Bacillus subtilis subsp. subtilis 6051-HGW", "rank": "Strain"}, "37138": {"name": "Galleria mellonella densovirus", "rank": "Strain"}, "1438793": {"name": "Klebsiella pneumoniae MGH 70", "rank": "Strain"}, "82789": {"name": "Agrobacterium sp. ATCC 31749", "rank": "Species"}, "568095": {"name": "Salmonella enterica subsp. enterica serovar Hartford", "rank": "Strain"}, "81877": {"name": "Grapevine berry inner necrosis virus", "rank": "Species"}, "285013": {"name": "Sulfolobus virus STSV1", "rank": "Species"}, "754327": {"name": "Escherichia sp. TW09231", "rank": "Species"}, "915486": {"name": "Chaetoceros tenuissimus DNA virus", "rank": "Species"}, "1087479": {"name": "Carnobacterium maltaromaticum ATCC 35586", "rank": "Strain"}, "12777": {"name": "Parsnip yellow fleck virus", "rank": "Species"}, "60035": {"name": "Geobacter bremensis", "rank": "Species"}, "1388495": {"name": "Staphylococcus aureus M0733", "rank": "Strain"}, "178306": {"name": "Pyrobaculum aerophilum str. IM2", "rank": "Strain"}, "1182171": {"name": "Salmonella enterica subsp. enterica serovar Braenderup str. CFSAN000756", "rank": "Strain"}, "1182170": {"name": "Salmonella enterica subsp. enterica serovar Heidelberg str. CFSAN00328", "rank": "Strain"}, "1461766": {"name": "Pseudoalteromonas sp. SCSIO_11900", "rank": "Species"}, "1182172": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN000661", "rank": "Strain"}, "1182175": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN000680", "rank": "Strain"}, "1182174": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN000669", "rank": "Strain"}, "1258575": {"name": "Staphylococcus aureus subsp. aureus H29", "rank": "Strain"}, "1182176": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN000700", "rank": "Strain"}, "1182179": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN000754", "rank": "Strain"}, "1182178": {"name": "Salmonella enterica subsp. enterica serovar Bareilly str. CFSAN000753", "rank": "Strain"}, "39640": {"name": "Cotesia congregata bracovirus", "rank": "Species"}, "39643": {"name": "Sorangium", "rank": "Genus"}, "39645": {"name": "Mesorhizobium ciceri", "rank": "Species"}, "255473": {"name": "Parvularculales", "rank": "Order"}, "255472": {"name": "Caldisphaeraceae", "rank": "Family"}, "255470": {"name": "Dehalococcoides mccartyi CBDB1", "rank": "Strain"}, "255475": {"name": "Aurantimonadaceae", "rank": "Family"}, "255474": {"name": "Parvularculaceae", "rank": "Family"}, "1392837": {"name": "Bacillus anthracis str. SVA11", "rank": "Strain"}, "135517": {"name": "Geobacillus vulcani", "rank": "Species"}, "1392839": {"name": "Bordetella trematum CCUG 13902", "rank": "Strain"}, "1392838": {"name": "Bordetella hinzii ATCC 51730", "rank": "Strain"}, "1051138": {"name": "Mycobacterium phage Doom", "rank": "Species"}, "113565": {"name": "Actinoplanes globisporus", "rank": "Species"}, "267368": {"name": "Halorubrum terrestre", "rank": "Species"}, "981330": {"name": "Tsukamurella phage TPA2", "rank": "Species"}, "362976": {"name": "Haloquadratum walsbyi DSM 16790", "rank": "Strain"}, "981331": {"name": "Acinetobacter calcoaceticus DSM 30006 = CIP 81.8", "rank": "Strain"}, "911104": {"name": "Weissella cibaria KACC 11862", "rank": "Strain"}, "981332": {"name": "Acinetobacter pittii DSM 9306", "rank": "Strain"}, "1141657": {"name": "Nocardia vulneris", "rank": "Species"}, "999630": {"name": "Thermoproteus uzoniensis 768-20", "rank": "Strain"}, "767528": {"name": "Geomicrobium", "rank": "No rank"}, "45261": {"name": "Rickettsia sibirica subsp. mongolitimonae", "rank": "Subspecies"}, "45262": {"name": "Rickettsia aeschlimannii", "rank": "Species"}, "754091": {"name": "Shigella flexneri CCH060", "rank": "Strain"}, "754090": {"name": "Escherichia coli STEC_S1191", "rank": "Strain"}, "754093": {"name": "Shigella dysenteriae 1617", "rank": "Strain"}, "754092": {"name": "Shigella flexneri J1713", "rank": "Strain"}, "465447": {"name": "American grass carp reovirus", "rank": "Strain"}, "161889": {"name": "Corynebacterium lipophiloflavum", "rank": "Species"}, "1104578": {"name": "Nanoarchaeota archaeon SCGC AAA011-K22", "rank": "Species"}, "1104577": {"name": "Nanoarchaeota archaeon SCGC AAA011-G17", "rank": "Species"}, "1104576": {"name": "Candidatus Iainarchaeum andersonii SCGC AAA011-E11", "rank": "Strain"}, "1104575": {"name": "Diapherotrites archaeon SCGC AAA011-K09", "rank": "Species"}, "1104574": {"name": "Aerophobetes bacterium JGI 0000014-A15", "rank": "Species"}, "1104573": {"name": "Aerophobetes bacterium JGI 0000014-C22", "rank": "Species"}, "1104572": {"name": "Unclassified Thaumarchaeota (miscellaneous)", "rank": "No rank"}, "1104571": {"name": "Thaumarchaeota archaeon SCGC AB-179-E04", "rank": "Species"}, "1073767": {"name": "Cronobacter phage ESP2949-1", "rank": "Species"}, "311227": {"name": "Mycoreovirus", "rank": "Genus"}, "311229": {"name": "Mycoreovirus 3", "rank": "Species"}, "311228": {"name": "Mycoreovirus 1", "rank": "Species"}, "627192": {"name": "Sphingobium sp. SYK-6", "rank": "Species"}, "375761": {"name": "Oceanicola nanhaiensis", "rank": "Species"}, "1158459": {"name": "Kosakonia sacchari", "rank": "Species"}, "363628": {"name": "Unclassified Anelloviridae", "rank": "No rank"}, "1498204": {"name": "Mycobacterium phage Pinto", "rank": "Species"}, "1403900": {"name": "Staphylococcus aureus M1519", "rank": "Strain"}, "1403901": {"name": "Staphylococcus aureus M1522", "rank": "Strain"}, "1403902": {"name": "Staphylococcus aureus M1523", "rank": "Strain"}, "1403903": {"name": "Staphylococcus aureus M1524", "rank": "Strain"}, "1403904": {"name": "Staphylococcus aureus M1525", "rank": "Strain"}, "1403905": {"name": "Staphylococcus aureus M1527", "rank": "Strain"}, "1403906": {"name": "Staphylococcus aureus M1528", "rank": "Strain"}, "1403907": {"name": "Staphylococcus aureus M1529", "rank": "Strain"}, "1403908": {"name": "Staphylococcus aureus M1530", "rank": "Strain"}, "1403909": {"name": "Staphylococcus aureus M1532", "rank": "Strain"}, "983437": {"name": "Tomato chlorotic leaf distortion virus-Venezuela:Zulia:2004", "rank": "Strain"}, "1423569": {"name": "Mycobacterium tuberculosis BTB13-001", "rank": "Strain"}, "1388474": {"name": "Staphylococcus aureus M0707", "rank": "Strain"}, "1388475": {"name": "Staphylococcus aureus M0708", "rank": "Strain"}, "1388476": {"name": "Staphylococcus aureus M0709", "rank": "Strain"}, "1388477": {"name": "Staphylococcus aureus M0710", "rank": "Strain"}, "1388470": {"name": "Staphylococcus aureus M0701", "rank": "Strain"}, "1388471": {"name": "Staphylococcus aureus M0703", "rank": "Strain"}, "1388472": {"name": "Staphylococcus aureus M0704", "rank": "Strain"}, "1388473": {"name": "Staphylococcus aureus M0706", "rank": "Strain"}, "1388478": {"name": "Staphylococcus aureus M0711", "rank": "Strain"}, "1388479": {"name": "Staphylococcus aureus M0713", "rank": "Strain"}, "1448789": {"name": "Mycobacterium tuberculosis M2459", "rank": "Strain"}, "1448788": {"name": "Mycobacterium tuberculosis M2142", "rank": "Strain"}, "1448783": {"name": "Mycobacterium tuberculosis M2278", "rank": "Strain"}, "1448781": {"name": "Mycobacterium tuberculosis M2323", "rank": "Strain"}, "1448780": {"name": "Mycobacterium tuberculosis M2324", "rank": "Strain"}, "1448787": {"name": "Mycobacterium tuberculosis M2249", "rank": "Strain"}, "1448786": {"name": "Mycobacterium tuberculosis M2259", "rank": "Strain"}, "1448785": {"name": "Mycobacterium tuberculosis M2276", "rank": "Strain"}, "1448784": {"name": "Mycobacterium tuberculosis M2277", "rank": "Strain"}, "1520791": {"name": "Umbilicariomycetidae", "rank": "Subclass"}, "1159036": {"name": "Helicobacter pylori GAM245Ai", "rank": "Strain"}, "469895": {"name": "Microsporidia incertae sedis", "rank": "No rank"}, "474454": {"name": "Rose spring dwarf-associated virus", "rank": "Species"}, "717516": {"name": "Leptospira interrogans serovar Jalna", "rank": "Strain"}, "502567": {"name": "Streptococcus porci", "rank": "Species"}, "1159037": {"name": "Helicobacter pylori GAM246Ai", "rank": "Strain"}, "914128": {"name": "Serratia symbiotica str. Tucson", "rank": "Strain"}, "914127": {"name": "Vibrio vulnificus MO6-24/O", "rank": "Strain"}, "747056": {"name": "Blueberry shock virus", "rank": "Species"}, "698737": {"name": "Staphylococcus lugdunensis HKU09-01", "rank": "Strain"}, "1308956": {"name": "Dickeya zeae MS1", "rank": "Strain"}, "1002918": {"name": "Simian sapelovirus 1", "rank": "Strain"}, "1159031": {"name": "Helicobacter pylori GAM201Ai", "rank": "Strain"}, "1529": {"name": "Clostridium cadaveris", "rank": "Species"}, "581037": {"name": "Pseudomonas phage 14-1", "rank": "Species"}, "1488557": {"name": "PoSCV Kor J481", "rank": "Species"}, "1520": {"name": "Clostridium beijerinckii", "rank": "Species"}, "1521": {"name": "Clostridium cellulolyticum", "rank": "Species"}, "1522": {"name": "Clostridium innocuum", "rank": "Species"}, "1525": {"name": "Moorella thermoacetica", "rank": "Species"}, "1526": {"name": "Clostridium aminophilum", "rank": "Species"}, "1422678": {"name": "Staphylococcus aureus VET0467R", "rank": "Strain"}, "345198": {"name": "Invertebrate iridescent virus 22", "rank": "Species"}, "345199": {"name": "Invertebrate iridescent virus 31", "rank": "Species"}, "345195": {"name": "Invertebrate iridescent virus 9", "rank": "Species"}, "260121": {"name": "Mycobacterium phage Bethlehem", "rank": "Species"}, "260120": {"name": "Mycobacterium phage U2", "rank": "Species"}, "114615": {"name": "Bradyrhizobium sp. ORS 278", "rank": "Species"}, "114616": {"name": "Methylobacterium nodulans", "rank": "Species"}, "428994": {"name": "Sphingobium sp. HDIP04", "rank": "Species"}, "1239415": {"name": "Dokdonia sp. PRO95", "rank": "Species"}, "1422672": {"name": "Staphylococcus aureus VET0459R", "rank": "Strain"}, "1292": {"name": "Staphylococcus warneri", "rank": "Species"}, "1402692": {"name": "Staphylococcus aureus M1183", "rank": "Strain"}, "1402691": {"name": "Staphylococcus aureus M1182", "rank": "Strain"}, "1402690": {"name": "Staphylococcus aureus M1181", "rank": "Strain"}, "1296": {"name": "Staphylococcus sciuri", "rank": "Species"}, "1297": {"name": "Deinococcus-Thermus", "rank": "Phylum"}, "1402695": {"name": "Staphylococcus aureus M1186", "rank": "Strain"}, "38251": {"name": "Goose parvovirus", "rank": "Strain"}, "1298": {"name": "Deinococcus", "rank": "Genus"}, "1299": {"name": "Deinococcus radiodurans", "rank": "Species"}, "473814": {"name": "Unclassified Planctomycetes", "rank": "No rank"}, "473819": {"name": "Bifidobacterium dentium ATCC 27678", "rank": "Strain"}, "1388198": {"name": "Staphylococcus aureus M0301", "rank": "Strain"}, "326574": {"name": "Haloarcula phage SH1", "rank": "Species"}, "430998": {"name": "Baudoinia compniacensis", "rank": "Species"}, "998091": {"name": "Mycobacterium bovis BCG str. ATCC 35740", "rank": "Strain"}, "1329377": {"name": "Bacillus mojavensis RRC 101", "rank": "Strain"}, "1214117": {"name": "Listeria fleischmannii LU2006-1", "rank": "Strain"}, "1090133": {"name": "Enterobacteria phage IME10", "rank": "Species"}, "94253": {"name": "Unclassified Cytophagaceae", "rank": "No rank"}, "530564": {"name": "Pirellula staleyi DSM 6068", "rank": "Strain"}, "1121829": {"name": "Fodinicurvata", "rank": "Genus"}, "94255": {"name": "Runella zeae", "rank": "Species"}, "94254": {"name": "Dyadobacter fermentans", "rank": "Species"}, "681573": {"name": "Streptococcus equi subsp. zooepidemicus BHS5", "rank": "Strain"}, "1096995": {"name": "Acinetobacter baumannii BJAB07104", "rank": "Strain"}, "1096997": {"name": "Acinetobacter baumannii BJAB0868", "rank": "Strain"}, "1096996": {"name": "Acinetobacter baumannii BJAB0715", "rank": "Strain"}, "1192589": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. 2010K-0262", "rank": "Strain"}, "1192588": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. 2009K1726", "rank": "Strain"}, "457431": {"name": "Streptomyces roseosporus NRRL 15998", "rank": "Strain"}, "457430": {"name": "Streptomyces roseosporus NRRL 11379", "rank": "Strain"}, "1192585": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. 08-1080", "rank": "Strain"}, "1192587": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. 2009K1651", "rank": "Strain"}, "1192586": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. 2009K0958", "rank": "Strain"}, "1413554": {"name": "Staphylococcus aureus Tur-6", "rank": "Strain"}, "1190569": {"name": "Neisseria meningitidis 96037", "rank": "Strain"}, "273371": {"name": "Candida orthopsilosis", "rank": "Species"}, "1190567": {"name": "Stenotrophomonas maltophilia EPM1", "rank": "Strain"}, "391295": {"name": "Streptococcus suis 05ZYH33", "rank": "Strain"}, "708616": {"name": "Mycoplasma gallisepticum str. F", "rank": "Strain"}, "169176": {"name": "Novosphingobium tardaugens", "rank": "Species"}, "169177": {"name": "Exiguobacterium undae", "rank": "Species"}, "1213588": {"name": "Rose yellow vein virus", "rank": "Species"}, "537021": {"name": "Candidatus Liberibacter asiaticus str. psy62", "rank": "Strain"}, "1472418": {"name": "Falsirhodobacter sp. alg1", "rank": "Species"}, "19": {"name": "Pelobacter carbinolicus", "rank": "Species"}, "18": {"name": "Pelobacter", "rank": "Genus"}, "758826": {"name": "Acidovorax radicis", "rank": "Species"}, "758827": {"name": "Unclassified Succinivibrionaceae", "rank": "No rank"}, "11": {"name": "Cellvibrio gilvus", "rank": "Species"}, "10": {"name": "Cellvibrio", "rank": "Genus"}, "13": {"name": "Dictyoglomus", "rank": "Genus"}, "14": {"name": "Dictyoglomus thermophilum", "rank": "Species"}, "17": {"name": "Methylophilus methylotrophus", "rank": "Species"}, "16": {"name": "Methylophilus", "rank": "Genus"}, "400065": {"name": "Streptococcus merionis", "rank": "Species"}, "400060": {"name": "Paludibacterium", "rank": "Genus"}, "400061": {"name": "Paludibacterium yongneupense", "rank": "Species"}, "445435": {"name": "Asparagus virus 3", "rank": "Species"}, "662946": {"name": "Mycoplasma genitalium M6282", "rank": "Strain"}, "450748": {"name": "Propionibacterium sp. 5_U_42AFAA", "rank": "Species"}, "450749": {"name": "Veillonella sp. 6_1_27", "rank": "Species"}, "458132": {"name": "Slow bee paralysis virus", "rank": "Species"}, "183713": {"name": "Methanopyraceae", "rank": "Family"}, "1422369": {"name": "Staphylococcus aureus DAR5804", "rank": "Strain"}, "1422368": {"name": "Staphylococcus aureus DAR5805", "rank": "Strain"}, "1422361": {"name": "Staphylococcus aureus DAR5813", "rank": "Strain"}, "1422360": {"name": "Staphylococcus aureus DAR5814", "rank": "Strain"}, "1422363": {"name": "Staphylococcus aureus DAR5811", "rank": "Strain"}, "1422362": {"name": "Staphylococcus aureus DAR5812", "rank": "Strain"}, "1422365": {"name": "Staphylococcus aureus DAR5808", "rank": "Strain"}, "54388": {"name": "Salmonella enterica subsp. enterica serovar Paratyphi A", "rank": "Strain"}, "1422367": {"name": "Staphylococcus aureus DAR5806", "rank": "Strain"}, "1422366": {"name": "Staphylococcus aureus DAR5807", "rank": "Strain"}, "1503183": {"name": "Marine Group I thaumarchaeote SCGC RSA3", "rank": "Species"}, "857087": {"name": "Methylomonas methanica MC09", "rank": "Strain"}, "1286143": {"name": "Nienokoue virus", "rank": "Species"}, "528": {"name": "Ochrobactrum", "rank": "Genus"}, "280239": {"name": "Nocardiopsis chromatogenes", "rank": "Species"}, "221109": {"name": "Oceanobacillus iheyensis HTE831", "rank": "Strain"}, "1500266": {"name": "Rahnella sp. WP5", "rank": "Species"}, "179239": {"name": "Unclassified Caliciviridae", "rank": "No rank"}, "172220": {"name": "Blueberry red ringspot virus", "rank": "Species"}, "179237": {"name": "Sinorhizobium phage PBC5", "rank": "Species"}, "55565": {"name": "Actinomyces graevenitzii", "rank": "Species"}, "1123279": {"name": "Spongiibacter tropicus DSM 19543", "rank": "Strain"}, "1123278": {"name": "Spirosoma spitsbergense DSM 19989", "rank": "Strain"}, "1123277": {"name": "Spirosoma panaciterrae DSM 21099", "rank": "Strain"}, "1123276": {"name": "Spirosoma luteum DSM 19990", "rank": "Strain"}, "1123275": {"name": "Spirochaeta cellobiosiphila DSM 17781", "rank": "Strain"}, "1123274": {"name": "Spirochaeta bajacaliforniensis DSM 16054", "rank": "Strain"}, "1123270": {"name": "Sphingopyxis baekryungensis DSM 16222", "rank": "Strain"}, "1519408": {"name": "Sewage-associated gemycircularvirus-3", "rank": "Species"}, "1519401": {"name": "Sewage-associated gemycircularvirus-6", "rank": "Species"}, "1519400": {"name": "Sewage-associated gemycircularvirus-5", "rank": "Species"}, "1519403": {"name": "Sewage-associated gemycircularvirus-8", "rank": "Species"}, "1532882": {"name": "Coccinia mosaic Tamil Nadu virus", "rank": "Species"}, "1519404": {"name": "Sewage-associated gemycircularvirus-9", "rank": "Species"}, "1519407": {"name": "Sewage-associated gemycircularvirus-2", "rank": "Species"}, "765698": {"name": "Mesorhizobium ciceri biovar biserrulae WSM1271", "rank": "Strain"}, "11660": {"name": "Caprine arthritis encephalitis virus", "rank": "Species"}, "91370": {"name": "Pyrenophora seminiperda", "rank": "Species"}, "1204515": {"name": "Mycobacterium phage Taj", "rank": "Species"}, "1204516": {"name": "Aeromonas phage CC2", "rank": "Species"}, "1204517": {"name": "Pseudomonas phage MP1412", "rank": "Species"}, "1094373": {"name": "Drosophila melanogaster sigmavirus", "rank": "Species"}, "1562888": {"name": "Desulfovibrio sp. TomC", "rank": "Species"}, "355688": {"name": "Agaricomycetes incertae sedis", "rank": "No rank"}, "1409520": {"name": "Staphylococcus aureus UCIM6049", "rank": "Strain"}, "1409521": {"name": "Staphylococcus aureus MISS6037", "rank": "Strain"}, "1409522": {"name": "Staphylococcus aureus UCIM6047", "rank": "Strain"}, "1409523": {"name": "Staphylococcus aureus SMMC6016", "rank": "Strain"}, "1409524": {"name": "Staphylococcus aureus WAMC6049", "rank": "Strain"}, "1409525": {"name": "Staphylococcus aureus WAMC6046", "rank": "Strain"}, "1409526": {"name": "Staphylococcus aureus LPIH6010", "rank": "Strain"}, "1409527": {"name": "Staphylococcus aureus SMMC6022", "rank": "Strain"}, "1409528": {"name": "Staphylococcus aureus HOAG6034", "rank": "Strain"}, "515609": {"name": "Ureaplasma parvum serovar 14 str. ATCC 33697", "rank": "Strain"}, "1412653": {"name": "Staphylococcus aureus H58165", "rank": "Strain"}, "696098": {"name": "Unclassified Betacoronavirus", "rank": "No rank"}, "1412651": {"name": "Staphylococcus aureus H47671", "rank": "Strain"}, "1005440": {"name": "Escherichia coli 99.1753", "rank": "Strain"}, "171436": {"name": "Tistrella", "rank": "Genus"}, "171437": {"name": "Tistrella mobilis", "rank": "Species"}, "886890": {"name": "Acinetobacter baumannii 4190", "rank": "Strain"}, "720605": {"name": "Halomonas smyrnensis", "rank": "Species"}, "1412659": {"name": "Staphylococcus aureus H64962", "rank": "Strain"}, "230356": {"name": "Methanolacinia paynteri", "rank": "Species"}, "230355": {"name": "Methanolacinia", "rank": "Genus"}, "11657": {"name": "Bovine immunodeficiency virus", "rank": "Species"}, "260479": {"name": "Cotton leaf curl Multan virus satellite U36-1", "rank": "Species"}, "37452": {"name": "Unclassified Bacteroidetes (miscellaneous)", "rank": "No rank"}, "447217": {"name": "Anaeromyxobacter sp. K", "rank": "Species"}, "447214": {"name": "Clostridium butyricum 5521", "rank": "Strain"}, "948870": {"name": "Enterobacteria phage phi92", "rank": "Species"}, "188524": {"name": "Felis domesticus papillomavirus type 1", "rank": "Strain"}, "92406": {"name": "Mycoplasma spumans", "rank": "Species"}, "92400": {"name": "Mycoplasma anseris", "rank": "Species"}, "92401": {"name": "Mycoplasma cloacale", "rank": "Species"}, "1333564": {"name": "Streptococcus agalactiae GBS10", "rank": "Strain"}, "1333565": {"name": "Streptococcus agalactiae GBS11", "rank": "Strain"}, "1333566": {"name": "Streptococcus agalactiae GBS12", "rank": "Strain"}, "1333567": {"name": "Streptococcus agalactiae MC621", "rank": "Strain"}, "1122218": {"name": "Meganema perideroedes DSM 15528", "rank": "Strain"}, "45064": {"name": "Legionella fairfieldensis", "rank": "Species"}, "1122212": {"name": "Marinospirillum minutulum DSM 6287", "rank": "Strain"}, "552061": {"name": "Sediminimonas qiaohouensis", "rank": "Species"}, "28211": {"name": "Alphaproteobacteria", "rank": "Class"}, "1122216": {"name": "Megamonas hypermegale DSM 1672", "rank": "Strain"}, "1122217": {"name": "Megamonas rupellensis DSM 19944", "rank": "Strain"}, "1122214": {"name": "Martelella mediterranea DSM 17316", "rank": "Strain"}, "1122215": {"name": "Massilia niastensis DSM 21313", "rank": "Strain"}, "392505": {"name": "Mastomys coucha papillomavirus 2", "rank": "Strain"}, "392504": {"name": "Turnip ringspot virus", "rank": "Species"}, "1005962": {"name": "Ogataea parapolymorpha", "rank": "Species"}, "75590": {"name": "Mycoplasma phage MAV1", "rank": "Species"}, "392503": {"name": "Unclassified Comovirus", "rank": "No rank"}, "408140": {"name": "Leptospira kmetyi serovar Malaysia", "rank": "Strain"}, "1403867": {"name": "Staphylococcus aureus M1483", "rank": "Strain"}, "168238": {"name": "Porcine endogenous retrovirus E", "rank": "Strain"}, "1403865": {"name": "Staphylococcus aureus M1480", "rank": "Strain"}, "1122928": {"name": "Paludibacterium yongneupense DSM 18731", "rank": "Strain"}, "1122929": {"name": "Pannonibacter phragmitetus DSM 14782", "rank": "Strain"}, "1417986": {"name": "Listeria monocytogenes LM201", "rank": "Strain"}, "4948": {"name": "Torulaspora", "rank": "Genus"}, "1122920": {"name": "Paenibacillus harenae DSM 16969", "rank": "Strain"}, "1122921": {"name": "Paenibacillus massiliensis 2301065 = DSM 16942", "rank": "Strain"}, "1122922": {"name": "Paenibacillus panacisoli DSM 21345", "rank": "Strain"}, "1122923": {"name": "Paenibacillus pasadenensis DSM 19293", "rank": "Strain"}, "1122924": {"name": "Paenibacillus pinihumi DSM 23905", "rank": "Strain"}, "1122925": {"name": "Paenibacillus sanguinis 2301083 = DSM 16941", "rank": "Strain"}, "1122926": {"name": "Paenibacillus taiwanensis DSM 18679", "rank": "Strain"}, "1122927": {"name": "Paenibacillus terrigena DSM 21567", "rank": "Strain"}, "1121293": {"name": "Clostridium akagii DSM 12554", "rank": "Strain"}, "1121296": {"name": "Clostridium aminophilum DSM 10710", "rank": "Strain"}, "37816": {"name": "Rickettsia honei", "rank": "Species"}, "1176422": {"name": "Croceibacter phage P2559S", "rank": "Species"}, "1176423": {"name": "Marinomonas phage P12026", "rank": "Species"}, "763057": {"name": "Mesorhizobium huakuii 7653R", "rank": "Strain"}, "1005038": {"name": "Fimbriimonas", "rank": "Genus"}, "1005039": {"name": "Fimbriimonas ginsengisoli", "rank": "Species"}, "904139": {"name": "Salmonella enterica subsp. enterica serovar Choleraesuis str. SCSA50", "rank": "Strain"}, "861906": {"name": "Escherichia coli O44:H18", "rank": "Strain"}, "243265": {"name": "Photorhabdus luminescens subsp. laumondii TTO1", "rank": "Strain"}, "57705": {"name": "Halomicrobium mukohataei", "rank": "Species"}, "57706": {"name": "Citrobacter braakii", "rank": "Species"}, "235434": {"name": "Ceratocystis polonica partitivirus", "rank": "Species"}, "889517": {"name": "Saccharomyces cerevisiae CEN.PK113-7D", "rank": "Strain"}, "889513": {"name": "Corynebacterium pseudotuberculosis I19", "rank": "Strain"}, "1417067": {"name": "Staphylococcus aureus W60060", "rank": "Strain"}, "1342299": {"name": "Sulfitobacter sp. MM-124", "rank": "Species"}, "1417673": {"name": "Haloarcula hispanica N601", "rank": "Strain"}, "595895": {"name": "Drosophila A virus", "rank": "Species"}, "1417063": {"name": "Staphylococcus aureus M32679", "rank": "Strain"}, "475795": {"name": "Pseudohaliea rubra", "rank": "Species"}, "12830": {"name": "Simian immunodeficiency virus - mnd", "rank": "Strain"}, "315405": {"name": "Streptococcus gallolyticus", "rank": "Species"}, "694573": {"name": "Valsa mali var. pyri", "rank": "Varietas"}, "11052": {"name": "Dengue virus group", "rank": "Subgenus"}, "11053": {"name": "Dengue virus 1", "rank": "Strain"}, "11050": {"name": "Flaviviridae", "rank": "Family"}, "11051": {"name": "Flavivirus", "rank": "Genus"}, "29472": {"name": "Salmonella enterica subsp. enterica serovar Panama", "rank": "Strain"}, "29471": {"name": "Pectobacterium atrosepticum", "rank": "Species"}, "863638": {"name": "Clostridium acetobutylicum EA 2018", "rank": "Strain"}, "246167": {"name": "Vibrio crassostreae", "rank": "Species"}, "93465": {"name": "Avian endogenous retrovirus EAV-HP", "rank": "Species"}, "93466": {"name": "Fervidobacterium pennivorans", "rank": "Species"}, "1448829": {"name": "Mycobacterium tuberculosis H2264", "rank": "Strain"}, "1001599": {"name": "Leptospira interrogans serovar Grippotyphosa str. LT2186", "rank": "Strain"}, "1001595": {"name": "Leptospira noguchii serovar Panama str. CZ214", "rank": "Strain"}, "1001597": {"name": "Leptospira interrogans serovar Canicola str. LT1962", "rank": "Strain"}, "1001596": {"name": "Leptospira interrogans serovar Djasiman str. LT1649", "rank": "Strain"}, "1001591": {"name": "Leptospira interrogans str. C10069", "rank": "Strain"}, "1001590": {"name": "Leptospira interrogans str. 2006001854", "rank": "Strain"}, "1001593": {"name": "Leptospira noguchii str. 2006001870", "rank": "Strain"}, "1001592": {"name": "Leptospira santarosai str. 2000027870", "rank": "Strain"}, "546182": {"name": "Mycobacterium phage Boomer", "rank": "Species"}, "745176": {"name": "Unclassified Alphabaculovirus", "rank": "No rank"}, "745177": {"name": "Lymantria xylina MNPV", "rank": "Species"}, "287986": {"name": "Amycolatopsis rifamycinica", "rank": "Species"}, "118001": {"name": "Chrysiogenetes", "rank": "Class"}, "1308863": {"name": "Bacillus phage vB_BanS-Tsamsa", "rank": "Species"}, "1308866": {"name": "Gracilibacillus halophilus YIM-C55.5", "rank": "Strain"}, "1496690": {"name": "Rhizobium sp. MGL06", "rank": "Species"}, "1447469": {"name": "Mycobacterium tuberculosis MD17021", "rank": "Strain"}, "1447468": {"name": "Mycobacterium tuberculosis MD16732", "rank": "Strain"}, "1415631": {"name": "Sporosarcina pasteurii NCIM 2477", "rank": "Strain"}, "1415630": {"name": "Pseudomonas sp. TKP", "rank": "Species"}, "1415632": {"name": "Crenarchaeote JGI-OTU-1", "rank": "Species"}, "1447463": {"name": "Mycobacterium tuberculosis MD18498", "rank": "Strain"}, "1447462": {"name": "Mycobacterium tuberculosis MD16728", "rank": "Strain"}, "1447461": {"name": "Mycobacterium tuberculosis MD15594", "rank": "Strain"}, "1447460": {"name": "Mycobacterium tuberculosis MD17903", "rank": "Strain"}, "1447467": {"name": "Mycobacterium tuberculosis MD16261", "rank": "Strain"}, "1447466": {"name": "Mycobacterium tuberculosis MD18314", "rank": "Strain"}, "1447465": {"name": "Mycobacterium tuberculosis MD18090", "rank": "Strain"}, "1264700": {"name": "Edwardsiella phage MSW-3", "rank": "Species"}, "1343901": {"name": "Fruit bat alphaherpesvirus 1", "rank": "Species"}, "351673": {"name": "Xenorhabdus cabanillasii", "rank": "Species"}, "297696": {"name": "Spondweni virus group", "rank": "No rank"}, "1427182": {"name": "Mycobacterium tuberculosis XTB13-088", "rank": "Strain"}, "1127830": {"name": "Candidatus Brocadiaceae", "rank": "Family"}, "1427180": {"name": "Mycobacterium tuberculosis XTB13-084", "rank": "Strain"}, "1427181": {"name": "Mycobacterium tuberculosis XTB13-086", "rank": "Strain"}, "36033": {"name": "Vanderwaltozyma polyspora", "rank": "Species"}, "1427187": {"name": "Mycobacterium tuberculosis XTB13-093", "rank": "Strain"}, "1427185": {"name": "Mycobacterium tuberculosis XTB13-091", "rank": "Strain"}, "159450": {"name": "Burkholderia sacchari", "rank": "Species"}, "1427188": {"name": "Mycobacterium tuberculosis XTB13-094", "rank": "Strain"}, "1427189": {"name": "Mycobacterium tuberculosis XTB13-095", "rank": "Strain"}, "326036": {"name": "Staphylococcus phage phiETA2", "rank": "Species"}, "326037": {"name": "Staphylococcus phage phiETA3", "rank": "Species"}, "576611": {"name": "Polynucleobacter necessarius subsp. asymbioticus", "rank": "Subspecies"}, "576610": {"name": "Polynucleobacter necessarius", "rank": "Species"}, "359408": {"name": "Methylotenera mobilis", "rank": "Species"}, "626418": {"name": "Burkholderia glumae BGR1", "rank": "Strain"}, "158500": {"name": "Novosphingobium resinovorum", "rank": "Species"}, "1577791": {"name": "Candidatus Methanoplasma termitum", "rank": "Species"}, "1577792": {"name": "Terrisporobacter sp. 08-306576", "rank": "Species"}, "926589": {"name": "Escherichia phage PhaxI", "rank": "Species"}, "338187": {"name": "Vibrio campbellii ATCC BAA-1116", "rank": "Strain"}, "1159066": {"name": "Helicobacter pylori HP250AFii", "rank": "Strain"}, "882768": {"name": "Fig cryptic virus", "rank": "Species"}, "1220510": {"name": "Staphylococcus epidermidis AU12-03", "rank": "Strain"}, "2115": {"name": "Mycoplasma fermentans", "rank": "Species"}, "2116": {"name": "Mycoplasma iowae", "rank": "Species"}, "1125720": {"name": "Capnocytophaga sp. oral taxon 335 str. F0486", "rank": "Strain"}, "2110": {"name": "Mycoplasma agalactiae", "rank": "Species"}, "593589": {"name": "Vibrio cholerae RC9", "rank": "Strain"}, "1182968": {"name": "Saccharomyces cerevisiae P301", "rank": "Strain"}, "2113": {"name": "Mycoplasma californicum", "rank": "Species"}, "1182966": {"name": "Saccharomyces cerevisiae R008", "rank": "Strain"}, "1182967": {"name": "Saccharomyces cerevisiae R103", "rank": "Strain"}, "593586": {"name": "Vibrio cholerae TM 11079-80", "rank": "Strain"}, "593587": {"name": "Vibrio cholerae BX 330286", "rank": "Strain"}, "2118": {"name": "Mycoplasma mobile", "rank": "Species"}, "1416009": {"name": "Achromobacter phage JWAlpha", "rank": "Species"}, "861299": {"name": "Gemmatimonadetes bacterium KBS708", "rank": "Species"}, "1330042": {"name": "Streptococcus pneumoniae BHN237", "rank": "Strain"}, "1330040": {"name": "Rhodococcus rhodochrous ATCC 17895", "rank": "Strain"}, "1330041": {"name": "Streptococcus pneumoniae BHN418", "rank": "Strain"}, "1330047": {"name": "Acinetobacter junii MTCC 11364", "rank": "Strain"}, "1330044": {"name": "Streptococcus pneumoniae BHN427", "rank": "Strain"}, "426355": {"name": "Methylobacterium radiotolerans JCM 2831", "rank": "Strain"}, "1385510": {"name": "Pontibacillus halophilus JSM 076056 = DSM 19796", "rank": "Strain"}, "1422207": {"name": "Staphylococcus aureus DAR5875", "rank": "Strain"}, "1385512": {"name": "Pontibacillus litoralis JSM 072002", "rank": "Strain"}, "1385513": {"name": "Pontibacillus chungwhensis BH030062", "rank": "Strain"}, "1385514": {"name": "Pontibacillus yanchengensis Y32", "rank": "Strain"}, "1422203": {"name": "Staphylococcus aureus DAR5880", "rank": "Strain"}, "1422200": {"name": "Staphylococcus aureus DAR3928", "rank": "Strain"}, "1385517": {"name": "Lysobacter daejeonensis GH1-9", "rank": "Strain"}, "1385518": {"name": "Knoellia flava TL1", "rank": "Strain"}, "1385519": {"name": "Knoellia aerolata DSM 18566", "rank": "Strain"}, "1422208": {"name": "Staphylococcus aureus DAR5874", "rank": "Strain"}, "1422209": {"name": "Staphylococcus aureus DAR5873", "rank": "Strain"}, "1410896": {"name": "Staphylococcus aureus M44987", "rank": "Strain"}, "1410897": {"name": "Staphylococcus aureus M44988", "rank": "Strain"}, "1410894": {"name": "Staphylococcus aureus W56246", "rank": "Strain"}, "31732": {"name": "Passion fruit woodiness virus", "rank": "Species"}, "1410892": {"name": "Staphylococcus aureus W56227", "rank": "Strain"}, "1410893": {"name": "Staphylococcus aureus W56243", "rank": "Strain"}, "1410890": {"name": "Staphylococcus aureus T72814", "rank": "Strain"}, "1410891": {"name": "Staphylococcus aureus T72838", "rank": "Strain"}, "1410898": {"name": "Staphylococcus aureus F74023", "rank": "Strain"}, "1410899": {"name": "Staphylococcus aureus F77709", "rank": "Strain"}, "871575": {"name": "Ogataea parapolymorpha DL-1", "rank": "Strain"}, "871571": {"name": "Mobiluncus mulieris ATCC 35239", "rank": "Strain"}, "698672": {"name": "Moussa virus", "rank": "Species"}, "249": {"name": "Terrimonas ferruginea", "rank": "Species"}, "247": {"name": "Empedobacter brevis", "rank": "Species"}, "1182673": {"name": "Escherichia coli KTE66", "rank": "Strain"}, "245": {"name": "Flavobacterium aquatile", "rank": "Species"}, "391625": {"name": "Plesiocystis pacifica SIR-1", "rank": "Strain"}, "46234": {"name": "Anabaena sp. 90", "rank": "Species"}, "1439169": {"name": "Streptococcus pyogenes ABC020047993", "rank": "Strain"}, "1439168": {"name": "Streptococcus pyogenes ABC020047977", "rank": "Strain"}, "1439167": {"name": "Streptococcus pyogenes ABC020047959", "rank": "Strain"}, "1439165": {"name": "Streptococcus pyogenes ABC020047955", "rank": "Strain"}, "1439163": {"name": "Streptococcus pyogenes ABC020047925", "rank": "Strain"}, "1439162": {"name": "Streptococcus pyogenes ABC020047635", "rank": "Strain"}, "1439161": {"name": "Streptococcus pyogenes ABC020047619", "rank": "Strain"}, "1335409": {"name": "Mycobacterium abscessus MAB_030201_1061", "rank": "Strain"}, "1073972": {"name": "Candidatus Arthromitus sp. SFB-mouse-NYU", "rank": "Strain"}, "1614": {"name": "Lactobacillus fructivorans", "rank": "Species"}, "1615": {"name": "Weissella halotolerans", "rank": "Species"}, "1612": {"name": "Lactobacillus farciminis", "rank": "Species"}, "1613": {"name": "Lactobacillus fermentum", "rank": "Species"}, "1610": {"name": "Lactobacillus coryniformis", "rank": "Species"}, "1618": {"name": "Lactobacillus mali", "rank": "Species"}, "1305781": {"name": "Kingella kingae D7330", "rank": "Strain"}, "1305780": {"name": "Kingella kingae BB114", "rank": "Strain"}, "1305783": {"name": "Kingella kingae BB060", "rank": "Strain"}, "1305782": {"name": "Kingella kingae KK113", "rank": "Strain"}, "1305785": {"name": "Kingella kingae Vir5453", "rank": "Strain"}, "1305787": {"name": "Kingella kingae AA105", "rank": "Strain"}, "1305786": {"name": "Kingella kingae KK12", "rank": "Strain"}, "1305789": {"name": "Kingella kingae KK6", "rank": "Strain"}, "1348578": {"name": "Bacillus licheniformis S 16", "rank": "Strain"}, "70734": {"name": "Vibrio phage K139", "rank": "Species"}, "510701": {"name": "Desulfurispora", "rank": "Genus"}, "216142": {"name": "Pseudomonas rhizosphaerae", "rank": "Species"}, "148959": {"name": "Wallemia", "rank": "Genus"}, "46239": {"name": "Mesoplasma", "rank": "Genus"}, "165597": {"name": "Crocosphaera watsonii WH 8501", "rank": "Strain"}, "218923": {"name": "Turnip rosette virus", "rank": "Species"}, "81931": {"name": "Sweet potato chlorotic stunt virus", "rank": "Species"}, "67373": {"name": "Streptomyces varsoviensis", "rank": "Species"}, "666510": {"name": "Acidilobus saccharovorans 345-15", "rank": "Strain"}, "1398066": {"name": "Staphylococcus aureus M1456", "rank": "Strain"}, "1392028": {"name": "Staphylococcus aureus M1009", "rank": "Strain"}, "1392029": {"name": "Staphylococcus aureus M1011", "rank": "Strain"}, "1392024": {"name": "Staphylococcus aureus M1002", "rank": "Strain"}, "1392025": {"name": "Staphylococcus aureus M1003", "rank": "Strain"}, "1392026": {"name": "Staphylococcus aureus M1006", "rank": "Strain"}, "1392027": {"name": "Staphylococcus aureus M1008", "rank": "Strain"}, "1392020": {"name": "Staphylococcus aureus M0993", "rank": "Strain"}, "1392021": {"name": "Staphylococcus aureus M0996", "rank": "Strain"}, "1392022": {"name": "Staphylococcus aureus M0997", "rank": "Strain"}, "1392023": {"name": "Staphylococcus aureus M1000", "rank": "Strain"}, "1221391": {"name": "Cedar virus", "rank": "Species"}, "1048245": {"name": "Mycobacterium canettii CIPT 140010059", "rank": "Strain"}, "857312": {"name": "Brochothrix phage A9", "rank": "Species"}, "1255303": {"name": "Erwinia amylovora Ea356", "rank": "Strain"}, "1541960": {"name": "Mollicutes bacterium HR2", "rank": "Species"}, "1255307": {"name": "Erwinia amylovora CFBP 1232", "rank": "Strain"}, "1255306": {"name": "Erwinia amylovora 01SFR-BO", "rank": "Strain"}, "1255305": {"name": "Erwinia amylovora CFBP 2585", "rank": "Strain"}, "1255304": {"name": "Erwinia amylovora Ea266", "rank": "Strain"}, "1255309": {"name": "Erwinia amylovora Ea644", "rank": "Strain"}, "1255308": {"name": "Erwinia amylovora UPN527", "rank": "Strain"}, "1051675": {"name": "Erwinia phage vB_EamP-S6", "rank": "Species"}, "1051676": {"name": "Erwinia phage vB_EamM-Y2", "rank": "Species"}, "1051673": {"name": "Erwinia phage vB_EamP-L1", "rank": "Species"}, "1349421": {"name": "Flavihumibacter solisilvae", "rank": "Species"}, "992118": {"name": "Helicobacter pylori Hp M2", "rank": "Strain"}, "992119": {"name": "Helicobacter pylori Hp M3", "rank": "Strain"}, "909330": {"name": "Human papillomavirus type 131", "rank": "Strain"}, "909331": {"name": "Human papillomavirus type 132", "rank": "Strain"}, "909333": {"name": "Human papillomavirus type 134", "rank": "Species"}, "64948": {"name": "Ilarvirus subgroup 1", "rank": "No rank"}, "992111": {"name": "Helicobacter pylori Hp P-25c", "rank": "Strain"}, "992112": {"name": "Helicobacter pylori Hp P-25d", "rank": "Strain"}, "992114": {"name": "Helicobacter pylori Hp P-28b", "rank": "Strain"}, "992117": {"name": "Helicobacter pylori Hp M1", "rank": "Strain"}, "1197884": {"name": "Acinetobacter venetianus VE-C3", "rank": "Strain"}, "214439": {"name": "Hosta virus X", "rank": "Species"}, "1111733": {"name": "Massilia alkalitolerans DSM 17462", "rank": "Strain"}, "1450142": {"name": "Staphylococcus phage phiSA012", "rank": "Species"}, "1288027": {"name": "Arcticibacter svalbardensis", "rank": "Species"}, "1111732": {"name": "Ignatzschineria larvae DSM 13226", "rank": "Strain"}, "1111731": {"name": "Glycomyces tenuis DSM 44171", "rank": "Strain"}, "216495": {"name": "Streptococcus agalactiae serogroup III", "rank": "Strain"}, "1111730": {"name": "Flavobacterium antarcticum DSM 19726", "rank": "Strain"}, "754254": {"name": "Actinobacillus pleuropneumoniae serovar 2 str. 4226", "rank": "Strain"}, "1111737": {"name": "Thermocrispum municipale DSM 44069", "rank": "Strain"}, "113355": {"name": "Geminocystis herdmanii PCC 6308", "rank": "Strain"}, "1098912": {"name": "Unclassified Mardivirus", "rank": "No rank"}, "100053": {"name": "Leptospira alexanderi", "rank": "Species"}, "548480": {"name": "Bifidobacterium longum subsp. longum ATCC 55813", "rank": "Strain"}, "881621": {"name": "Listeria ivanovii subsp. ivanovii PAM 55", "rank": "Strain"}, "1422156": {"name": "Staphylococcus aureus DAR3752", "rank": "Strain"}, "1365011": {"name": "Pseudomonas aeruginosa B3-CFI", "rank": "Strain"}, "1422157": {"name": "Staphylococcus aureus DAR3758", "rank": "Strain"}, "1422154": {"name": "Staphylococcus aureus DAR3629", "rank": "Strain"}, "1422155": {"name": "Staphylococcus aureus DAR3632", "rank": "Strain"}, "1422152": {"name": "Staphylococcus aureus DAR3627", "rank": "Strain"}, "908937": {"name": "Prevotella dentalis DSM 3688", "rank": "Strain"}, "836": {"name": "Porphyromonas", "rank": "Genus"}, "1422151": {"name": "Staphylococcus aureus DAR3624", "rank": "Strain"}, "73501": {"name": "Cordyceps militaris", "rank": "Species"}, "296210": {"name": "Penicillium stoloniferum virus F", "rank": "Species"}, "1411701": {"name": "Pseudomonas aeruginosa DHS29", "rank": "Strain"}, "1411700": {"name": "Pseudomonas aeruginosa DHS01", "rank": "Strain"}, "501022": {"name": "Glaciibacter", "rank": "Genus"}, "501023": {"name": "Glaciibacter superstes", "rank": "Species"}, "1403829": {"name": "Streptococcus mutans PKUSS-HG01", "rank": "Strain"}, "1418427": {"name": "Staphylococcus aureus W27852", "rank": "Strain"}, "1418426": {"name": "Staphylococcus aureus W24177", "rank": "Strain"}, "1418425": {"name": "Staphylococcus aureus W13012_022013", "rank": "Strain"}, "1418424": {"name": "Staphylococcus aureus T63898", "rank": "Strain"}, "1406819": {"name": "Escherichia coli GSK2022", "rank": "Strain"}, "1406818": {"name": "Escherichia coli GSK202U", "rank": "Strain"}, "1418421": {"name": "Staphylococcus aureus T31892", "rank": "Strain"}, "1418420": {"name": "Staphylococcus aureus T22074", "rank": "Strain"}, "714583": {"name": "Salmonella phage ST160", "rank": "Species"}, "1151186": {"name": "Enterococcus faecalis EnGen0065", "rank": "Strain"}, "199202": {"name": "Pseudomonas syringae pv. panici", "rank": "Strain"}, "1418429": {"name": "Staphylococcus aureus W34839", "rank": "Strain"}, "1418428": {"name": "Staphylococcus aureus W34837", "rank": "Strain"}, "1286839": {"name": "Variovorax sp. JGI 0001020-M05", "rank": "Species"}, "1286838": {"name": "Variovorax sp. JGI 0001013-B23", "rank": "Species"}, "1286831": {"name": "Burkholderia sp. JGI 0001009-M21", "rank": "Species"}, "1286833": {"name": "Variovorax sp. JGI 0001014-I04", "rank": "Species"}, "139208": {"name": "Isoptericola variabilis", "rank": "Species"}, "1286835": {"name": "Variovorax sp. JGI 0001020-D06", "rank": "Species"}, "1286834": {"name": "Variovorax sp. JGI 0001011-P21", "rank": "Species"}, "1286837": {"name": "Variovorax sp. JGI 0001016-C20", "rank": "Species"}, "1286836": {"name": "Variovorax sp. JGI 0001014-H11", "rank": "Species"}, "1448860": {"name": "Halobellus rufus", "rank": "Species"}, "196375": {"name": "Beet black scorch virus", "rank": "Species"}, "407188": {"name": "Pelobacter seleniigenes", "rank": "Species"}, "186650": {"name": "Microvirga", "rank": "Genus"}, "1287120": {"name": "Mesorhizobium sp. L2C089B000", "rank": "Species"}, "208215": {"name": "Parvularcula", "rank": "Genus"}, "83986": {"name": "Methanoculleus bourgensis", "rank": "Species"}, "208216": {"name": "Parvularcula bermudensis", "rank": "Species"}, "1567505": {"name": "Brucella abortus bv. 9", "rank": "Strain"}, "630129": {"name": "Bifidobacterium kashiwanohense", "rank": "Species"}, "1567501": {"name": "Brucella suis bv. 4", "rank": "Strain"}, "1567503": {"name": "Brucella abortus bv. 5", "rank": "Strain"}, "1567502": {"name": "Brucella suis bv. 5", "rank": "Strain"}, "1388229": {"name": "Staphylococcus aureus M0345", "rank": "Strain"}, "1388228": {"name": "Staphylococcus aureus M0344", "rank": "Strain"}, "1388225": {"name": "Staphylococcus aureus M0339", "rank": "Strain"}, "1388224": {"name": "Staphylococcus aureus M0338", "rank": "Strain"}, "1388227": {"name": "Staphylococcus aureus M0342", "rank": "Strain"}, "1388226": {"name": "Staphylococcus aureus M0341", "rank": "Strain"}, "1388221": {"name": "Staphylococcus aureus M0335", "rank": "Strain"}, "1388220": {"name": "Staphylococcus aureus M0333", "rank": "Strain"}, "1388223": {"name": "Staphylococcus aureus M0337", "rank": "Strain"}, "1388222": {"name": "Staphylococcus aureus M0336", "rank": "Strain"}, "1352600": {"name": "Mycobacterium tuberculosis PanR1101", "rank": "Strain"}, "1352602": {"name": "Streptococcus equi subsp. zooepidemicus SzS31A1", "rank": "Strain"}, "1352603": {"name": "Salmonella enterica subsp. enterica serovar Typhimurium str. STm7", "rank": "Strain"}, "717785": {"name": "Hyphomicrobium sp. MC1", "rank": "Species"}, "248551": {"name": "Nocardia testacea", "rank": "Species"}, "742742": {"name": "Collinsella tanakaei YIT 12063", "rank": "Strain"}, "742743": {"name": "Dialister succinatiphilus YIT 11850", "rank": "Strain"}, "742740": {"name": "Clostridium symbiosum WAL-14163", "rank": "Strain"}, "742741": {"name": "Clostridium symbiosum WAL-14673", "rank": "Strain"}, "631345": {"name": "Solenopsis invicta virus 3", "rank": "Species"}, "90814": {"name": "Thiomicrospira sp. Milos-T2", "rank": "Species"}, "1198140": {"name": "Felixounalikevirus", "rank": "Genus"}, "1198147": {"name": "Caladenia virus A", "rank": "Species"}, "90813": {"name": "Thiomicrospira sp. Milos-T1", "rank": "Species"}, "1198144": {"name": "Donkey orchid virus A", "rank": "Species"}, "1329781": {"name": "Cryphonectria parasitica bipartite mycovirus 1", "rank": "Species"}, "1417162": {"name": "Staphylococcus aureus H49864", "rank": "Strain"}, "1206095": {"name": "Teredinibacter turnerae T0609", "rank": "Strain"}, "1417160": {"name": "Staphylococcus aureus F92128", "rank": "Strain"}, "1417167": {"name": "Staphylococcus aureus H59303_080912", "rank": "Strain"}, "1417166": {"name": "Staphylococcus aureus H59298", "rank": "Strain"}, "35801": {"name": "Nitrospina gracilis", "rank": "Species"}, "522772": {"name": "Denitrovibrio acetiphilus DSM 12809", "rank": "Strain"}, "278137": {"name": "Mycobacterium gilvum Spyr1", "rank": "Strain"}, "1417164": {"name": "Staphylococcus aureus H56219", "rank": "Strain"}, "278132": {"name": "Loktanella hongkongensis", "rank": "Species"}, "1151212": {"name": "Enterococcus faecalis EnGen0070", "rank": "Strain"}, "1402798": {"name": "Staphylococcus aureus M1316", "rank": "Strain"}, "1402799": {"name": "Staphylococcus aureus M1317", "rank": "Strain"}, "1402796": {"name": "Staphylococcus aureus M1314", "rank": "Strain"}, "1402797": {"name": "Staphylococcus aureus M1315", "rank": "Strain"}, "1402794": {"name": "Staphylococcus aureus M1312", "rank": "Strain"}, "1402795": {"name": "Staphylococcus aureus M1313", "rank": "Strain"}, "1402792": {"name": "Staphylococcus aureus M1308", "rank": "Strain"}, "1402793": {"name": "Staphylococcus aureus M1310", "rank": "Strain"}, "1402790": {"name": "Staphylococcus aureus M1305", "rank": "Strain"}, "1402791": {"name": "Staphylococcus aureus M1306", "rank": "Strain"}, "1257039": {"name": "Streptococcus mutans KK23", "rank": "Strain"}, "1257038": {"name": "Streptococcus mutans KK21", "rank": "Strain"}, "1257037": {"name": "Streptococcus mutans 5DC8", "rank": "Strain"}, "1196653": {"name": "Fusobacterium nucleatum subsp. fusiforme ATCC 51190", "rank": "Strain"}, "1549608": {"name": "Unclassified Higrevirus", "rank": "No rank"}, "581": {"name": "Morganella", "rank": "Genus"}, "1121947": {"name": "Helcococcus sueciensis DSM 17243", "rank": "Strain"}, "1121946": {"name": "Hamadaea tsunoensis DSM 44101", "rank": "Strain"}, "1121945": {"name": "Halorubrum ezzemoulense DSM 17463", "rank": "Strain"}, "1121943": {"name": "Halomonas lutea DSM 23508", "rank": "Strain"}, "939857": {"name": "Marinimicrobia bacterium SCGC AAA298-D23", "rank": "Species"}, "1121941": {"name": "Halomonas halodenitrificans DSM 735", "rank": "Strain"}, "1121940": {"name": "Halomonas halocynthiae DSM 14573", "rank": "Strain"}, "583": {"name": "Proteus", "rank": "Genus"}, "1121949": {"name": "Henriciella marina DSM 19595", "rank": "Strain"}, "1121948": {"name": "Hellea balneolensis DSM 19091", "rank": "Strain"}, "1041146": {"name": "Rhizobium sullae WSM1592", "rank": "Strain"}, "1408428": {"name": "Bilophila wadsworthia ATCC 49260", "rank": "Strain"}, "1408429": {"name": "Borrelia coriaceae ATCC 43381", "rank": "Strain"}, "1408422": {"name": "Alkaliphilus transvaalensis ATCC 700919", "rank": "Strain"}, "1408423": {"name": "Anaerovibrio lipolyticus LB2005", "rank": "Strain"}, "1408420": {"name": "Acidovorax oryzae ATCC 19882", "rank": "Strain"}, "1408426": {"name": "Bartonella doshiae ATCC 700133", "rank": "Strain"}, "1408427": {"name": "Bartonella elizabethae ATCC 49927", "rank": "Strain"}, "1408424": {"name": "Bacillus bogoriensis ATCC BAA-922", "rank": "Strain"}, "1408425": {"name": "Bartonella clarridgeiae ATCC 51734", "rank": "Strain"}, "405212": {"name": "Alicyclobacillus acidocaldarius", "rank": "Species"}, "1041145": {"name": "Rhizobium leguminosarum bv. viciae VF39", "rank": "Strain"}, "588": {"name": "Providencia stuartii", "rank": "Species"}, "109168": {"name": "Desulfotalea", "rank": "Genus"}, "12131": {"name": "Human rhinovirus B14", "rank": "Strain"}, "933280": {"name": "Neisseria lactamica NS19", "rank": "Strain"}, "547228": {"name": "Bacillus phage PM1", "rank": "Species"}, "1392540": {"name": "Acinetobacter nectaris CIP 110549", "rank": "Strain"}, "59504": {"name": "Petunia vein clearing virus", "rank": "Species"}, "59505": {"name": "Actinobaculum schaalii", "rank": "Species"}, "1233219": {"name": "Unclassified Salterprovirus", "rank": "No rank"}, "1422341": {"name": "Staphylococcus aureus DAR5833", "rank": "Strain"}, "1422347": {"name": "Staphylococcus aureus DAR5827", "rank": "Strain"}, "316997": {"name": "Rubrivivax benzoatilyticus", "rank": "Species"}, "86264": {"name": "Pseudomonas brassicacearum subsp. brassicacearum", "rank": "Subspecies"}, "1471398": {"name": "Prolixibacteraceae", "rank": "Family"}, "1471399": {"name": "Draconibacterium", "rank": "Genus"}, "1388349": {"name": "Staphylococcus aureus M0530", "rank": "Strain"}, "469595": {"name": "Citrobacter sp. 30_2", "rank": "Species"}, "1053174": {"name": "Bacillus cereus BAG1X2-2", "rank": "Strain"}, "742821": {"name": "Sutterella wadsworthensis 3_1_45B", "rank": "Strain"}, "1069610": {"name": "Neisseria meningitidis NM255", "rank": "Strain"}, "1069611": {"name": "Neisseria meningitidis NM140", "rank": "Strain"}, "1069612": {"name": "Neisseria meningitidis NM183", "rank": "Strain"}, "1069613": {"name": "Neisseria meningitidis NM2781", "rank": "Strain"}, "1069614": {"name": "Neisseria meningitidis 69166", "rank": "Strain"}, "1281156": {"name": "Escherichia coli KOEGE 30 (63a)", "rank": "Strain"}, "1069616": {"name": "Neisseria meningitidis 98008", "rank": "Strain"}, "1069617": {"name": "Neisseria meningitidis 80179", "rank": "Strain"}, "1069618": {"name": "Neisseria meningitidis 92045", "rank": "Strain"}, "1069619": {"name": "Neisseria meningitidis NM2657", "rank": "Strain"}, "1281159": {"name": "Escherichia coli KOEGE 40 (102a)", "rank": "Strain"}, "1281158": {"name": "Escherichia coli KOEGE 33 (68a)", "rank": "Strain"}, "1154879": {"name": "Streptococcus agalactiae MRI Z1-216", "rank": "Strain"}, "742826": {"name": "Environmental samples", "rank": "No rank"}, "1409779": {"name": "Staphylococcus aureus GGMC6057", "rank": "Strain"}, "1409778": {"name": "Staphylococcus aureus GGMC6053", "rank": "Strain"}, "739": {"name": "Aggregatibacter segnis", "rank": "Species"}, "738": {"name": "Haemophilus parasuis", "rank": "Species"}, "732": {"name": "Aggregatibacter aphrophilus", "rank": "Species"}, "1409773": {"name": "Staphylococcus aureus WAMC6081", "rank": "Strain"}, "730": {"name": "Haemophilus ducreyi", "rank": "Species"}, "1409775": {"name": "Staphylococcus aureus PLAC6058", "rank": "Strain"}, "1409774": {"name": "Staphylococcus aureus GGMC6043", "rank": "Strain"}, "1409777": {"name": "Staphylococcus aureus WAMC6086", "rank": "Strain"}, "1158148": {"name": "Thioalkalivibrio sp. ARh3", "rank": "Species"}, "40410": {"name": "Cryptococcus neoformans var. neoformans", "rank": "Varietas"}, "439847": {"name": "Salmonella enterica subsp. enterica serovar Saintpaul str. SARA29", "rank": "Strain"}, "655438": {"name": "Cycloclasticus pugetii PS-1", "rank": "Strain"}, "439842": {"name": "Salmonella enterica subsp. enterica serovar Kentucky str. CVM29188", "rank": "Strain"}, "439843": {"name": "Salmonella enterica subsp. enterica serovar Schwarzengrund str. CVM19633", "rank": "Strain"}, "1540221": {"name": "Deinococcus sp. YIM 77859", "rank": "Species"}, "90105": {"name": "Salmonella enterica subsp. enterica serovar Saintpaul", "rank": "Strain"}, "1053179": {"name": "Bacillus cereus BAG2X1-1", "rank": "Strain"}, "1094492": {"name": "Bartonella bovis m02", "rank": "Strain"}, "886289": {"name": "Streptococcus pneumoniae GA17545", "rank": "Strain"}, "1094496": {"name": "Bartonella schoenbuchensis m07a", "rank": "Strain"}, "1094497": {"name": "Bartonella vinsonii subsp. berkhoffii str. Winnie", "rank": "Strain"}, "691338": {"name": "Campylobacter jejuni subsp. jejuni 327", "rank": "Strain"}, "1265662": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 50.E.08", "rank": "Strain"}, "691336": {"name": "Campylobacter jejuni subsp. jejuni DFVF1099", "rank": "Strain"}, "691337": {"name": "Campylobacter jejuni subsp. jejuni 305", "rank": "Strain"}, "795666": {"name": "Ralstonia sp. PBA", "rank": "Species"}, "1313211": {"name": "Lentisphaeria", "rank": "Class"}, "1423469": {"name": "Mycobacterium tuberculosis BTB07-275", "rank": "Strain"}, "1423468": {"name": "Mycobacterium tuberculosis BTB07-261", "rank": "Strain"}, "1423465": {"name": "Mycobacterium tuberculosis BTB07-243", "rank": "Strain"}, "1423464": {"name": "Mycobacterium tuberculosis BTB07-234", "rank": "Strain"}, "1423467": {"name": "Mycobacterium tuberculosis BTB07-254", "rank": "Strain"}, "1156551": {"name": "Salmonella enterica subsp. enterica serovar Kentucky str. 0253", "rank": "Strain"}, "1423461": {"name": "Mycobacterium tuberculosis BTB03-144", "rank": "Strain"}, "1423460": {"name": "Mycobacterium tuberculosis BTB07-126", "rank": "Strain"}, "1423463": {"name": "Mycobacterium tuberculosis BTB07-206", "rank": "Strain"}, "1423462": {"name": "Mycobacterium tuberculosis BTB07-170", "rank": "Strain"}, "1439057": {"name": "Streptococcus pyogenes ABC020029793", "rank": "Strain"}, "469590": {"name": "Bacteroides sp. 2_2_4", "rank": "Species"}, "458817": {"name": "Shewanella halifaxensis HAW-EB4", "rank": "Strain"}, "889238": {"name": "Campylobacter jejuni subsp. jejuni LMG 23211", "rank": "Strain"}, "340070": {"name": "Criblamydia", "rank": "Genus"}, "340071": {"name": "Criblamydia sequanensis", "rank": "Species"}, "393060": {"name": "Mesoflavibacter zeaxanthinifaciens", "rank": "Species"}, "220685": {"name": "Bacillus bataviensis", "rank": "Species"}, "220686": {"name": "Bacillus vireti", "rank": "Species"}, "1138905": {"name": "Enterococcus faecium EnGen0032", "rank": "Strain"}, "1423799": {"name": "Lactobacillus salivarius DSM 20555 = ATCC 11741", "rank": "Strain"}, "1429867": {"name": "Penicillium camemberti FM 013", "rank": "Strain"}, "1138904": {"name": "Enterococcus faecium EnGen0027", "rank": "Strain"}, "1423790": {"name": "Lactobacillus pasteurii DSM 23907 = CRBIP 24.76", "rank": "Strain"}, "1423797": {"name": "Lactobacillus rhamnosus DSM 20021 = JCM 1136 = NBRC 3425", "rank": "Strain"}, "760192": {"name": "Haliscomenobacter hydrossis DSM 1100", "rank": "Strain"}, "1208323": {"name": "Celeribacter baekdonensis B30", "rank": "Strain"}, "1208321": {"name": "Marinomonas profundimaris", "rank": "Species"}, "1208320": {"name": "Thalassolituus oleivorans R6-15", "rank": "Strain"}, "1123044": {"name": "Ponticaulis", "rank": "Genus"}, "1123045": {"name": "Ponticaulis koreensis", "rank": "Species"}, "1208324": {"name": "Celeribacter indicus", "rank": "Species"}, "1138901": {"name": "Enterococcus faecium EnGen0003", "rank": "Strain"}, "1138900": {"name": "Enterococcus faecium EnGen0007", "rank": "Strain"}, "262776": {"name": "Rhodococcus imtechensis", "rank": "Species"}, "1004954": {"name": "Brucella suis bv. 1 str. S2", "rank": "Strain"}, "1004955": {"name": "Brucella melitensis bv. 1 str. M111", "rank": "Strain"}, "227307": {"name": "Gyrovirus", "rank": "Genus"}, "459495": {"name": "Arthrospira platensis C1", "rank": "Strain"}, "1159077": {"name": "Helicobacter pylori HP260AFii", "rank": "Strain"}, "1138909": {"name": "Enterococcus faecium EnGen0039", "rank": "Strain"}, "596330": {"name": "Peptoniphilus lacrimalis 315-B", "rank": "Strain"}, "1416746": {"name": "Vibrio cholerae O1 biovar El Tor str. Ogawa RND6878", "rank": "Strain"}, "1341181": {"name": "Flavobacterium limnosediminis JC2902", "rank": "Strain"}, "36854": {"name": "Desulfitobacterium dehalogenans", "rank": "Species"}, "1335760": {"name": "Sphingobium sp. YL23", "rank": "Species"}, "663587": {"name": "Unclassified Sporolactobacillaceae", "rank": "No rank"}, "1172206": {"name": "Neisseria meningitidis NMB", "rank": "Strain"}, "53369": {"name": "Staphylococcus phage 80alpha", "rank": "Species"}, "1335766": {"name": "Chili leaf curl Bhatinda betasatellite", "rank": "Species"}, "1172203": {"name": "Clostridium tetani ATCC 9441", "rank": "Strain"}, "1335768": {"name": "Tomato yellow leaf curl Yunnan virus", "rank": "Species"}, "886913": {"name": "Burkholderia cepacia Bu72", "rank": "Strain"}, "128706": {"name": "Haloviruses", "rank": "No rank"}, "903520": {"name": "Bacillus atrophaeus ATCC 9372-1", "rank": "Strain"}, "1071080": {"name": "Bacillus sp. SB49", "rank": "Species"}, "1071085": {"name": "Haloarchaeon 3A1_DGR", "rank": "Species"}, "79205": {"name": "Unclassified dsDNA phages", "rank": "No rank"}, "79206": {"name": "Desulfosporosinus", "rank": "Genus"}, "1070977": {"name": "Teredinibacter turnerae T8513", "rank": "Strain"}, "857150": {"name": "Streptococcus mutans 4SM1", "rank": "Strain"}, "857151": {"name": "Streptococcus mutans 1SM1", "rank": "Strain"}, "857152": {"name": "Streptococcus mutans 15JP3", "rank": "Strain"}, "857153": {"name": "Streptococcus mutans 8ID3", "rank": "Strain"}, "79209": {"name": "Desulfosporosinus meridiei", "rank": "Species"}, "857155": {"name": "Streptococcus mutans 11A1", "rank": "Strain"}, "392734": {"name": "Terriglobus roseus", "rank": "Species"}, "392735": {"name": "Uliginosibacterium", "rank": "Genus"}, "1549858": {"name": "Sphingomonas taxi", "rank": "Species"}, "223334": {"name": "Tobacco leaf curl Kochi virus", "rank": "Species"}, "223337": {"name": "Tobacco leaf curl Zimbabwe virus", "rank": "Species"}, "1412704": {"name": "Staphylococcus aureus W64921", "rank": "Strain"}, "1412705": {"name": "Staphylococcus aureus W64958", "rank": "Strain"}, "1412706": {"name": "Staphylococcus aureus W75098", "rank": "Strain"}, "935558": {"name": "Sinorhizobium medicae WSM1115", "rank": "Strain"}, "1412700": {"name": "Staphylococcus aureus T92876", "rank": "Strain"}, "1412701": {"name": "Staphylococcus aureus T92889", "rank": "Strain"}, "1412702": {"name": "Staphylococcus aureus W16028", "rank": "Strain"}, "1412703": {"name": "Staphylococcus aureus W20096", "rank": "Strain"}, "469616": {"name": "Fusobacterium mortiferum ATCC 9817", "rank": "Strain"}, "469617": {"name": "Fusobacterium ulcerans ATCC 49185", "rank": "Strain"}, "469614": {"name": "Erysipelotrichaceae bacterium 6_1_45", "rank": "Species"}, "469615": {"name": "Fusobacterium gonidiaformans ATCC 25563", "rank": "Strain"}, "1412708": {"name": "Staphylococcus aureus W75119", "rank": "Strain"}, "469613": {"name": "Enterobacteriaceae bacterium 9_2_54FAA", "rank": "Species"}, "469610": {"name": "Burkholderiales bacterium 1_1_47", "rank": "Species"}, "332951": {"name": "Halovivax", "rank": "Genus"}, "332952": {"name": "Aspergillus flavus NRRL3357", "rank": "Strain"}, "332953": {"name": "Halovivax asiaticus", "rank": "Species"}, "1268324": {"name": "Proteobacteria bacterium JGI 0001019-D04", "rank": "Species"}, "1268327": {"name": "Xanthomonadaceae bacterium JGI 0001020-F16", "rank": "Species"}, "306543": {"name": "Paenibacillus harenae", "rank": "Species"}, "1268320": {"name": "Rhizobium sp. JGI 0001003-J22", "rank": "Species"}, "306546": {"name": "Marinimicrobium agarilyticum", "rank": "Species"}, "1268322": {"name": "Cupriavidus sp. JGI 0001016-D21", "rank": "Species"}, "1229662": {"name": "Pestalotiopsis fici W106-1", "rank": "Strain"}, "10284": {"name": "Entomopoxvirinae", "rank": "Subfamily"}, "930990": {"name": "Botryobasidium botryosum FD-172 SS1", "rank": "Strain"}, "10286": {"name": "Betaentomopoxvirus", "rank": "Genus"}, "10280": {"name": "Molluscum contagiosum virus subtype 1", "rank": "Strain"}, "10282": {"name": "Yatapoxvirus", "rank": "Genus"}, "10288": {"name": "Choristoneura biennis entomopoxvirus 'L'", "rank": "Species"}, "1074308": {"name": "Mycobacterium phage Patience", "rank": "Species"}, "1074309": {"name": "Mycobacterium phage BigNuz", "rank": "Species"}, "1074304": {"name": "Mycobacterium phage Liefie", "rank": "Species"}, "1074305": {"name": "Mycobacterium phage Dandelion", "rank": "Species"}, "1074307": {"name": "Mycobacterium phage LinStu", "rank": "Species"}, "1074303": {"name": "Mycobacterium phage Drago", "rank": "Species"}, "657309": {"name": "Bacteroides xylanisolvens XB1A", "rank": "Strain"}, "657308": {"name": "Gordonibacter pamelaeae 7-10-1-b", "rank": "Strain"}, "205869": {"name": "Mycobacterium phage Cjw1", "rank": "Species"}, "205868": {"name": "Mycobacterium phage Che8", "rank": "Species"}, "382640": {"name": "Bartonella tribocorum CIP 105476", "rank": "Strain"}, "1357287": {"name": "Pseudomonas syringae UB303", "rank": "Strain"}, "1387231": {"name": "Pseudomonas sp. CMAA1215", "rank": "Species"}, "1500300": {"name": "Rhizobium sp. CF258", "rank": "Species"}, "1159491": {"name": "Cronobacter malonaticus LMG 23826", "rank": "Strain"}, "1071378": {"name": "Naumovozyma dairenensis CBS 421", "rank": "Strain"}, "1071379": {"name": "Tetrapisispora blattae", "rank": "Species"}, "84998": {"name": "Coriobacteridae", "rank": "Subclass"}, "1500304": {"name": "Rhizobium sp. CF394", "rank": "Species"}, "749500": {"name": "Enterococcus faecalis TX0043", "rank": "Strain"}, "1500307": {"name": "Rhizobium sp. OV201", "rank": "Species"}, "749505": {"name": "Enterococcus faecalis TX0312", "rank": "Strain"}, "694430": {"name": "Natronococcus occultus SP4", "rank": "Strain"}, "694431": {"name": "Desulfurella acetivorans A63", "rank": "Strain"}, "694433": {"name": "Saprospira grandis DSM 2844", "rank": "Strain"}, "1357289": {"name": "Pseudomonas syringae USA011", "rank": "Strain"}, "550748": {"name": "Ureaplasma urealyticum serovar 4 str. ATCC 27816", "rank": "Strain"}, "550747": {"name": "Ureaplasma urealyticum serovar 12 str. ATCC 33696", "rank": "Strain"}, "1354720": {"name": "Helicobacter pylori HP87tlpD", "rank": "Strain"}, "1354722": {"name": "Roseovarius sp. MCTG156(2b)", "rank": "Species"}, "550743": {"name": "Pseudomonas sp. W15Feb9B", "rank": "Species"}, "420950": {"name": "Methanolobus psychrophilus", "rank": "Species"}, "1238203": {"name": "Vibrio parahaemolyticus 970107", "rank": "Strain"}, "1238202": {"name": "Vibrio parahaemolyticus 50", "rank": "Strain"}, "1318628": {"name": "Marinobacter lipolyticus SM19", "rank": "Strain"}, "1318629": {"name": "Lactobacillus fermentum Lf1", "rank": "Strain"}, "1238207": {"name": "Vibrio parahaemolyticus Peru-288", "rank": "Strain"}, "1238206": {"name": "Vibrio parahaemolyticus B-265", "rank": "Strain"}, "10537": {"name": "Canine mastadenovirus A", "rank": "Species"}, "362418": {"name": "Flavobacterium reichenbachii", "rank": "Species"}, "185636": {"name": "Mythimna loreyi densovirus", "rank": "Strain"}, "329726": {"name": "Acaryochloris marina MBIC11017", "rank": "Strain"}, "584721": {"name": "Pasteurella multocida subsp. multocida str. 3480", "rank": "Strain"}, "1302863": {"name": "Streptococcus oligofermentans AS 1.3089", "rank": "Strain"}, "1354027": {"name": "Lysinibacillus sphaericus KCTC 3346", "rank": "Strain"}, "1388398": {"name": "Staphylococcus aureus M0601", "rank": "Strain"}, "288705": {"name": "Renibacterium salmoninarum ATCC 33209", "rank": "Strain"}, "844": {"name": "Wolinella succinogenes", "rank": "Species"}, "847": {"name": "Oxalobacter formigenes", "rank": "Species"}, "846": {"name": "Oxalobacter", "rank": "Genus"}, "841": {"name": "Roseburia", "rank": "Genus"}, "840": {"name": "Prevotella loescheii", "rank": "Species"}, "843": {"name": "Wolinella", "rank": "Genus"}, "849": {"name": "Fusobacterium gonidiaformans", "rank": "Species"}, "848": {"name": "Fusobacterium", "rank": "Genus"}, "1183400": {"name": "Agrobacterium tumefaciens complex", "rank": "Species group"}, "149698": {"name": "Massilia", "rank": "Genus"}, "1400169": {"name": "Klebsiella pneumoniae BIDMC 53", "rank": "Strain"}, "1438839": {"name": "Mycobacterium tuberculosis UT0014", "rank": "Strain"}, "1400167": {"name": "Klebsiella pneumoniae BIDMC 51", "rank": "Strain"}, "1400166": {"name": "Klebsiella pneumoniae BIDMC 48", "rank": "Strain"}, "1400165": {"name": "Klebsiella pneumoniae BIDMC 47", "rank": "Strain"}, "1400164": {"name": "Klebsiella pneumoniae BIDMC 46b", "rank": "Strain"}, "1400163": {"name": "Klebsiella pneumoniae BIDMC 46a", "rank": "Strain"}, "1400162": {"name": "Klebsiella pneumoniae BIDMC 45", "rank": "Strain"}, "1400161": {"name": "Klebsiella pneumoniae BIDMC 42b", "rank": "Strain"}, "1400160": {"name": "Klebsiella pneumoniae BIDMC 42a", "rank": "Strain"}, "1384549": {"name": "Klebsiella pneumoniae subsp. pneumoniae KKBO-1", "rank": "Strain"}, "202752": {"name": "Listeria ivanovii subsp. londoniensis", "rank": "Subspecies"}, "333146": {"name": "Ferroplasma acidarmanus fer1", "rank": "Strain"}, "197221": {"name": "Thermosynechococcus elongatus BP-1", "rank": "Strain"}, "197222": {"name": "Glaciecola mesophila", "rank": "Species"}, "576790": {"name": "Enterobacteria phage JS10", "rank": "Species"}, "576791": {"name": "Escherichia phage wV8", "rank": "Species"}, "1368616": {"name": "Brazoran virus", "rank": "Species"}, "1350389": {"name": "Sweet potato leaf curl China Henan virus", "rank": "Species"}, "1295782": {"name": "Mycobacterium tuberculosis TKK_02_0066", "rank": "Strain"}, "1295781": {"name": "Mycobacterium tuberculosis TKK_02_0065", "rank": "Strain"}, "909768": {"name": "Acinetobacter calcoaceticus/baumannii complex", "rank": "Species group"}, "154122": {"name": "Mink calicivirus", "rank": "Species"}, "31909": {"name": "Halothermothrix orenii", "rank": "Species"}, "654421": {"name": "Anoxybacillus sp. SK3-4", "rank": "Species"}, "1458859": {"name": "Shewanella sp. phage 1/4", "rank": "Species"}, "1458856": {"name": "Listeria phage LP-101", "rank": "Species"}, "1458857": {"name": "Listeria phage LP-114", "rank": "Species"}, "1458855": {"name": "Listeria phage LP-083-2", "rank": "Species"}, "1458852": {"name": "Listeria phage LP-030-3", "rank": "Species"}, "1458851": {"name": "Enterococcus phage VD13", "rank": "Species"}, "685038": {"name": "Escherichia coli O83:H1 str. NRG 857C", "rank": "Strain"}, "685039": {"name": "Staphylococcus aureus subsp. aureus ED133", "rank": "Strain"}, "685037": {"name": "Escherichia coli O83:H1", "rank": "Strain"}, "685035": {"name": "Citromicrobium bathyomarinum JL354", "rank": "Strain"}, "2307": {"name": "Pyrodictiaceae", "rank": "Family"}, "2301": {"name": "Thermoplasmatales", "rank": "Order"}, "2303": {"name": "Thermoplasma acidophilum", "rank": "Species"}, "2302": {"name": "Thermoplasma", "rank": "Genus"}, "1146872": {"name": "Snake adenovirus A", "rank": "Species"}, "1146873": {"name": "Murine mastadenovirus B", "rank": "Species"}, "1146874": {"name": "Bat mastadenovirus B", "rank": "Species"}, "1146875": {"name": "Turkey aviadenovirus B", "rank": "Species"}, "1146877": {"name": "Bat mastadenovirus A", "rank": "Species"}, "12230": {"name": "Turnip mosaic virus", "rank": "Species"}, "65497": {"name": "Actinoalloteichus cyanogriseus", "rank": "Species"}, "65496": {"name": "Actinoalloteichus", "rank": "Genus"}, "261933": {"name": "Pleomorphomonas", "rank": "Genus"}, "162171": {"name": "Magnetococcus", "rank": "Genus"}, "585544": {"name": "Bacteroides sp. D22", "rank": "Species"}, "585543": {"name": "Bacteroides sp. D20", "rank": "Species"}, "363858": {"name": "Paenibacillus panacisoli", "rank": "Species"}, "1116092": {"name": "Escherichia coli p0305293.4", "rank": "Strain"}, "642259": {"name": "Circovirus-like genome SAR-B", "rank": "Species"}, "248026": {"name": "Cupriavidus pinatubonensis", "rank": "Species"}, "320374": {"name": "Burkholderia pseudomallei S13", "rank": "Strain"}, "191291": {"name": "Nautilia", "rank": "Genus"}, "129910": {"name": "Arthrospira maxima", "rank": "Species"}, "1321369": {"name": "Staphylococcus aureus Bmb9393", "rank": "Strain"}, "1221451": {"name": "Staphylococcus aureus subsp. aureus 120", "rank": "Strain"}, "1221452": {"name": "Staphylococcus aureus subsp. aureus 333", "rank": "Strain"}, "1221453": {"name": "Staphylococcus aureus subsp. aureus 3989", "rank": "Strain"}, "256701": {"name": "Arthrobacter arilaitensis", "rank": "Species"}, "200451": {"name": "Pseudomonas poae", "rank": "Species"}, "1804": {"name": "Mycobacterium gilvum", "rank": "Species"}, "1802": {"name": "Mycobacterium farcinogenes", "rank": "Species"}, "1800": {"name": "Mycobacterium chubuense", "rank": "Species"}, "1809": {"name": "Mycobacterium ulcerans", "rank": "Species"}, "1263870": {"name": "Rhodopirellula sallentina SM41", "rank": "Strain"}, "1263871": {"name": "Klebsiella pneumoniae ATCC BAA-2146", "rank": "Strain"}, "1423425": {"name": "Mycobacterium tuberculosis BTB03-012", "rank": "Strain"}, "1265680": {"name": "Salmonella enterica subsp. enterica serovar Agona str. 15.H.03", "rank": "Strain"}, "1520881": {"name": "OSLEUM clade", "rank": "No rank"}, "85085": {"name": "Arthrobacter chlorophenolicus", "rank": "Species"}, "48409": {"name": "Salmonella enterica subsp. enterica serovar Virchow", "rank": "Strain"}, "48408": {"name": "Photobacterium leiognathi subsp. mandapamensis", "rank": "Subspecies"}, "264635": {"name": "Acholeplasma granularum", "rank": "Species"}, "1403329": {"name": "Listeria monocytogenes Lm25180", "rank": "Strain"}, "264636": {"name": "Acholeplasma hippikon", "rank": "Species"}, "264638": {"name": "Acholeplasma multilocale", "rank": "Species"}, "1403327": {"name": "Listeria monocytogenes Lm26686", "rank": "Strain"}, "290400": {"name": "Jannaschia sp. CCS1", "rank": "Species"}, "290402": {"name": "Clostridium beijerinckii NCIMB 8052", "rank": "Strain"}, "219685": {"name": "Gemmatimonadetes", "rank": "Class"}, "219686": {"name": "Gemmatimonadales", "rank": "Order"}, "219687": {"name": "Gemmatimonadaceae", "rank": "Family"}, "285091": {"name": "Alcanivorax dieselolei", "rank": "Species"}, "110321": {"name": "Sinorhizobium medicae", "rank": "Species"}, "622759": {"name": "Zymomonas mobilis subsp. mobilis NCIMB 11163", "rank": "Strain"}, "279572": {"name": "Agromyces italicus", "rank": "Species"}, "1417165": {"name": "Staphylococcus aureus H56227", "rank": "Strain"}, "1409672": {"name": "Staphylococcus aureus OCMM6102", "rank": "Strain"}, "669462": {"name": "Paenibacillus pinihumi", "rank": "Species"}, "669461": {"name": "Paenibacillus pini", "rank": "Species"}, "745410": {"name": "Gallaecimonas", "rank": "Genus"}, "1158182": {"name": "Thioalkalivibrio sp. ALE31", "rank": "Species"}, "1409737": {"name": "Staphylococcus aureus UCIM6145", "rank": "Strain"}, "637909": {"name": "Streptococcus gallolyticus UCN34", "rank": "Strain"}, "1242690": {"name": "Thermoplasmatales archaeon SCGC AB-539-C06", "rank": "Species"}, "196024": {"name": "Aeromonas dhakensis", "rank": "Species"}, "637905": {"name": "Shewanella violacea DSS12", "rank": "Strain"}, "1423428": {"name": "Mycobacterium tuberculosis BTB05-481", "rank": "Strain"}, "1281119": {"name": "Escherichia coli HVH 192 (4-3054470)", "rank": "Strain"}, "144053": {"name": "Actinomyces neuii subsp. neuii", "rank": "Subspecies"}, "144051": {"name": "Cripavirus", "rank": "Genus"}, "1107882": {"name": "Mesorhizobium alhagi CCNWXJ12-2", "rank": "Strain"}, "1107880": {"name": "Leuconostoc mesenteroides subsp. mesenteroides J18", "rank": "Strain"}, "1107881": {"name": "Sinorhizobium meliloti CCNWSX0020", "rank": "Strain"}, "84757": {"name": "Beutenbergia cavernae", "rank": "Species"}, "84756": {"name": "Beutenbergia", "rank": "Genus"}, "84754": {"name": "Pseudozyma aphidis", "rank": "Species"}, "84753": {"name": "Pseudozyma antarctica", "rank": "Species"}, "1049973": {"name": "Leptospira noguchii str. 1993005606", "rank": "Strain"}, "1049972": {"name": "Leptospira licerasiae serovar Varillal str. VAR 010", "rank": "Strain"}, "1049971": {"name": "Leptospira licerasiae str. MMD4847", "rank": "Strain"}, "262177": {"name": "Orgyia pseudotsugata multiple nucleopolyhedrovirus", "rank": "Species"}, "1049977": {"name": "Leptospira santarosai str. 200702252", "rank": "Strain"}, "1049976": {"name": "Leptospira santarosai serovar Arenal str. MAVJ 401", "rank": "Strain"}, "1049975": {"name": "Leptospira santarosai serovar Arenal", "rank": "Strain"}, "1049974": {"name": "Leptospira noguchii str. 2007001578", "rank": "Strain"}, "1281113": {"name": "Escherichia coli HVH 186 (4-3405044)", "rank": "Strain"}, "1049979": {"name": "Leptospira santarosai str. CBC523", "rank": "Strain"}, "1049978": {"name": "Leptospira santarosai str. CBC379", "rank": "Strain"}, "1281112": {"name": "Escherichia coli HVH 185 (4-2876639)", "rank": "Strain"}, "45151": {"name": "Pyrenophora tritici-repentis", "rank": "Species"}, "1265689": {"name": "Nafulsella", "rank": "Genus"}, "1223567": {"name": "Dickeya zeae CSL RW192", "rank": "Strain"}, "1223564": {"name": "Acinetobacter baumannii ZWS1122", "rank": "Strain"}, "1126926": {"name": "Escherichia coli C80_08", "rank": "Strain"}, "332055": {"name": "Sphingobium indicum", "rank": "Species"}, "408558": {"name": "Comamonas composti", "rank": "Species"}, "587851": {"name": "Pseudomonas chlororaphis subsp. aureofaciens", "rank": "Subspecies"}, "1117644": {"name": "Mycoplasma canis PG 14", "rank": "Strain"}, "58051": {"name": "Moritella sp. PE36", "rank": "Species"}, "162145": {"name": "Human metapneumovirus", "rank": "Species"}, "332056": {"name": "Sphingobium japonicum", "rank": "Species"}, "1182653": {"name": "Escherichia coli KTE46", "rank": "Strain"}, "1505657": {"name": "Intestinibacter", "rank": "Genus"}, "699370": {"name": "Thermus phage TMA", "rank": "Species"}, "1422106": {"name": "Mycobacterium tuberculosis TB_RSA192", "rank": "Strain"}, "1182658": {"name": "Escherichia coli KTE51", "rank": "Strain"}, "1144312": {"name": "Rhizobium sp. CF122", "rank": "Species"}, "629260": {"name": "Pseudomonas syringae pv. lachrymans str. M301315", "rank": "Strain"}, "665024": {"name": "Bipolaris maydis ATCC 48331", "rank": "Strain"}, "629265": {"name": "Pseudomonas syringae pv. maculicola str. ES4326", "rank": "Strain"}, "1223568": {"name": "Dickeya dianthicola NCPPB 453", "rank": "Strain"}, "629267": {"name": "Pseudomonas syringae pv. lachrymans str. M302278", "rank": "Strain"}, "629266": {"name": "Pseudomonas syringae pv. actinidiae str. M302091", "rank": "Strain"}, "1245922": {"name": "Scytonema millei", "rank": "Species"}, "1245923": {"name": "Scytonema millei VB511283", "rank": "Strain"}, "1223569": {"name": "Dickeya chrysanthemi NCPPB 402", "rank": "Strain"}, "665029": {"name": "Erwinia amylovora CFBP1430", "rank": "Strain"}, "665028": {"name": "Yersinia pestis EV76-CN", "rank": "Strain"}, "74545": {"name": "Prochlorococcus marinus str. MIT 9302", "rank": "Strain"}, "74547": {"name": "Prochlorococcus marinus str. MIT 9313", "rank": "Strain"}, "74546": {"name": "Prochlorococcus marinus str. MIT 9312", "rank": "Strain"}, "1188241": {"name": "Ureaplasma diversum NCTC 246", "rank": "Strain"}, "1188240": {"name": "Mycoplasma yeatsii 13926", "rank": "Strain"}, "1188243": {"name": "Mycoplasma capricolum subsp. capripneumoniae 99108", "rank": "Strain"}, "1235799": {"name": "Lachnospiraceae bacterium 3-2", "rank": "Species"}, "684719": {"name": "Alpha proteobacterium HIMB114", "rank": "Species"}, "1188246": {"name": "Mycoplasma mycoides subsp. capri PG3", "rank": "Strain"}, "1235792": {"name": "Lachnospiraceae bacterium M18-1", "rank": "Species"}, "1235793": {"name": "Lachnospiraceae bacterium COE1", "rank": "Species"}, "1235790": {"name": "Eubacterium sp. 14-2", "rank": "Species"}, "1235796": {"name": "Firmicutes bacterium M10-2", "rank": "Species"}, "1235797": {"name": "Oscillibacter sp. 1-3", "rank": "Species"}, "1235794": {"name": "Enterorhabdus caecimuris B7", "rank": "Strain"}, "1235795": {"name": "Paenibacillus barengoltzii G22", "rank": "Strain"}, "995087": {"name": "Acidovorax avenae subsp. avenae RS-1", "rank": "Strain"}, "995085": {"name": "Stenotrophomonas maltophilia group", "rank": "No rank"}, "1339254": {"name": "Chitinibacter sp. ZOR0017", "rank": "Species"}, "1339256": {"name": "Dehalobacter sp. UNSWDHB", "rank": "Species"}, "1339252": {"name": "Firmicutes bacterium ZOR0006", "rank": "Species"}, "1339253": {"name": "Alistipes sp. ZOR0009", "rank": "Species"}, "102611": {"name": "Helicobacter pylori J166", "rank": "Strain"}, "1327950": {"name": "Mycobacterium phage DNAIII", "rank": "Species"}, "1327952": {"name": "Mycobacterium phage Leo", "rank": "Species"}, "1327956": {"name": "Escherichia phage 2 JES-2013", "rank": "Species"}, "1327958": {"name": "Salmonella enterica subsp. enterica serovar Manhattan str. 111113", "rank": "Strain"}, "1327959": {"name": "Mycobacterium phage Adler", "rank": "Species"}, "393661": {"name": "Congregibacter", "rank": "Genus"}, "746360": {"name": "Pseudomonas fluorescens WH6", "rank": "Strain"}, "746361": {"name": "Lactococcus lactis subsp. cremoris NZ9000", "rank": "Strain"}, "1402697": {"name": "Staphylococcus aureus M1189", "rank": "Strain"}, "479058": {"name": "Bandicoot papillomatosis carcinomatosis virus type 1", "rank": "Species"}, "1310594": {"name": "Acinetobacter baumannii 653020", "rank": "Strain"}, "1235863": {"name": "Thermotoga sp. Xyl54", "rank": "Species"}, "1310592": {"name": "Acinetobacter baumannii 1039621", "rank": "Strain"}, "1310593": {"name": "Acinetobacter baumannii 796380-2102", "rank": "Strain"}, "1310590": {"name": "Acinetobacter baumannii 1040094", "rank": "Strain"}, "1310591": {"name": "Acinetobacter baumannii 942194", "rank": "Strain"}, "1122124": {"name": "Idiomarina sediminum DSM 21906", "rank": "Strain"}, "1310598": {"name": "Acinetobacter baumannii 1121032", "rank": "Strain"}, "1071782": {"name": "Chlamydia trachomatis L2b/Ams5", "rank": "Strain"}, "1214191": {"name": "Streptococcus suis YS19", "rank": "Strain"}, "1214190": {"name": "Streptococcus suis YS17", "rank": "Strain"}, "1214193": {"name": "Streptococcus suis YS23", "rank": "Strain"}, "1214192": {"name": "Streptococcus suis YS21", "rank": "Strain"}, "1214195": {"name": "Streptococcus suis YS27", "rank": "Strain"}, "1214194": {"name": "Streptococcus suis YS24", "rank": "Strain"}, "1214197": {"name": "Streptococcus suis YS31", "rank": "Strain"}, "1214196": {"name": "Streptococcus suis YS3", "rank": "Strain"}, "1214199": {"name": "Streptococcus suis YS35", "rank": "Strain"}, "1214198": {"name": "Streptococcus suis YS34", "rank": "Strain"}, "539003": {"name": "Bacillales Family X. Incertae Sedis", "rank": "Family"}, "1402696": {"name": "Staphylococcus aureus M1187", "rank": "Strain"}, "539002": {"name": "Bacillales incertae sedis", "rank": "No rank"}, "314127": {"name": "Drechslerella stenobrocha", "rank": "Species"}, "314126": {"name": "Drechslerella", "rank": "Genus"}, "270374": {"name": "Marinobacter sp. ELB17", "rank": "Species"}, "691955": {"name": "Avihepatovirus", "rank": "Genus"}, "691956": {"name": "Duck hepatitis A virus", "rank": "Species"}, "104664": {"name": "Indian citrus ringspot virus", "rank": "Species"}, "186196": {"name": "Rhodococcus sp. DK17", "rank": "Species"}, "186191": {"name": "Marinithermus", "rank": "Genus"}, "186192": {"name": "Marinithermus hydrothermalis", "rank": "Species"}, "186786": {"name": "Ourmia melon virus", "rank": "Species"}, "1129191": {"name": "Klebsiella phage KP36", "rank": "Species"}, "1129194": {"name": "Xanthomonas phage vB_XveM_DIBBI", "rank": "Species"}, "200630": {"name": "Unclassified Peptostreptococcaceae", "rank": "No rank"}, "1577903": {"name": "Ruegeria sp. ANG-R", "rank": "Species"}, "1054862": {"name": "Streptomyces bottropensis ATCC 25435", "rank": "Strain"}, "1054860": {"name": "Streptomyces purpureus KA281", "rank": "Strain"}, "262957": {"name": "Piper yellow mottle virus", "rank": "Species"}, "1471454": {"name": "Prochlorococcus sp. scB241_528J8", "rank": "Species"}, "10730": {"name": "Enterobacteria phage 933W", "rank": "Strain"}, "10732": {"name": "Streptomyces phage R4", "rank": "Species"}, "1402699": {"name": "Staphylococcus aureus M1191", "rank": "Strain"}, "312295": {"name": "Cotton leafroll dwarf virus", "rank": "Species"}, "485913": {"name": "Ktedonobacter racemifer DSM 44963", "rank": "Strain"}, "1391190": {"name": "Pseudomonas phage MP48", "rank": "Species"}, "485917": {"name": "Pedobacter heparinus DSM 2366", "rank": "Strain"}, "485916": {"name": "Desulfotomaculum acetoxidans DSM 771", "rank": "Strain"}, "485915": {"name": "Desulfohalobium retbaense DSM 5692", "rank": "Strain"}, "485914": {"name": "Halomicrobium mukohataei DSM 12286", "rank": "Strain"}, "485918": {"name": "Chitinophaga pinensis DSM 2588", "rank": "Strain"}, "238015": {"name": "Lactobacillus vini", "rank": "Species"}, "35339": {"name": "LuIII virus", "rank": "Strain"}, "1069073": {"name": "Amycolatopsis halophila", "rank": "Species"}, "1310833": {"name": "Acinetobacter baumannii 796380-1375", "rank": "Strain"}, "889962": {"name": "Candidatus Nanosalinarum sp. J07AB56", "rank": "Species"}, "55884": {"name": "Enterobacteria phage SfV", "rank": "Species"}, "1471459": {"name": "Prochlorococcus sp. scB241_528O2", "rank": "Species"}, "1158721": {"name": "Pseudomonas phage MR299-2", "rank": "Species"}, "101191": {"name": "Methanomethylovorans", "rank": "Genus"}, "1402619": {"name": "Staphylococcus aureus M1427", "rank": "Strain"}, "1402618": {"name": "Staphylococcus aureus M1426", "rank": "Strain"}, "1476973": {"name": "Peptostreptococcaceae bacterium VA2", "rank": "Species"}, "1402613": {"name": "Staphylococcus aureus M1375", "rank": "Strain"}, "1402612": {"name": "Staphylococcus aureus M1104", "rank": "Strain"}, "1402611": {"name": "Staphylococcus aureus M1098", "rank": "Strain"}, "1402610": {"name": "Staphylococcus aureus M1086", "rank": "Strain"}, "1402617": {"name": "Staphylococcus aureus M1399", "rank": "Strain"}, "339420": {"name": "Blackberry chlorotic ringspot virus", "rank": "Species"}, "1402615": {"name": "Staphylococcus aureus M1381", "rank": "Strain"}, "1402614": {"name": "Staphylococcus aureus M1376", "rank": "Strain"}, "1446709": {"name": "Escherichia coli O26:H1", "rank": "Strain"}, "1446708": {"name": "Escherichia coli O25:NM str. E2539C1", "rank": "Strain"}, "1446701": {"name": "Escherichia coli O169:H41", "rank": "Strain"}, "1446700": {"name": "Escherichia coli O165:H25 str. 2010C-4874", "rank": "Strain"}, "1446703": {"name": "Escherichia coli O174:H21 str. 03-3269", "rank": "Strain"}, "1446702": {"name": "Escherichia coli O169:H41 str. F9792", "rank": "Strain"}, "1446705": {"name": "Escherichia coli O177:NM", "rank": "Strain"}, "1446704": {"name": "Escherichia coli O174:H8 str. 04-3038", "rank": "Strain"}, "1446707": {"name": "Escherichia coli O25:NM", "rank": "Strain"}, "1446706": {"name": "Escherichia coli O177:NM str. 2010C-4558", "rank": "Strain"}, "1437595": {"name": "Bifidobacterium pseudolongum subsp. pseudolongum DSM 20099", "rank": "Strain"}, "1422098": {"name": "Mycobacterium tuberculosis TB_RSA182", "rank": "Strain"}, "1422097": {"name": "Mycobacterium tuberculosis TB_RSA181", "rank": "Strain"}, "1422096": {"name": "Mycobacterium tuberculosis TB_RSA180", "rank": "Strain"}, "1422095": {"name": "Mycobacterium tuberculosis TB_RSA179", "rank": "Strain"}, "1422094": {"name": "Mycobacterium tuberculosis TB_RSA178", "rank": "Strain"}, "1422093": {"name": "Mycobacterium tuberculosis TB_RSA177", "rank": "Strain"}, "1422092": {"name": "Mycobacterium tuberculosis TB_RSA176", "rank": "Strain"}, "1422091": {"name": "Mycobacterium tuberculosis TB_RSA175", "rank": "Strain"}, "1422090": {"name": "Mycobacterium tuberculosis TB_RSA174", "rank": "Strain"}, "346377": {"name": "Echinicola pacifica", "rank": "Species"}, "573061": {"name": "Clostridium cellulovorans 743B", "rank": "Strain"}, "700750": {"name": "Candidatus Poribacteria sp. WGA-A3", "rank": "Species"}, "28152": {"name": "Yersinia kristensenii", "rank": "Species"}, "28151": {"name": "Serratia proteamaculans", "rank": "Species"}, "28150": {"name": "Salmonella enterica subsp. enterica serovar Senftenberg", "rank": "Strain"}, "1413325": {"name": "Staphylococcus aureus 81629", "rank": "Strain"}, "1044999": {"name": "Erwinia tracheiphila PSU-1", "rank": "Strain"}, "437897": {"name": "Megamonas funiformis", "rank": "Species"}, "320390": {"name": "Burkholderia mallei GB8 horse 4", "rank": "Strain"}, "1415159": {"name": "Rhodobacter capsulatus YW2", "rank": "Strain"}, "93830": {"name": "Hantavirus Z10", "rank": "Species"}, "93838": {"name": "Influenza A virus (A/goose/Guangdong/1/1996(H5N1))", "rank": "Strain"}, "451516": {"name": "Staphylococcus aureus subsp. aureus USA300_TCH1516", "rank": "Strain"}, "1291743": {"name": "Lactobacillus oryzae JCM 18671", "rank": "Strain"}, "451515": {"name": "Staphylococcus aureus subsp. aureus USA300_FPR3757", "rank": "Strain"}, "451512": {"name": "Mangrovibacter", "rank": "Genus"}, "487514": {"name": "Mycobacterium kyorinense", "rank": "Species"}, "1286632": {"name": "Zhouia amylolytica AD3", "rank": "Strain"}, "94785": {"name": "Endosymbiont of Tevnia jerichonana", "rank": "Species"}, "329254": {"name": "Xanthomonas phage OP1", "rank": "Species"}, "1191478": {"name": "Magnetococcales", "rank": "Order"}, "1269942": {"name": "Salinivibrio costicola subsp. costicola ATCC 33508 = LMG 11651", "rank": "Strain"}, "130310": {"name": "Human mastadenovirus D", "rank": "Species"}, "1269943": {"name": "Vibrio gazogenes ATCC 43941", "rank": "Strain"}, "1191475": {"name": "Pseudomonas aeruginosa PAO579", "rank": "Strain"}, "1422679": {"name": "Staphylococcus aureus VET0468R", "rank": "Strain"}, "754085": {"name": "Escherichia coli STEC_C165-02", "rank": "Strain"}, "1286635": {"name": "Desulfotignum phosphitoxidans DSM 13687", "rank": "Strain"}, "1422673": {"name": "Staphylococcus aureus VET0460R", "rank": "Strain"}, "383911": {"name": "Pseudoalteromonas sp. BSi20311", "rank": "Species"}, "1422671": {"name": "Staphylococcus aureus VET0456R", "rank": "Strain"}, "1422670": {"name": "Staphylococcus aureus VET0455R", "rank": "Strain"}, "1422677": {"name": "Staphylococcus aureus VET0465R", "rank": "Strain"}, "1422676": {"name": "Staphylococcus aureus VET0464R", "rank": "Strain"}, "1422675": {"name": "Staphylococcus aureus VET0463R", "rank": "Strain"}, "1422674": {"name": "Staphylococcus aureus VET0462R", "rank": "Strain"}, "32049": {"name": "Synechococcus sp. PCC 7002", "rank": "Species"}, "32046": {"name": "Synechococcus elongatus", "rank": "Species"}, "32045": {"name": "Unclassified Proteobacteria", "rank": "No rank"}, "32042": {"name": "Pseudomonas stutzeri ATCC 14405 = CCUG 16156", "rank": "Strain"}, "1343557": {"name": "Burkholderia pseudomallei str. NCTC 13392 substr. morphotype_1", "rank": "Strain"}, "273376": {"name": "Sphaerochaeta coccoides", "rank": "Species"}, "1476485": {"name": "Andrographis yellow vein leaf curl betasatellite", "rank": "Species"}, "1476487": {"name": "Axonopus compressus streak virus", "rank": "Species"}, "641491": {"name": "Desulfovibrio desulfuricans ND132", "rank": "Strain"}, "1343558": {"name": "Burkholderia pseudomallei str. NCTC 13392 substr. morphotype_2", "rank": "Strain"}, "1343559": {"name": "Burkholderia pseudomallei str. NCTC 13392 substr. morphotype_3", "rank": "Strain"}, "522": {"name": "Acidiphilium", "rank": "Genus"}, "523": {"name": "Acidiphilium angustum", "rank": "Species"}, "520": {"name": "Bordetella pertussis", "rank": "Species"}, "521": {"name": "Bordetella avium", "rank": "Species"}, "929556": {"name": "Solitalea canadensis DSM 3403", "rank": "Strain"}, "929557": {"name": "Chlamydia psittaci RD1", "rank": "Strain"}, "524": {"name": "Acidiphilium cryptum", "rank": "Species"}, "525": {"name": "Acidocella facilis", "rank": "Species"}, "691160": {"name": "Peptoclostridium difficile 6503", "rank": "Strain"}, "929558": {"name": "Sulfurimonas gotlandica GD1", "rank": "Strain"}, "529": {"name": "Ochrobactrum anthropi", "rank": "Species"}, "691164": {"name": "Geobacter metallireducens RCH3", "rank": "Strain"}, "1089121": {"name": "Mycobacterium phage Dori", "rank": "Species"}, "1089122": {"name": "Mycobacterium phage Gadjet", "rank": "Species"}, "11974": {"name": "Caliciviridae", "rank": "Family"}, "11976": {"name": "Rabbit hemorrhagic disease virus", "rank": "Species"}, "11970": {"name": "Woolly monkey sarcoma virus", "rank": "Species"}, "11084": {"name": "Tick-borne encephalitis virus", "rank": "Species"}, "11978": {"name": "Feline calicivirus", "rank": "Species"}, "979220": {"name": "Staphylococcus epidermidis NIH05005", "rank": "Strain"}, "882879": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. CDC_2010K_1810", "rank": "Strain"}, "882878": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. CDC_2010K_1441", "rank": "Strain"}, "388413": {"name": "Algoriphagus machipongonensis", "rank": "Species"}, "882873": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. CDC_2010K_1884", "rank": "Strain"}, "882872": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. CDC_2010K_1882", "rank": "Strain"}, "882875": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. CDC_2010K_1566", "rank": "Strain"}, "882874": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. CDC_2010K_1594", "rank": "Strain"}, "882877": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. CDC_2010K_1543", "rank": "Strain"}, "882876": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. CDC_2010K_1580", "rank": "Strain"}, "232080": {"name": "Fusarium solani species complex", "rank": "No rank"}, "166056": {"name": "Epinotia aporema granulovirus", "rank": "Species"}, "886360": {"name": "Rudaea", "rank": "Genus"}, "1438742": {"name": "Klebsiella pneumoniae CHS 36", "rank": "Strain"}, "579932": {"name": "Streptomyces sp. FXJ7.023", "rank": "Species"}, "1167690": {"name": "Xanthophyllomyces dendrorhous virus L1A", "rank": "Species"}, "990550": {"name": "Campylobacter phage CP81", "rank": "Species"}, "1423521": {"name": "Mycobacterium tuberculosis BTB10-258", "rank": "Strain"}, "5340": {"name": "Agaricus", "rank": "Genus"}, "794903": {"name": "Opitutaceae bacterium TAV5", "rank": "Species"}, "336260": {"name": "Thermovirga", "rank": "Genus"}, "336261": {"name": "Thermovirga lienii", "rank": "Species"}, "1208236": {"name": "Helicobacter phage KHP30", "rank": "Species"}, "159191": {"name": "Nodularia", "rank": "Genus"}, "1069827": {"name": "Listeria fleischmannii", "rank": "Species"}, "1340822": {"name": "Mycobacterium phage Daenerys", "rank": "Species"}, "1340821": {"name": "Mycobacterium phage Velveteen", "rank": "Species"}, "1340820": {"name": "Mycobacterium phage Jabbawokkie", "rank": "Species"}, "1340827": {"name": "Mycobacterium phage Sarfire", "rank": "Species"}, "1340826": {"name": "Mycobacterium phage Whirlwind", "rank": "Species"}, "1340825": {"name": "Mycobacterium phage Trouble", "rank": "Species"}, "1340824": {"name": "Mycobacterium phage Hamulus", "rank": "Species"}, "1340829": {"name": "Mycobacterium phage Muddy", "rank": "Species"}, "1340828": {"name": "Mycobacterium phage Reprobate", "rank": "Species"}, "523831": {"name": "Salmonella enterica subsp. houtenae str. ATCC BAA-1581", "rank": "Strain"}, "1005505": {"name": "Escherichia coli PA34", "rank": "Strain"}, "1005500": {"name": "Escherichia coli PA25", "rank": "Strain"}, "1005501": {"name": "Escherichia coli PA28", "rank": "Strain"}, "1005508": {"name": "Escherichia coli PA40", "rank": "Strain"}, "795750": {"name": "Ignavibacterium", "rank": "Genus"}, "1345504": {"name": "Helicobacter pylori SA29A", "rank": "Strain"}, "453230": {"name": "Desulfarculus baarsii", "rank": "Species"}, "1412539": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20111514", "rank": "Strain"}, "1412538": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20111515", "rank": "Strain"}, "376725": {"name": "Escherichia coli O103:H2", "rank": "Strain"}, "1412533": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20120775", "rank": "Strain"}, "1412532": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20120776", "rank": "Strain"}, "1412531": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20120963", "rank": "Strain"}, "1412530": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20121004", "rank": "Strain"}, "1412537": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20120528", "rank": "Strain"}, "1412536": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20120544", "rank": "Strain"}, "1412535": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20111576", "rank": "Strain"}, "1412534": {"name": "Salmonella enterica subsp. enterica serovar Enteritidis str. EC20120685", "rank": "Strain"}, "1417163": {"name": "Staphylococcus aureus H53188", "rank": "Strain"}, "35806": {"name": "Rhodovulum sulfidophilum", "rank": "Species"}, "1417161": {"name": "Staphylococcus aureus H49831", "rank": "Strain"}, "1122185": {"name": "Lysobacter concretionis Ko07 = DSM 16239", "rank": "Strain"}, "1122182": {"name": "Longispora albida DSM 44784", "rank": "Strain"}, "1122183": {"name": "Luteimonas mephitis DSM 12574", "rank": "Strain"}, "1122180": {"name": "Loktanella hongkongensis DSM 17492", "rank": "Strain"}, "1122181": {"name": "Loktanella vestfoldensis DSM 16212", "rank": "Strain"}, "1417169": {"name": "Staphylococcus aureus H59329", "rank": "Strain"}, "1417168": {"name": "Staphylococcus aureus H59312_080912", "rank": "Strain"}, "1414586": {"name": "Rhodobacter capsulatus YW1", "rank": "Strain"}, "1414587": {"name": "Paenibacillus polymyxa A18", "rank": "Strain"}, "420336": {"name": "Epulopiscium sp. 'N.t. morphotype B'", "rank": "Species"}, "1497019": {"name": "Leishmania aethiopica RNA virus", "rank": "Species"}, "44454": {"name": "Mycobacterium avium subsp. avium", "rank": "Subspecies"}, "1035117": {"name": "Vibrio vulnificus JY1701", "rank": "Strain"}, "1280978": {"name": "Escherichia coli HVH 27 (4-7449267)", "rank": "Strain"}, "1499681": {"name": "Collinsella sp. MS5", "rank": "Species"}, "1280979": {"name": "Escherichia coli HVH 28 (4-0907367)", "rank": "Strain"}, "585196": {"name": "Lactobacillus brevis subsp. gravesensis", "rank": "Subspecies"}, "1055192": {"name": "Comamonas sp. B-9", "rank": "Species"}, "1416747": {"name": "Vibrio cholerae O1 biovar El Tor str. Ogawa RND19187", "rank": "Strain"}, "471499": {"name": "Dasania marina", "rank": "Species"}, "471498": {"name": "Peach chlorotic mottle virus", "rank": "Species"}, "1416748": {"name": "Vibrio cholerae O1 biovar El Tor str. Inaba RND18899", "rank": "Strain"}, "1416749": {"name": "Vibrio cholerae O1 biovar El Tor str. Inaba RND18826", "rank": "Strain"}, "324769": {"name": "Cryptococcus bestiolae", "rank": "Species"}, "1130266": {"name": "Candidate division EM 3", "rank": "No rank"}, "324767": {"name": "Bacillus infantis", "rank": "Species"}, "749509": {"name": "Enterococcus faecalis EnGen0311", "rank": "Strain"}, "749508": {"name": "Enterococcus faecalis TX0630", "rank": "Strain"}, "1357285": {"name": "Pseudomonas syringae CC457", "rank": "Strain"}, "1357284": {"name": "Pseudomonas syringae CC440", "rank": "Strain"}, "1357283": {"name": "Pseudomonas syringae CC1630", "rank": "Strain"}, "1357282": {"name": "Pseudomonas syringae CC1629", "rank": "Strain"}, "1357281": {"name": "Pseudomonas syringae CC1583", "rank": "Strain"}, "1357280": {"name": "Pseudomonas syringae CC1559", "rank": "Strain"}, "749501": {"name": "Enterococcus faecalis TX0102", "rank": "Strain"}, "431675": {"name": "Idiomarina sediminum", "rank": "Species"}, "749503": {"name": "Enterococcus faecalis TX0309A", "rank": "Strain"}, "749502": {"name": "Enterococcus faecalis TX0109", "rank": "Strain"}, "860343": {"name": "Unclassified Herpesvirales", "rank": "No rank"}, "749504": {"name": "Enterococcus faecalis TX0309B", "rank": "Strain"}, "749507": {"name": "Enterococcus faecalis TX0470", "rank": "Strain"}, "1357288": {"name": "Pseudomonas syringae USA007", "rank": "Strain"}, "1280975": {"name": "Escherichia coli HVH 24 (4-5985145)", "rank": "Strain"}, "467661": {"name": "Rhodobacteraceae bacterium KLH11", "rank": "Species"}, "6": {"name": "Azorhizobium", "rank": "Genus"}, "1287274": {"name": "Mesorhizobium sp. LNJC394B00", "rank": "Species"}, "1287275": {"name": "Mesorhizobium sp. LNJC395A00", "rank": "Species"}, "85642": {"name": "Vaccinium witches'-broom phytoplasma", "rank": "Species"}, "202956": {"name": "Acinetobacter towneri", "rank": "Species"}, "274539": {"name": "Chlorobaculum parvum", "rank": "Species"}, "1287277": {"name": "Mesorhizobium sp. LNJC399B00", "rank": "Species"}, "1185688": {"name": "Xanthomonas axonopodis pv. manihotis str. IBSBF 2820", "rank": "Strain"}, "1185689": {"name": "Xanthomonas axonopodis pv. manihotis str. IBSBF 2821", "rank": "Strain"}, "1185686": {"name": "Xanthomonas axonopodis pv. manihotis str. IBSBF 2818", "rank": "Strain"}, "526347": {"name": "Ureaplasma urealyticum serovar 11 str. ATCC 33695", "rank": "Strain"}, "1185685": {"name": "Xanthomonas axonopodis pv. manihotis str. IBSBF 2816", "rank": "Strain"}, "1185682": {"name": "Xanthomonas axonopodis pv. manihotis str. IBSBF 2673", "rank": "Strain"}, "1185683": {"name": "Xanthomonas axonopodis pv. manihotis str. IBSBF 278", "rank": "Strain"}, "1185680": {"name": "Xanthomonas axonopodis pv. manihotis str. IBSBF 2670", "rank": "Strain"}, "1185681": {"name": "Xanthomonas axonopodis pv. manihotis str. IBSBF 2672", "rank": "Strain"}, "1335916": {"name": "Escherichia coli LY180", "rank": "Strain"}, "1414671": {"name": "Solenopsis invicta densovirus", "rank": "Species"}, "451804": {"name": "Aspergillus fumigatus A1163", "rank": "Strain"}, "391036": {"name": "Ehrlichia sp. HF", "rank": "Species"}, "391037": {"name": "Salinispora arenicola CNS-205", "rank": "Strain"}, "164546": {"name": "Cupriavidus taiwanensis", "rank": "Species"}, "1499682": {"name": "Alistipes sp. AL-1", "rank": "Species"}, "1236703": {"name": "Candidatus Photodesmus katoptron Akat1", "rank": "Strain"}, "1208365": {"name": "SAR86 cluster bacterium SAR86E", "rank": "Species"}, "1182654": {"name": "Escherichia coli KTE47", "rank": "Strain"}, "1182655": {"name": "Escherichia coli KTE48", "rank": "Strain"}, "1182656": {"name": "Escherichia coli KTE49", "rank": "Strain"}, "1182657": {"name": "Escherichia coli KTE50", "rank": "Strain"}, "1223562": {"name": "Golden Gate virus", "rank": "Species"}, "1144319": {"name": "Herbaspirillum sp. CF444", "rank": "Species"}, "1144318": {"name": "Polaromonas sp. CF318", "rank": "Species"}, "1144317": {"name": "Acidovorax sp. CF316", "rank": "Species"}, "1144316": {"name": "Chryseobacterium sp. CF314", "rank": "Species"}, "1144315": {"name": "Variovorax sp. CF313", "rank": "Species"}, "1144314": {"name": "Rhizobium sp. CF142", "rank": "Species"}, "1144313": {"name": "Flavobacterium sp. CF136", "rank": "Species"}, "159345": {"name": "Roseibacterium", "rank": "Genus"}, "159346": {"name": "Roseibacterium elongatum", "rank": "Species"}, "1144310": {"name": "Rhizobium sp. CF080", "rank": "Species"}, "84111": {"name": "Eggerthella", "rank": "Genus"}, "84110": {"name": "Slackia heliotrinireducens", "rank": "Species"}, "84113": {"name": "Unclassified Coriobacteriaceae", "rank": "No rank"}, "84112": {"name": "Eggerthella lenta", "rank": "Species"}, "511969": {"name": "Enterobacteria phage ID2 Moscow/ID/2001", "rank": "Species"}, "1355371": {"name": "Arcobacter sp. AF1078", "rank": "Species"}, "1355373": {"name": "Arcobacter sp. AF1430", "rank": "Species"}, "1439191": {"name": "Streptococcus pyogenes ABC020049545", "rank": "Strain"}, "1355374": {"name": "Arcobacter sp. AF1440", "rank": "Species"}, "1355376": {"name": "Arcobacter sp. AF1581", "rank": "Species"}, "1382279": {"name": "University of Helsinki virus", "rank": "Species"}, "1074133": {"name": "Streptococcus sobrinus TCI-160", "rank": "Strain"}, "35338": {"name": "Aedes albopictus densovirus", "rank": "Strain"}, "1074130": {"name": "Streptococcus mutans TCI-154", "rank": "Strain"}, "1074137": {"name": "Streptococcus mutans TCI-169", "rank": "Strain"}, "1074136": {"name": "Streptococcus mutans TCI-164", "rank": "Strain"}, "1074135": {"name": "Streptococcus mutans TCI-163", "rank": "Strain"}, "1074134": {"name": "Streptococcus mutans TCI-162", "rank": "Strain"}, "1074139": {"name": "Streptococcus sobrinus TCI-172", "rank": "Strain"}, "1074138": {"name": "Streptococcus mutans TCI-170", "rank": "Strain"}, "527032": {"name": "Bacillus thuringiensis serovar andalousiensis BGSC 4AW1", "rank": "Strain"}, "527031": {"name": "Bacillus thuringiensis serovar berliner ATCC 10792", "rank": "Strain"}, "1413323": {"name": "Staphylococcus aureus M118-B", "rank": "Strain"}, "81093": {"name": "Magnaporthaceae", "rank": "Family"}, "1413324": {"name": "Staphylococcus aureus 81070", "rank": "Strain"}, "1413327": {"name": "Staphylococcus aureus 7-B-1", "rank": "Strain"}, "1413329": {"name": "Staphylococcus aureus 2010-60-7626-19", "rank": "Strain"}, "1413328": {"name": "Staphylococcus aureus 2010-60-6063-29", "rank": "Strain"}, "1134786": {"name": "Enterococcus faecalis ERV116", "rank": "Strain"}, "249583": {"name": "Irkut virus", "rank": "Species"}, "149715": {"name": "Marinitoga piezophila", "rank": "Species"}, "149710": {"name": "Salinivibrio costicola subsp. costicola", "rank": "Subspecies"}, "249585": {"name": "Whispovirus", "rank": "Genus"}, "249588": {"name": "Mamastrovirus", "rank": "Genus"}, "249589": {"name": "Avastrovirus", "rank": "Genus"}, "585198": {"name": "Mobiluncus curtisii subsp. curtisii ATCC 35241", "rank": "Strain"}, "585199": {"name": "Mobiluncus mulieris ATCC 35243", "rank": "Strain"}, "1448639": {"name": "Mycobacterium tuberculosis M1233", "rank": "Strain"}, "1448638": {"name": "Mycobacterium tuberculosis M1232", "rank": "Strain"}, "1448637": {"name": "Mycobacterium tuberculosis M1221", "rank": "Strain"}, "1448636": {"name": "Mycobacterium tuberculosis M1215", "rank": "Strain"}, "1448635": {"name": "Mycobacterium tuberculosis M1213", "rank": "Strain"}, "1448634": {"name": "Mycobacterium tuberculosis M1212", "rank": "Strain"}, "1448633": {"name": "Mycobacterium tuberculosis M1210", "rank": "Strain"}, "1448632": {"name": "Mycobacterium tuberculosis M1034", "rank": "Strain"}, "1448631": {"name": "Mycobacterium tuberculosis M1030", "rank": "Strain"}, "1448630": {"name": "Mycobacterium tuberculosis M1029", "rank": "Strain"}, "1499086": {"name": "Cronobacter sp. 1383", "rank": "Species"}, "119": {"name": "Planctomyces brasiliensis", "rank": "Species"}, "118": {"name": "Planctomyces", "rank": "Genus"}, "113": {"name": "Gemmata", "rank": "Genus"}, "112": {"name": "Planctomycetales", "rank": "Order"}, "411459": {"name": "Ruminococcus obeum ATCC 29174", "rank": "Strain"}, "453850": {"name": "Joostella", "rank": "Genus"}, "211110": {"name": "Streptococcus agalactiae NEM316", "rank": "Strain"}, "51363": {"name": "Mycoplasma auris", "rank": "Species"}, "51365": {"name": "Mycoplasma yeatsii", "rank": "Species"}, "51366": {"name": "Salinivibrio", "rank": "Genus"}, "51367": {"name": "Salinivibrio costicola", "rank": "Species"}, "51368": {"name": "Unclassified dsDNA viruses", "rank": "No rank"}, "51369": {"name": "Lactobacillus phage A2", "rank": "Species"}, "1244856": {"name": "Edwardsiella phage KF-1", "rank": "Species"}, "629": {"name": "Yersinia", "rank": "Genus"}, "628": {"name": "Xenorhabdus nematophila", "rank": "Species"}, "909455": {"name": "Fusarium oxysporum FOSC 3-a", "rank": "Strain"}, "624": {"name": "Shigella sonnei", "rank": "Species"}, "626": {"name": "Xenorhabdus", "rank": "Genus"}, "621": {"name": "Shigella boydii", "rank": "Species"}, "620": {"name": "Shigella", "rank": "Genus"}, "623": {"name": "Shigella flexneri", "rank": "Species"}, "622": {"name": "Shigella dysenteriae", "rank": "Species"}}
    # with open('data/taxonomy_metadata.json','r') as infile:
    #     data = json.load(infile)
    for tax_id,species_dict in data.iteritems():
        tax_id_to_species[tax_id] = species_dict['name']
    return tax_id_to_species